(*^

::[paletteColors = 128; 
	fontset = text, "Times", 14, L2, nohscroll;
	fontset = smalltext, "Times", 12, L2, nohscroll;
	fontset = special1, "Times", 24, L2, center, italic, nowordwrap;
	fontset = special2, "Times", 20, L2, center, italic, nowordwrap;
	fontset = special3, "Times", 16, L2, italic, nowordwrap;
	fontset = special4, "New York", 16, L2, nowordwrap;
	fontset = special5, "New York", 20, L2, nowordwrap;]
:[font = title; inactive; ]
Signal Processing Packages:
:[font = title; inactive; ]
Implementing Linear Systems Theory in
:[font = special1; inactive; ]
MATHEMATICA
:[font = special4; inactive; center; ]

by
:[font = subtitle; inactive; ]

Brian L. Evans and James H. McClellan
:[font = special4; inactive; center; ]

Digital Signal Processing Laboratory
School of Electrical Engineering
Georgia Institute of Technology
Atlanta, GA  30332-0250

:[font = special5; inactive; center; ]
EMAIL:  evans@eedsp.gatech.edu

:[font = text; inactive; ]
		What you are reading is a Mathematica notebook.  It is a collection of cells containing text, graphics, animation, equations, tables, and "live" Mathematica code arranged a tree structure.  You can read about subjects in a notebook like you would in a book.  The advantage over a book is that you can interact with the "text" by tinkering with the mathematics underlying the subject.  And because the information is presented in a hierarchy, you can select more information on a topic either by searching for more information on a subject via the Find menu option or by opening up a closed section of cells.  A closed section is displayed with a downward pointing half arrow, such as the one shown below:
:[font = special2; inactive; startGroup; Cclosed; ]
Example of a section with more information in it
(Open by clicking twice on the half arrow)
:[font = text; inactive; ]
Here is more information
:[font = text; inactive; center; ]
and more information.
:[font = text; inactive; endGroup; right; ]
and more information.
:[font = text; inactive; ]
		Fonts are indicative of what the cell is.  For example, this cell is normal-sized text.  The next cell is "live" Mathematica code, and the cell after that contains the output of the "live" code:
:[font = input; startGroup; ]
2 + 2
:[font = output; inactive; output; endGroup; ]
4
;[o]
4
:[font = text; inactive; ]
You can have the Mathematica kernel evaluate code by selecting the cell with the code in it and then hitting either SHIFT-RETURN or ENTER.  The RETURN key by itself is only useful for formatting text.
:[font = text; inactive; ]
		A Notebook is completely defined by a portable ASCII file but  machine-dependent binary information (bitmaps, etc.) is generated as side information to speed up the display of parts of the Notebook.   Mathematica 1.2 generates missing side information as needed whereas Mathematica 2.0 and higher generates all missing side information when a Notebook is opened.    Mathematica 2.0 and higher will display the message "Rendering ..." in the header of the Notebook when it is generating bitmaps for PostScript graphics contained in the Notebook.  This particular Notebook contains 40 or so graphics cells whose bitmaps will require an 800 kb of memory (40 cells x 20 kb/cell) to store.  The ASCII version of this Notebook occupies 220 kb.
:[font = text; inactive; ]
		Note that we have written this notebook so that each closed groups of cells will expand to fill one screen lengthwise.  So, please expand this notebook window so that it fills the screen lengthwise.
:[font = text; inactive; ]
		As a reminder, in order to open a section below, just move the mouse to the downward-pointing arrow and double click. To get help information for any command, place the cursor in an input cell and type ?Command (like ?ZTransform).
:[font = special1; inactive; ]

Table of Contents

:[font = section; inactive; startGroup; Cclosed; ]
Introduction
:[font = text; inactive; ]
		This notebook provides an overview of packages that implement aspects of linear systems theory.  The packages can take transforms, perform convolution, etc.  Several notebooks accompany the packages.  Three teach the z-transform, the mechanics of convolution, and analog filter design.  The other signal processing notebooks serve as user guides and reference manuals. 
:[font = text; inactive; ]
		Because you are reading this notebook, you probably already have access to the other notebooks and the signal processing packages.  If not, you can order them from Wolfram Research Inc. (for the cost of the distribution medium, shipping, and handling) or you can download them from InterNet at no cost via anonymous ftp (which is the topic of the first subsection below).
:[font = subsection; inactive; startGroup; Cclosed; ]
Obtaining the Signal Processing Packages
:[font = text; inactive; ]
		To download the extensions, perform the following commands (begin at Unix prompt):
:[font = text; inactive; ]
		unix>  ftp gauss.eedsp.gatech.edu
:[font = special3; inactive; ]
		Connected to gauss.eedsp.gatech.edu
		220 gauss.eedsp.gatech.edu FTP server ...
:[font = text; inactive; ]
		Name:  anonymous
:[font = special3; inactive; ]
		331 Guest login ok, send ident as password
:[font = text; inactive; ]
		Password:  <your email address goes here>
:[font = text; inactive; ]
		ftp> cd Mathematica
:[font = special3; inactive; ]
		250 CWD command successful
:[font = text; inactive; ]
		ftp> binary
:[font = special3; inactive; ]
		200 Type set to I
:[font = text; inactive; ]
		ftp> get SigProc2.0.tar.Z
:[font = text; inactive; ]
		ftp> quit
:[font = text; inactive; ]
		unix> uncompress SigProc2.0.tar.Z
:[font = text; inactive; ]
		unix> tar xf SigProc2.0.tar
:[font = text; inactive; endGroup; ]
(The "get" command should take 2 minutes or so.)  These commands should produce a README and four sub-directories:  Macintosh, Notebooks, Packages, and doc.  Packages and Notebooks contain the signal processing packages and notebooks, respectively, which are discussed in detail in this notebook.  A reference manual and a user's guide to the packages reside in the doc sub-directory as two LaTeX files.  The notebooks document the extensions more thoroughly than do the LaTeX files.
:[font = subsection; inactive; startGroup; Cclosed; ]
Loading the Signal Processing Packages
:[font = text; inactive; ]
		Once you have acquired the signal processing packages, you can load all or part of them as desired.   To load all of the packages, simply execute the following command:
:[font = input; center; ]
Needs[ "SignalProcessing`SignalProcessing`" ]
:[font = text; inactive; ]
To load in only the digital signal processing packages, execute
:[font = input; center; ]
Needs[ "SignalProcessing`Digital`" ]
:[font = text; inactive; ]
To load in only the digital signal processing packages, execute
:[font = input; center; ]
Needs[ "SignalProcessing`Analog`" ]
:[font = text; inactive; endGroup; ]
The loading process for all of the packages may take up to five minutes.  You the reader do not have to execute any of the above commands to make sense out of this document, but the drawback is that you will not be able to evaluate any of the Mathematica expressions in the two signal processing sections.
:[font = subsection; inactive; startGroup; Cclosed; ]
Getting a Print Out of this Notebook
:[font = text; inactive; ]
		You can also obtain a print out of this document by:
:[font = text; inactive; ]
1.  select all cells in the notebook by clicking on the first cell and dragging
      the mouse down so as to select all of the cells in the notebook
2.  use the "Open All Subgroups" option under the Cell menu (or
      hit COMMAND-{ as keyboard shortcut)
3.  use the Print... option (or hit COMMAND-p).
:[font = text; inactive; endGroup; endGroup; ]
The result will be a 54-page document.  In the Print menu, you have the option of previewing the document instead of printing it.
:[font = section; inactive; startGroup; Cclosed; ]
Introduction to Mathematica
:[font = text; inactive; ]
		Mathematica is really two distinct programs:  the kernel and the user interface.  The kernel is available for a dozen computer systems.  All extensions to the kernel written in the Mathematica programming language are 100% portable across machines.  The user interface varies from machine to machine.  On the NeXT, Macintosh, and 386 machines (under MicroSoft Windows), this notebook interface is available.  A notebook is an ASCII file which is compatible on all three machines.  You are reading such a notebook.
:[font = subsection; inactive; startGroup; Cclosed; ]
Capabilities of the Kernel
:[font = text; inactive; ]
		All of the built-in Mathematica functions and variables begin with a capital letter.  Therefore, in order to avoid conflict with the built-in objects, users can begin their own functions and variables with lower case letters.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Numeric Computations
:[font = text; inactive; ]
		Mathematica is a powerful symbolic calculator, but it can 
		crunch numbers
:[font = input; startGroup; ]
2 + 2
:[font = output; inactive; output; endGroup; ]
4
;[o]
4
:[font = text; inactive; ]
		to exact precision or to arbitrary precision.   For example, the
		exact value of 40 factorial
:[font = input; startGroup; ]
40!
:[font = output; inactive; output; endGroup; ]
815915283247897734345611269596115894272000000000
;[o]
815915283247897734345611269596115894272000000000
:[font = text; inactive; ]
		can be approximated as a double precision floating point 		number
:[font = input; startGroup; ]
N[40!]
:[font = output; inactive; output; endGroup; ]
8.15915283247898*10^47
;[o]
          47
8.15915 10
:[font = text; inactive; ]
		or as a floating point number to 23 digits:
:[font = input; startGroup; ]
N[40!, 23]
:[font = output; inactive; output; endGroup; ]
8.1591528324789773434561*10^47
;[o]
                           47
8.1591528324789773434561 10
:[font = text; inactive; ]
		Mathematica understands common short-hand notation for
		common mathematical operations.  For example, a space
		indicates multiplication:
:[font = input; startGroup; ]
3 4 5
:[font = output; inactive; output; endGroup; ]
60
;[o]
60
:[font = text; inactive; ]
		Mathematica can handle higher mathematical functions
		as well:
:[font = input; startGroup; ]
N[ BesselI[1, 2 + 3 I] ]
:[font = output; inactive; output; endGroup; endGroup; ]
-1.260982060238848 + 0.7801488485792538*I
;[o]
-1.26098 + 0.780149 I
:[font = subsubsection; inactive; startGroup; Cclosed; pageBreak; ]
Algebraic  Manipulation
:[font = text; inactive; ]
		Mathematica can factor polynomials
:[font = input; startGroup; ]
Factor[ 6 + 11 x + 6 x^2 + x^3 ]
:[font = output; inactive; output; endGroup; ]
(1 + x)*(2 + x)*(3 + x)
;[o]
(1 + x) (2 + x) (3 + x)
:[font = text; inactive; ]
		or generate new ones
:[font = input; startGroup; ]
ChebyshevT[5, x]
:[font = output; inactive; output; endGroup; ]
5*x - 20*x^3 + 16*x^5
;[o]
          3       5
5 x - 20 x  + 16 x
:[font = text; inactive; ]
		or decompose a ratio of polynomials into partial fractions.
:[font = input; startGroup; ]
Apart[ ( s^3 + 27 s^2 + 242 s + 720 ) /
		(s^4 + 10 s^3 + 35 s^2 + 50 s + 24 ), s ]
:[font = output; inactive; output; endGroup; ]
84/(1 + s) - 168/(2 + s) + 105/(3 + s) - 20/(4 + s)
;[o]
 84      168     105     20
----- - ----- + ----- - -----
1 + s   2 + s   3 + s   4 + s
:[font = text; inactive; ]
		Mathematica can solve simultaneous equations,
		even non-linear ones.
:[font = input; startGroup; ]
N[ Solve[ { a b^2 + Pi == 0, a + b == 2 },
		   {a, b} ], 4 ]
:[font = output; inactive; output; endGroup; ]
{{a -> -0.5019, b -> 2.502}, 
  {a -> 2.251 - 1.092*I, b -> -0.2509 + 1.092*I}, 
  {a -> 2.251 + 1.092*I, b -> -0.2509 - 1.092*I}}
;[o]
{{a -> -0.5019, b -> 2.502}, 
 
  {a -> 2.251 - 1.092 I, b -> -0.2509 + 1.092 I}, 
 
  {a -> 2.251 + 1.092 I, b -> -0.2509 - 1.092 I}}
:[font = text; inactive; endGroup; ]
		Here, we get three solutions to two equations.  Generating
		three solutions makes sense because we have equations
		in a, b, and b^2.
:[font = subsubsection; inactive; startGroup; Cclosed; pageBreak; ]
Integral and Differential Calculus
:[font = text; inactive; ]
		Mathematica can perform symbolic differentiation
:[font = input; startGroup; ]
D[ x^2 + x Log[x], x ]
:[font = output; inactive; output; endGroup; ]
1 + 2*x + Log[x]
;[o]
1 + 2 x + Log[x]
:[font = text; inactive; ]
		and indefinite integration
:[font = input; startGroup; ]
Integrate[ 1 + 2 x + Log[x], x ]
:[font = output; inactive; output; endGroup; ]
x^2 + x*Log[x]
;[o]
 2
x  + x Log[x]
:[font = text; inactive; ]
		and numerical integration (even in two dimensions).
:[font = input; startGroup; ]
NIntegrate[x^2 + y^2, {x, -1, 1}, {y, -1, 1}]
:[font = output; inactive; output; endGroup; ]
2.666666666666668
;[o]
2.66667
:[font = text; inactive; ]
		Mathematica can compute contour integrations.  For
		example,  the next cell integrates 1/z around the closed
		contour in the complex plane, going from -1, through the
		points -i, 1, and i, then back to -i, which yields  2 Pi  i  *
		residue where the residue is 1:
:[font = input; startGroup; ]
NIntegrate[1/z, {z, -1, -I, 1, I, -1}]
:[font = output; inactive; output; endGroup; endGroup; ]
6.28318530717959*I
;[o]
6.28319 I
:[font = subsubsection; inactive; startGroup; Cclosed; pageBreak; ]
Graphics and Plotting
:[font = text; inactive; ]
		Mathematica handles all of the details of plotting badly
		behaved functions
:[font = input; startGroup; ]
Plot[ Tan[x], {x, 0, 6 Pi} ]
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.05053 0.304 0.01364 [
[(2.5)] 0.15012 0.2915 0 1 Msboxa
[(5)] 0.27644 0.2915 0 1 Msboxa
[(7.5)] 0.40275 0.2915 0 1 Msboxa
[(10)] 0.52906 0.2915 0 1 Msboxa
[(12.5)] 0.65538 0.2915 0 1 Msboxa
[(15)] 0.78169 0.2915 0 1 Msboxa
[(17.5)] 0.908 0.2915 0 1 Msboxa
[(-20)] 0.01131 0.03126 1 0 Msboxa
[(-10)] 0.01131 0.16763 1 0 Msboxa
[(10)] 0.01131 0.44037 1 0 Msboxa
[(20)] 0.01131 0.57674 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.304 moveto
1 0.304 lineto
stroke
0.15012 0.29775 moveto
0.15012 0.31025 lineto
stroke
0 setgray
[(2.5)] 0.15012 0.2915 0 1 Mshowa
0.27644 0.29775 moveto
0.27644 0.31025 lineto
stroke
0 setgray
[(5)] 0.27644 0.2915 0 1 Mshowa
0.40275 0.29775 moveto
0.40275 0.31025 lineto
stroke
0 setgray
[(7.5)] 0.40275 0.2915 0 1 Mshowa
0.52906 0.29775 moveto
0.52906 0.31025 lineto
stroke
0 setgray
[(10)] 0.52906 0.2915 0 1 Mshowa
0.65538 0.29775 moveto
0.65538 0.31025 lineto
stroke
0 setgray
[(12.5)] 0.65538 0.2915 0 1 Mshowa
0.78169 0.29775 moveto
0.78169 0.31025 lineto
stroke
0 setgray
[(15)] 0.78169 0.2915 0 1 Mshowa
0.908 0.29775 moveto
0.908 0.31025 lineto
stroke
0 setgray
[(17.5)] 0.908 0.2915 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.03126 moveto
0.03006 0.03126 lineto
stroke
0 setgray
[(-20)] 0.01131 0.03126 1 0 Mshowa
0.01756 0.16763 moveto
0.03006 0.16763 lineto
stroke
0 setgray
[(-10)] 0.01131 0.16763 1 0 Mshowa
0.01756 0.44037 moveto
0.03006 0.44037 lineto
stroke
0 setgray
[(10)] 0.01131 0.44037 1 0 Mshowa
0.01756 0.57674 moveto
0.03006 0.57674 lineto
stroke
0 setgray
[(20)] 0.01131 0.57674 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.304 moveto
0.04365 0.30965 lineto
0.05357 0.31311 lineto
0.05853 0.31519 lineto
0.06349 0.31764 lineto
0.06845 0.32062 lineto
0.07341 0.32441 lineto
0.07837 0.32951 lineto
0.08085 0.33283 lineto
0.08333 0.33692 lineto
0.08581 0.34211 lineto
0.08829 0.34896 lineto
0.09077 0.35844 lineto
0.09201 0.36473 lineto
0.09325 0.37256 lineto
0.09449 0.38259 lineto
0.09573 0.39593 lineto
0.09697 0.41457 lineto
0.09821 0.44246 lineto
0.09945 0.48887 lineto
0.10069 0.58159 lineto
0.10193 0.85951 lineto
0.10317 2.227182e+14 lineto
0.10441 -0.25151 lineto
0.10565 0.02641 lineto
0.10689 0.11913 lineto
0.10813 0.16554 lineto
0.10938 0.19343 lineto
0.11062 0.21207 lineto
0.11186 0.22541 lineto
0.1131 0.23544 lineto
0.11434 0.24327 lineto
0.11558 0.24956 lineto
0.11806 0.25904 lineto
0.12054 0.26589 lineto
0.12302 0.27108 lineto
0.1255 0.27517 lineto
0.12798 0.27849 lineto
0.13294 0.28359 lineto
0.1379 0.28738 lineto
0.14286 0.29036 lineto
0.15278 0.29489 lineto
0.1627 0.29835 lineto
0.18254 0.304 lineto
0.20238 0.30965 lineto
0.2123 0.31311 lineto
0.21726 0.31519 lineto
0.22222 0.31764 lineto
0.22718 0.32062 lineto
0.23214 0.32441 lineto
Mistroke
0.23462 0.32675 lineto
0.2371 0.32951 lineto
0.23958 0.33283 lineto
0.24206 0.33692 lineto
0.24454 0.34211 lineto
0.24702 0.34896 lineto
0.2495 0.35844 lineto
0.25074 0.36473 lineto
0.25198 0.37256 lineto
0.25322 0.38259 lineto
0.25446 0.39593 lineto
0.2557 0.41457 lineto
0.25694 0.44246 lineto
0.25818 0.48887 lineto
0.25942 0.58159 lineto
0.26066 0.85951 lineto
0.2619 7.42394e+13 lineto
0.26314 -0.25151 lineto
0.26438 0.02641 lineto
0.26563 0.11913 lineto
0.26687 0.16554 lineto
0.26811 0.19343 lineto
0.26935 0.21207 lineto
0.27059 0.22541 lineto
0.27183 0.23544 lineto
0.27307 0.24327 lineto
0.27431 0.24956 lineto
0.27679 0.25904 lineto
0.27927 0.26589 lineto
0.28175 0.27108 lineto
0.28423 0.27517 lineto
0.28671 0.27849 lineto
0.29167 0.28359 lineto
0.29663 0.28738 lineto
0.30159 0.29036 lineto
0.31151 0.29489 lineto
0.32143 0.29835 lineto
0.34127 0.304 lineto
0.36111 0.30965 lineto
0.37103 0.31311 lineto
0.37599 0.31519 lineto
0.38095 0.31764 lineto
0.38591 0.32062 lineto
0.39087 0.32441 lineto
0.39335 0.32675 lineto
0.39583 0.32951 lineto
0.39831 0.33283 lineto
0.40079 0.33692 lineto
0.40327 0.34211 lineto
0.40575 0.34896 lineto
Mistroke
0.40823 0.35844 lineto
0.40947 0.36473 lineto
0.41071 0.37256 lineto
0.41195 0.38259 lineto
0.41319 0.39593 lineto
0.41443 0.41457 lineto
0.41567 0.44246 lineto
0.41691 0.48887 lineto
0.41815 0.58159 lineto
0.41939 0.85951 lineto
0.42063 4.454364e+13 lineto
0.42188 -0.25151 lineto
0.42312 0.02641 lineto
0.42436 0.11913 lineto
0.4256 0.16554 lineto
0.42684 0.19343 lineto
0.42808 0.21207 lineto
0.42932 0.22541 lineto
0.43056 0.23544 lineto
0.4318 0.24327 lineto
0.43304 0.24956 lineto
0.43552 0.25904 lineto
0.438 0.26589 lineto
0.44048 0.27108 lineto
0.44296 0.27517 lineto
0.44544 0.27849 lineto
0.4504 0.28359 lineto
0.45536 0.28738 lineto
0.46032 0.29036 lineto
0.47024 0.29489 lineto
0.48016 0.29835 lineto
0.5 0.304 lineto
0.51984 0.30965 lineto
0.52976 0.31311 lineto
0.53472 0.31519 lineto
0.53968 0.31764 lineto
0.54464 0.32062 lineto
0.5496 0.32441 lineto
0.55208 0.32675 lineto
0.55456 0.32951 lineto
0.55704 0.33283 lineto
0.55952 0.33692 lineto
0.562 0.34211 lineto
0.56448 0.34896 lineto
0.56572 0.35328 lineto
0.56696 0.35844 lineto
0.5682 0.36473 lineto
0.56944 0.37256 lineto
0.57068 0.38259 lineto
0.57192 0.39593 lineto
Mistroke
0.57316 0.41457 lineto
0.5744 0.44246 lineto
0.57564 0.48887 lineto
0.57688 0.58159 lineto
0.57813 0.85951 lineto
0.57937 3.181689e+13 lineto
0.58061 -0.25151 lineto
0.58185 0.02641 lineto
0.58309 0.11913 lineto
0.58433 0.16554 lineto
0.58557 0.19343 lineto
0.58681 0.21207 lineto
0.58805 0.22541 lineto
0.58929 0.23544 lineto
0.59053 0.24327 lineto
0.59177 0.24956 lineto
0.59425 0.25904 lineto
0.59673 0.26589 lineto
0.59921 0.27108 lineto
0.60169 0.27517 lineto
0.60417 0.27849 lineto
0.60913 0.28359 lineto
0.61409 0.28738 lineto
0.61905 0.29036 lineto
0.62897 0.29489 lineto
0.63889 0.29835 lineto
0.65873 0.304 lineto
0.67857 0.30965 lineto
0.68849 0.31311 lineto
0.69345 0.31519 lineto
0.69841 0.31764 lineto
0.70337 0.32062 lineto
0.70833 0.32441 lineto
0.71081 0.32675 lineto
0.71329 0.32951 lineto
0.71577 0.33283 lineto
0.71825 0.33692 lineto
0.72073 0.34211 lineto
0.72321 0.34896 lineto
0.72445 0.35328 lineto
0.72569 0.35844 lineto
0.72693 0.36473 lineto
0.72817 0.37256 lineto
0.72941 0.38259 lineto
0.73065 0.39593 lineto
0.73189 0.41457 lineto
0.73313 0.44246 lineto
0.73438 0.48887 lineto
0.73562 0.58159 lineto
0.73686 0.85951 lineto
Mistroke
0.7381 2.474647e+13 lineto
0.73934 -0.25151 lineto
0.74058 0.02641 lineto
0.74182 0.11913 lineto
0.74306 0.16554 lineto
0.7443 0.19343 lineto
0.74554 0.21207 lineto
0.74678 0.22541 lineto
0.74802 0.23544 lineto
0.74926 0.24327 lineto
0.7505 0.24956 lineto
0.75298 0.25904 lineto
0.75546 0.26589 lineto
0.75794 0.27108 lineto
0.76042 0.27517 lineto
0.7629 0.27849 lineto
0.76786 0.28359 lineto
0.77282 0.28738 lineto
0.77778 0.29036 lineto
0.7877 0.29489 lineto
0.79762 0.29835 lineto
0.81746 0.304 lineto
0.8373 0.30965 lineto
0.84722 0.31311 lineto
0.85218 0.31519 lineto
0.85714 0.31764 lineto
0.8621 0.32062 lineto
0.86706 0.32441 lineto
0.86954 0.32675 lineto
0.87202 0.32951 lineto
0.8745 0.33283 lineto
0.87698 0.33692 lineto
0.87946 0.34211 lineto
0.88194 0.34896 lineto
0.88318 0.35328 lineto
0.88442 0.35844 lineto
0.88566 0.36473 lineto
0.8869 0.37256 lineto
0.88814 0.38259 lineto
0.88938 0.39593 lineto
0.89063 0.41457 lineto
0.89187 0.44246 lineto
0.89311 0.48887 lineto
0.89435 0.58159 lineto
0.89559 0.85951 lineto
0.89683 5.566415e+12 lineto
0.89807 -0.25151 lineto
0.89931 0.02641 lineto
0.90055 0.11913 lineto
0.90179 0.16554 lineto
Mistroke
0.90303 0.19343 lineto
0.90427 0.21207 lineto
0.90551 0.22541 lineto
0.90675 0.23544 lineto
0.90923 0.24956 lineto
0.91047 0.25472 lineto
0.91171 0.25904 lineto
0.91419 0.26589 lineto
0.91667 0.27108 lineto
0.91915 0.27517 lineto
0.92163 0.27849 lineto
0.92659 0.28359 lineto
0.93155 0.28738 lineto
0.93651 0.29036 lineto
0.94643 0.29489 lineto
0.95635 0.29835 lineto
0.97619 0.304 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = text; inactive; ]
		and can render two-dimensional functions as 3-D graphics.
:[font = input; startGroup; ]
Plot3D[ Sin[x y], {x, 0, 3}, {y, 0, 3} ]
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.02381 0.95238 0.02381 0.95238 [
[(0)] 0.05688 0.31214 1 0.933946 Msboxa
[(1)] 0.23549 0.24184 0.931731 1 Msboxa
[(2)] 0.42902 0.16572 0.792736 1 Msboxa
[(3)] 0.63943 0.08304 0.653742 1 Msboxa
[(0)] 0.65703 0.08867 -1 0.391569 Msboxa
[(1)] 0.75282 0.23534 -1 0.355817 Msboxa
[(2)] 0.83538 0.36178 -1 0.326047 Msboxa
[(3)] 0.90729 0.47191 -1 0.300874 Msboxa
[(-1)] 0.05378 0.32904 1 -0.390635 Msboxa
[(-0.5)] 0.04626 0.37616 1 -0.380695 Msboxa
[(0)] 0.03848 0.42493 1 -0.370371 Msboxa
[(0.5)] 0.03042 0.47544 1 -0.359642 Msboxa
[(1)] 0.02207 0.52777 1 -0.348483 Msboxa
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: SurfaceGraphics
[ ] 0 setdash
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06123 0.3162 moveto
0.06993 0.32433 lineto
stroke
0 setgray
[(0)] 0.05688 0.31214 1 0.933946 Mshowa
0.23954 0.2462 moveto
0.24766 0.25491 lineto
stroke
0 setgray
[(1)] 0.23549 0.24184 0.931731 1 Mshowa
0.43272 0.17039 moveto
0.44012 0.17972 lineto
stroke
0 setgray
[(2)] 0.42902 0.16572 0.792736 1 Mshowa
0.64269 0.08803 moveto
0.6492 0.09799 lineto
stroke
0 setgray
[(3)] 0.63943 0.08304 0.653742 1 Mshowa
grestore
gsave
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.65149 0.09084 moveto
0.6404 0.09518 lineto
stroke
0 setgray
[(0)] 0.65703 0.08867 -1 0.391569 Mshowa
0.74721 0.23734 moveto
0.73599 0.24133 lineto
stroke
0 setgray
[(1)] 0.75282 0.23534 -1 0.355817 Mshowa
0.82972 0.36363 moveto
0.8184 0.36732 lineto
stroke
0 setgray
[(2)] 0.83538 0.36178 -1 0.326047 Mshowa
0.90159 0.47362 moveto
0.89019 0.47705 lineto
stroke
0 setgray
[(3)] 0.90729 0.47191 -1 0.300874 Mshowa
grestore
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.05933 0.32687 moveto
0.07042 0.32254 lineto
stroke
0 setgray
[(-1)] 0.05378 0.32904 1 -0.390635 Mshowa
0.05183 0.37404 moveto
0.06295 0.36981 lineto
stroke
0 setgray
[(-0.5)] 0.04626 0.37616 1 -0.380695 Mshowa
0.04406 0.42286 moveto
0.05523 0.41873 lineto
stroke
0 setgray
[(0)] 0.03848 0.42493 1 -0.370371 Mshowa
0.03602 0.47342 moveto
0.04722 0.46939 lineto
stroke
0 setgray
[(0.5)] 0.03042 0.47544 1 -0.359642 Mshowa
0.02769 0.52581 moveto
0.03893 0.5219 lineto
stroke
0 setgray
[(1)] 0.02207 0.52777 1 -0.348483 Mshowa
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.39347 0.6265 lineto
stroke
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.39347 0.6265 moveto
0.38687 0.8155 lineto
stroke
0.39347 0.6265 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.64594 0.09301 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
grestore
0.49975 setgray
0.0015 setlinewidth
0.37007 0.70047 0.39027 0.7181 0.4226 0.76375 0.40243 0.74276 Metetra
0.71417 setgray
0.40243 0.74276 0.4226 0.76375 0.45688 0.78857 0.43676 0.76824 Metetra
0.85443 setgray
0.43676 0.76824 0.45688 0.78857 0.49252 0.77696 0.47266 0.76305 Metetra
0.87201 setgray
0.47266 0.76305 0.49252 0.77696 0.5283 0.72948 0.5091 0.72503 Metetra
0.76083 setgray
0.5091 0.72503 0.5283 0.72948 0.56336 0.6626 0.54511 0.66484 Metetra
0.55935 setgray
0.54511 0.66484 0.56336 0.6626 0.59773 0.59974 0.58037 0.60079 Metetra
0.33725 setgray
0.58037 0.60079 0.59773 0.59974 0.63244 0.56082 0.61543 0.551 Metetra
0.17136 setgray
0.61543 0.551 0.63244 0.56082 0.66891 0.55603 0.65143 0.52779 Metetra
0.11905 setgray
0.65143 0.52779 0.66891 0.55603 0.70832 0.58368 0.68962 0.53501 Metetra
0.19841 setgray
0.68962 0.53501 0.70832 0.58368 0.75084 0.63038 0.7308 0.56751 Metetra
0.382 setgray
0.7308 0.56751 0.75084 0.63038 0.79516 0.67396 0.77481 0.61176 Metetra
0.60632 setgray
0.77481 0.61176 0.79516 0.67396 0.83868 0.6911 0.82019 0.64873 Metetra
0.79377 setgray
0.82019 0.64873 0.83868 0.6911 0.87879 0.66869 0.86456 0.66011 Metetra
0.87953 setgray
0.86456 0.66011 0.87879 0.66869 0.9145 0.61155 0.90563 0.63651 Metetra
0.49975 setgray
0.34934 0.68237 0.37007 0.70047 0.40243 0.74276 0.38177 0.72115 Metetra
0.69946 setgray
0.38177 0.72115 0.40243 0.74276 0.43676 0.76824 0.41614 0.74662 Metetra
0.84006 setgray
0.41614 0.74662 0.43676 0.76824 0.47266 0.76305 0.45223 0.74691 Metetra
0.87991 setgray
0.45223 0.74691 0.47266 0.76305 0.5091 0.72503 0.48919 0.71816 Metetra
0.80723 setgray
0.48919 0.71816 0.5091 0.72503 0.54511 0.66484 0.52609 0.66639 Metetra
0.64353 setgray
0.52609 0.66639 0.54511 0.66484 0.58037 0.60079 0.56235 0.60485 Metetra
0.43727 setgray
0.56235 0.60485 0.58037 0.60079 0.61543 0.551 0.59811 0.54878 Metetra
0.2495 setgray
0.59811 0.54878 0.61543 0.551 0.65143 0.52779 0.63411 0.51072 Metetra
0.1358 setgray
0.63411 0.51072 0.65143 0.52779 0.68962 0.53501 0.67146 0.49774 Metetra
0.12985 setgray
0.67146 0.49774 0.68962 0.53501 0.7308 0.56751 0.71119 0.51046 Metetra
0.23338 setgray
0.71119 0.51046 0.7308 0.56751 0.77481 0.61176 0.75387 0.54291 Metetra
0.41577 setgray
0.75387 0.54291 0.77481 0.61176 0.82019 0.64873 0.79919 0.58323 Metetra
0.62302 setgray
0.79919 0.58323 0.82019 0.64873 0.86456 0.66011 0.84578 0.61598 Metetra
0.79377 setgray
0.84578 0.61598 0.86456 0.66011 0.90563 0.63651 0.89152 0.62656 Metetra
0.49975 setgray
0.32804 0.66379 0.34934 0.68237 0.38177 0.72115 0.3606 0.69888 Metetra
0.68433 setgray
0.3606 0.69888 0.38177 0.72115 0.41614 0.74662 0.39502 0.72372 Metetra
0.82282 setgray
0.39502 0.72372 0.41614 0.74662 0.45223 0.74691 0.43123 0.72841 Metetra
0.88062 setgray
0.43123 0.72841 0.45223 0.74691 0.48919 0.71816 0.4686 0.70836 Metetra
0.84329 setgray
0.4686 0.70836 0.48919 0.71816 0.52609 0.66639 0.50627 0.66609 Metetra
0.72017 setgray
0.50627 0.66609 0.52609 0.66639 0.56235 0.60485 0.54355 0.61027 Metetra
0.54199 setgray
0.54355 0.61027 0.56235 0.60485 0.59811 0.54878 0.58024 0.55266 Metetra
0.35327 setgray
0.58024 0.55266 0.59811 0.54878 0.63411 0.51072 0.61672 0.5046 Metetra
0.20112 setgray
0.61672 0.5046 0.63411 0.51072 0.67146 0.49774 0.65376 0.47441 Metetra
0.12356 setgray
0.65376 0.47441 0.67146 0.49774 0.71119 0.51046 0.69237 0.46618 Metetra
0.13995 setgray
0.69237 0.46618 0.71119 0.51046 0.75387 0.54291 0.73341 0.47933 Metetra
0.2462 setgray
0.73341 0.47933 0.75387 0.54291 0.79919 0.58323 0.77732 0.50861 Metetra
0.41577 setgray
0.77732 0.50861 0.79919 0.58323 0.84578 0.61598 0.82382 0.54465 Metetra
0.60632 setgray
0.82382 0.54465 0.84578 0.61598 0.89152 0.62656 0.87179 0.57538 Metetra
0.49975 setgray
0.30617 0.6447 0.32804 0.66379 0.3606 0.69888 0.33889 0.67596 Metetra
0.66881 setgray
0.33889 0.67596 0.3606 0.69888 0.39502 0.72372 0.37339 0.69953 Metetra
0.80286 setgray
0.37339 0.69953 0.39502 0.72372 0.43123 0.72841 0.40968 0.70749 Metetra
0.8741 setgray
0.40968 0.70749 0.43123 0.72841 0.4686 0.70836 0.44733 0.69519 Metetra
0.86779 setgray
0.44733 0.69519 0.4686 0.70836 0.50627 0.66609 0.48562 0.66276 Metetra
0.78524 setgray
0.48562 0.66276 0.50627 0.66609 0.54355 0.61027 0.52386 0.61512 Metetra
0.64353 setgray
0.52386 0.61512 0.54355 0.61027 0.58024 0.55266 0.56164 0.56045 Metetra
0.47204 setgray
0.56164 0.56045 0.58024 0.55266 0.61672 0.5046 0.59897 0.50788 Metetra
0.30629 setgray
0.59897 0.50788 0.61672 0.5046 0.65376 0.47441 0.6363 0.46548 Metetra
0.18062 setgray
0.6363 0.46548 0.65376 0.47441 0.69237 0.46618 0.67438 0.43889 Metetra
0.12106 setgray
0.67438 0.43889 0.69237 0.46618 0.73341 0.47933 0.71407 0.43075 Metetra
0.13995 setgray
0.71407 0.43075 0.73341 0.47933 0.77732 0.50861 0.75612 0.44048 Metetra
0.23338 setgray
0.75612 0.44048 0.77732 0.50861 0.82382 0.54465 0.80095 0.46426 Metetra
0.382 setgray
0.80095 0.46426 0.82382 0.54465 0.87179 0.57538 0.84846 0.49537 Metetra
0.49975 setgray
0.2837 0.62508 0.30617 0.6447 0.33889 0.67596 0.31663 0.65236 Metetra
0.65294 setgray
0.31663 0.65236 0.33889 0.67596 0.37339 0.69953 0.35124 0.67407 Metetra
0.78034 setgray
0.35124 0.67407 0.37339 0.69953 0.40968 0.70749 0.3876 0.68412 Metetra
0.8605 setgray
0.3876 0.68412 0.40968 0.70749 0.44733 0.69519 0.42543 0.67828 Metetra
0.87991 setgray
0.42543 0.67828 0.44733 0.69519 0.48562 0.66276 0.46419 0.65533 Metetra
0.83532 setgray
0.46419 0.65533 0.48562 0.66276 0.52386 0.61512 0.50325 0.61737 Metetra
0.73423 setgray
0.50325 0.61737 0.52386 0.61512 0.56164 0.56045 0.54212 0.56935 Metetra
0.59365 setgray
0.54212 0.56935 0.56164 0.56045 0.59897 0.50788 0.58057 0.51775 Metetra
0.43727 setgray
0.58057 0.51775 0.59897 0.50788 0.6363 0.46548 0.6187 0.46929 Metetra
0.2914 setgray
0.6187 0.46929 0.6363 0.46548 0.67438 0.43889 0.65696 0.42968 Metetra
0.18062 setgray
0.65696 0.42968 0.67438 0.43889 0.71407 0.43075 0.696 0.403 Metetra
0.12356 setgray
0.696 0.403 0.71407 0.43075 0.75612 0.44048 0.73654 0.3913 Metetra
0.12985 setgray
0.73654 0.3913 0.75612 0.44048 0.80095 0.46426 0.77928 0.39451 Metetra
0.19841 setgray
0.77928 0.39451 0.80095 0.46426 0.84846 0.49537 0.82468 0.41045 Metetra
0.49975 setgray
0.2606 0.60492 0.2837 0.62508 0.31663 0.65236 0.29381 0.62806 Metetra
0.63674 setgray
0.29381 0.62806 0.31663 0.65236 0.35124 0.67407 0.32857 0.64736 Metetra
0.75546 setgray
0.32857 0.64736 0.35124 0.67407 0.3876 0.68412 0.365 0.65831 Metetra
0.84006 setgray
0.365 0.65831 0.3876 0.68412 0.42543 0.67828 0.40293 0.65742 Metetra
0.87924 setgray
0.40293 0.65742 0.42543 0.67828 0.46419 0.65533 0.44201 0.64288 Metetra
0.86779 setgray
0.44201 0.64288 0.46419 0.65533 0.50325 0.61737 0.48172 0.61501 Metetra
0.80723 setgray
0.48172 0.61501 0.50325 0.61737 0.54212 0.56935 0.52158 0.57617 Metetra
0.70565 setgray
0.52158 0.57617 0.54212 0.56935 0.58057 0.51775 0.56124 0.53029 Metetra
0.57658 setgray
0.56124 0.53029 0.58057 0.51775 0.6187 0.46929 0.60055 0.48211 Metetra
0.43727 setgray
0.60055 0.48211 0.6187 0.46929 0.65696 0.42968 0.63965 0.43639 Metetra
0.30629 setgray
0.63965 0.43639 0.65696 0.42968 0.696 0.403 0.67889 0.39724 Metetra
0.20112 setgray
0.67889 0.39724 0.696 0.403 0.73654 0.3913 0.7188 0.3678 Metetra
0.1358 setgray
0.7188 0.3678 0.73654 0.3913 0.77928 0.39451 0.76 0.34992 Metetra
0.11905 setgray
0.76 0.34992 0.77928 0.39451 0.82468 0.41045 0.8031 0.34415 Metetra
0.49975 setgray
0.23685 0.58419 0.2606 0.60492 0.29381 0.62806 0.27039 0.60306 Metetra
0.62026 setgray
0.27039 0.60306 0.29381 0.62806 0.32857 0.64736 0.30537 0.61941 Metetra
0.72842 setgray
0.30537 0.61941 0.32857 0.64736 0.365 0.65831 0.34189 0.63011 Metetra
0.81317 setgray
0.34189 0.63011 0.365 0.65831 0.40293 0.65742 0.3799 0.63249 Metetra
0.86581 setgray
0.3799 0.63249 0.40293 0.65742 0.44201 0.64288 0.41917 0.62475 Metetra
0.88095 setgray
0.41917 0.62475 0.44201 0.64288 0.48172 0.61501 0.45933 0.60626 Metetra
0.85705 setgray
0.45933 0.60626 0.48172 0.61501 0.52158 0.57617 0.5 0.57767 Metetra
0.79655 setgray
0.5 0.57767 0.52158 0.57617 0.56124 0.53029 0.54079 0.54081 Metetra
0.70565 setgray
0.54079 0.54081 0.56124 0.53029 0.60055 0.48211 0.58144 0.49842 Metetra
0.59365 setgray
0.58144 0.49842 0.60055 0.48211 0.63965 0.43639 0.62185 0.4537 Metetra
0.47204 setgray
0.62185 0.4537 0.63965 0.43639 0.67889 0.39724 0.66209 0.40992 Metetra
0.35327 setgray
0.66209 0.40992 0.67889 0.39724 0.7188 0.3678 0.70242 0.37007 Metetra
0.2495 setgray
0.70242 0.37007 0.7188 0.3678 0.76 0.34992 0.74322 0.33658 Metetra
0.17136 setgray
0.74322 0.33658 0.76 0.34992 0.8031 0.34415 0.78499 0.31121 Metetra
0.49975 setgray
0.21241 0.56286 0.23685 0.58419 0.27039 0.60306 0.24636 0.57734 Metetra
0.60352 setgray
0.24636 0.57734 0.27039 0.60306 0.30537 0.61941 0.28162 0.59026 Metetra
0.69946 setgray
0.28162 0.59026 0.30537 0.61941 0.34189 0.63011 0.31829 0.59961 Metetra
0.78034 setgray
0.31829 0.59961 0.34189 0.63011 0.3799 0.63249 0.35637 0.60354 Metetra
0.84006 setgray
0.35637 0.60354 0.3799 0.63249 0.41917 0.62475 0.39575 0.60056 Metetra
0.8741 setgray
0.39575 0.60056 0.41917 0.62475 0.45933 0.60626 0.4362 0.58975 Metetra
0.87991 setgray
0.4362 0.58975 0.45933 0.60626 0.5 0.57767 0.47744 0.57088 Metetra
0.85705 setgray
0.47744 0.57088 0.5 0.57767 0.54079 0.54081 0.51917 0.5444 Metetra
0.80723 setgray
0.51917 0.5444 0.54079 0.54081 0.58144 0.49842 0.56109 0.51143 Metetra
0.73423 setgray
0.56109 0.51143 0.58144 0.49842 0.62185 0.4537 0.603 0.47361 Metetra
0.64353 setgray
0.603 0.47361 0.62185 0.4537 0.66209 0.40992 0.64479 0.43293 Metetra
0.54199 setgray
0.64479 0.43293 0.66209 0.40992 0.70242 0.37007 0.68645 0.39149 Metetra
0.43727 setgray
0.68645 0.39149 0.70242 0.37007 0.74322 0.33658 0.72812 0.35134 Metetra
0.33725 setgray
0.72812 0.35134 0.74322 0.33658 0.78499 0.31121 0.77004 0.31432 Metetra
0.49975 setgray
0.18726 0.54091 0.21241 0.56286 0.24636 0.57734 0.2217 0.55087 Metetra
0.58656 setgray
0.2217 0.55087 0.24636 0.57734 0.28162 0.59026 0.25732 0.55995 Metetra
0.66881 setgray
0.25732 0.55995 0.28162 0.59026 0.31829 0.59961 0.29421 0.56695 Metetra
0.7422 setgray
0.29421 0.56695 0.31829 0.59961 0.35637 0.60354 0.3324 0.57073 Metetra
0.80286 setgray
0.3324 0.57073 0.35637 0.60354 0.39575 0.60056 0.37186 0.57025 Metetra
0.84761 setgray
0.37186 0.57025 0.39575 0.60056 0.4362 0.58975 0.41246 0.56472 Metetra
0.8741 setgray
0.41246 0.56472 0.4362 0.58975 0.47744 0.57088 0.45406 0.55361 Metetra
0.88095 setgray
0.45406 0.55361 0.47744 0.57088 0.51917 0.5444 0.49644 0.53673 Metetra
0.86779 setgray
0.49644 0.53673 0.51917 0.5444 0.56109 0.51143 0.53939 0.51422 Metetra
0.83532 setgray
0.53939 0.51422 0.56109 0.51143 0.603 0.47361 0.58269 0.48659 Metetra
0.78524 setgray
0.58269 0.48659 0.603 0.47361 0.64479 0.43293 0.62617 0.45463 Metetra
0.72017 setgray
0.62617 0.45463 0.64479 0.43293 0.68645 0.39149 0.66969 0.41936 Metetra
0.64353 setgray
0.66969 0.41936 0.68645 0.39149 0.72812 0.35134 0.71319 0.38197 Metetra
0.55935 setgray
0.71319 0.38197 0.72812 0.35134 0.77004 0.31432 0.75669 0.3437 Metetra
0.49975 setgray
0.16137 0.51831 0.18726 0.54091 0.2217 0.55087 0.19637 0.52363 Metetra
0.56942 setgray
0.19637 0.52363 0.2217 0.55087 0.25732 0.55995 0.23244 0.5285 Metetra
0.63674 setgray
0.23244 0.5285 0.25732 0.55995 0.29421 0.56695 0.26964 0.53228 Metetra
0.69946 setgray
0.26964 0.53228 0.29421 0.56695 0.3324 0.57073 0.30802 0.53436 Metetra
0.75546 setgray
0.30802 0.53436 0.3324 0.57073 0.37186 0.57025 0.34758 0.53414 Metetra
0.80286 setgray
0.34758 0.53414 0.37186 0.57025 0.41246 0.56472 0.38828 0.5311 Metetra
0.84006 setgray
0.38828 0.5311 0.41246 0.56472 0.45406 0.55361 0.43007 0.52478 Metetra
0.86581 setgray
0.43007 0.52478 0.45406 0.55361 0.49644 0.53673 0.47283 0.51487 Metetra
0.87924 setgray
0.47283 0.51487 0.49644 0.53673 0.53939 0.51422 0.51645 0.50115 Metetra
0.87991 setgray
0.51645 0.50115 0.53939 0.51422 0.58269 0.48659 0.56079 0.48356 Metetra
0.86779 setgray
0.56079 0.48356 0.58269 0.48659 0.62617 0.45463 0.6057 0.4622 Metetra
0.84329 setgray
0.6057 0.4622 0.62617 0.45463 0.66969 0.41936 0.65104 0.4373 Metetra
0.80723 setgray
0.65104 0.4373 0.66969 0.41936 0.71319 0.38197 0.6967 0.40922 Metetra
0.76083 setgray
0.6967 0.40922 0.71319 0.38197 0.75669 0.3437 0.74256 0.37844 Metetra
0.49975 setgray
0.13469 0.49503 0.16137 0.51831 0.19637 0.52363 0.17035 0.49562 Metetra
0.55213 setgray
0.17035 0.49562 0.19637 0.52363 0.23244 0.5285 0.20697 0.49596 Metetra
0.60352 setgray
0.20697 0.49596 0.23244 0.5285 0.26964 0.53228 0.24459 0.4958 Metetra
0.65294 setgray
0.24459 0.4958 0.26964 0.53228 0.30802 0.53436 0.28325 0.49484 Metetra
0.69946 setgray
0.28325 0.49484 0.30802 0.53436 0.34758 0.53414 0.32299 0.49284 Metetra
0.7422 setgray
0.32299 0.49284 0.34758 0.53414 0.38828 0.5311 0.36381 0.48951 Metetra
0.78034 setgray
0.36381 0.48951 0.38828 0.5311 0.43007 0.52478 0.4057 0.48463 Metetra
0.81317 setgray
0.4057 0.48463 0.43007 0.52478 0.47283 0.51487 0.44863 0.47796 Metetra
0.84006 setgray
0.44863 0.47796 0.47283 0.51487 0.51645 0.50115 0.49258 0.4693 Metetra
0.8605 setgray
0.49258 0.4693 0.51645 0.50115 0.56079 0.48356 0.53749 0.45851 Metetra
0.8741 setgray
0.53749 0.45851 0.56079 0.48356 0.6057 0.4622 0.58329 0.44545 Metetra
0.88062 setgray
0.58329 0.44545 0.6057 0.4622 0.65104 0.4373 0.62992 0.43005 Metetra
0.87991 setgray
0.62992 0.43005 0.65104 0.4373 0.6967 0.40922 0.6773 0.4123 Metetra
0.87201 setgray
0.6773 0.4123 0.6967 0.40922 0.74256 0.37844 0.72533 0.39219 Metetra
0.49975 setgray
0.10721 0.47104 0.13469 0.49503 0.17035 0.49562 0.14362 0.4668 Metetra
0.53473 setgray
0.14362 0.4668 0.17035 0.49562 0.20697 0.49596 0.18088 0.46238 Metetra
0.56942 setgray
0.18088 0.46238 0.20697 0.49596 0.24459 0.4958 0.21903 0.4577 Metetra
0.60352 setgray
0.21903 0.4577 0.24459 0.4958 0.28325 0.49484 0.25811 0.45268 Metetra
0.63674 setgray
0.25811 0.45268 0.28325 0.49484 0.32299 0.49284 0.29813 0.44723 Metetra
0.66881 setgray
0.29813 0.44723 0.32299 0.49284 0.36381 0.48951 0.33913 0.44125 Metetra
0.69946 setgray
0.33913 0.44125 0.36381 0.48951 0.4057 0.48463 0.38113 0.43467 Metetra
0.72842 setgray
0.38113 0.43467 0.4057 0.48463 0.44863 0.47796 0.42415 0.4274 Metetra
0.75546 setgray
0.42415 0.4274 0.44863 0.47796 0.49258 0.4693 0.46818 0.41935 Metetra
0.78034 setgray
0.46818 0.41935 0.49258 0.4693 0.53749 0.45851 0.51325 0.41045 Metetra
0.80286 setgray
0.51325 0.41045 0.53749 0.45851 0.58329 0.44545 0.55936 0.40061 Metetra
0.82282 setgray
0.55936 0.40061 0.58329 0.44545 0.62992 0.43005 0.6065 0.38975 Metetra
0.84006 setgray
0.6065 0.38975 0.62992 0.43005 0.6773 0.4123 0.65466 0.37783 Metetra
0.85443 setgray
0.65466 0.37783 0.6773 0.4123 0.72533 0.39219 0.70384 0.36476 Metetra
0.49975 setgray
0.07887 0.44631 0.10721 0.47104 0.14362 0.4668 0.11613 0.43715 Metetra
0.51726 setgray
0.11613 0.43715 0.14362 0.4668 0.18088 0.46238 0.15415 0.42779 Metetra
0.53473 setgray
0.15415 0.42779 0.18088 0.46238 0.21903 0.4577 0.19295 0.41822 Metetra
0.55213 setgray
0.19295 0.41822 0.21903 0.4577 0.25811 0.45268 0.23256 0.40842 Metetra
0.56942 setgray
0.23256 0.40842 0.25811 0.45268 0.29813 0.44723 0.273 0.39838 Metetra
0.58656 setgray
0.273 0.39838 0.29813 0.44723 0.33913 0.44125 0.3143 0.38808 Metetra
0.60352 setgray
0.3143 0.38808 0.33913 0.44125 0.38113 0.43467 0.35648 0.3775 Metetra
0.62026 setgray
0.35648 0.3775 0.38113 0.43467 0.42415 0.4274 0.39958 0.36662 Metetra
0.63674 setgray
0.39958 0.36662 0.42415 0.4274 0.46818 0.41935 0.44361 0.35543 Metetra
0.65294 setgray
0.44361 0.35543 0.46818 0.41935 0.51325 0.41045 0.4886 0.3439 Metetra
0.66881 setgray
0.4886 0.3439 0.51325 0.41045 0.55936 0.40061 0.53458 0.33202 Metetra
0.68433 setgray
0.53458 0.33202 0.55936 0.40061 0.6065 0.38975 0.58158 0.31976 Metetra
0.69946 setgray
0.58158 0.31976 0.6065 0.38975 0.65466 0.37783 0.62963 0.30711 Metetra
0.71417 setgray
0.62963 0.30711 0.65466 0.37783 0.70384 0.36476 0.67875 0.29405 Metetra
0.49975 setgray
0.04964 0.4208 0.07887 0.44631 0.11613 0.43715 0.08786 0.40664 Metetra
0.49975 setgray
0.08786 0.40664 0.11613 0.43715 0.15415 0.42779 0.12675 0.39224 Metetra
0.49975 setgray
0.12675 0.39224 0.15415 0.42779 0.19295 0.41822 0.16631 0.37759 Metetra
0.49975 setgray
0.16631 0.37759 0.19295 0.41822 0.23256 0.40842 0.20657 0.36267 Metetra
0.49975 setgray
0.20657 0.36267 0.23256 0.40842 0.273 0.39838 0.24755 0.3475 Metetra
0.49975 setgray
0.24755 0.3475 0.273 0.39838 0.3143 0.38808 0.28926 0.33205 Metetra
0.49975 setgray
0.28926 0.33205 0.3143 0.38808 0.35648 0.3775 0.33173 0.31632 Metetra
0.49975 setgray
0.33173 0.31632 0.35648 0.3775 0.39958 0.36662 0.37498 0.3003 Metetra
0.49975 setgray
0.37498 0.3003 0.39958 0.36662 0.44361 0.35543 0.41902 0.28399 Metetra
0.49975 setgray
0.41902 0.28399 0.44361 0.35543 0.4886 0.3439 0.46389 0.26737 Metetra
0.49975 setgray
0.46389 0.26737 0.4886 0.3439 0.53458 0.33202 0.50959 0.25044 Metetra
0.49975 setgray
0.50959 0.25044 0.53458 0.33202 0.58158 0.31976 0.55617 0.23319 Metetra
0.49975 setgray
0.55617 0.23319 0.58158 0.31976 0.62963 0.30711 0.60363 0.21561 Metetra
0.49975 setgray
0.60363 0.21561 0.62963 0.30711 0.67875 0.29405 0.65202 0.19769 Metetra
0 setgray
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
gsave
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06123 0.3162 moveto
0.06993 0.32433 lineto
stroke
0 setgray
[(0)] 0.05688 0.31214 1 0.933946 Mshowa
0.23954 0.2462 moveto
0.24766 0.25491 lineto
stroke
0 setgray
[(1)] 0.23549 0.24184 0.931731 1 Mshowa
0.43272 0.17039 moveto
0.44012 0.17972 lineto
stroke
0 setgray
[(2)] 0.42902 0.16572 0.792736 1 Mshowa
0.64269 0.08803 moveto
0.6492 0.09799 lineto
stroke
0 setgray
[(3)] 0.63943 0.08304 0.653742 1 Mshowa
grestore
gsave
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.65149 0.09084 moveto
0.6404 0.09518 lineto
stroke
0 setgray
[(0)] 0.65703 0.08867 -1 0.391569 Mshowa
0.74721 0.23734 moveto
0.73599 0.24133 lineto
stroke
0 setgray
[(1)] 0.75282 0.23534 -1 0.355817 Mshowa
0.82972 0.36363 moveto
0.8184 0.36732 lineto
stroke
0 setgray
[(2)] 0.83538 0.36178 -1 0.326047 Mshowa
0.90159 0.47362 moveto
0.89019 0.47705 lineto
stroke
0 setgray
[(3)] 0.90729 0.47191 -1 0.300874 Mshowa
grestore
gsave
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.05933 0.32687 moveto
0.07042 0.32254 lineto
stroke
0 setgray
[(-1)] 0.05378 0.32904 1 -0.390635 Mshowa
0.05183 0.37404 moveto
0.06295 0.36981 lineto
stroke
0 setgray
[(-0.5)] 0.04626 0.37616 1 -0.380695 Mshowa
0.04406 0.42286 moveto
0.05523 0.41873 lineto
stroke
0 setgray
[(0)] 0.03848 0.42493 1 -0.370371 Mshowa
0.03602 0.47342 moveto
0.04722 0.46939 lineto
stroke
0 setgray
[(0.5)] 0.03042 0.47544 1 -0.359642 Mshowa
0.02769 0.52581 moveto
0.03893 0.5219 lineto
stroke
0 setgray
[(1)] 0.02207 0.52777 1 -0.348483 Mshowa
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-SurfaceGraphics-
:[font = subsubsection; inactive; startGroup; Cclosed; pageBreak; ]
Programming Paradigms
:[font = text; inactive; ]
		Mathematica resembles many other programming languages
		because it supports
:[font = special3; inactive; ]
1.	the writing of procedures by providing Block and Function
	constructs
:[font = special3; inactive; ]
2.	the alteration of arguments by changing an object's attributes
	via SetAttributes
:[font = special3; inactive; ]
3.	the extending of operators by attaching functions to operators
	based on the data type (tag) of one of the inputs.
:[font = special3; inactive; ]
4.	the ability to chain conditional rules in one direction via Replace,
	ReplaceAll, and ReplaceRepeated commands,
:[font = special3; inactive; ]
5.	the pattern matching of expressions via MatchQ, TagSetDelayed,
	and TagSet, and
:[font = special3; inactive; ]
6.	the immediate and delayed evaluation of expressions via = and :=.
:[font = text; inactive; endGroup; ]
		Mathematica is a superset of many common modern
		programming styles.  One drawback, however, is that it is
		not an expert system per se.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Getting Help On-Line
:[font = text; inactive; ]
		The kernel offers a help function called Help (abbreviated ?) 
		which can give usage information on a particular object
		(function)
:[font = input; startGroup; ]
?Integrate
:[font = info; inactive; endGroup; ]
Integrate[f, x] gives the indefinite integral
   of f with respect to x. Integrate[f, {x,
   xmin, xmax}] gives the definite integral.
   Integrate[f, {x, xmin, xmax}, {y, ymin,
   ymax}] gives a multiple integral.
:[font = text; inactive; ]
		or match a collection of object names to a pattern.
:[font = input; startGroup; ]
?*Solve*
:[font = info; inactive; endGroup; ]
DSolve      MainSolve   SolveAlways
LinearSolve Solve
:[font = text; inactive; endGroup; endGroup; ]
		The notebook interface offers kinds of help to you the
		home viewer.
:[font = subsection; inactive; startGroup; Cclosed; ]
Educational Uses of the Notebook Interface
:[font = text; inactive; ]
		The interactive nature of Mathematica and its multimedia capabilities make it a good platform in which to write tutorials.  Teachers can also use them to create problem sets and their solutions.  Students can use them to solve problems and document their solution as they go.   At the very least, such a facility can provide decent on-line help.
:[font = subsubsection; inactive; startGroup; Cclosed; pageBreak; ]
Calculus Courseware
:[font = text; inactive; ]
		For the last three years,  Don Brown, Horacio Porta, and Jerry Uhl at the University of Illinois at Urbana-Champaign have been developing a one-year Calculus course in the form of tutorial notebooks.  They have adapted a conventional one-year freshmen Calculus course into a laboratory setting where the teacher only lecture 30 minutes per week.  The lessons are broken down into 60 notebooks, which students complete at a rate of two per week.  The developers faced two major obstacles.  First, how does one take advantage of the multimedia capabilities so that one does not simply dump the contents of a text book into a notebook format?  So, they split each notebook into six sections:
:[font = special5; inactive; ]
1. Introduction				2. Basic Problems
:[font = special5; inactive; ]
3. Tutorial problems		4. "Give It a Try"
:[font = special5; inactive; ]
5. Student feedback			6. "Literacy Sheet"
:[font = text; inactive; endGroup; ]
The second issue was grading.  They decided to embed problems in the notebook which had been partially completed.  It was then up to the students to fill in the missing pieces and document why they chose certain procedures.  Students also worked problems from scratch.  The primary source of their grades was conventional paper-and-pencil tests.
:[font = subsubsection; inactive; startGroup; Cclosed; pageBreak; ]
Current Classroom Uses
:[font = text; inactive; ]
		Besides the Calculus courseware discussed in the previous subsubsection, other educators are using Mathematica to enhance the learning process.  The list below is only representative and by no means exhaustive.   The first two lines identify the departments and the school.  The third line indicates the purpose.  The remaining lines list the classes in which Mathematica without any extensions is being used.  (The next section entitled "Signal Processing Notebooks" lists some of the schools that are using the signal processing packages and notebooks as educational tools).
:[font = text; inactive; ]

:[font = special3; inactive; ]
Engineering, Mathematics, Physics, and Chemistry Departments
Rose-Hulman Institute of Technology
:[font = output; inactive; ]
Joint effort by above department to teach the
:[font = name; inactive; ]
		Integrated Freshmen Curriculum
:[font = text; inactive; ]

:[font = special3; inactive; ]
Mathematics Department
Georgia Institute of Technology
:[font = output; inactive; ]
Lecture from notebooks with laboratory 
:[font = name; inactive; ]
		Advanced Engineering Mathematics I & II
:[font = name; inactive; ]
		Mathematical Programming
:[font = text; inactive; ]

:[font = special3; inactive; ]
Music Department
Stanford University
:[font = output; inactive; ]
Plotting windows and their spectra
:[font = name; inactive; ]
		The Discrete Fourier Transform 
:[font = name; inactive; endGroup; endGroup; ]
		Applications of the Short-Time Fourier Transform
:[font = subsection; inactive; startGroup; Cclosed; ]
For More Information
:[font = text; inactive; ]
		Mathematica comes with several notebooks.  The notebook entitled "TourOfMathematica", which is located in the standard directory /NextLibrary/Mathematica/Notebooks, provides an overview of the Mathematica. 		
:[font = text; inactive; ]
		Several books published by Addison-Wesley are listed below.  The first is more of a reference manual than a user's guide.  The 1988 edition documents Mathematica 1.0 and the 1991 edition documents Mathematica 2.0.   The second book is an introduction on how to encode knowledge in Mathematica.  The other book are less general.
:[font = subsubsection; inactive; ]
S. Wolfram, Mathematica:  A System for Doing Mathematics by Computer,  1988.
:[font = subsubsection; inactive; ]
R. Maeder, Programming in Mathematica,  1990.
:[font = subsubsection; inactive; ]
S. Skiena, Implementing Discrete Mathematics:  Combinatorics and Graph Theory with Mathematica, 1990.
:[font = subsubsection; inactive; ]
T. Gray and J. Glynn, Exploring Mathematics with Mathematica, 1991.
:[font = subsubsection; inactive; ]
R. Crandall, Mathematica for the Sciences, 1991.
:[font = subsubsection; inactive; endGroup; endGroup; ]
I. Vardi, Computational Recreations with Mathematica, 1991.
:[font = section; inactive; startGroup; Cclosed; ]
Introduction to Signal Processing
:[font = special3; inactive; wordwrap; ]
Except for the sub-section and sub-sub-section headings, the following is taken from "Symbolic Transforms with Applications to Signal Processing" by B. L. Evans, J. H. McClellan, and W. B. McClure which appeared in the Fall 1990 issue of "The Mathematica Journal" pages 70-80.  The reference section lists this article as [Evans, 1990].
:[font = text; inactive; ]
		Transform theory is a powerful tool employed by scientists
[Oberhettinger and Badii 1973], mathematicians [Churchill 1958], and engineers [Lathi 1983; Muth 1978; Oppenheim and Schafer 1989].  One important use of this theory is to transform equations involving integrals and derivatives into algebraic equations that are easier to solve.  The solutions to the original equations are obtained by inverse transforming the algebraic solutions.  This is the case when the Laplace transform is applied to linear
differential equations with constant coefficients, or when the z-transform is applied to linear difference equations with constant coefficients.
:[font = subsection; inactive; startGroup; Cclosed; ]
Signal Processing
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Signals
:[font = text; inactive; endGroup; ]
		This process is one of the staples of signal processing, the area of engineering that deals with the design and analysis of systems that act on signals in prescribed ways.  A signal is essentially a function of one or more variables; often, in the one-variable case, the variable is time.  The variable can be continuous (for an analog signal), or discrete (for a digital, or sampled, signal).  Thus a one-dimensional discrete-time signal is a finite or infinite sequence of values, or samples.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Systems
:[font = text; inactive; endGroup; endGroup; ]
		A system is a mathematical operator that transforms one signal into another, according to characteristic rules.  Filters, or linear time-invariant  systems, form a particularly important class of systems, eminently suited to the application of transform methods.  A filter is characterized by a function, its impulse response, in terms of which the filter's action on any signal can be determined.  The output signal is the convolution of the input signal with the filter's impulse response; the operation of convolution involves an integral for continuous signals and a summation for discrete ones.  Using transforms, one can reduce the task of convolving these two functions to that of multiplying two algebraic expressions--- the functions' transforms--- and then inverse transforming the product.
:[font = subsection; inactive; startGroup; Cclosed; ]
Analog Signal Processing (ASP)
:[font = text; inactive; endGroup; ]
		For an example of analog system design, consider the transmission of AM radio signals.  Each AM radio station broadcasts at a specific frequency fo which is between 550 kHz and 1600 kHz and is a multiple of 10 kHz [Lathi 1983].  In order to avoid overlap with other stations, a station must transmit its signal between the frequencies fo - 5 kHz and fo + 5 kHz.  Before transmission, a station filters its signal so that frequencies above 5 kHz are rejected and frequencies below 5 kHz are passed.  This filtered signal is then shifted by fo in the frequency domain and transmitted.  The entire design and analysis of this system can be carried out in the frequency domain:  the Laplace transform would be used for the design and implementation of the 5 kHz low-pass filter, and the Fourier transform would be used to analyze the transmission system.
:[font = subsection; inactive; startGroup; Cclosed; ]
Digital Signal Processing (DSP)
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Discrete Signals and Systems
:[font = text; inactive; endGroup; ]
		By contrast, digital signal processing (DSP) deals with discrete-time signals (sequences) and systems that act on them [Oppenheim and Schafer 1989].  Primarily, digital signals come from sampling and quantizing analog signals.  In many cases, implementing a system in digital hardware is faster, more flexible, and more cost-effective than building it from analog components.  One reason for this is that increasing precision in discrete systems is as simple as adding bits, whereas more expensive components may be required in analog systems.  Another reason is that the time to prototype a system is often shorter for discrete systems. Apart from that, some DSP operators, like those that alter the sampling rate, have little meaning in the continuous domain, and may be very difficult to implement with analog components.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Commonly Used Transforms
:[font = text; inactive; endGroup; endGroup; ]
		The most commonly used transforms in DSP are the z-transform, the discrete-time Fourier transform (DTFT) and the discrete Fourier transform (DFT).  Just as the Laplace transform is a generalization of the Fourier transform, the z-transform is a generalized form of the DTFT.  The z-transform is most useful in the implementation of digital filters as digital hardware or programs for DSP chips, while the DTFT is preferred when the frequency-domain characteristics of a system must be defined.
:[font = subsection; inactive; startGroup; Cclosed; ]
Multidimensional Signal Processing
:[font = text; inactive; endGroup; ]
		Neither digital nor analog signal processing is confined to a single dimension.  Many spatial array and imaging applications require two- and three-dimensional processing.  This is the case for detecting edges in monochrome digital images, or finding angles of arrival with an array of sensors.  A digitized image can be thought of as a function defined on an N x M grid, where each grid square is assigned an intensity value known as a grey level (usually a positive integer).  In such a digitized image, human eyes perceive an edge as a sharp transition between grey levels in adjacent regions.  Such a sharp transition gives rise to high-frequency components in the image.  Therefore, filtering the image to boost its high-frequency components and decrease its low-frequency components would sharpen edges in the image.  This operation on the image is a two-dimensional high-pass filter; it corresponds to convolution in the two-dimensional ``time'' domain.
:[font = subsection; inactive; startGroup; Cclosed; ]
Computer Implementations of DSP
:[font = text; inactive; ]
		Digital signal processing has always been tied closely to computer implementations, where the signals are viewed as a stream of numbers.  The machine provides an efficient way to compute the DSP operator that transforms one stream of numbers into another.  On the other hand, the design of a signal processing system treats the signals as functions (in the mathematical sense).
:[font = text; inactive; endGroup; ]
		Over the last decade, special attention has been devoted by several researchers to the field of symbolic signal processing [Kopec 1980, 1985; Myers 1986; Covell 1989].  In symbolic processing, the signal is represented in a computer as a formula, rather than as a sequence of numbers.  Thus, the value of a signal might only be known in terms of a formula, instead of a number.  In a similar manner, signal processing operators, the building blocks for systems, are maintained in symbolic form.  This enables a machine to simplify, rearrange, and rewrite symbolic expressions until they take a desired form.  For example, the desired form might be an optimal implementation of an expression in which the number of additions and multiplications is minimized.
:[font = subsection; inactive; startGroup; Cclosed; ]
Rest of the Paper [Notebook]
:[font = text; inactive; ]
		The remainder of this paper [notebook] describes a set of packages that provide a general platform for implementing symbolic transforms in Mathematica and that represent a first step toward the building of a comprehensive signal processing environment in Mathematica.  The packages are divided into three groups, corresponding to the contexts
:[font = input; center; ]
SignalProcessing`Support`
:[font = input; center; ]
SignalProcessing`Digital`
:[font = input; center; ]
SignalProcessing`Analog` 
:[font = text; inactive; endGroup; endGroup; ]
(Loading either of the last two automatically causes the first to load as well.)  In Mathematica 2.0, loading these files will define ``stubs'' for all of the new functions, data structures, and operators introduced by the signal processing packages.  This means that Mathematica will automatically load packages as needed.  For example, the z-transform rule base would only be loaded if the user wanted to take a z-transform. 
:[font = section; inactive; startGroup; Cclosed; ]
Signal Processing Packages
:[font = text; inactive; ]
		The signal processing packages are extensions to the Mathematica kernel.  These packages add knowledge representations for functions, operators, and structures common in signal processing and implement the bilateral forms of the usual linear transforms: 
:[font = special3; inactive; center; ]
discrete signals
:[font = network; inactive; center; ]
 z-transform
discrete-time Fourier transform
discrete Fourier transform
:[font = special3; inactive; center; ]
continuous signals
:[font = network; inactive; center; ]
Laplace transform
Fourier transform
:[font = text; inactive; ]
The transforms can fully justify their answers so that students can learn the mechanics of how to compute transform. [Evans, 1990]
:[font = text; inactive; ]
		The packages also perform convolution and solve difference/differential equations.  The solvers can tackle linear constant coefficient (lcc) difference and differential equations subject to initial conditions.  Like the transform rule base, these solvers can fully justify their answers. [Evans, 1990]
:[font = special3; inactive; center; ]
discrete signals
:[font = network; inactive; center; ]
 one-dimensional convolution
solving lcc difference equations
:[font = special3; inactive; center; ]
continuous signals
:[font = network; inactive; center; ]
one-dimensional piecewise convolution
solving lcc differential equations
one-dimensional analog filter design
:[font = subsection; inactive; startGroup; Cclosed; ]
New Signals and Systems
:[font = text; inactive; ]
		Here are the new signals (functions) introduced by the packages:
:[font = network; inactive; center; ]
Kronecker impulse, Dirac delta, sinc,
continuous and discrete step functions,
continuous and discrete pulse functions,
aliased sinc, filter representations
:[font = text; inactive; ]
		Here are the new systems (operators) introduced by the packages:
:[font = network; inactive; endGroup; center; ]
aliasing, convolution, DFT, DTFT, backward
difference, downsampling, Fourier transform,
interleave samples, Laplace transform,
periodic, reverse, scale axis, shift,
summation, upsampling
:[font = subsection; inactive; startGroup; Cclosed; ]
New Graphics Capabilities
:[font = text; inactive; ]
		Of course, no implementation of signal processing operations would be complete without special graphical representations for signals (functions) and systems (operators):
:[font = special3; inactive; center; ]
general plotting
:[font = network; inactive; endGroup; center; ]
1-D and 2-D signals and sequences
frequency responses
pole-zero diagrams
root loci

:[font = subsection; inactive; startGroup; Cclosed; ]
Laplace Transform Examples
:[font = text; inactive; ]
		These packages can compute transforms as well as fully justify the answers.  This is useful for showing the mechanics of  taking transforms to students.   Since the justification (dialogue) capabilities are pretty much the same for all of the transforms, we have included only Laplace transform examples because the Laplace transform is probably the most familiar of the implemented linear transforms.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Forward Transform with Complete Justification
:[font = text; inactive; ]
		For the example below, note that  CStep  is the continuous step function.  The justification is enabled by the Dialogue -> All option.  Other possible values for Dialogue are True and False.   True, the default value, tells the Laplace transform object LaPlace to report only strategies used in finding the transform (like partial fractions or series expansion).
:[font = input; startGroup; ]
LaPlace[ A t Exp[a t] CStep[t],
		  t, s, Dialogue -> All ]
:[font = print; inactive; startGroup; ]
       a t
L  {A E    t CStep[t]}
  t
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
       a t
A L  {E    t CStep[t]}
    t
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
A {L  {t CStep[t]}}
     t             s -> -a + s and shift ROC
:[font = print; inactive; ]
which becomes
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[A/(-a + s)^2, Rminus[Re[a]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
               A
LTransData[---------, Rminus[Re[a]], 
                   2
           (-a + s)
 
  Rplus[Infinity], LVariables[s]]
:[font = text; inactive; endGroup; ]
Here, the transform is A / (s - a)^2 with a region of convergence of
Re{a} < Re{s}.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Inverse Transform with Justification
:[font = text; inactive; ]
		The justification is enabled by the Dialogue -> Trueoption.  Other possible values for Dialogue are All and False.   True, the default value, tells the Laplace transform object LaPlace to report only strategies used in finding the transform (like partial fractions or series expansion).
:[font = input; startGroup; ]
InvLaPlace[ ( s^3 + 27 s^2 + 242 s + 720 ) /
			 ( s^4 + 10 s^3 + 35 s^2 + 50 s + 24 ),
			 s, t, Simplify -> False ]
:[font = print; inactive; startGroup; ]
( After performing partial fraction expansion on
:[font = print; inactive; ]
                       2    3
     720 + 242 s + 27 s  + s
  ------------------------------
                  2       3    4
  24 + 50 s + 35 s  + 10 s  + s
:[font = print; inactive; ]
  in order to break it up into first and
:[font = print; inactive; ]
  second order sections:
:[font = print; inactive; ]
   84      168     105     20
  ----- - ----- + ----- - ----- . )
  1 + s   2 + s   3 + s   4 + s
:[font = output; inactive; output; endGroup; endGroup; ]
(-20*CStep[t])/E^(4*t) + (105*CStep[t])/E^(3*t) - 
  (168*CStep[t])/E^(2*t) + (84*CStep[t])/E^t
;[o]
-20 CStep[t]   105 CStep[t]   168 CStep[t]
------------ + ------------ - ------------ + 
     4 t            3 t            2 t
    E              E              E
 
  84 CStep[t]
  -----------
       t
      E
:[font = text; inactive; endGroup; ]
Here, the inverse transform is a sum of four decaying exponentials.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Providing Your Own Transform Pairs
:[font = text; inactive; ]
		All ten transform rule bases allow you to specify your own transform pairs through the TransformLookup option.  These transform pairs are evaluated after the rule base has finished applying its knowledge to find the transform.  Thus, the transform pairs that the user specifies will not override the transform pairs encoded into the rule bases.
:[font = text; inactive; ]
		Besides augmenting the knowledge of an existing rule base, another advantage to being able to provide your own transform pairs is transforming general functions, e.g.  x(t) <---> X(s). 
:[font = input; startGroup; ]
LaPlace[ t x[t], t, s,
         TransformLookup -> { x[t] :> X[s] } ]
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
LTransData[-Derivative[1][X][s], 
  Rminus[DirectedInfinity[-1]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
LTransData[-X'[s], Rminus[-Infinity], 
 
  Rplus[Infinity], LVariables[s]]
:[font = subsection; inactive; startGroup; Cclosed; ]
Signal Analysis
:[font = text; inactive; ]
		The signal processing packages can perform high-level signal analysis on digital signals (via DSPAnalyze) and analog signals (via ASPAnalyze).  The analysis mimics that expected of a junior or senior electrical engineering student.   For 1-D and 2-D signals, DSPAnalyze and ASPAnalyze 
:[font = special3; inactive; ]
	1.	plot the time-domain signal,
:[font = special3; inactive; ]
	2.	take its transform (z-transform for digital signals and Laplace
		transform for analog signals),
:[font = special3; inactive; ]
	3.	determine conditions on the free parameters for the signal
		to be stable,
:[font = special3; inactive; ]
	4.	display the pole-zero diagram, and
:[font = special3; inactive; ]
	5.	compute and plots the frequency response (if it exists).
:[font = text; inactive; ]
		Since the digital analysis performed by DSPAnalyze is similar to the analog analysis by ASPAnalyze, we have included one example.  Here is the analysis of a two-sided decaying one-dimensional discrete-time exponential signal:
:[font = input; startGroup; Cclosed; ]
DSPAnalyze[ a^Abs[n], n, -10, 10, a -> 4/5 ]
:[font = print; inactive; startGroup; ]
For plotting only, these symbols will
:[font = print; inactive; ]
will be assigned default values:
:[font = print; inactive; ]
      4
{a -> -}
      5
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.04762 0.01472 0.5886 [
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Msboxa
[(-10)] 0.02381 0.00222 0 1 Msboxa
[(-5)] 0.2619 0.00222 0 1 Msboxa
[(5)] 0.7381 0.00222 0 1 Msboxa
[(10)] 0.97619 0.00222 0 1 Msboxa
[(n)] 1.00625 0.01472 -1 0 Msboxa
[(0.2)] 0.4875 0.13244 1 0 Msboxa
[(0.4)] 0.4875 0.25016 1 0 Msboxa
[(0.6)] 0.4875 0.36788 1 0 Msboxa
[(0.8)] 0.4875 0.4856 1 0 Msboxa
[(1)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.02381 0.00847 moveto
0.02381 0.02097 lineto
stroke
0 setgray
[(-10)] 0.02381 0.00222 0 1 Mshowa
0.2619 0.00847 moveto
0.2619 0.02097 lineto
stroke
0 setgray
[(-5)] 0.2619 0.00222 0 1 Mshowa
0.7381 0.00847 moveto
0.7381 0.02097 lineto
stroke
0 setgray
[(5)] 0.7381 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(10)] 0.97619 0.00222 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.01472 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.13244 moveto
0.50625 0.13244 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.13244 1 0 Mshowa
0.49375 0.25016 moveto
0.50625 0.25016 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.25016 1 0 Mshowa
0.49375 0.36788 moveto
0.50625 0.36788 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.36788 1 0 Mshowa
0.49375 0.4856 moveto
0.50625 0.4856 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.4856 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(1)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.02381 0.07792 lineto
stroke
0.008 setlinewidth
0.02381 0.07792 Mdot
0.004 setlinewidth
0.07143 0.01472 moveto
0.07143 0.09372 lineto
stroke
0.008 setlinewidth
0.07143 0.09372 Mdot
0.004 setlinewidth
0.11905 0.01472 moveto
0.11905 0.11347 lineto
stroke
0.008 setlinewidth
0.11905 0.11347 Mdot
0.004 setlinewidth
0.16667 0.01472 moveto
0.16667 0.13815 lineto
stroke
0.008 setlinewidth
0.16667 0.13815 Mdot
0.004 setlinewidth
0.21429 0.01472 moveto
0.21429 0.16901 lineto
stroke
0.008 setlinewidth
0.21429 0.16901 Mdot
0.004 setlinewidth
0.2619 0.01472 moveto
0.2619 0.20759 lineto
stroke
0.008 setlinewidth
0.2619 0.20759 Mdot
0.004 setlinewidth
0.30952 0.01472 moveto
0.30952 0.25581 lineto
stroke
0.008 setlinewidth
0.30952 0.25581 Mdot
0.004 setlinewidth
0.35714 0.01472 moveto
0.35714 0.31608 lineto
stroke
0.008 setlinewidth
0.35714 0.31608 Mdot
0.004 setlinewidth
0.40476 0.01472 moveto
0.40476 0.39142 lineto
stroke
0.008 setlinewidth
0.40476 0.39142 Mdot
0.004 setlinewidth
0.45238 0.01472 moveto
0.45238 0.4856 lineto
stroke
0.008 setlinewidth
0.45238 0.4856 Mdot
0.004 setlinewidth
0.5 0.01472 moveto
0.5 0.60332 lineto
stroke
0.008 setlinewidth
0.5 0.60332 Mdot
0.004 setlinewidth
0.54762 0.01472 moveto
0.54762 0.4856 lineto
stroke
0.008 setlinewidth
0.54762 0.4856 Mdot
0.004 setlinewidth
0.59524 0.01472 moveto
0.59524 0.39142 lineto
stroke
0.008 setlinewidth
0.59524 0.39142 Mdot
0.004 setlinewidth
0.64286 0.01472 moveto
0.64286 0.31608 lineto
stroke
0.008 setlinewidth
0.64286 0.31608 Mdot
0.004 setlinewidth
0.69048 0.01472 moveto
0.69048 0.25581 lineto
stroke
0.008 setlinewidth
0.69048 0.25581 Mdot
0.004 setlinewidth
0.7381 0.01472 moveto
0.7381 0.20759 lineto
stroke
0.008 setlinewidth
0.7381 0.20759 Mdot
0.004 setlinewidth
0.78571 0.01472 moveto
0.78571 0.16901 lineto
stroke
0.008 setlinewidth
0.78571 0.16901 Mdot
0.004 setlinewidth
0.83333 0.01472 moveto
0.83333 0.13815 lineto
stroke
0.008 setlinewidth
0.83333 0.13815 Mdot
0.004 setlinewidth
0.88095 0.01472 moveto
0.88095 0.11347 lineto
stroke
0.008 setlinewidth
0.88095 0.11347 Mdot
0.004 setlinewidth
0.92857 0.01472 moveto
0.92857 0.09372 lineto
stroke
0.008 setlinewidth
0.92857 0.09372 Mdot
0.004 setlinewidth
0.97619 0.01472 moveto
0.97619 0.07792 lineto
stroke
0.008 setlinewidth
0.97619 0.07792 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
( after rewriting the two-sided expression
:[font = print; inactive; ]
   Abs[n]
  a
:[font = print; inactive; ]
  as a left-sided plus a right sided sequence
:[font = print; inactive; ]
  Step[-1 - n]    n
  ------------ + a  Step[n] )
        n
       a
:[font = print; inactive; ]
 Abs[n]
a
:[font = print; inactive; ]
has the following z-transform:
:[font = print; inactive; ]
  1       a z
----- + -------
    a   1 - a z
1 - -
    z
:[font = print; inactive; ]
The region of convergence is:
:[font = print; inactive; ]
                 1
Abs[a] < |z| < ------
               Abs[a]
:[font = print; inactive; ]
                              1
The system is stable if 1 < ------ && Abs[a] < 1
                            Abs[a]
:[font = print; inactive; ]

:[font = print; inactive; ]
The zeroes are:  {0.}
:[font = print; inactive; ]
The poles are:   {0.8, 1.25}
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.32 0.5 0.32 [
[(-1.5)] 0.02 0.4875 0 1 Msboxa
[(-1)] 0.18 0.4875 0 1 Msboxa
[(-0.5)] 0.34 0.4875 0 1 Msboxa
[(0.5)] 0.66 0.4875 0 1 Msboxa
[(1)] 0.82 0.4875 0 1 Msboxa
[(1.5)] 0.98 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1.5)] 0.4875 0.02 1 0 Msboxa
[(-1)] 0.4875 0.18 1 0 Msboxa
[(-0.5)] 0.4875 0.34 1 0 Msboxa
[(0.5)] 0.4875 0.66 1 0 Msboxa
[(1)] 0.4875 0.82 1 0 Msboxa
[(1.5)] 0.4875 0.98 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.02 0.49375 moveto
0.02 0.50625 lineto
stroke
0 setgray
[(-1.5)] 0.02 0.4875 0 1 Mshowa
0.18 0.49375 moveto
0.18 0.50625 lineto
stroke
0 setgray
[(-1)] 0.18 0.4875 0 1 Mshowa
0.34 0.49375 moveto
0.34 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.34 0.4875 0 1 Mshowa
0.66 0.49375 moveto
0.66 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.66 0.4875 0 1 Mshowa
0.82 0.49375 moveto
0.82 0.50625 lineto
stroke
0 setgray
[(1)] 0.82 0.4875 0 1 Mshowa
0.98 0.49375 moveto
0.98 0.50625 lineto
stroke
0 setgray
[(1.5)] 0.98 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.02 moveto
0.50625 0.02 lineto
stroke
0 setgray
[(-1.5)] 0.4875 0.02 1 0 Mshowa
0.49375 0.18 moveto
0.50625 0.18 lineto
stroke
0 setgray
[(-1)] 0.4875 0.18 1 0 Mshowa
0.49375 0.34 moveto
0.50625 0.34 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.34 1 0 Mshowa
0.49375 0.66 moveto
0.50625 0.66 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.66 1 0 Mshowa
0.49375 0.82 moveto
0.50625 0.82 lineto
stroke
0 setgray
[(1)] 0.4875 0.82 1 0 Mshowa
0.49375 0.98 moveto
0.50625 0.98 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.98 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.756 0.5 moveto
0.75599 0.50209 lineto
0.75597 0.50419 lineto
0.75592 0.50628 lineto
0.75586 0.50838 lineto
0.75579 0.51047 lineto
0.75569 0.51256 lineto
0.75545 0.51674 lineto
0.75514 0.52092 lineto
0.75477 0.52509 lineto
0.75381 0.53341 lineto
0.75258 0.5417 lineto
0.75108 0.54994 lineto
0.74728 0.56626 lineto
0.74241 0.58229 lineto
0.73651 0.59797 lineto
0.7217 0.628 lineto
0.7031 0.65584 lineto
0.68102 0.68102 lineto
0.65584 0.7031 lineto
0.628 0.7217 lineto
0.61323 0.7296 lineto
0.59797 0.73651 lineto
0.58229 0.74241 lineto
0.56626 0.74728 lineto
0.54994 0.75108 lineto
0.5417 0.75258 lineto
0.53341 0.75381 lineto
0.52509 0.75477 lineto
0.52092 0.75514 lineto
0.51674 0.75545 lineto
0.51256 0.75569 lineto
0.51047 0.75579 lineto
0.50838 0.75586 lineto
0.50628 0.75592 lineto
0.50419 0.75597 lineto
0.50209 0.75599 lineto
0.5 0.756 lineto
0.49791 0.75599 lineto
0.49581 0.75597 lineto
0.49372 0.75592 lineto
0.49162 0.75586 lineto
0.48744 0.75569 lineto
0.48326 0.75545 lineto
0.47908 0.75514 lineto
0.47491 0.75477 lineto
0.46659 0.75381 lineto
0.4583 0.75258 lineto
0.45006 0.75108 lineto
0.43374 0.74728 lineto
Mistroke
0.41771 0.74241 lineto
0.40203 0.73651 lineto
0.372 0.7217 lineto
0.34416 0.7031 lineto
0.31898 0.68102 lineto
0.2969 0.65584 lineto
0.2783 0.628 lineto
0.26349 0.59797 lineto
0.25759 0.58229 lineto
0.25272 0.56626 lineto
0.24892 0.54994 lineto
0.24742 0.5417 lineto
0.24619 0.53341 lineto
0.24523 0.52509 lineto
0.24486 0.52092 lineto
0.24455 0.51674 lineto
0.24431 0.51256 lineto
0.24421 0.51047 lineto
0.24414 0.50838 lineto
0.24408 0.50628 lineto
0.24403 0.50419 lineto
0.24401 0.50209 lineto
0.244 0.5 lineto
0.24401 0.49791 lineto
0.24403 0.49581 lineto
0.24408 0.49372 lineto
0.24414 0.49162 lineto
0.24431 0.48744 lineto
0.24455 0.48326 lineto
0.24486 0.47908 lineto
0.24523 0.47491 lineto
0.24619 0.46659 lineto
0.24742 0.4583 lineto
0.24892 0.45006 lineto
0.25272 0.43374 lineto
0.25759 0.41771 lineto
0.26349 0.40203 lineto
0.2783 0.372 lineto
0.2969 0.34416 lineto
0.31898 0.31898 lineto
0.34416 0.2969 lineto
0.372 0.2783 lineto
0.38677 0.2704 lineto
0.40203 0.26349 lineto
0.41771 0.25759 lineto
0.43374 0.25272 lineto
0.45006 0.24892 lineto
0.4583 0.24742 lineto
0.46659 0.24619 lineto
0.47491 0.24523 lineto
Mistroke
0.47908 0.24486 lineto
0.48326 0.24455 lineto
0.48744 0.24431 lineto
0.48953 0.24421 lineto
0.49162 0.24414 lineto
0.49372 0.24408 lineto
0.49581 0.24403 lineto
0.49791 0.24401 lineto
0.5 0.244 lineto
0.50209 0.24401 lineto
0.50419 0.24403 lineto
0.50628 0.24408 lineto
0.50838 0.24414 lineto
0.51256 0.24431 lineto
0.51674 0.24455 lineto
0.52092 0.24486 lineto
0.52509 0.24523 lineto
0.53341 0.24619 lineto
0.5417 0.24742 lineto
0.54994 0.24892 lineto
0.56626 0.25272 lineto
0.58229 0.25759 lineto
0.59797 0.26349 lineto
0.628 0.2783 lineto
0.65584 0.2969 lineto
0.68102 0.31898 lineto
0.7031 0.34416 lineto
0.7217 0.372 lineto
0.7296 0.38677 lineto
0.73651 0.40203 lineto
0.74241 0.41771 lineto
0.74728 0.43374 lineto
0.75108 0.45006 lineto
0.75258 0.4583 lineto
0.75381 0.46659 lineto
0.75477 0.47491 lineto
0.75514 0.47908 lineto
0.75545 0.48326 lineto
0.75569 0.48744 lineto
0.75579 0.48953 lineto
0.75586 0.49162 lineto
0.75592 0.49372 lineto
0.75597 0.49581 lineto
0.75599 0.49791 lineto
0.756 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.87588 0.63681 moveto
0.74056 0.58756 lineto
stroke
0.25275 0.43366 moveto
0.1171 0.38429 lineto
stroke
0.24789 0.45554 moveto
0.11125 0.4058 lineto
stroke
0.24494 0.47811 moveto
0.10658 0.42775 lineto
stroke
0.244 0.50142 moveto
0.10312 0.45014 lineto
stroke
0.24528 0.52553 moveto
0.10091 0.47299 lineto
stroke
0.24904 0.55055 moveto
0.10002 0.49631 lineto
stroke
0.25574 0.57664 moveto
0.10051 0.52014 lineto
stroke
0.2661 0.60406 moveto
0.10248 0.5445 lineto
stroke
0.28143 0.63328 moveto
0.10608 0.56946 lineto
stroke
0.30456 0.66535 moveto
0.11146 0.59507 lineto
stroke
0.34494 0.70369 moveto
0.11887 0.62141 lineto
stroke
0.68896 0.85256 moveto
0.12863 0.64861 lineto
stroke
0.66117 0.86609 moveto
0.14121 0.67684 lineto
stroke
0.62985 0.87834 moveto
0.15734 0.70636 lineto
stroke
0.59377 0.88885 moveto
0.17822 0.73761 lineto
stroke
0.55059 0.89679 moveto
0.20619 0.77144 lineto
stroke
0.49433 0.89996 moveto
0.24725 0.81003 lineto
stroke
0.75275 0.18997 moveto
0.50567 0.10004 lineto
stroke
0.79381 0.22856 moveto
0.44941 0.10321 lineto
stroke
0.82178 0.26239 moveto
0.40623 0.11115 lineto
stroke
0.84266 0.29364 moveto
0.37015 0.12166 lineto
stroke
0.85879 0.32316 moveto
0.33883 0.13391 lineto
stroke
0.87137 0.35139 moveto
0.31104 0.14744 lineto
stroke
0.51215 0.24429 moveto
0.28608 0.16201 lineto
stroke
0.45657 0.24771 moveto
0.26347 0.17743 lineto
stroke
0.41824 0.25741 moveto
0.24288 0.19358 lineto
stroke
0.38771 0.26994 moveto
0.22409 0.21039 lineto
stroke
0.36215 0.28429 moveto
0.20691 0.22779 lineto
stroke
0.34025 0.29996 moveto
0.19122 0.24572 lineto
stroke
0.32128 0.31671 moveto
0.17692 0.26417 lineto
stroke
0.30481 0.33436 moveto
0.16392 0.28308 lineto
stroke
0.29054 0.35282 moveto
0.15218 0.30246 lineto
stroke
0.27829 0.37201 moveto
0.14165 0.32227 lineto
stroke
0.26795 0.39189 moveto
0.1323 0.34252 lineto
stroke
0.25944 0.41244 moveto
0.12412 0.36319 lineto
stroke
0.8677 0.65748 moveto
0.73205 0.60811 lineto
stroke
0.8829 0.61571 moveto
0.74725 0.56634 lineto
stroke
0.85835 0.67773 moveto
0.72171 0.62799 lineto
stroke
0.88875 0.5942 moveto
0.75211 0.54446 lineto
stroke
0.84782 0.69754 moveto
0.70946 0.64718 lineto
stroke
0.89342 0.57225 moveto
0.75506 0.52189 lineto
stroke
0.83608 0.71692 moveto
0.69519 0.66564 lineto
stroke
0.89688 0.54986 moveto
0.756 0.49858 lineto
stroke
0.82308 0.73583 moveto
0.67872 0.68329 lineto
stroke
0.89909 0.52701 moveto
0.75472 0.47447 lineto
stroke
0.80878 0.75428 moveto
0.65975 0.70004 lineto
stroke
0.89998 0.50369 moveto
0.75096 0.44945 lineto
stroke
0.79309 0.77221 moveto
0.63785 0.71571 lineto
stroke
0.89949 0.47986 moveto
0.74426 0.42336 lineto
stroke
0.77591 0.78961 moveto
0.61229 0.73006 lineto
stroke
0.89752 0.4555 moveto
0.7339 0.39594 lineto
stroke
0.75712 0.80642 moveto
0.58176 0.74259 lineto
stroke
0.89392 0.43054 moveto
0.71857 0.36672 lineto
stroke
0.73653 0.82257 moveto
0.54343 0.75229 lineto
stroke
0.88854 0.40493 moveto
0.69544 0.33465 lineto
stroke
0.71392 0.83799 moveto
0.48785 0.75571 lineto
stroke
0.88113 0.37859 moveto
0.65506 0.29631 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.756 0.5 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.9 0.5 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = text; inactive; ]


:[font = print; inactive; ]
By substituting into the z-transform,
:[font = print; inactive; ]
the frequency response is
:[font = print; inactive; ]
                 I w
     1          E    a
----------- + ----------
     -I w          I w
1 - E     a   1 - E    a
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.20601 0.0103 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.19351 0 1 Msboxa
[(-4)] 0.19685 0.19351 0 1 Msboxa
[(-2)] 0.34842 0.19351 0 1 Msboxa
[(2)] 0.65158 0.19351 0 1 Msboxa
[(4)] 0.80315 0.19351 0 1 Msboxa
[(6)] 0.95473 0.19351 0 1 Msboxa
[(w)] 1.00625 0.20601 -1 0 Msboxa
[(-20)] 0.4875 0 1 0 Msboxa
[(-10)] 0.4875 0.10301 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(20)] 0.4875 0.41202 1 0 Msboxa
[(30)] 0.4875 0.51503 1 0 Msboxa
[(40)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.20601 moveto
1 0.20601 lineto
stroke
0.04527 0.19976 moveto
0.04527 0.21226 lineto
stroke
0 setgray
[(-6)] 0.04527 0.19351 0 1 Mshowa
0.19685 0.19976 moveto
0.19685 0.21226 lineto
stroke
0 setgray
[(-4)] 0.19685 0.19351 0 1 Mshowa
0.34842 0.19976 moveto
0.34842 0.21226 lineto
stroke
0 setgray
[(-2)] 0.34842 0.19351 0 1 Mshowa
0.65158 0.19976 moveto
0.65158 0.21226 lineto
stroke
0 setgray
[(2)] 0.65158 0.19351 0 1 Mshowa
0.80315 0.19976 moveto
0.80315 0.21226 lineto
stroke
0 setgray
[(4)] 0.80315 0.19351 0 1 Mshowa
0.95473 0.19976 moveto
0.95473 0.21226 lineto
stroke
0 setgray
[(6)] 0.95473 0.19351 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.20601 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0 moveto
0.50625 0 lineto
stroke
0 setgray
[(-20)] 0.4875 0 1 0 Mshowa
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(-10)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(20)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(30)] 0.4875 0.51503 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(40)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.50089 moveto
0.04365 0.42395 lineto
0.05357 0.37586 lineto
0.06349 0.33538 lineto
0.08333 0.27338 lineto
0.10317 0.2285 lineto
0.12302 0.19468 lineto
0.14286 0.16864 lineto
0.1627 0.14849 lineto
0.18254 0.13309 lineto
0.19246 0.12693 lineto
0.20238 0.1217 lineto
0.2123 0.11735 lineto
0.22222 0.11384 lineto
0.23214 0.11115 lineto
0.2371 0.11009 lineto
0.24206 0.10924 lineto
0.24702 0.10857 lineto
0.2495 0.10831 lineto
0.25198 0.1081 lineto
0.25446 0.10793 lineto
0.2557 0.10787 lineto
0.25694 0.10781 lineto
0.25818 0.10777 lineto
0.25942 0.10774 lineto
0.26066 0.10772 lineto
0.2619 0.10772 lineto
0.26314 0.10772 lineto
0.26438 0.10774 lineto
0.26562 0.10777 lineto
0.26687 0.10781 lineto
0.26935 0.10793 lineto
0.27183 0.1081 lineto
0.27431 0.10831 lineto
0.27679 0.10857 lineto
0.28175 0.10924 lineto
0.28671 0.11009 lineto
0.29167 0.11115 lineto
0.30159 0.11384 lineto
0.31151 0.11735 lineto
0.32143 0.1217 lineto
0.34127 0.13309 lineto
0.36111 0.14849 lineto
0.38095 0.16864 lineto
0.40079 0.19468 lineto
0.42063 0.2285 lineto
0.44048 0.27338 lineto
0.46032 0.33538 lineto
0.48016 0.42395 lineto
0.48512 0.44987 lineto
Mistroke
0.49008 0.47456 lineto
0.49256 0.48513 lineto
0.4938 0.48965 lineto
0.49504 0.49354 lineto
0.49628 0.49668 lineto
0.49752 0.49899 lineto
0.49876 0.50041 lineto
0.5 0.50089 lineto
0.50124 0.50041 lineto
0.50248 0.49899 lineto
0.50372 0.49668 lineto
0.50496 0.49354 lineto
0.5062 0.48965 lineto
0.50744 0.48513 lineto
0.50992 0.47456 lineto
0.51984 0.42395 lineto
0.53968 0.33538 lineto
0.5496 0.3017 lineto
0.55952 0.27338 lineto
0.57937 0.2285 lineto
0.59921 0.19468 lineto
0.61905 0.16864 lineto
0.63889 0.14849 lineto
0.65873 0.13309 lineto
0.67857 0.1217 lineto
0.68849 0.11735 lineto
0.69841 0.11384 lineto
0.70833 0.11115 lineto
0.71329 0.11009 lineto
0.71825 0.10924 lineto
0.72321 0.10857 lineto
0.72569 0.10831 lineto
0.72817 0.1081 lineto
0.73065 0.10793 lineto
0.73189 0.10787 lineto
0.73313 0.10781 lineto
0.73438 0.10777 lineto
0.73562 0.10774 lineto
0.73686 0.10772 lineto
0.7381 0.10772 lineto
0.73934 0.10772 lineto
0.74058 0.10774 lineto
0.74182 0.10777 lineto
0.74306 0.10781 lineto
0.74554 0.10793 lineto
0.74802 0.1081 lineto
0.7505 0.10831 lineto
0.75298 0.10857 lineto
0.75794 0.10924 lineto
0.7629 0.11009 lineto
Mistroke
0.76786 0.11115 lineto
0.77778 0.11384 lineto
0.7877 0.11735 lineto
0.79762 0.1217 lineto
0.81746 0.13309 lineto
0.8373 0.14849 lineto
0.85714 0.16864 lineto
0.87698 0.19468 lineto
0.89683 0.2285 lineto
0.91667 0.27338 lineto
0.93651 0.33538 lineto
0.97619 0.50089 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = text; inactive; ]


:[font = postscript; inactive; PostScript; output; endGroup; endGroup; endGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.5886 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-0.4)] 0.4875 0.07358 1 0 Msboxa
[(-0.2)] 0.4875 0.1913 1 0 Msboxa
[(0.2)] 0.4875 0.42674 1 0 Msboxa
[(0.4)] 0.4875 0.54446 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07358 moveto
0.50625 0.07358 lineto
stroke
0 setgray
[(-0.4)] 0.4875 0.07358 1 0 Mshowa
0.49375 0.1913 moveto
0.50625 0.1913 lineto
stroke
0 setgray
[(-0.2)] 0.4875 0.1913 1 0 Mshowa
0.49375 0.42674 moveto
0.50625 0.42674 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.42674 1 0 Mshowa
0.49375 0.54446 moveto
0.50625 0.54446 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.54446 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.06349 0.30902 lineto
0.10317 0.30902 lineto
0.14286 0.30902 lineto
0.18254 0.30902 lineto
0.22222 0.30902 lineto
0.2619 0.30902 lineto
0.30159 0.30902 lineto
0.34127 0.30902 lineto
0.38095 0.30902 lineto
0.42063 0.30902 lineto
0.46032 0.30902 lineto
0.5 0.30902 lineto
0.53968 0.30902 lineto
0.57937 0.30902 lineto
0.61905 0.30902 lineto
0.65873 0.30902 lineto
0.69841 0.30902 lineto
0.7381 0.30902 lineto
0.77778 0.30902 lineto
0.81746 0.30902 lineto
0.85714 0.30902 lineto
0.89683 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = subsection; inactive; startGroup; Cclosed; ]
Solving Difference and Differential Equations
:[font = text; inactive; ]
		The signal processing packages can solve linear constant coefficient (lcc) difference (via via ZSolve) and differential (LSolve) equations subject to initial conditions.  ZSolve and LSolve need to know the difference / differential equation and the function to be solved for.  Like the transform rule bases, ZSolve and LSolve can fully justify their answers.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Second-Order Difference Equation
:[font = special3; inactive; startGroup; Cclosed; center; ]
--  Without Justification  --
:[font = input; startGroup; ]
yofn =
  ZSolve[ y[n-2] + 1/2 y[n-1] + 1/4 y[n] == 0,
          y[n], y[1] -> 1, Dialogue -> False ]
:[font = output; inactive; output; endGroup; endGroup; ]
(2^n*Sin[(2*Pi*n)/3]*Step[n])/3^(1/2)
;[o]
 n     2 Pi n
2  Sin[------] Step[n]
         3
----------------------
       Sqrt[3]
:[font = special3; inactive; startGroup; Cclosed; center; ]
--  With Partial Justification   --
:[font = input; startGroup; ]
yofn =
  ZSolve[ y[n-2] + 1/2 y[n-1] + 1/4 y[n] == 0,
          y[n], y[1] -> 1 ]
:[font = print; inactive; startGroup; ]
Solving for y[n] in the difference equation
:[font = print; inactive; ]
augmented by the initial conditions:
:[font = print; inactive; ]
              y[-1 + n]   y[n]   Impulse[-1 + n]
  y[-2 + n] + --------- + ---- = ---------------
                  2        4            4
:[font = print; inactive; ]
After taking the z-transform of both sides and
:[font = print; inactive; ]
solving for the z-transform of y[n]:
:[font = print; inactive; ]
        1
  --------------
       4    2
  (1 + -- + -) z
        2   z
       z
:[font = print; inactive; ]
Inversing transforming this gives y[n]:
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
(2^n*Sin[(2*Pi*n)/3]*Step[n])/3^(1/2)
;[o]
 n     2 Pi n
2  Sin[------] Step[n]
         3
----------------------
       Sqrt[3]
:[font = special3; inactive; startGroup; Cclosed; center; ]
--  Verifying the Result  --
:[font = text; inactive; ]
		Assuming that the value of y[n] determined by ZSolve has been
		assigned to the variable yofn, we can verify that yofn is indeed the
		solution.  First, we substitute yofn back into the original difference
		equation to obtain a function of n in closed form called expdiffequ:
:[font = input; startGroup; ]
expdiffequ = (yofn /. n -> n - 2) +
             1/2 (yofn /. n -> n - 1) +
             1/4 yofn
:[font = output; inactive; output; endGroup; ]
(2^(-2 + n)*Sin[(2*Pi*(-2 + n))/3]*Step[-2 + n])/3^(1/2) + 
  (2^(-1 + n)*Sin[(2*Pi*(-1 + n))/3]*Step[-1 + n])/
   (2*3^(1/2)) + (2^n*Sin[(2*Pi*n)/3]*Step[n])/(4*3^(1/2))
;[o]
 -2 + n     2 Pi (-2 + n)
2       Sin[-------------] Step[-2 + n]
                  3
--------------------------------------- + 
                  1/2
                 3
 
   -1 + n     2 Pi (-1 + n)
  2       Sin[-------------] Step[-1 + n]
                    3
  --------------------------------------- + 
                     1/2
                  2 3
 
   n     2 Pi n
  2  Sin[------] Step[n]
           3
  ----------------------
             1/2
          4 3
:[font = text; inactive; ]
		We can then ask for the values of the difference equation, which has
		been assign to expdiffequ, for n = 0 to n = 10.  Here, y[1] = 1/4 and
		y[0] = 0 which agrees with the initial conditions.  The difference
		equation should produce 0 for all values of n greater than 1:
:[font = input; startGroup; ]
Table[expdiffequ, {n, 0, 10} ]
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
{0, 1/4, 0, 0, 0, 0, 0, 0, 0, 0, 0}
;[o]
    1
{0, -, 0, 0, 0, 0, 0, 0, 0, 0, 0}
    4
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Second-Order Differential Equation
:[font = special3; inactive; startGroup; Cclosed; center; ]
-- With Full Justification  --
:[font = input; startGroup; ]
yoft =
  LSolve[ y''[t] + 3/2 y'[t] + 1/2 y[t] ==
          Exp[a t] CStep[t], y[t], y[0] -> 4,
          y'[0] -> 4, Dialogue -> All ]
:[font = print; inactive; startGroup; ]
Solving for y[t] in the differential equation
:[font = print; inactive; ]
  y[t]   3 y'[t]             a t
  ---- + ------- + y''[t] = E    CStep[t]
   2        2
:[font = print; inactive; ]
  subject to the initial conditions
:[font = print; inactive; ]
  {y[0] -> 4, y'[0] -> 4}
:[font = print; inactive; ]

:[font = print; inactive; ]
The Laplace transform of the left side is:
:[font = print; inactive; ]
              1   3 s    2    3 y[0]
  L { y[t] } (- + --- + s ) - ------ - s y[0] - y'[0]
              2    2            2
:[font = print; inactive; ]
( In the general case, the bilateral Laplace
:[font = print; inactive; ]
  transform of the nth derivative of y[t] is:
:[font = print; inactive; ]
                                    -1 + n
      (n)                    n     s       y[t0]
  L {y   [t] } = L { y[t] } s  + -(-------------) + 
                                        s t0
                                       E
 
     -2 + n                    (-1 + n)
    s       y'[t0]            y        [t0]
  -(--------------) + ... + -(-------------)
         s t0                      s t0
        E                         E
:[font = print; inactive; ]
  where t=t0 is the initial condition. )
:[font = print; inactive; ]

:[font = print; inactive; ]
The Laplace transform of the right side is:
:[font = print; inactive; ]
    1
  -----
  s - a
:[font = print; inactive; ]
Solving for the unknown transform yields
:[font = print; inactive; ]
    1     3 y[0]
  ----- + ------ + s y[0] + y'[0]
  s - a     2
  -------------------------------
           1   3 s    2
           - + --- + s
           2    2
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
               1
  10 + 4 s + -----
             s - a
  ----------------
    1   3 s    2
    - + --- + s
    2    2
:[font = print; inactive; ]
Inverse transforming this gives y[t]:
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
((-24 - 64*a)*CStep[t])/(2*E^(t/2)*(-1 - 2*a)) + 
  ((10 + 12*a)*CStep[t])/(E^t*(-1 - a)) - 
  (2*E^(a*t)*CStep[t])/(-1 - 3*a - 2*a^2)
;[o]
(-24 - 64 a) CStep[t]   (10 + 12 a) CStep[t]
--------------------- + -------------------- - 
     t/2                     t
  2 E    (-1 - 2 a)         E  (-1 - a)
 
     a t
  2 E    CStep[t]
  ---------------
                2
  -1 - 3 a - 2 a
:[font = special3; inactive; startGroup; Cclosed; center; ]
--  Interpreting and Verifying the Solution  --
:[font = text; inactive; ]
		Assuming that the value of y(t) determined by LSolve has been
		assigned to the variable yoft, we can verify that yofn is indeed the
		solution.  First, we interpret the solution for t >= 0+ so we can
		replace all of the continuous step functions of by 1:
:[font = input; startGroup; ]
yoftpos = yoft /. { CStep[t] -> 1 }
:[font = output; inactive; output; endGroup; ]
(-24 - 64*a)/(2*E^(t/2)*(-1 - 2*a)) + 
  (10 + 12*a)/(E^t*(-1 - a)) - 
  (2*E^(a*t))/(-1 - 3*a - 2*a^2)
;[o]
                                         a t
   -24 - 64 a        10 + 12 a        2 E
----------------- + ----------- - ---------------
   t/2               t                          2
2 E    (-1 - 2 a)   E  (-1 - a)   -1 - 3 a - 2 a
:[font = text; inactive; ]
		We can now plot y(t) for positive values of t.  However, we must
		give a value to the parameter a (which controls the damping of the
		driving function in the differential equation).  Here, we have chosen
		to set a to 2:
:[font = input; startGroup; ]
Plot[ yoftpos /. a -> -2, {t, 0, 10} ]
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.09524 0.01472 0.10759 [
[(2)] 0.21429 0.00222 0 1 Msboxa
[(4)] 0.40476 0.00222 0 1 Msboxa
[(6)] 0.59524 0.00222 0 1 Msboxa
[(8)] 0.78571 0.00222 0 1 Msboxa
[(10)] 0.97619 0.00222 0 1 Msboxa
[(1)] 0.01131 0.1223 1 0 Msboxa
[(2)] 0.01131 0.22989 1 0 Msboxa
[(3)] 0.01131 0.33747 1 0 Msboxa
[(4)] 0.01131 0.44506 1 0 Msboxa
[(5)] 0.01131 0.55265 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.21429 0.00847 moveto
0.21429 0.02097 lineto
stroke
0 setgray
[(2)] 0.21429 0.00222 0 1 Mshowa
0.40476 0.00847 moveto
0.40476 0.02097 lineto
stroke
0 setgray
[(4)] 0.40476 0.00222 0 1 Mshowa
0.59524 0.00847 moveto
0.59524 0.02097 lineto
stroke
0 setgray
[(6)] 0.59524 0.00222 0 1 Mshowa
0.78571 0.00847 moveto
0.78571 0.02097 lineto
stroke
0 setgray
[(8)] 0.78571 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(10)] 0.97619 0.00222 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.1223 moveto
0.03006 0.1223 lineto
stroke
0 setgray
[(1)] 0.01131 0.1223 1 0 Mshowa
0.01756 0.22989 moveto
0.03006 0.22989 lineto
stroke
0 setgray
[(2)] 0.01131 0.22989 1 0 Mshowa
0.01756 0.33747 moveto
0.03006 0.33747 lineto
stroke
0 setgray
[(3)] 0.01131 0.33747 1 0 Mshowa
0.01756 0.44506 moveto
0.03006 0.44506 lineto
stroke
0 setgray
[(4)] 0.01131 0.44506 1 0 Mshowa
0.01756 0.55265 moveto
0.03006 0.55265 lineto
stroke
0 setgray
[(5)] 0.01131 0.55265 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.44506 moveto
0.03373 0.48593 lineto
0.04365 0.5194 lineto
0.05357 0.54621 lineto
0.06349 0.56706 lineto
0.06845 0.57544 lineto
0.07341 0.58258 lineto
0.08333 0.59339 lineto
0.08829 0.5972 lineto
0.09077 0.59874 lineto
0.09325 0.60004 lineto
0.09573 0.60111 lineto
0.09821 0.60196 lineto
0.09945 0.60231 lineto
0.10069 0.6026 lineto
0.10193 0.60285 lineto
0.10317 0.60304 lineto
0.10441 0.60318 lineto
0.10565 0.60327 lineto
0.10689 0.60332 lineto
0.10813 0.60332 lineto
0.10938 0.60327 lineto
0.11062 0.60318 lineto
0.1131 0.60286 lineto
0.11434 0.60263 lineto
0.11558 0.60236 lineto
0.11806 0.6017 lineto
0.12302 0.59991 lineto
0.12798 0.59753 lineto
0.13294 0.59459 lineto
0.14286 0.58724 lineto
0.1627 0.56764 lineto
0.18254 0.54324 lineto
0.22222 0.48632 lineto
0.2619 0.42584 lineto
0.30159 0.36722 lineto
0.34127 0.31329 lineto
0.38095 0.26531 lineto
0.42063 0.22358 lineto
0.46032 0.18786 lineto
0.5 0.15764 lineto
0.53968 0.13231 lineto
0.57937 0.11122 lineto
0.61905 0.09374 lineto
0.65873 0.07932 lineto
0.69841 0.06747 lineto
0.7381 0.05774 lineto
0.77778 0.04977 lineto
0.81746 0.04327 lineto
0.85714 0.03795 lineto
Mistroke
0.89683 0.03362 lineto
0.93651 0.03009 lineto
0.97619 0.02721 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = text; inactive; startGroup; ]
		We can also verifying that y(0+) = 4:
:[font = input; startGroup; ]
Simplify[ yoftpos /. t -> 0 ]
:[font = output; inactive; output; endGroup; endGroup; ]
4
;[o]
4
:[font = text; inactive; startGroup; ]
		We can also verifying that y'(0+) = 4.  This boils down to taking
		the derivative of y(t) and substituting t = 0+:
:[font = input; startGroup; ]
D[ yoftpos, t ]
:[font = output; inactive; output; endGroup; ]
-(-24 - 64*a)/(4*E^(t/2)*(-1 - 2*a)) - 
  (10 + 12*a)/(E^t*(-1 - a)) - 
  (2*E^(a*t)*a)/(-1 - 3*a - 2*a^2)
;[o]
                                        a t
  -(-24 - 64 a)      10 + 12 a       2 E    a
----------------- - ----------- - ---------------
   t/2               t                          2
4 E    (-1 - 2 a)   E  (-1 - a)   -1 - 3 a - 2 a
:[font = input; startGroup; ]
Simplify[ % /. t -> 0 ]
:[font = output; inactive; output; endGroup; endGroup; endGroup; endGroup; endGroup; endGroup; ]
4
;[o]
4
:[font = section; inactive; startGroup; Cclosed; pageBreak; ]
Signal Processing Notebooks
:[font = text; inactive; ]
		We have written several notebooks to accompany the signal processing packages, including tutorials on convolution, the z-transform, and analog filter design.   The tutorials are designed to accompany junior, senior, and first-year graduate engineering courses.  The other notebooks provided on-line help and training.  The LaplaceTest notebook demonstrates how-to-use the forward and inverse Laplace transform objects as well as their limitations.  Two notebooks, SignalProcessingExamples and EducationalTool, provide an overview of the signal processing packages and notebooks.  The last notebook, SignalProcessingUsage, contains an on-line reference to all of the new Mathematica objects introduced by the signal processing packages. [Evans, 1991]
:[font = subsection; inactive; startGroup; Cclosed; ]
Tutorial Notebooks
:[font = text; inactive; ]
		These tutorials present the usual text book information, but they allow the reader to tinker with mathematical models and to visualize ideas through animation.  For example, the analog filter design notebook animates the effect of filter order on filter roll-off .  The z-transform notebook illustrates the effect on a filter's magnitude response when the location of a pair of poles is slightly disturbed.  The convolution notebook animates the flip-and-slide approach to piecewise convolution.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Animation of the Flip-and-Slide View of Convolution
:[font = text; inactive; ]
		Teaching the mechanics of the flip-and-slide approach to piecewise convolution is difficult.  The following animation illustrates the method of "sliding" one function against another by showing the resulting function as it is generated in time.  We will convolve x with h.
:[font = input; startGroup; ]
x = ConvertFromList[{{2 t,0,2}},t]
:[font = output; inactive; output; endGroup; ]
2*t*CPulse[2, t]
;[o]
2 t CPulse  [t]
           2
:[font = input; startGroup; ]
h = ConvertFromList[{{2,0,2},{1,2,3}},t]
:[font = output; inactive; output; endGroup; ]
CPulse[1, -2 + t] + 2*CPulse[2, t]
;[o]
CPulse  [-2 + t] + 2 CPulse  [t]
       1                    2
:[font = text; inactive; ]
		To animate the graphics below, select the grouped closed cells and select the "Animate Selected Graphics" option (COMMAND-y) off of the Graph menu.  The new function is aligned with the leading edge of h(t-u).
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.15451 lineto
0.40823 0.15451 lineto
0.41071 0.15451 lineto
0.42063 0.15451 lineto
0.46032 0.15451 lineto
0.5 0.15451 lineto
0.53968 0.15451 lineto
0.55952 0.15451 lineto
0.57937 0.15451 lineto
0.58433 0.15451 lineto
0.58929 0.15451 lineto
0.59177 0.15451 lineto
0.59301 0.15451 lineto
0.59425 0.15451 lineto
0.59549 0.07725 lineto
0.59673 0.07725 lineto
0.59797 0.07725 lineto
0.59921 0.07725 lineto
0.61905 0.07725 lineto
0.63889 0.07725 lineto
0.65873 0.07725 lineto
0.67857 0.07725 lineto
0.68353 0.07725 lineto
0.68601 0.07725 lineto
0.68725 0.07725 lineto
0.68849 0.07725 lineto
0.68973 0.07725 lineto
0.69097 0 lineto
0.69345 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
Mistroke
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.15451 lineto
0.40823 0.15451 lineto
0.41071 0.15451 lineto
0.42063 0.15451 lineto
0.46032 0.15451 lineto
0.5 0.15451 lineto
0.53968 0.15451 lineto
0.55952 0.15451 lineto
0.57937 0.15451 lineto
0.58433 0.15451 lineto
0.58929 0.15451 lineto
0.59177 0.15451 lineto
0.59301 0.15451 lineto
0.59425 0.15451 lineto
0.59549 0.07725 lineto
0.59673 0.07725 lineto
0.59797 0.07725 lineto
0.59921 0.07725 lineto
0.61905 0.07725 lineto
0.63889 0.07725 lineto
0.65873 0.07725 lineto
0.67857 0.07725 lineto
0.68353 0.07725 lineto
0.68601 0.07725 lineto
0.68725 0.07725 lineto
0.68849 0.07725 lineto
0.68973 0.07725 lineto
0.69097 0 lineto
0.69345 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
Mistroke
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.15451 lineto
0.40823 0.15451 lineto
0.41071 0.15451 lineto
0.42063 0.15451 lineto
0.46032 0.15451 lineto
0.5 0.15451 lineto
0.53968 0.15451 lineto
0.55952 0.15451 lineto
0.57937 0.15451 lineto
0.58433 0.15451 lineto
0.58929 0.15451 lineto
0.59177 0.15451 lineto
0.59301 0.15451 lineto
0.59425 0.15451 lineto
0.59549 0.07725 lineto
0.59673 0.07725 lineto
0.59797 0.07725 lineto
0.59921 0.07725 lineto
0.61905 0.07725 lineto
0.63889 0.07725 lineto
0.65873 0.07725 lineto
0.67857 0.07725 lineto
0.68353 0.07725 lineto
0.68601 0.07725 lineto
0.68725 0.07725 lineto
0.68849 0.07725 lineto
0.68973 0.07725 lineto
0.69097 0 lineto
0.69345 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
Mistroke
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.15451 lineto
0.40823 0.15451 lineto
0.41071 0.15451 lineto
0.42063 0.15451 lineto
0.46032 0.15451 lineto
0.5 0.15451 lineto
0.53968 0.15451 lineto
0.55952 0.15451 lineto
0.57937 0.15451 lineto
0.58433 0.15451 lineto
0.58929 0.15451 lineto
0.59177 0.15451 lineto
0.59301 0.15451 lineto
0.59425 0.15451 lineto
0.59549 0.07725 lineto
0.59673 0.07725 lineto
0.59797 0.07725 lineto
0.59921 0.07725 lineto
0.61905 0.07725 lineto
0.63889 0.07725 lineto
0.65873 0.07725 lineto
0.67857 0.07725 lineto
0.68353 0.07725 lineto
0.68601 0.07725 lineto
0.68725 0.07725 lineto
0.68849 0.07725 lineto
0.68973 0.07725 lineto
0.69097 0 lineto
0.69345 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
Mistroke
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.15451 lineto
0.40823 0.15451 lineto
0.41071 0.15451 lineto
0.42063 0.15451 lineto
0.46032 0.15451 lineto
0.5 0.15451 lineto
0.53968 0.15451 lineto
0.55952 0.15451 lineto
0.57937 0.15451 lineto
0.58433 0.15451 lineto
0.58929 0.15451 lineto
0.59177 0.15451 lineto
0.59301 0.15451 lineto
0.59425 0.15451 lineto
0.59549 0.07725 lineto
0.59673 0.07725 lineto
0.59797 0.07725 lineto
0.59921 0.07725 lineto
0.61905 0.07725 lineto
0.63889 0.07725 lineto
0.65873 0.07725 lineto
0.67857 0.07725 lineto
0.68353 0.07725 lineto
0.68601 0.07725 lineto
0.68725 0.07725 lineto
0.68849 0.07725 lineto
0.68973 0.07725 lineto
0.69097 0 lineto
0.69345 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
Mistroke
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.08333 0 lineto
0.09325 0 lineto
0.10317 0 lineto
0.1131 0 lineto
0.11558 0 lineto
0.11682 0 lineto
0.11806 0 lineto
0.1193 0.07725 lineto
0.12054 0.07725 lineto
0.12178 0.07725 lineto
0.12302 0.07725 lineto
0.14286 0.07725 lineto
0.1627 0.07725 lineto
0.18254 0.07725 lineto
0.20238 0.07725 lineto
0.20734 0.07725 lineto
0.20982 0.07725 lineto
0.21106 0.07725 lineto
0.2123 0.07725 lineto
0.21354 0.07725 lineto
0.21478 0.15451 lineto
0.21602 0.15451 lineto
0.21726 0.15451 lineto
0.22222 0.15451 lineto
0.2619 0.15451 lineto
0.30159 0.15451 lineto
0.34127 0.15451 lineto
0.36111 0.15451 lineto
0.38095 0.15451 lineto
0.39087 0.15451 lineto
0.39583 0.15451 lineto
0.40079 0.15451 lineto
0.40203 0.15451 lineto
0.40327 0.15451 lineto
0.40451 0.15451 lineto
0.40575 0 lineto
0.40823 0 lineto
0.41071 0 lineto
0.42063 0 lineto
0.46032 0 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
Mistroke
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.08333 0 lineto
0.09325 0 lineto
0.10317 0 lineto
0.1131 0 lineto
0.11558 0 lineto
0.11682 0 lineto
0.11806 0 lineto
0.1193 0.07725 lineto
0.12054 0.07725 lineto
0.12178 0.07725 lineto
0.12302 0.07725 lineto
0.14286 0.07725 lineto
0.1627 0.07725 lineto
0.18254 0.07725 lineto
0.20238 0.07725 lineto
0.20734 0.07725 lineto
0.20982 0.07725 lineto
0.21106 0.07725 lineto
0.2123 0.07725 lineto
0.21354 0.07725 lineto
0.21478 0.15451 lineto
0.21602 0.15451 lineto
0.21726 0.15451 lineto
0.22222 0.15451 lineto
0.2619 0.15451 lineto
0.30159 0.15451 lineto
0.34127 0.15451 lineto
0.36111 0.15451 lineto
0.38095 0.15451 lineto
0.39087 0.15451 lineto
0.39583 0.15451 lineto
0.40079 0.15451 lineto
0.40203 0.15451 lineto
0.40327 0.15451 lineto
0.40451 0.15451 lineto
0.40575 0 lineto
0.40823 0 lineto
0.41071 0 lineto
0.42063 0 lineto
0.46032 0 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
Mistroke
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.08333 0 lineto
0.09325 0 lineto
0.10317 0 lineto
0.1131 0 lineto
0.11558 0 lineto
0.11682 0 lineto
0.11806 0 lineto
0.1193 0.07725 lineto
0.12054 0.07725 lineto
0.12178 0.07725 lineto
0.12302 0.07725 lineto
0.14286 0.07725 lineto
0.1627 0.07725 lineto
0.18254 0.07725 lineto
0.20238 0.07725 lineto
0.20734 0.07725 lineto
0.20982 0.07725 lineto
0.21106 0.07725 lineto
0.2123 0.07725 lineto
0.21354 0.07725 lineto
0.21478 0.15451 lineto
0.21602 0.15451 lineto
0.21726 0.15451 lineto
0.22222 0.15451 lineto
0.2619 0.15451 lineto
0.30159 0.15451 lineto
0.34127 0.15451 lineto
0.36111 0.15451 lineto
0.38095 0.15451 lineto
0.39087 0.15451 lineto
0.39583 0.15451 lineto
0.40079 0.15451 lineto
0.40203 0.15451 lineto
0.40327 0.15451 lineto
0.40451 0.15451 lineto
0.40575 0 lineto
0.40823 0 lineto
0.41071 0 lineto
0.42063 0 lineto
0.46032 0 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
Mistroke
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.08333 0 lineto
0.09325 0 lineto
0.10317 0 lineto
0.1131 0 lineto
0.11558 0 lineto
0.11682 0 lineto
0.11806 0 lineto
0.1193 0.07725 lineto
0.12054 0.07725 lineto
0.12178 0.07725 lineto
0.12302 0.07725 lineto
0.14286 0.07725 lineto
0.1627 0.07725 lineto
0.18254 0.07725 lineto
0.20238 0.07725 lineto
0.20734 0.07725 lineto
0.20982 0.07725 lineto
0.21106 0.07725 lineto
0.2123 0.07725 lineto
0.21354 0.07725 lineto
0.21478 0.15451 lineto
0.21602 0.15451 lineto
0.21726 0.15451 lineto
0.22222 0.15451 lineto
0.2619 0.15451 lineto
0.30159 0.15451 lineto
0.34127 0.15451 lineto
0.36111 0.15451 lineto
0.38095 0.15451 lineto
0.39087 0.15451 lineto
0.39583 0.15451 lineto
0.40079 0.15451 lineto
0.40203 0.15451 lineto
0.40327 0.15451 lineto
0.40451 0.15451 lineto
0.40575 0 lineto
0.40823 0 lineto
0.41071 0 lineto
0.42063 0 lineto
0.46032 0 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
Mistroke
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.08333 0 lineto
0.09325 0 lineto
0.10317 0 lineto
0.1131 0 lineto
0.11558 0 lineto
0.11682 0 lineto
0.11806 0 lineto
0.1193 0.07725 lineto
0.12054 0.07725 lineto
0.12178 0.07725 lineto
0.12302 0.07725 lineto
0.14286 0.07725 lineto
0.1627 0.07725 lineto
0.18254 0.07725 lineto
0.20238 0.07725 lineto
0.20734 0.07725 lineto
0.20982 0.07725 lineto
0.21106 0.07725 lineto
0.2123 0.07725 lineto
0.21354 0.07725 lineto
0.21478 0.15451 lineto
0.21602 0.15451 lineto
0.21726 0.15451 lineto
0.22222 0.15451 lineto
0.2619 0.15451 lineto
0.30159 0.15451 lineto
0.34127 0.15451 lineto
0.36111 0.15451 lineto
0.38095 0.15451 lineto
0.39087 0.15451 lineto
0.39583 0.15451 lineto
0.40079 0.15451 lineto
0.40203 0.15451 lineto
0.40327 0.15451 lineto
0.40451 0.15451 lineto
0.40575 0 lineto
0.40823 0 lineto
0.41071 0 lineto
0.42063 0 lineto
0.46032 0 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
Mistroke
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.08333 0 lineto
0.09325 0 lineto
0.10317 0 lineto
0.1131 0 lineto
0.11558 0 lineto
0.11682 0 lineto
0.11806 0 lineto
0.1193 0.07725 lineto
0.12054 0.07725 lineto
0.12178 0.07725 lineto
0.12302 0.07725 lineto
0.14286 0.07725 lineto
0.1627 0.07725 lineto
0.18254 0.07725 lineto
0.20238 0.07725 lineto
0.20734 0.07725 lineto
0.20982 0.07725 lineto
0.21106 0.07725 lineto
0.2123 0.07725 lineto
0.21354 0.07725 lineto
0.21478 0.15451 lineto
0.21602 0.15451 lineto
0.21726 0.15451 lineto
0.22222 0.15451 lineto
0.2619 0.15451 lineto
0.30159 0.15451 lineto
0.34127 0.15451 lineto
0.36111 0.15451 lineto
0.38095 0.15451 lineto
0.39087 0.15451 lineto
0.39583 0.15451 lineto
0.40079 0.15451 lineto
0.40203 0.15451 lineto
0.40327 0.15451 lineto
0.40451 0.15451 lineto
0.40575 0 lineto
0.40823 0 lineto
0.41071 0 lineto
0.42063 0 lineto
0.46032 0 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
Mistroke
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.38095 0 lineto
0.42063 0 lineto
0.46032 0 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.08333 0 lineto
0.10317 0 lineto
0.1131 0 lineto
0.12302 0 lineto
0.12798 0 lineto
0.13294 0 lineto
0.13542 0 lineto
0.13666 0 lineto
0.1379 0 lineto
0.13914 0.07725 lineto
0.14038 0.07725 lineto
0.14286 0.07725 lineto
0.18254 0.07725 lineto
0.20238 0.07725 lineto
0.2123 0.07725 lineto
0.22222 0.07725 lineto
0.22718 0.07725 lineto
0.22966 0.07725 lineto
0.2309 0.07725 lineto
0.23214 0.07725 lineto
0.23338 0.15451 lineto
0.23462 0.15451 lineto
0.2371 0.15451 lineto
0.24206 0.15451 lineto
0.2619 0.15451 lineto
0.30159 0.15451 lineto
0.34127 0.15451 lineto
0.38095 0.15451 lineto
0.40079 0.15451 lineto
0.41071 0.15451 lineto
0.41567 0.15451 lineto
0.41815 0.15451 lineto
0.42063 0.15451 lineto
0.42188 0.15451 lineto
0.42312 0.15451 lineto
0.42436 0 lineto
0.4256 0 lineto
0.42808 0 lineto
0.43056 0 lineto
0.44048 0 lineto
0.46032 0 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
Mistroke
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.42188 0.00499 lineto
0.42312 0.00574 lineto
0.42436 0 lineto
0.4256 0 lineto
0.42808 0 lineto
0.43056 0 lineto
0.44048 0 lineto
0.46032 0 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.12302 0 lineto
0.14286 0 lineto
0.14782 0 lineto
0.1503 0 lineto
0.15278 0 lineto
0.15402 0 lineto
0.15526 0 lineto
0.1565 0 lineto
0.15774 0.07725 lineto
0.15898 0.07725 lineto
0.16022 0.07725 lineto
0.1627 0.07725 lineto
0.18254 0.07725 lineto
0.20238 0.07725 lineto
0.22222 0.07725 lineto
0.23214 0.07725 lineto
0.24206 0.07725 lineto
0.24702 0.07725 lineto
0.2495 0.07725 lineto
0.25074 0.07725 lineto
0.25198 0.07725 lineto
0.25322 0.15451 lineto
0.25446 0.15451 lineto
0.2557 0.15451 lineto
0.25694 0.15451 lineto
0.2619 0.15451 lineto
0.30159 0.15451 lineto
0.34127 0.15451 lineto
0.38095 0.15451 lineto
0.40079 0.15451 lineto
0.42063 0.15451 lineto
0.43056 0.15451 lineto
0.43552 0.15451 lineto
0.438 0.15451 lineto
0.43924 0.15451 lineto
0.44048 0.15451 lineto
0.44172 0.15451 lineto
0.44296 0 lineto
0.44544 0 lineto
0.4504 0 lineto
0.46032 0 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
Mistroke
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.43552 0.01611 lineto
0.438 0.01881 lineto
0.43924 0.02025 lineto
0.44048 0.02173 lineto
0.44172 0.02326 lineto
0.44296 0 lineto
0.44544 0 lineto
0.4504 0 lineto
0.46032 0 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mistroke
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.15278 0 lineto
0.1627 0 lineto
0.16766 0 lineto
0.17262 0 lineto
0.17386 0 lineto
0.1751 0 lineto
0.17634 0.07725 lineto
0.17758 0.07725 lineto
0.18006 0.07725 lineto
0.18254 0.07725 lineto
0.22222 0.07725 lineto
0.24206 0.07725 lineto
0.25198 0.07725 lineto
0.2619 0.07725 lineto
0.26438 0.07725 lineto
0.26687 0.07725 lineto
0.26935 0.07725 lineto
0.27059 0.07725 lineto
0.27183 0.15451 lineto
0.28175 0.15451 lineto
0.30159 0.15451 lineto
0.34127 0.15451 lineto
0.38095 0.15451 lineto
0.42063 0.15451 lineto
0.44048 0.15451 lineto
0.4504 0.15451 lineto
0.45536 0.15451 lineto
0.45784 0.15451 lineto
0.46032 0.15451 lineto
0.46156 0.15451 lineto
0.4628 0 lineto
0.46528 0 lineto
0.47024 0 lineto
0.48016 0 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
Mistroke
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.45536 0.04361 lineto
0.45784 0.04799 lineto
0.46032 0.05258 lineto
0.46156 0.05495 lineto
0.4628 0 lineto
0.46528 0 lineto
0.47024 0 lineto
0.48016 0 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
Mistroke
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.1627 0 lineto
0.17262 0 lineto
0.18254 0 lineto
0.1875 0 lineto
0.18998 0 lineto
0.19246 0 lineto
0.1937 0 lineto
0.19494 0 lineto
0.19618 0.07725 lineto
0.19742 0.07725 lineto
0.20238 0.07725 lineto
0.22222 0.07725 lineto
0.2619 0.07725 lineto
0.27183 0.07725 lineto
0.27679 0.07725 lineto
0.28175 0.07725 lineto
0.28423 0.07725 lineto
0.28671 0.07725 lineto
0.28795 0.07725 lineto
0.28919 0.07725 lineto
0.29043 0.07725 lineto
0.29167 0.15451 lineto
0.29291 0.15451 lineto
0.29415 0.15451 lineto
0.29663 0.15451 lineto
0.30159 0.15451 lineto
0.34127 0.15451 lineto
0.38095 0.15451 lineto
0.42063 0.15451 lineto
0.46032 0.15451 lineto
0.47024 0.15451 lineto
0.4752 0.15451 lineto
0.47768 0.15451 lineto
0.47892 0.15451 lineto
0.48016 0.15451 lineto
0.4814 0 lineto
0.48264 0 lineto
0.48388 0 lineto
0.48512 0 lineto
0.49008 0 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
Mistroke
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.47024 0.07303 lineto
0.4752 0.08451 lineto
0.47768 0.09057 lineto
0.47892 0.09368 lineto
0.48016 0.09684 lineto
0.4814 0 lineto
0.48264 0 lineto
0.48388 0 lineto
0.48512 0 lineto
0.49008 0 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
Mistroke
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.1627 0 lineto
0.18254 0 lineto
0.20238 0 lineto
0.20734 0 lineto
0.20982 0 lineto
0.21106 0 lineto
0.2123 0 lineto
0.21354 0 lineto
0.21478 0.07725 lineto
0.21602 0.07725 lineto
0.21726 0.07725 lineto
0.22222 0.07725 lineto
0.2619 0.07725 lineto
0.28175 0.07725 lineto
0.29167 0.07725 lineto
0.29663 0.07725 lineto
0.30159 0.07725 lineto
0.30655 0.07725 lineto
0.30779 0.07725 lineto
0.30903 0.07725 lineto
0.31027 0.15451 lineto
0.31151 0.15451 lineto
0.31399 0.15451 lineto
0.31647 0.15451 lineto
0.32143 0.15451 lineto
0.34127 0.15451 lineto
0.38095 0.15451 lineto
0.42063 0.15451 lineto
0.46032 0.15451 lineto
0.47024 0.15451 lineto
0.48016 0.15451 lineto
0.49008 0.15451 lineto
0.49256 0.15451 lineto
0.49504 0.15451 lineto
0.49752 0.15451 lineto
0.49876 0.15451 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
Mistroke
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.47024 0.07303 lineto
0.48016 0.09684 lineto
0.49008 0.124 lineto
0.49256 0.13131 lineto
0.49504 0.13883 lineto
0.49752 0.14657 lineto
0.49876 0.15051 lineto
0.5 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
Mistroke
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.20238 0 lineto
0.2123 0 lineto
0.22222 0 lineto
0.22718 0 lineto
0.22966 0 lineto
0.2309 0 lineto
0.23214 0 lineto
0.23338 0.07725 lineto
0.23462 0.07725 lineto
0.2371 0.07725 lineto
0.24206 0.07725 lineto
0.2619 0.07725 lineto
0.28175 0.07725 lineto
0.30159 0.07725 lineto
0.31151 0.07725 lineto
0.31647 0.07725 lineto
0.32143 0.07725 lineto
0.32391 0.07725 lineto
0.32515 0.07725 lineto
0.32639 0.07725 lineto
0.32763 0.07725 lineto
0.32887 0.15451 lineto
0.33135 0.15451 lineto
0.34127 0.15451 lineto
0.38095 0.15451 lineto
0.42063 0.15451 lineto
0.46032 0.15451 lineto
0.48016 0.15451 lineto
0.49008 0.15451 lineto
0.5 0.15451 lineto
0.50496 0.15451 lineto
0.50992 0.15451 lineto
0.5124 0.15451 lineto
0.51488 0.15451 lineto
0.51612 0.15451 lineto
0.51736 0.15451 lineto
0.5186 0.15451 lineto
0.51984 0 lineto
0.52108 0 lineto
0.52232 0 lineto
0.5248 0 lineto
0.52976 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
Mistroke
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.49008 0.124 lineto
0.5 0.15451 lineto
0.50496 0.17102 lineto
0.50992 0.18837 lineto
0.5124 0.19736 lineto
0.51488 0.20656 lineto
0.51612 0.21124 lineto
0.51736 0.21597 lineto
0.5186 0.22076 lineto
0.51984 0 lineto
0.52108 0 lineto
0.52232 0 lineto
0.5248 0 lineto
0.52976 0 lineto
0.53968 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
Mistroke
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.20238 0 lineto
0.22222 0 lineto
0.23214 0 lineto
0.24206 0 lineto
0.24702 0 lineto
0.2495 0 lineto
0.25074 0 lineto
0.25198 0 lineto
0.25322 0.07725 lineto
0.25446 0.07725 lineto
0.2557 0.07725 lineto
0.25694 0.07725 lineto
0.2619 0.07725 lineto
0.30159 0.07725 lineto
0.32143 0.07725 lineto
0.33135 0.07725 lineto
0.33631 0.07725 lineto
0.34127 0.07725 lineto
0.34375 0.07725 lineto
0.34499 0.07725 lineto
0.34623 0.07725 lineto
0.34747 0.07725 lineto
0.34871 0.15451 lineto
0.34995 0.15451 lineto
0.35119 0.15451 lineto
0.36111 0.15451 lineto
0.38095 0.15451 lineto
0.42063 0.15451 lineto
0.46032 0.15451 lineto
0.48016 0.15451 lineto
0.5 0.15451 lineto
0.51984 0.15451 lineto
0.5248 0.15451 lineto
0.52976 0.15451 lineto
0.53472 0.15451 lineto
0.53596 0.15451 lineto
0.5372 0.15451 lineto
0.53844 0 lineto
0.53968 0 lineto
0.54216 0 lineto
0.54464 0 lineto
0.5496 0 lineto
0.55952 0 lineto
0.57937 0 lineto
0.61905 0 lineto
Mistroke
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.51984 0.22559 lineto
0.5248 0.24546 lineto
0.52976 0.26617 lineto
0.53472 0.28771 lineto
0.53596 0.29323 lineto
0.5372 0.29879 lineto
0.53844 0 lineto
0.53968 0 lineto
0.54216 0 lineto
0.54464 0 lineto
0.5496 0 lineto
0.55952 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
Mistroke
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.24206 0 lineto
0.25198 0 lineto
0.2619 0 lineto
0.26438 0 lineto
0.26687 0 lineto
0.26935 0 lineto
0.27059 0 lineto
0.27183 0.07725 lineto
0.28175 0.07725 lineto
0.30159 0.07725 lineto
0.32143 0.07725 lineto
0.34127 0.07725 lineto
0.35119 0.07725 lineto
0.35615 0.07725 lineto
0.36111 0.07725 lineto
0.36359 0.07725 lineto
0.36483 0.07725 lineto
0.36607 0.07725 lineto
0.36731 0.15451 lineto
0.36855 0.15451 lineto
0.37103 0.15451 lineto
0.38095 0.15451 lineto
0.42063 0.15451 lineto
0.46032 0.15451 lineto
0.5 0.15451 lineto
0.51984 0.15451 lineto
0.52976 0.15451 lineto
0.53968 0.15451 lineto
0.5496 0.15451 lineto
0.55208 0.15451 lineto
0.55456 0.15451 lineto
0.5558 0.15451 lineto
0.55704 0.15451 lineto
0.55828 0 lineto
0.55952 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
Mistroke
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.51984 0.22559 lineto
0.52976 0.26617 lineto
0.53968 0.31009 lineto
0.5496 0.35737 lineto
0.55208 0.36971 lineto
0.55456 0.38226 lineto
0.5558 0.38862 lineto
0.55704 0.39503 lineto
0.55828 0 lineto
0.55952 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
Mistroke
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.27183 0 lineto
0.27679 0 lineto
0.28175 0 lineto
0.28423 0 lineto
0.28671 0 lineto
0.28795 0 lineto
0.28919 0 lineto
0.29043 0 lineto
0.29167 0.07725 lineto
0.29291 0.07725 lineto
0.29415 0.07725 lineto
0.29663 0.07725 lineto
0.30159 0.07725 lineto
0.34127 0.07725 lineto
0.36111 0.07725 lineto
0.37103 0.07725 lineto
0.37599 0.07725 lineto
0.38095 0.07725 lineto
0.38219 0.07725 lineto
0.38343 0.07725 lineto
0.38467 0.07725 lineto
0.38591 0.15451 lineto
0.38839 0.15451 lineto
0.39087 0.15451 lineto
0.40079 0.15451 lineto
0.42063 0.15451 lineto
0.46032 0.15451 lineto
0.5 0.15451 lineto
0.51984 0.15451 lineto
0.53968 0.15451 lineto
0.5496 0.15451 lineto
0.55952 0.15451 lineto
0.56448 0.15451 lineto
0.56944 0.15451 lineto
0.57192 0.15451 lineto
0.57316 0.15451 lineto
0.5744 0.15451 lineto
0.57564 0.15451 lineto
0.57688 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
Mistroke
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.51984 0.22559 lineto
0.53968 0.31009 lineto
0.5496 0.35737 lineto
0.55952 0.408 lineto
0.56448 0.43457 lineto
0.56944 0.46198 lineto
0.57192 0.476 lineto
0.57316 0.48309 lineto
0.5744 0.49023 lineto
0.57564 0.49743 lineto
0.57688 0 lineto
0.57937 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
Mistroke
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.28175 0 lineto
0.29167 0 lineto
0.29663 0 lineto
0.30159 0 lineto
0.30655 0 lineto
0.30779 0 lineto
0.30903 0 lineto
0.31027 0.07725 lineto
0.31151 0.07725 lineto
0.31399 0.07725 lineto
0.31647 0.07725 lineto
0.32143 0.07725 lineto
0.34127 0.07725 lineto
0.36111 0.07725 lineto
0.38095 0.07725 lineto
0.39087 0.07725 lineto
0.39583 0.07725 lineto
0.40079 0.07725 lineto
0.40203 0.07725 lineto
0.40327 0.07725 lineto
0.40451 0.07725 lineto
0.40575 0.15451 lineto
0.40823 0.15451 lineto
0.41071 0.15451 lineto
0.42063 0.15451 lineto
0.46032 0.15451 lineto
0.5 0.15451 lineto
0.53968 0.15451 lineto
0.55952 0.15451 lineto
0.57937 0.15451 lineto
0.58433 0.15451 lineto
0.58929 0.15451 lineto
0.59177 0.15451 lineto
0.59301 0.15451 lineto
0.59425 0.15451 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
Mistroke
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.53968 0.31009 lineto
0.55952 0.408 lineto
0.57937 0.51932 lineto
0.58433 0.54925 lineto
0.58929 0.58001 lineto
0.59177 0.59571 lineto
0.59301 0.60363 lineto
0.59425 0.61161 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
Mistroke
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.28175 0 lineto
0.30159 0 lineto
0.31151 0 lineto
0.31647 0 lineto
0.32143 0 lineto
0.32391 0 lineto
0.32515 0 lineto
0.32639 0 lineto
0.32763 0 lineto
0.32887 0.07725 lineto
0.33135 0.07725 lineto
0.34127 0.07725 lineto
0.38095 0.07725 lineto
0.40079 0.07725 lineto
0.41071 0.07725 lineto
0.41567 0.07725 lineto
0.41815 0.07725 lineto
0.42063 0.07725 lineto
0.42188 0.07725 lineto
0.42312 0.07725 lineto
0.42436 0.15451 lineto
0.4256 0.15451 lineto
0.42808 0.15451 lineto
0.43056 0.15451 lineto
0.44048 0.15451 lineto
0.46032 0.15451 lineto
0.5 0.15451 lineto
0.53968 0.15451 lineto
0.57937 0.15451 lineto
0.58929 0.15451 lineto
0.59921 0.15451 lineto
0.60417 0.15451 lineto
0.60913 0.15451 lineto
0.61161 0.15451 lineto
0.61285 0.15451 lineto
0.61409 0.15451 lineto
0.61533 0 lineto
0.61657 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
Mistroke
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.53968 0.31009 lineto
0.57937 0.51932 lineto
0.58433 0.54925 lineto
0.58929 0.58001 lineto
0.59177 0.59571 lineto
0.59301 0.60363 lineto
0.59425 0.61161 lineto
0.59549 0.61803 lineto
0.59673 0.61802 lineto
0.59797 0.61797 lineto
0.59921 0.6179 lineto
0.60045 0.6178 lineto
0.60169 0.61768 lineto
0.60417 0.61735 lineto
0.60665 0.61693 lineto
0.60913 0.61639 lineto
0.61161 0.61575 lineto
Mistroke
0.61285 0.61539 lineto
0.61409 0.61501 lineto
0.61533 0 lineto
0.61657 0 lineto
0.61905 0 lineto
0.63889 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.32143 0 lineto
0.33135 0 lineto
0.33631 0 lineto
0.34127 0 lineto
0.34375 0 lineto
0.34499 0 lineto
0.34623 0 lineto
0.34747 0 lineto
0.34871 0.07725 lineto
0.34995 0.07725 lineto
0.35119 0.07725 lineto
0.36111 0.07725 lineto
0.38095 0.07725 lineto
0.40079 0.07725 lineto
0.42063 0.07725 lineto
0.43056 0.07725 lineto
0.43552 0.07725 lineto
0.438 0.07725 lineto
0.43924 0.07725 lineto
0.44048 0.07725 lineto
0.44172 0.07725 lineto
0.44296 0.15451 lineto
0.44544 0.15451 lineto
0.4504 0.15451 lineto
0.46032 0.15451 lineto
0.5 0.15451 lineto
0.53968 0.15451 lineto
0.57937 0.15451 lineto
0.59921 0.15451 lineto
0.60913 0.15451 lineto
0.61905 0.15451 lineto
0.62401 0.15451 lineto
0.62897 0.15451 lineto
0.63021 0.15451 lineto
0.63145 0.15451 lineto
0.63269 0.15451 lineto
0.63393 0 lineto
0.63641 0 lineto
0.63889 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
Mistroke
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.53968 0.31009 lineto
0.57937 0.51932 lineto
0.58433 0.54925 lineto
0.58929 0.58001 lineto
0.59177 0.59571 lineto
0.59301 0.60363 lineto
0.59425 0.61161 lineto
0.59549 0.61803 lineto
0.59673 0.61802 lineto
0.59797 0.61797 lineto
0.59921 0.6179 lineto
0.60045 0.6178 lineto
0.60169 0.61768 lineto
0.60417 0.61735 lineto
0.60665 0.61693 lineto
0.60913 0.61639 lineto
0.61409 0.61501 lineto
Mistroke
0.61905 0.61321 lineto
0.62401 0.61098 lineto
0.62897 0.60834 lineto
0.63021 0.60762 lineto
0.63145 0.60687 lineto
0.63269 0.60609 lineto
0.63393 0 lineto
0.63641 0 lineto
0.63889 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.32143 0 lineto
0.34127 0 lineto
0.35119 0 lineto
0.35615 0 lineto
0.36111 0 lineto
0.36359 0 lineto
0.36483 0 lineto
0.36607 0 lineto
0.36731 0.07725 lineto
0.36855 0.07725 lineto
0.37103 0.07725 lineto
0.38095 0.07725 lineto
0.42063 0.07725 lineto
0.44048 0.07725 lineto
0.4504 0.07725 lineto
0.45536 0.07725 lineto
0.45784 0.07725 lineto
0.46032 0.07725 lineto
0.46156 0.07725 lineto
0.4628 0.15451 lineto
0.46528 0.15451 lineto
0.47024 0.15451 lineto
0.48016 0.15451 lineto
0.5 0.15451 lineto
0.53968 0.15451 lineto
0.57937 0.15451 lineto
0.59921 0.15451 lineto
0.61905 0.15451 lineto
0.62897 0.15451 lineto
0.63889 0.15451 lineto
0.64385 0.15451 lineto
0.64633 0.15451 lineto
0.64881 0.15451 lineto
0.65005 0.15451 lineto
0.65129 0.15451 lineto
0.65253 0 lineto
0.65377 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
Mistroke
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.53968 0.31009 lineto
0.57937 0.51932 lineto
0.58433 0.54925 lineto
0.58929 0.58001 lineto
0.59177 0.59571 lineto
0.59301 0.60363 lineto
0.59425 0.61161 lineto
0.59549 0.61803 lineto
0.59673 0.61802 lineto
0.59797 0.61797 lineto
0.59921 0.6179 lineto
0.60045 0.6178 lineto
0.60169 0.61768 lineto
0.60417 0.61735 lineto
0.60665 0.61693 lineto
0.60913 0.61639 lineto
0.61409 0.61501 lineto
Mistroke
0.61905 0.61321 lineto
0.62897 0.60834 lineto
0.63889 0.60181 lineto
0.64385 0.59791 lineto
0.64633 0.5958 lineto
0.64881 0.59359 lineto
0.65005 0.59245 lineto
0.65129 0.59127 lineto
0.65253 0 lineto
0.65377 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.37103 0 lineto
0.37599 0 lineto
0.38095 0 lineto
0.38219 0 lineto
0.38343 0 lineto
0.38467 0 lineto
0.38591 0.07725 lineto
0.38839 0.07725 lineto
0.39087 0.07725 lineto
0.40079 0.07725 lineto
0.42063 0.07725 lineto
0.46032 0.07725 lineto
0.47024 0.07725 lineto
0.4752 0.07725 lineto
0.47768 0.07725 lineto
0.47892 0.07725 lineto
0.48016 0.07725 lineto
0.4814 0.15451 lineto
0.48264 0.15451 lineto
0.48388 0.15451 lineto
0.48512 0.15451 lineto
0.49008 0.15451 lineto
0.5 0.15451 lineto
0.53968 0.15451 lineto
0.57937 0.15451 lineto
0.61905 0.15451 lineto
0.63889 0.15451 lineto
0.64881 0.15451 lineto
0.65873 0.15451 lineto
0.66369 0.15451 lineto
0.66617 0.15451 lineto
0.66865 0.15451 lineto
0.66989 0.15451 lineto
0.67113 0.15451 lineto
0.67237 0 lineto
0.67361 0 lineto
0.67857 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
Mistroke
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.53968 0.31009 lineto
0.57937 0.51932 lineto
0.58433 0.54925 lineto
0.58929 0.58001 lineto
0.59177 0.59571 lineto
0.59301 0.60363 lineto
0.59425 0.61161 lineto
0.59549 0.61803 lineto
0.59673 0.61802 lineto
0.59797 0.61797 lineto
0.59921 0.6179 lineto
0.60045 0.6178 lineto
0.60169 0.61768 lineto
0.60417 0.61735 lineto
0.60665 0.61693 lineto
0.60913 0.61639 lineto
0.61409 0.61501 lineto
Mistroke
0.61905 0.61321 lineto
0.62897 0.60834 lineto
0.63889 0.60181 lineto
0.64881 0.59359 lineto
0.65873 0.5837 lineto
0.66369 0.57812 lineto
0.66617 0.57518 lineto
0.66865 0.57213 lineto
0.66989 0.57057 lineto
0.67113 0.56898 lineto
0.67237 0 lineto
0.67361 0 lineto
0.67857 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.07725 lineto
0.40823 0.07725 lineto
0.41071 0.07725 lineto
0.42063 0.07725 lineto
0.46032 0.07725 lineto
0.47024 0.07725 lineto
0.48016 0.07725 lineto
0.49008 0.07725 lineto
0.49256 0.07725 lineto
0.49504 0.07725 lineto
0.49752 0.07725 lineto
0.49876 0.07725 lineto
0.5 0.15451 lineto
0.53968 0.15451 lineto
0.57937 0.15451 lineto
0.61905 0.15451 lineto
0.63889 0.15451 lineto
0.65873 0.15451 lineto
0.67857 0.15451 lineto
0.68353 0.15451 lineto
0.68601 0.15451 lineto
0.68725 0.15451 lineto
0.68849 0.15451 lineto
0.68973 0.15451 lineto
0.69097 0 lineto
0.69345 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
Mistroke
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.53968 0.31009 lineto
0.57937 0.51932 lineto
0.58433 0.54925 lineto
0.58929 0.58001 lineto
0.59177 0.59571 lineto
0.59301 0.60363 lineto
0.59425 0.61161 lineto
0.59549 0.61803 lineto
0.59673 0.61802 lineto
0.59797 0.61797 lineto
0.59921 0.6179 lineto
0.60045 0.6178 lineto
0.60169 0.61768 lineto
0.60417 0.61735 lineto
0.60665 0.61693 lineto
0.60913 0.61639 lineto
0.61409 0.61501 lineto
Mistroke
0.61905 0.61321 lineto
0.62897 0.60834 lineto
0.63889 0.60181 lineto
0.65873 0.5837 lineto
0.67857 0.55889 lineto
0.68353 0.55164 lineto
0.68601 0.54785 lineto
0.68725 0.54592 lineto
0.68849 0.54397 lineto
0.68973 0.54198 lineto
0.69097 0 lineto
0.69345 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.38095 0 lineto
0.40079 0 lineto
0.41071 0 lineto
0.41567 0 lineto
0.41815 0 lineto
0.42063 0 lineto
0.42188 0 lineto
0.42312 0 lineto
0.42436 0.07725 lineto
0.4256 0.07725 lineto
0.42808 0.07725 lineto
0.43056 0.07725 lineto
0.44048 0.07725 lineto
0.46032 0.07725 lineto
0.48016 0.07725 lineto
0.49008 0.07725 lineto
0.5 0.07725 lineto
0.50496 0.07725 lineto
0.50992 0.07725 lineto
0.5124 0.07725 lineto
0.51488 0.07725 lineto
0.51612 0.07725 lineto
0.51736 0.07725 lineto
0.5186 0.07725 lineto
0.51984 0.15451 lineto
0.52108 0.15451 lineto
0.52232 0.15451 lineto
0.5248 0.15451 lineto
0.52976 0.15451 lineto
0.53968 0.15451 lineto
0.57937 0.15451 lineto
0.61905 0.15451 lineto
0.65873 0.15451 lineto
0.67857 0.15451 lineto
0.68849 0.15451 lineto
0.69841 0.15451 lineto
0.70337 0.15451 lineto
0.70585 0.15451 lineto
0.70709 0.15451 lineto
0.70833 0.15451 lineto
0.70957 0 lineto
Mistroke
0.71081 0 lineto
0.71329 0 lineto
0.71825 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.53968 0.31009 lineto
0.57937 0.51932 lineto
0.58433 0.54925 lineto
0.58929 0.58001 lineto
0.59177 0.59571 lineto
0.59301 0.60363 lineto
0.59425 0.61161 lineto
0.59549 0.61803 lineto
0.59673 0.61802 lineto
0.59797 0.61797 lineto
0.59921 0.6179 lineto
0.60045 0.6178 lineto
0.60169 0.61768 lineto
0.60417 0.61735 lineto
0.60665 0.61693 lineto
0.60913 0.61639 lineto
0.61409 0.61501 lineto
Mistroke
0.61905 0.61321 lineto
0.62897 0.60834 lineto
0.63889 0.60181 lineto
0.65873 0.5837 lineto
0.67857 0.55889 lineto
0.68849 0.54397 lineto
0.69841 0.52683 lineto
0.70337 0.51702 lineto
0.70585 0.51181 lineto
0.70709 0.50912 lineto
0.70833 0.50638 lineto
0.70957 0 lineto
0.71081 0 lineto
0.71329 0 lineto
0.71825 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.38095 0 lineto
0.40079 0 lineto
0.42063 0 lineto
0.43056 0 lineto
0.43552 0 lineto
0.438 0 lineto
0.43924 0 lineto
0.44048 0 lineto
0.44172 0 lineto
0.44296 0.07725 lineto
0.44544 0.07725 lineto
0.4504 0.07725 lineto
0.46032 0.07725 lineto
0.48016 0.07725 lineto
0.5 0.07725 lineto
0.51984 0.07725 lineto
0.5248 0.07725 lineto
0.52976 0.07725 lineto
0.53472 0.07725 lineto
0.53596 0.07725 lineto
0.5372 0.07725 lineto
0.53844 0.15451 lineto
0.53968 0.15451 lineto
0.54216 0.15451 lineto
0.54464 0.15451 lineto
0.5496 0.15451 lineto
0.55952 0.15451 lineto
0.57937 0.15451 lineto
0.61905 0.15451 lineto
0.65873 0.15451 lineto
0.69841 0.15451 lineto
0.70833 0.15451 lineto
0.71825 0.15451 lineto
0.72321 0.15451 lineto
0.72569 0.15451 lineto
0.72693 0.15451 lineto
0.72817 0.15451 lineto
0.72941 0 lineto
0.73065 0 lineto
0.73313 0 lineto
0.7381 0 lineto
Mistroke
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.53968 0.31009 lineto
0.57937 0.51932 lineto
0.58433 0.54925 lineto
0.58929 0.58001 lineto
0.59177 0.59571 lineto
0.59301 0.60363 lineto
0.59425 0.61161 lineto
0.59549 0.61803 lineto
0.59673 0.61802 lineto
0.59797 0.61797 lineto
0.59921 0.6179 lineto
0.60045 0.6178 lineto
0.60169 0.61768 lineto
0.60417 0.61735 lineto
0.60665 0.61693 lineto
0.60913 0.61639 lineto
0.61409 0.61501 lineto
Mistroke
0.61905 0.61321 lineto
0.62897 0.60834 lineto
0.63889 0.60181 lineto
0.65873 0.5837 lineto
0.67857 0.55889 lineto
0.69841 0.52683 lineto
0.70833 0.50638 lineto
0.71825 0.48257 lineto
0.72321 0.46941 lineto
0.72569 0.46252 lineto
0.72693 0.45899 lineto
0.72817 0.45541 lineto
0.72941 0 lineto
0.73065 0 lineto
0.73313 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.38095 0 lineto
0.42063 0 lineto
0.44048 0 lineto
0.4504 0 lineto
0.45536 0 lineto
0.45784 0 lineto
0.46032 0 lineto
0.46156 0 lineto
0.4628 0.07725 lineto
0.46528 0.07725 lineto
0.47024 0.07725 lineto
0.48016 0.07725 lineto
0.5 0.07725 lineto
0.51984 0.07725 lineto
0.52976 0.07725 lineto
0.53968 0.07725 lineto
0.5496 0.07725 lineto
0.55208 0.07725 lineto
0.55456 0.07725 lineto
0.5558 0.07725 lineto
0.55704 0.07725 lineto
0.55828 0.15451 lineto
0.55952 0.15451 lineto
0.57937 0.15451 lineto
0.61905 0.15451 lineto
0.65873 0.15451 lineto
0.69841 0.15451 lineto
0.71825 0.15451 lineto
0.72817 0.15451 lineto
0.73313 0.15451 lineto
0.7381 0.15451 lineto
0.74058 0.15451 lineto
0.74306 0.15451 lineto
0.7443 0.15451 lineto
0.74554 0.15451 lineto
0.74678 0.15451 lineto
0.74802 0 lineto
0.74926 0 lineto
0.7505 0 lineto
0.75298 0 lineto
0.75794 0 lineto
Mistroke
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.53968 0.31009 lineto
0.57937 0.51932 lineto
0.58433 0.54925 lineto
0.58929 0.58001 lineto
0.59177 0.59571 lineto
0.59301 0.60363 lineto
0.59425 0.61161 lineto
0.59549 0.61803 lineto
0.59673 0.61802 lineto
0.59797 0.61797 lineto
0.59921 0.6179 lineto
0.60045 0.6178 lineto
0.60169 0.61768 lineto
0.60417 0.61735 lineto
0.60665 0.61693 lineto
0.60913 0.61639 lineto
0.61409 0.61501 lineto
Mistroke
0.61905 0.61321 lineto
0.62897 0.60834 lineto
0.63889 0.60181 lineto
0.65873 0.5837 lineto
0.67857 0.55889 lineto
0.69841 0.52683 lineto
0.71825 0.48257 lineto
0.72817 0.45541 lineto
0.73313 0.44057 lineto
0.7381 0.4249 lineto
0.74058 0.41675 lineto
0.74306 0.40838 lineto
0.7443 0.40413 lineto
0.74554 0.39981 lineto
0.74678 0.39545 lineto
0.74802 0 lineto
0.74926 0 lineto
0.7505 0 lineto
0.75298 0 lineto
0.75794 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.38095 0 lineto
0.42063 0 lineto
0.46032 0 lineto
0.47024 0 lineto
0.4752 0 lineto
0.47768 0 lineto
0.47892 0 lineto
0.48016 0 lineto
0.4814 0.07725 lineto
0.48264 0.07725 lineto
0.48388 0.07725 lineto
0.48512 0.07725 lineto
0.49008 0.07725 lineto
0.5 0.07725 lineto
0.51984 0.07725 lineto
0.53968 0.07725 lineto
0.5496 0.07725 lineto
0.55952 0.07725 lineto
0.56448 0.07725 lineto
0.56944 0.07725 lineto
0.57192 0.07725 lineto
0.57316 0.07725 lineto
0.5744 0.07725 lineto
0.57564 0.07725 lineto
0.57688 0.15451 lineto
0.57937 0.15451 lineto
0.61905 0.15451 lineto
0.65873 0.15451 lineto
0.69841 0.15451 lineto
0.71825 0.15451 lineto
0.7381 0.15451 lineto
0.74802 0.15451 lineto
0.75298 0.15451 lineto
0.75794 0.15451 lineto
0.7629 0.15451 lineto
0.76414 0.15451 lineto
0.76538 0.15451 lineto
0.76662 0.15451 lineto
0.76786 0 lineto
0.77034 0 lineto
0.77282 0 lineto
Mistroke
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.53968 0.31009 lineto
0.57937 0.51932 lineto
0.58433 0.54925 lineto
0.58929 0.58001 lineto
0.59177 0.59571 lineto
0.59301 0.60363 lineto
0.59425 0.61161 lineto
0.59549 0.61803 lineto
0.59673 0.61802 lineto
0.59797 0.61797 lineto
0.59921 0.6179 lineto
0.60045 0.6178 lineto
0.60169 0.61768 lineto
0.60417 0.61735 lineto
0.60665 0.61693 lineto
0.60913 0.61639 lineto
0.61409 0.61501 lineto
Mistroke
0.61905 0.61321 lineto
0.62897 0.60834 lineto
0.63889 0.60181 lineto
0.65873 0.5837 lineto
0.67857 0.55889 lineto
0.69841 0.52683 lineto
0.71825 0.48257 lineto
0.7381 0.4249 lineto
0.74802 0.39103 lineto
0.75298 0.37284 lineto
0.75794 0.35381 lineto
0.7629 0.33395 lineto
0.76414 0.32885 lineto
0.76538 0.3237 lineto
0.76662 0.3185 lineto
0.76786 0 lineto
0.77034 0 lineto
0.77282 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.38095 0 lineto
0.42063 0 lineto
0.46032 0 lineto
0.48016 0 lineto
0.49008 0 lineto
0.49504 0 lineto
0.49752 0 lineto
0.49876 0 lineto
0.5 0 lineto
0.50124 0.07725 lineto
0.50248 0.07725 lineto
0.50496 0.07725 lineto
0.50992 0.07725 lineto
0.51984 0.07725 lineto
0.53968 0.07725 lineto
0.55952 0.07725 lineto
0.57937 0.07725 lineto
0.58433 0.07725 lineto
0.58929 0.07725 lineto
0.59177 0.07725 lineto
0.59301 0.07725 lineto
0.59425 0.07725 lineto
0.59549 0.15451 lineto
0.59673 0.15451 lineto
0.59797 0.15451 lineto
0.59921 0.15451 lineto
0.61905 0.15451 lineto
0.65873 0.15451 lineto
0.69841 0.15451 lineto
0.7381 0.15451 lineto
0.75794 0.15451 lineto
0.76786 0.15451 lineto
0.77778 0.15451 lineto
0.78026 0.15451 lineto
0.78274 0.15451 lineto
0.78398 0.15451 lineto
0.78522 0.15451 lineto
0.78646 0 lineto
0.7877 0 lineto
0.79762 0 lineto
0.81746 0 lineto
Mistroke
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.53968 0.31009 lineto
0.57937 0.51932 lineto
0.58433 0.54925 lineto
0.58929 0.58001 lineto
0.59177 0.59571 lineto
0.59301 0.60363 lineto
0.59425 0.61161 lineto
0.59549 0.61803 lineto
0.59673 0.61802 lineto
0.59797 0.61797 lineto
0.59921 0.6179 lineto
0.60045 0.6178 lineto
0.60169 0.61768 lineto
0.60417 0.61735 lineto
0.60665 0.61693 lineto
0.60913 0.61639 lineto
0.61409 0.61501 lineto
Mistroke
0.61905 0.61321 lineto
0.62897 0.60834 lineto
0.63889 0.60181 lineto
0.65873 0.5837 lineto
0.67857 0.55889 lineto
0.69841 0.52683 lineto
0.71825 0.48257 lineto
0.7381 0.4249 lineto
0.75794 0.35381 lineto
0.76786 0.31324 lineto
0.77778 0.26932 lineto
0.78026 0.25781 lineto
0.78274 0.2461 lineto
0.78398 0.24016 lineto
0.78522 0.23417 lineto
0.78646 0 lineto
0.7877 0 lineto
0.79762 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.38095 0 lineto
0.42063 0 lineto
0.46032 0 lineto
0.48016 0 lineto
0.49008 0 lineto
0.5 0 lineto
0.50496 0 lineto
0.50992 0 lineto
0.5124 0 lineto
0.51488 0 lineto
0.51612 0 lineto
0.51736 0 lineto
0.5186 0 lineto
0.51984 0.07725 lineto
0.52108 0.07725 lineto
0.52232 0.07725 lineto
0.5248 0.07725 lineto
0.52976 0.07725 lineto
0.53968 0.07725 lineto
0.57937 0.07725 lineto
0.58929 0.07725 lineto
0.59921 0.07725 lineto
0.60417 0.07725 lineto
0.60913 0.07725 lineto
0.61161 0.07725 lineto
0.61285 0.07725 lineto
0.61409 0.07725 lineto
0.61533 0.15451 lineto
0.61657 0.15451 lineto
0.61905 0.15451 lineto
0.65873 0.15451 lineto
0.69841 0.15451 lineto
0.7381 0.15451 lineto
0.77778 0.15451 lineto
0.7877 0.15451 lineto
0.79762 0.15451 lineto
0.8001 0.15451 lineto
0.80134 0.15451 lineto
0.80258 0.15451 lineto
0.80382 0.15451 lineto
0.80506 0 lineto
Mistroke
0.8063 0 lineto
0.80754 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.53968 0.31009 lineto
0.57937 0.51932 lineto
0.58433 0.54925 lineto
0.58929 0.58001 lineto
0.59177 0.59571 lineto
0.59301 0.60363 lineto
0.59425 0.61161 lineto
0.59549 0.61803 lineto
0.59673 0.61802 lineto
0.59797 0.61797 lineto
0.59921 0.6179 lineto
0.60045 0.6178 lineto
0.60169 0.61768 lineto
0.60417 0.61735 lineto
0.60665 0.61693 lineto
0.60913 0.61639 lineto
0.61409 0.61501 lineto
Mistroke
0.61905 0.61321 lineto
0.62897 0.60834 lineto
0.63889 0.60181 lineto
0.65873 0.5837 lineto
0.67857 0.55889 lineto
0.69841 0.52683 lineto
0.71825 0.48257 lineto
0.7381 0.4249 lineto
0.77778 0.26932 lineto
0.78274 0.2461 lineto
0.78398 0.24016 lineto
0.78522 0.23417 lineto
0.78646 0.23055 lineto
0.7877 0.22851 lineto
0.79266 0.22009 lineto
0.79762 0.21124 lineto
0.8001 0.20666 lineto
0.80134 0.20433 lineto
0.80258 0.20198 lineto
0.80382 0.1996 lineto
0.80506 0 lineto
0.8063 0 lineto
0.80754 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.38095 0 lineto
0.42063 0 lineto
0.46032 0 lineto
0.48016 0 lineto
0.5 0 lineto
0.51984 0 lineto
0.5248 0 lineto
0.52976 0 lineto
0.53472 0 lineto
0.53596 0 lineto
0.5372 0 lineto
0.53844 0.07725 lineto
0.53968 0.07725 lineto
0.54216 0.07725 lineto
0.54464 0.07725 lineto
0.5496 0.07725 lineto
0.55952 0.07725 lineto
0.57937 0.07725 lineto
0.59921 0.07725 lineto
0.60913 0.07725 lineto
0.61905 0.07725 lineto
0.62401 0.07725 lineto
0.62897 0.07725 lineto
0.63021 0.07725 lineto
0.63145 0.07725 lineto
0.63269 0.07725 lineto
0.63393 0.15451 lineto
0.63641 0.15451 lineto
0.63889 0.15451 lineto
0.65873 0.15451 lineto
0.69841 0.15451 lineto
0.7381 0.15451 lineto
0.77778 0.15451 lineto
0.79762 0.15451 lineto
0.80754 0.15451 lineto
0.8125 0.15451 lineto
0.81746 0.15451 lineto
0.81994 0.15451 lineto
0.82118 0.15451 lineto
0.82242 0.15451 lineto
0.82366 0.15451 lineto
Mistroke
0.8249 0 lineto
0.82738 0 lineto
0.8373 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.53968 0.31009 lineto
0.57937 0.51932 lineto
0.58433 0.54925 lineto
0.58929 0.58001 lineto
0.59177 0.59571 lineto
0.59301 0.60363 lineto
0.59425 0.61161 lineto
0.59549 0.61803 lineto
0.59673 0.61802 lineto
0.59797 0.61797 lineto
0.59921 0.6179 lineto
0.60045 0.6178 lineto
0.60169 0.61768 lineto
0.60417 0.61735 lineto
0.60665 0.61693 lineto
0.60913 0.61639 lineto
0.61409 0.61501 lineto
Mistroke
0.61905 0.61321 lineto
0.62897 0.60834 lineto
0.63889 0.60181 lineto
0.65873 0.5837 lineto
0.67857 0.55889 lineto
0.69841 0.52683 lineto
0.71825 0.48257 lineto
0.7381 0.4249 lineto
0.77778 0.26932 lineto
0.78274 0.2461 lineto
0.78398 0.24016 lineto
0.78522 0.23417 lineto
0.78646 0.23055 lineto
0.7877 0.22851 lineto
0.79266 0.22009 lineto
0.79762 0.21124 lineto
0.80754 0.1923 lineto
0.8125 0.1822 lineto
0.81746 0.17168 lineto
0.81994 0.16626 lineto
0.82118 0.16351 lineto
0.82242 0.16074 lineto
0.82366 0.15794 lineto
0.8249 0 lineto
0.82738 0 lineto
0.8373 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.38095 0 lineto
0.42063 0 lineto
0.46032 0 lineto
0.5 0 lineto
0.51984 0 lineto
0.52976 0 lineto
0.53968 0 lineto
0.5496 0 lineto
0.55208 0 lineto
0.55456 0 lineto
0.5558 0 lineto
0.55704 0 lineto
0.55828 0.07725 lineto
0.55952 0.07725 lineto
0.57937 0.07725 lineto
0.59921 0.07725 lineto
0.61905 0.07725 lineto
0.62897 0.07725 lineto
0.63889 0.07725 lineto
0.64385 0.07725 lineto
0.64633 0.07725 lineto
0.64881 0.07725 lineto
0.65005 0.07725 lineto
0.65129 0.07725 lineto
0.65253 0.15451 lineto
0.65377 0.15451 lineto
0.65873 0.15451 lineto
0.69841 0.15451 lineto
0.7381 0.15451 lineto
0.77778 0.15451 lineto
0.79762 0.15451 lineto
0.81746 0.15451 lineto
0.82738 0.15451 lineto
0.83234 0.15451 lineto
0.8373 0.15451 lineto
0.83978 0.15451 lineto
0.84102 0.15451 lineto
0.84226 0.15451 lineto
0.8435 0 lineto
0.84474 0 lineto
0.84722 0 lineto
Mistroke
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.53968 0.31009 lineto
0.57937 0.51932 lineto
0.58433 0.54925 lineto
0.58929 0.58001 lineto
0.59177 0.59571 lineto
0.59301 0.60363 lineto
0.59425 0.61161 lineto
0.59549 0.61803 lineto
0.59673 0.61802 lineto
0.59797 0.61797 lineto
0.59921 0.6179 lineto
0.60045 0.6178 lineto
0.60169 0.61768 lineto
0.60417 0.61735 lineto
0.60665 0.61693 lineto
0.60913 0.61639 lineto
0.61409 0.61501 lineto
Mistroke
0.61905 0.61321 lineto
0.62897 0.60834 lineto
0.63889 0.60181 lineto
0.65873 0.5837 lineto
0.67857 0.55889 lineto
0.69841 0.52683 lineto
0.71825 0.48257 lineto
0.7381 0.4249 lineto
0.77778 0.26932 lineto
0.78274 0.2461 lineto
0.78398 0.24016 lineto
0.78522 0.23417 lineto
0.78646 0.23055 lineto
0.7877 0.22851 lineto
0.79266 0.22009 lineto
0.79762 0.21124 lineto
0.80754 0.1923 lineto
0.81746 0.17168 lineto
0.82738 0.14938 lineto
0.83234 0.1376 lineto
0.8373 0.1254 lineto
0.83978 0.11915 lineto
0.84102 0.11598 lineto
0.84226 0.11279 lineto
0.8435 0 lineto
0.84474 0 lineto
0.84722 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.38095 0 lineto
0.42063 0 lineto
0.46032 0 lineto
0.5 0 lineto
0.51984 0 lineto
0.53968 0 lineto
0.5496 0 lineto
0.55952 0 lineto
0.56448 0 lineto
0.56944 0 lineto
0.57192 0 lineto
0.57316 0 lineto
0.5744 0 lineto
0.57564 0 lineto
0.57688 0.07725 lineto
0.57937 0.07725 lineto
0.61905 0.07725 lineto
0.63889 0.07725 lineto
0.64881 0.07725 lineto
0.65873 0.07725 lineto
0.66369 0.07725 lineto
0.66617 0.07725 lineto
0.66865 0.07725 lineto
0.66989 0.07725 lineto
0.67113 0.07725 lineto
0.67237 0.15451 lineto
0.67361 0.15451 lineto
0.67857 0.15451 lineto
0.69841 0.15451 lineto
0.7381 0.15451 lineto
0.77778 0.15451 lineto
0.81746 0.15451 lineto
0.8373 0.15451 lineto
0.84722 0.15451 lineto
0.85218 0.15451 lineto
0.85714 0.15451 lineto
0.85838 0.15451 lineto
0.85962 0.15451 lineto
0.86086 0.15451 lineto
0.8621 0 lineto
0.86458 0 lineto
Mistroke
0.86706 0 lineto
0.87698 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.53968 0.31009 lineto
0.57937 0.51932 lineto
0.58433 0.54925 lineto
0.58929 0.58001 lineto
0.59177 0.59571 lineto
0.59301 0.60363 lineto
0.59425 0.61161 lineto
0.59549 0.61803 lineto
0.59673 0.61802 lineto
0.59797 0.61797 lineto
0.59921 0.6179 lineto
0.60045 0.6178 lineto
0.60169 0.61768 lineto
0.60417 0.61735 lineto
0.60665 0.61693 lineto
0.60913 0.61639 lineto
0.61409 0.61501 lineto
Mistroke
0.61905 0.61321 lineto
0.62897 0.60834 lineto
0.63889 0.60181 lineto
0.65873 0.5837 lineto
0.67857 0.55889 lineto
0.69841 0.52683 lineto
0.71825 0.48257 lineto
0.7381 0.4249 lineto
0.77778 0.26932 lineto
0.78274 0.2461 lineto
0.78398 0.24016 lineto
0.78522 0.23417 lineto
0.78646 0.23055 lineto
0.7877 0.22851 lineto
0.79266 0.22009 lineto
0.79762 0.21124 lineto
0.80754 0.1923 lineto
0.81746 0.17168 lineto
0.85714 0.07243 lineto
0.85838 0.06889 lineto
0.85962 0.06533 lineto
0.86086 0.06175 lineto
0.8621 0 lineto
0.86458 0 lineto
0.86706 0 lineto
0.87698 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; endGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.40476 0.09524 0 0.07725 [
[(-4)] 0.02381 -0.0125 0 1 Msboxa
[(-2)] 0.21429 -0.0125 0 1 Msboxa
[(2)] 0.59524 -0.0125 0 1 Msboxa
[(4)] 0.78571 -0.0125 0 1 Msboxa
[(6)] 0.97619 -0.0125 0 1 Msboxa
[(1)] 0.39226 0.07725 1 0 Msboxa
[(2)] 0.39226 0.15451 1 0 Msboxa
[(3)] 0.39226 0.23176 1 0 Msboxa
[(4)] 0.39226 0.30902 1 0 Msboxa
[(5)] 0.39226 0.38627 1 0 Msboxa
[(6)] 0.39226 0.46353 1 0 Msboxa
[(7)] 0.39226 0.54078 1 0 Msboxa
[(8)] 0.39226 0.61803 1 0 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02381 -0.00625 moveto
0.02381 0.00625 lineto
stroke
0 setgray
[(-4)] 0.02381 -0.0125 0 1 Mshowa
0.21429 -0.00625 moveto
0.21429 0.00625 lineto
stroke
0 setgray
[(-2)] 0.21429 -0.0125 0 1 Mshowa
0.59524 -0.00625 moveto
0.59524 0.00625 lineto
stroke
0 setgray
[(2)] 0.59524 -0.0125 0 1 Mshowa
0.78571 -0.00625 moveto
0.78571 0.00625 lineto
stroke
0 setgray
[(4)] 0.78571 -0.0125 0 1 Mshowa
0.97619 -0.00625 moveto
0.97619 0.00625 lineto
stroke
0 setgray
[(6)] 0.97619 -0.0125 0 1 Mshowa
0.40476 0 moveto
0.40476 0.61803 lineto
stroke
0.39851 0.07725 moveto
0.41101 0.07725 lineto
stroke
0 setgray
[(1)] 0.39226 0.07725 1 0 Mshowa
0.39851 0.15451 moveto
0.41101 0.15451 lineto
stroke
0 setgray
[(2)] 0.39226 0.15451 1 0 Mshowa
0.39851 0.23176 moveto
0.41101 0.23176 lineto
stroke
0 setgray
[(3)] 0.39226 0.23176 1 0 Mshowa
0.39851 0.30902 moveto
0.41101 0.30902 lineto
stroke
0 setgray
[(4)] 0.39226 0.30902 1 0 Mshowa
0.39851 0.38627 moveto
0.41101 0.38627 lineto
stroke
0 setgray
[(5)] 0.39226 0.38627 1 0 Mshowa
0.39851 0.46353 moveto
0.41101 0.46353 lineto
stroke
0 setgray
[(6)] 0.39226 0.46353 1 0 Mshowa
0.39851 0.54078 moveto
0.41101 0.54078 lineto
stroke
0 setgray
[(7)] 0.39226 0.54078 1 0 Mshowa
0.39851 0.61803 moveto
0.41101 0.61803 lineto
stroke
0 setgray
[(8)] 0.39226 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.38095 0 lineto
0.42063 0 lineto
0.46032 0 lineto
0.5 0 lineto
0.53968 0 lineto
0.55952 0 lineto
0.57937 0 lineto
0.58433 0 lineto
0.58929 0 lineto
0.59177 0 lineto
0.59301 0 lineto
0.59425 0 lineto
0.59549 0.07725 lineto
0.59673 0.07725 lineto
0.59797 0.07725 lineto
0.59921 0.07725 lineto
0.61905 0.07725 lineto
0.63889 0.07725 lineto
0.65873 0.07725 lineto
0.67857 0.07725 lineto
0.68353 0.07725 lineto
0.68601 0.07725 lineto
0.68725 0.07725 lineto
0.68849 0.07725 lineto
0.68973 0.07725 lineto
0.69097 0.15451 lineto
0.69345 0.15451 lineto
0.69841 0.15451 lineto
0.7381 0.15451 lineto
0.77778 0.15451 lineto
0.81746 0.15451 lineto
0.85714 0.15451 lineto
0.86706 0.15451 lineto
0.87202 0.15451 lineto
0.8745 0.15451 lineto
0.87698 0.15451 lineto
0.87946 0.15451 lineto
0.8807 0.15451 lineto
0.88194 0 lineto
0.8869 0 lineto
0.89683 0 lineto
Mistroke
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 0.00161 lineto
0.40823 0.00563 lineto
0.41071 0.00966 lineto
0.42063 0.02575 lineto
0.46032 0.09013 lineto
0.5 0.15451 lineto
0.53968 0.21889 lineto
0.55952 0.25108 lineto
0.57937 0.28327 lineto
0.58433 0.29131 lineto
0.58929 0.29936 lineto
0.59177 0.30338 lineto
0.59301 0.3054 lineto
0.59425 0.30741 lineto
0.59549 0 lineto
0.59673 0 lineto
0.59797 0 lineto
0.59921 0 lineto
0.61905 0 lineto
0.65873 0 lineto
0.69841 0 lineto
0.7381 0 lineto
0.77778 0 lineto
0.81746 0 lineto
0.85714 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
stroke
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.02381 0 moveto
0.06349 0 lineto
0.10317 0 lineto
0.14286 0 lineto
0.18254 0 lineto
0.22222 0 lineto
0.2619 0 lineto
0.30159 0 lineto
0.34127 0 lineto
0.36111 0 lineto
0.38095 0 lineto
0.39087 0 lineto
0.39583 0 lineto
0.40079 0 lineto
0.40203 0 lineto
0.40327 0 lineto
0.40451 0 lineto
0.40575 2e-05 lineto
0.40699 8e-05 lineto
0.40823 0.00021 lineto
0.40947 0.00038 lineto
0.41071 0.0006 lineto
0.41319 0.00121 lineto
0.41567 0.00203 lineto
0.41815 0.00306 lineto
0.42063 0.00429 lineto
0.4256 0.00739 lineto
0.43056 0.01133 lineto
0.44048 0.02173 lineto
0.4504 0.03548 lineto
0.46032 0.05258 lineto
0.48016 0.09684 lineto
0.5 0.15451 lineto
0.53968 0.31009 lineto
0.57937 0.51932 lineto
0.58433 0.54925 lineto
0.58929 0.58001 lineto
0.59177 0.59571 lineto
0.59301 0.60363 lineto
0.59425 0.61161 lineto
0.59549 0.61803 lineto
0.59673 0.61802 lineto
0.59797 0.61797 lineto
0.59921 0.6179 lineto
0.60045 0.6178 lineto
0.60169 0.61768 lineto
0.60417 0.61735 lineto
0.60665 0.61693 lineto
0.60913 0.61639 lineto
0.61409 0.61501 lineto
Mistroke
0.61905 0.61321 lineto
0.62897 0.60834 lineto
0.63889 0.60181 lineto
0.65873 0.5837 lineto
0.67857 0.55889 lineto
0.69841 0.52683 lineto
0.71825 0.48257 lineto
0.7381 0.4249 lineto
0.77778 0.26932 lineto
0.78274 0.2461 lineto
0.78398 0.24016 lineto
0.78522 0.23417 lineto
0.78646 0.23055 lineto
0.7877 0.22851 lineto
0.79266 0.22009 lineto
0.79762 0.21124 lineto
0.80754 0.1923 lineto
0.81746 0.17168 lineto
0.85714 0.07243 lineto
0.86706 0.04342 lineto
0.87202 0.02829 lineto
0.87698 0.01274 lineto
0.87946 0.00481 lineto
0.8807 0.0008 lineto
0.88194 0 lineto
0.8869 0 lineto
0.89683 0 lineto
0.93651 0 lineto
0.97619 0 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = subsubsection; inactive; startGroup; Cclosed; pageBreak; ]
Overview of the z-Transform Notebook
:[font = text; inactive; endGroup; ]
		The z-transform notebook defines the bilateral z-transform and discusses the importance of the region of convergence (ROC).  This ROC coupled with the location of poles characterizes the stability and causality of the signal.  The notebook then explores the relationship between the z-transform and the discrete-time Fourier transform (DTFT), namely the fact that not every function with a z-transform has a DTFT and vice-versa.  The notebook comes stocked with built-in exercises and many animations, including two that show the effect on the magnitude response of slight perturbations of poles and several that show how the locations of poles and zeroes influence the magnitude response.
:[font = subsubsection; inactive; startGroup; Cclosed; pageBreak; ]
Overview of the Filter Design Notebook
:[font = text; inactive; endGroup; endGroup; ]
		The analog filter design notebook discusses the characteristics of the classical Bessel, Butterworth, Chebyshev I, Chebyshev II, and Elliptic analog filters as well as lowpass, bandpass, bandstop, and highpass magnitude responses.  It shows how to manipulate filter representations (namely how to take transforms and plot the results).  It demonstrates the effects of coefficient truncation and how to convolve an input function with a filter symbolically.  The notebook contains two animations.  One shows how the magnitude filter response varies with filter order and the other how the ripple varies with the ripple gain parameter epsilon.
:[font = subsection; inactive; startGroup; Cclosed; pageBreak; ]
Current Uses of Signal Processing Notebooks
:[font = text; inactive; ]

:[font = special2; inactive; ]
Case-Western Reserve University
:[font = special3; inactive; ]
School of EngineeringSystems
:[font = text; inactive; ]
	Laplace transforms for graduate class in Modern Controls Theory.
:[font = text; inactive; ]

:[font = special2; inactive; ]
Georgia Institute of Technology
:[font = special3; inactive; ]
School of Electrical Engineering
:[font = text; inactive; ]
	Teaching convolution and Fourier transforms in an introductory Signals and Systems class.
:[font = text; inactive; ]
	Generating problems z-transform sets and their solutions for an introductory digital signal processing class.
:[font = special3; inactive; ]
School of Mathematics
:[font = text; inactive; ]
	Teaching transform theory.
:[font = text; inactive; ]

:[font = special2; inactive; ]
Pennsylvania State University
:[font = special3; inactive; ]
Department of Civil Engineering
:[font = text; inactive; ]
	Teaching convolution  water flow (input) through soil (linear system) to find contribution to local water level (output) in graduate-level hydrology class.
:[font = text; inactive; ]

:[font = special2; inactive; ]
Rose-Hulman Institute of Technology
:[font = special3; inactive; ]
Department of Electrical Engineering
:[font = text; inactive; ]
	Teaching solving analog circuits using Laplace transforms.
:[font = special3; inactive; ]
Department of Mathematics
:[font = text; inactive; ]
	Teaching how to solve differential equations using Laplace transforms.
:[font = text; inactive; ]

:[font = special2; inactive; ]
Stanford University
:[font = special3; inactive; ]
Department of Electrical Engineering
:[font = text; inactive; ]
	Teaching convolution and Fourier transforms in a sophomore class.
:[font = special3; inactive; ]
Department of Music
:[font = text; inactive; ]
	Teaching Fourier transforms and spectral properties of windows.
:[font = text; inactive; ]

:[font = special2; inactive; ]
University of the Pacific
:[font = special3; inactive; ]
Department of Electrical Engineering
:[font = text; inactive; ]
	Teaching convolution (discrete and continuous) as well as z- and Laplace transforms.
:[font = text; inactive; ]

:[font = special2; inactive; ]
University of Pennsylvannia
:[font = special3; inactive; ]
Department of Electrical Engineering
:[font = text; inactive; endGroup; endGroup; ]
	Computer projects for class on Signals and Linear Systems.
:[font = section; inactive; startGroup; Cclosed; ]
Summary
:[font = text; inactive; ]
		Several schools (Rose-Hulman, University of Illinois, etc.) are experimenting with integrating Mathematica into the freshmen curriculum.   The signal processing packages and notebooks are an attempt at developing the extensions for classes at a higher level, namely those that teach linear systems, signal processing, and transform methods.  This means that engineering, mathematics, chemistry, and physics students can benefit from these extensions.
:[font = subsection; inactive; startGroup; Cclosed; ]
Signal Processing Packages
:[font = text; inactive; ]
    	 The signal processing packages implement a wide range of topics from linear systems theory from an engineering perspective.  These packages provide many functions and operators common in linear systems theory and signal processing that are not defined in Mathematica: [Evans, 1990]
:[font = text; inactive; ]

:[font = special3; inactive; center; ]
discrete signals
:[font = network; inactive; center; ]
 z-transform
discrete-time Fourier transform
discrete Fourier transform
:[font = network; inactive; center; ]
 one-dimensional convolution
solving lcc difference equations
:[font = network; inactive; center; ]
 signal analysis
:[font = text; inactive; ]

:[font = special3; inactive; center; ]
continuous signals
:[font = network; inactive; center; ]
Laplace transform *
Fourier transform *
:[font = network; inactive; center; ]
one-dimensional piecewise convolution
solving lcc differential equations
:[font = network; inactive; center; ]
 signal analysis
:[font = network; inactive; center; ]
one-dimensional analog filter design
:[font = text; inactive; ]

:[font = special3; inactive; center; ]
general plotting
:[font = network; inactive; center; ]
1-D and 2-D signals and sequences
frequency responses
pole-zero diagrams
root loci
:[font = text; inactive; endGroup; ]
*  Although Mathematica 2.0 comes with some Laplace  and  Fourier
     transform capabilities (written from a mathematicians point of view), 
     it will not be able to transform expressions common  in  signal
     processing because Mathematica 2.0 manipulates mathematical
     formulas not signal processing expressions.  Besides, Mathematica's
     implementation is for one-dimensional, one-sided functions, whereas
     ours handles two-sided and multidimensional functions.
:[font = subsection; inactive; startGroup; Cclosed; ]
Signal Processing Notebooks
:[font = text; inactive; ]
		So far, seven notebooks (besides the one you are presently reading) describe the signal processing packages.  Three serve as tutorials on the z-transform, convolution, and analog filter design.  The others serve as on-line help.  Together, these notebooks allow students to read about signal processing, tinker with equations, and visualize ideas through animation [Evans, 1991].  With Mathematica 2.0, students will also be able to learn through hearing.  As a multimedia tool, Mathematica can enhance the learning process and make it more enjoyable.
:[font = text; inactive; ]

:[font = subtitle; inactive; startGroup; ]
Tutorial Notebooks
:[font = special2; inactive; ]
Convolution
:[font = special2; inactive; ]
z-Transform
:[font = special2; inactive; endGroup; ]
Analog Filter Design
:[font = text; inactive; ]

:[font = subtitle; inactive; startGroup; ]
Demonstration Notebooks
:[font = special2; inactive; endGroup; ]
Laplace Transforms
:[font = text; inactive; ]

:[font = subtitle; inactive; startGroup; ]
On-Line Documentation
:[font = special2; inactive; ]
Usage Information
:[font = special2; inactive; ]
Overview with Examples
:[font = special2; inactive; endGroup; endGroup; endGroup; ]
Southeastcon Paper
:[font = section; inactive; startGroup; Cclosed; ]
References
:[font = subsection; inactive; startGroup; Cclosed; ]
[Clements and Pease 1989]
:[font = text; inactive; endGroup; ]
M. A. Clements and J. P. Pease. 1989.  ``On Causal Linear Phase IIR Digital Filters,''  {IEEE Transactions on Acoustics, Speech, and Signal Processing},  vol.  37 (4), pp. 479-484.
:[font = subsection; inactive; startGroup; Cclosed; ]
[Churchill 1978]
:[font = text; inactive; endGroup; ]
R. Churchill.  1958. {Operational Mathematics}.  McGraw-Hill, New York.
:[font = subsection; inactive; startGroup; Cclosed; ]
[Covell 1989]
:[font = text; inactive; endGroup; ]
M. M. Covell. 1989.  {An Algorithm Design Environment for Signal Processing}.  Ph.  D. Thesis and RLE Tech. Rep. #549.  MIT, Cambridge (MA).
:[font = subsection; inactive; startGroup; Cclosed; ]
[Dudgeon & Mersereau 1984]
:[font = text; inactive; endGroup; ]
D. E. Dudgeon and R. M. Mersereau. 1984.  {Multidimensional Digital Signal Processing}.  Prentice Hall, Englewood Cliffs (NJ).
:[font = subsection; inactive; startGroup; Cclosed; ]
[Evans 1990]
:[font = text; inactive; endGroup; ]
B. L. Evans, J. H. McClellan, and W. B. McClure.  1990.  "Symbolic Transforms with Application to Signal Processing."  {The Mathematica Journal}.  Fall, 1990.  vol. 1, issue #2, pp. 70-80.
:[font = subsection; inactive; startGroup; Cclosed; ]
[Evans 1991]
:[font = text; inactive; endGroup; ]
B. L. Evans, J. H. McClellan, and K. A. West.  "Mathematica As An Educational Tool for Signal Processing".  {Proc. of IEEE Southeastern Conference}.  April, 1991.  pp. 1172-1176.
:[font = subsection; inactive; startGroup; Cclosed; ]
[Kopec 1980]
:[font = text; inactive; endGroup; ]
G. Kopec. 1980.  {The Representation of Discrete-Time Signals and Systems in Programs.}  Ph. D. Thesis. MIT, Cambridge (MA).
:[font = subsection; inactive; startGroup; Cclosed; ]
[Kopec 1985]
:[font = text; inactive; endGroup; ]
G. Kopec. 1985.  ``The Signal Representation Language SRL.''  {IEEE Transactions on Acoustics, Speech, and Signal Processing}, vol.  33 (4), pp. 921-932.
:[font = subsection; inactive; startGroup; Cclosed; ]
[Lathi 1983]
:[font = text; inactive; endGroup; ]
B. P. Lathi. 1983.  {Modern Digital and Analog Communication Systems}.  Holt, Rinehart, and Winston, New York.
:[font = subsection; inactive; startGroup; Cclosed; ]
[Muth 1978]
:[font = text; inactive; endGroup; ]
E. J. Muth. 1978.  {Transform Methods}.  Prentice Hall, Englewood Cliffs (NJ).
:[font = subsection; inactive; startGroup; Cclosed; ]
[Myers 1986]
:[font = text; inactive; endGroup; ]
C. S. Myers. 1986.  {Signal Representation for Symbolic and Numeric Processing}.  Ph.  D. Thesis and RLE Tech. Rep. #521.  MIT, Cambridge (MA).
:[font = subsection; inactive; startGroup; Cclosed; ]
[Oberhettinger & Badii 1973]
:[font = text; inactive; endGroup; ]
F. Oberhettinger and L. Badii. 1973.  {Tables of Laplace Transforms}.  Springer-Verlag, New York.
:[font = subsection; inactive; startGroup; Cclosed; ]
[Oppenheim & Schafer 1989]
:[font = text; inactive; endGroup; ]
A. V. Oppenheim and R. W. Schafer. 1989.  {Discrete-Time Signal Processing}.  Prentice Hall, Englewood Cliffs (NJ).
:[font = subsection; inactive; startGroup; Cclosed; ]
[Oppenheim & Willsky 1983]
:[font = text; inactive; endGroup; endGroup; ]
A. V. Oppenheim and A. Willsky. 1983.  {Signals and Systems}.  Prentice Hall, Englewood Cliffs (NJ).
:[font = smalltext; inactive; ]
This work was supported in part by the Joint Services Electronics Program
contract #DAAL-03-90-C-0004.  
^*)