(*^

::[paletteColors = 128; 
	fontset = text, "Times", 14, L2, nohscroll;
	fontset = smalltext, "Times", 12, L2, nohscroll;
	fontset = special1, "Times", 24, L2, center, italic, nowordwrap;
	fontset = special2, "Times", 20, L2, center, italic, nowordwrap;
	fontset = special3, "Times", 16, L2, italic, nowordwrap;
	fontset = special4, "New York", 16, L2, nowordwrap;
	fontset = special5, "New York", 20, L2, nowordwrap;]
:[font = title; inactive; ]
The z-Transform
:[font = special2; inactive; ]
Part II:
Frequency Responses of Rational Systems
:[font = subtitle; inactive; ]
by 
Lina J. Karam
with
Brian L. Evans and James H. McClellan
:[font = subsubtitle; inactive; ]

Digital Signal Processing  Laboratory
   School of Electrical Engineering
  Georgia Institute of Technology
  Atlanta, GA  30332-0250
  
  EMAIL:  evans@eedsp.gatech.edu
:[font = message; inactive; center; ]
This notebook has been divided into
three parts because of its size
:[font = text; inactive; ]
	This notebook is a highly interactive tutorial on the z-transform.  In addition to discussing the basic theoretical concept behind the z-transform, this notebook provides users with means to evaluate z-transforms and inverse z-transforms, to observe changes in parameters in the examples by animation, and to visualize z-transforms graphically.
:[font = text; inactive; ]
	This notebook automatically loads the needed Digital Signal Processing packages by executing the Needs command in the Initialization section.  Under Mathematica 1.2, the entire initialization process may take a few minutes. 
:[font = text; inactive; ]
	A Notebook is completely defined by a portable ASCII file but  machine-dependent binary information (bitmaps, etc.) is generated as side information to speed up the display of parts of the Notebook.   Mathematica 1.2 generates missing side information as needed whereas Mathematica 2.0 and higher generates all missing side information when a Notebook is opened.    Mathematica 2.0 and higher will display the message "Rendering ..." in the header of the Notebook when it is generating bitmaps for PostScript graphics contained in the Notebook.  This particular Notebook contains 110 or so graphics cells whose bitmaps will require an 2.2 Mb of memory (110 cells x 20 kb/cell) to store.  The ASCII version of this Notebook occupies 840 kb.
:[font = text; inactive; ]
	As a reminder, in order to open a section below, just move the mouse to the downward-pointing arrow and double click. To get help information for any command, place the cursor in an input cell and type ?Command (like ?ZTransform).
:[font = special1; inactive; ]

Table of Contents

:[font = section; inactive; startGroup; Cclosed; ]
Initialization
:[font = input; initialization; startGroup; Cclosed; ]
*)
Needs [ "SignalProcessing`Digital`" ]
(*
:[font = print; inactive; ]
Loading the signal processing support packages ...
:[font = print; inactive; ]
Support module has been loaded.
:[font = print; inactive; ]
Supporting routines for filter design are loaded.
:[font = print; inactive; ]
The knowledge base of signal processing operators has been\
 
  loaded.
:[font = print; inactive; ]
Region of convergence routines for the transform rule\
 
  bases are loaded.
:[font = print; inactive; ]
Supporting routines for transform rule bases are loaded.
:[font = message; inactive; ]
Support::loaded: 
   Supporting routines, objects, and rules for the signal
    processing package have been loaded successfully.
:[font = message; inactive; ]
Support::change: 
   The loading process has changed such that the files
    Tree.m and DataType.m are no longer automatically
    loaded (the signal processing packages no longer rely
    on the definitions in these files).
:[font = print; inactive; ]
Loading in the digital signal processing packages ...
:[font = print; inactive; ]
Supporting routines for the z-transform rule bases are\
 
  loaded.
:[font = print; inactive; ]
The supporting functions are loaded for symbolic Fourier\
 
  transforms.
:[font = print; inactive; ]
The forward z-transform rules have been loaded.
:[font = print; inactive; ]
The inverse z-transform rules have been loaded.
:[font = print; inactive; ]
The discrete-time Fourier transform (DTFT) rule bases are\
 
  loaded.
:[font = print; inactive; ]
Correlation functions are now loaded.
:[font = print; inactive; ]
ZSolve, a difference equation solver, is loaded.
:[font = print; inactive; ]
The digital signal analyzer is now loaded.
:[font = print; inactive; ]
The discrete Fourier transform (DFT) rule bases are\
 
  loaded.
:[font = message; inactive; ]
Digital::loaded: 
   Routines, objects, and rules for the digital signal
    processing package have been loaded successfully.
:[font = print; inactive; ]

:[font = print; inactive; ]
The digital signal processing extensions has been loaded.
:[font = print; inactive; ]
Good starting points are the objects DSPAnalyze and\
 
  ZTransform.
:[font = print; inactive; ]
Active packages are maintained in the variable\
 
  $ContextPath.
:[font = print; inactive; ]
  New signal primitives are in SPsignals.
:[font = print; inactive; ]
  New system primitives are in SPoperators.
:[font = print; inactive; ]
  New Mathematica functions are in SPfunctions.
:[font = print; inactive; ]
Note that all signal processing expressions will
:[font = print; inactive; ]
be automatically simplified.
:[font = print; inactive; endGroup; ]

:[font = input; initialization; ]
*)
AllPoleZeroPlots[ trans_, z_ ]:= 
   Block[ {i, numrocs, key,key1,key2, polelist, roclist}, 
             polelist = GetRootList [ Denominator[trans], z ]; 
             roclist = Join[ {0}, Sort[ Abs[polelist] ], {Infinity}];
             numrocs = Length [roclist];
            i = 1; 
             key1 = "";
             While [ (key1 != "y") && (key1 != "n"),
                   key1 = ToString [ Input[ "\
                            Want Inverse Z Transform (y/n)?"]]];
           While [ True, 
             key = "a";
             Print[" ROC # ", i];  
             PoleZeroPlot [trans, z, roclist[[i]], roclist[[i+1]],
                                  True];
             if [key1 === "y", Print[" The time sequence is: ", 
                           InvZTransform[{trans,roclist[[i]],roclist[[i+1]]},
                                         z,n,Dialogue -> False]]];                       
            While [ ! MemberQ[{"n","p","f","l","q","s"}, key ],                     
             key = ToString[ Input["PRESS THE FOLLOWING KEYS FOLLOWED\
                   BY A CARRIAGE RETURN: \n
 n : NEXT ROC - \
 p : PREVIOUS ROC - \n
 f : FIRST ROC - \
 l : LAST ROC - \n
 s : SAME - q : QUIT " ]];                
                   If [ (key === "n"),
                     If [i < (numrocs - 1), i = i + 1, i = 1 ] ];
                   If [ (key === "p"),
                      If [ i > 1, i = i - 1, i = numrocs - 1] ];
                   If [ key === "f", i = 1 ];
                   If [ key === "l", i = numrocs - 1];       
                   If [ key  === "q",
                           key2 = "";
                           While [ (key2 != "y") && (key2 != "n"),
                                 key2 = ToString [ Input[ "         \
                                            QUIT (y/n)?"]]
                                 ];
                           If [key2 === "n", key = "a" ]
                      ]
                     ];
                     If [key2 === "y", Break[] ] 
                  ];
             Print[" End of ROCs ! "]
        ]              
(*
:[font = input; initialization; endGroup; ]
*)

(*  InvalidZPoleQ  *)
InvalidZPoleQ[rminus_, r_, rplus_] := TrueQ[rminus < Abs[N[r]] < rplus]

(*  MyRationalPolyQ  *)
MyRationalPolyQ[f_, z_] :=
	MixedPolynomialQ[ Expand[Numerator[f]], z ] &&
	MixedPolynomialQ[ Expand[Denominator[f]], z ]

(*  One-dimensional pole-zero plotting in the z-domain  *)
VectorPoleZeroPlot[f_, z_Symbol, rm_, rp_, w_, True, op___] :=	
	Block [ {abspolelist, fillplot, invalidROClist, options, polelist,
		 poleplot, vectorsplot, polezerolist, rmax, rminus, rplus, 
		 rminuscircle,rpluscircle, unitcircle, xlabel, ylabel, dot, 
		 zeroplot, zstr, ztrans},

		options = ToList[op] ~Join~ Options[PoleZeroPlot];

		rmax = 1;				  (* default values *)
		unitcircle = CirclePS[1];

		(*  Analyze the z-transform function  *)

		ztrans = Together[f];
		If [ ! MyRationalPolyQ[ztrans, z],
		     Message[ PoleZeroPlot::notrational ] ];

		zerolist = GetRootList[Numerator[ztrans], z];
		polelist = GetRootList[Denominator[ztrans], z];
		If [ InformUserQ[Replace[Dialogue, options]],
		     Print[ " " ];
		     Print[ "The zeroes are:  ", zerolist ];
		     Print[ "The poles are:   ", polelist ] ];

		(*  Check consistency of poles with region of convergence  *)
		(*  Exit function if inconsistency encountered		   *)

		rminus = N[rm];			  (* numeric approximation *)
		rplus = N[rp];
		invalidROClist = Select[ polelist,
					 InvalidZPoleQ[rminus, #1, rplus]& ];
		If [ ! SameQ[invalidROClist, {}],
		     Message[PoleZeroPlot::invalidROC, invalidROClist, rm, rp];
		     Return[polelist] ];

		(*  Compute plot of poles and zeroes		*)
		(*  Determine the plot's its circular extent	*)

		rmax = Max[ Join[ {rmax},
				  Map[Abs, ToList[N[zerolist]]],
				  Map[Abs, ToList[N[polelist]]] ] ];

		zeroplot = If [ EmptyQ[zerolist],
		     	        NullPlot,
				PointwisePlot[ComplexTo2DCoordList[zerolist],
					      "O", "*O*"] ];

		poleplot = If [ EmptyQ[polelist],
				NullPlot,
				PointwisePlot[ComplexTo2DCoordList[polelist],
					      "X", "*X*"] ];
        (* Draw pole and zero vectors *)
         polezerolist = zerolist ~Join~ polelist;
         vectorsplot = Graphics[Map[Line[{{Cos[w],Sin[w]}, #1}]&,
                                ComplexTo2DCoordList[polezerolist]]];
         dot = Graphics[{PointSize[0.05], Point[{Cos[w],Sin[w]}]}];
        
		(*  Build region of convergence plot  *)
		If [ NumberQ[rminus],
		     rminuscircle = CirclePS[ rminus, Dashing[{0.05,0.05}] ];
			 rmax = Max[rmax, Abs[rminus]],
		     rminuscircle = NullPlot ];

		If [ NumberQ[rplus],
		     rpluscircle = CirclePS[ rplus, Dashing[{0.05,0.05}] ];
			 rmax = Max[rmax, Abs[rplus]],
		     rpluscircle = NullPlot ];

		rplus = N[ If[ SameQ[rp, Infinity], 2 rmax, rp] ];  (* kludge *)

		fillplot = If [ NumberQ[rminus] && NumberQ[rplus],
				ShadedAnnulus[rminus, rplus],
				NullPlot ];

		(*  Send the contour plot to the screen  *)
		rmax *= 1.25;
		zstr = StripPackage[z];
		xlabel = "Re " ~StringJoin~ zstr;
		ylabel = "Im " ~StringJoin~ zstr;

		Show [unitcircle, rminuscircle, rpluscircle,
		      fillplot, zeroplot, poleplot, vectorsplot, dot,
		      PlotRange -> {{-rmax, rmax}, {-rmax, rmax}},
		      AspectRatio -> Automatic,
		      AxesLabel -> { xlabel, ylabel },
		      Axes -> Automatic,
		      DisplayFunction -> $DisplayFunction ];

		polelist ]
(*
:[font = section; inactive; startGroup; Cclosed; ]
The DTFT and the z-Transform Are Similar But Not the Same
:[font = text; inactive; ]
	The  discrete-time Fourier transform X(e^jw) of a sequence x[n] is defined by the following equation:
:[font = postscript; inactive; PostScript; output; pictureLeft = 139; pictureWidth = 167; pictureHeight = 47; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.281437 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.281437 scale
1 string
167 47 1 [167 0 0 47 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F03FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F1C7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F1F8000
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7E3FFFF
FFFFFFFFF0381FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7E38000
1F80001F8FC7E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE381FFFFF
FFFFFFFFF0381FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000
000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00
000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFC7
FFFFFFE07FFFFFFFFF000FFFFFFFF8007FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFC7FFFFFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFF
1FFFFFFC7FFFFFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFF
E3FFFFFFFFFFFFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
0001C0000FF8FFFFC003FFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFF
FC7FFFFFFFF81FF03F1FFFF81FF007FC7FF8007FFFFFFFFFFFFFFFFFFFFF
FFFFF8
FC0FFF007FC0FFFE00FC7FFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFF
FF8FFFFFFFFF0380071FFFF81FF038FC7FC01F8FFFFFFFFFFFFFFFFFFFFF
FFFFF8
FF8FFF03FFC0FFFE07FF8FFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFF
FFF1FFFFFFFFE381FF1FFFF81FF03FFC7FC0FFF1FFFFFFFFFFFFFFFFFFFF
FFFFF8
FFF1FF03FFC0FFFE001FFFFFFFFFFFFFFFFF03FFF8000000FFFFFFFFFFFF
FFFE3FFFFFFFE00FFF1FFFF81FF03FFC7FC003FFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFE381FFFC0FFFE07E07FFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFF
FFFE07FFFFFFFC0FFF1FFFFF03FE07FC7FC0FC0FFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFE001FFFC0FFFFC7FC003FFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFF
FFF03FFFFFFFE001FF1FFFFF007E07FC7FF8FF8007FFFFFFFFFFFFFFFFFF
FFFFF8
FFFFC0FFFFC0FFFFC0FC01C7FFFFFFFFFFFF03FFF8000000FFFFFFFFFFFF
FF81FFFFFFFFE0703F1FFFFF038007FC7FF81F8038FFFFFFFFFFFFFFFFFF
FFFFF8
FFFFC0FFFFF8FFFFFF007FC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFF
FC0FFFFFFFFF007E071FFFF803F03FFC7FFFE00FF8FFFFFFFFFFFFFFFFFF
FFFFF8
FFFE001FFFF8FFFFFFFFFFF8FFF0381FFFFF1FFFFFFFFFFFFFFFFFFFFFFF
E07FFFFFFFFFFFFFFF1FFFFFFFFFFFFC7FFFFFFFFF1FFFFFE0703FFFFFC7
E07FF8
FFFE07E3FFFF1FFFFFFFFFF8FF8FC7E3FFF8FFFFFFFFFFFFFFFFFFFFFFFF
03FFFFFFFFFFFFFFFF1FFFFFFFFFFFFC7FFFFFFFFF1FFFFF1F8FC7FFFFC7
E38FF8
FFF007E07FFF1FFFFFFFFFF8FFF1F8FC7FF8FFFFFFFFFFFFFFFFFFFFFFF8
1FFFFFFC7FFFFFFFFF1FFFFFFFFFFFFC7FFFFFFFFF1FFFFFE3F1F8FFFFC7
E3FFF8
FFF03FFC0FFFE3FFFFFFFFFF1FF1F8FC7FC7FFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFC7FFFFFFFFF000FFFFFFFF8007FFFFFFFFFE3FFFFE3F1F8FFFFF8
FC7FF8
FC0000E0003FFFFFFFFFFFFF1FFE3F1F8FFFFFFFFFFFFFFFFFFFFFFFFE07
FFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFC7E3F1FFFF8
FC7FF8
FFFFFFFFFFFFFFFFFFFFFFF81FFFC7FC7FFFFFFFFFFFFFFFFFFFFFFFF000
000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFF8FF8FFFFC7
03FFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0703FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1F8FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0703FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
Comparing the definition of the DTFT above and that of the z-transform
:[font = postscript; inactive; PostScript; output; pictureLeft = 157; pictureWidth = 133; pictureHeight = 47; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.353384 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.353384 scale
1 string
133 47 1 [133 0 0 47 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F81FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F8E3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F8FF80001FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F1FFFFFFFFFFFFF81C0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F1F80001C0000FC7E3F
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1C0FFFFFFFFFFFFFF81C0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000007FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000007FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFE3FFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFE07FFF
FFFFFF000FFFFFFFF8007FFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFF1FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFC7FFF
FFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFF1FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFC7FFF
FFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFE
FFFFFFFFFFF8FFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFF
FFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFE
0001C0000FF8FFF00003FFF8FFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFF8
1FF03F1FFFC0FF803FFC7FF80001FFFFFFFFFFFE
FC0FFF007FC0FFF03FE3FFF81FFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFF
0380071FFFC0FF81C7FC7FF81FF1FFFFFFFFFFFE
FF8FFF03FFC0FFFE07FFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFF
E381FF1FFFC0FF81FFFC7FFF03FFFFFFFFFFFFFE
FFF1FF03FFC0FFFFC0FFFFF81FFFC0000007FFFFFFFFFFFFFFFE3FFFFFFF
E00FFF1FFFC0FF81FFFC7FFFE07FFFFFFFFFFFFE
FFFE381FFFC0FFFFF81FFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFF
FC0FFF1FFFF81FF03FFC7FFFFC0FFFFFFFFFFFFE
FFFE001FFFC0FFFFFF03FFF81FFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFF
E001FF1FFFF803F03FFC7FFFFF81FFFFFFFFFFFE
FFFFC0FFFFC0FFFE3FE07FF81FFFC0000007FFFFFFFFFFFFFF81FFFFFFFF
E0703F1FFFF81C003FFC7FFF1FF03FFFFFFFFFFE
FFFFC0FFFFF8FFFE00007FF8FFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFF
007E071FFFC01F81FFFC7FFF00003FFFFFFFFFFE
FFFE001FFFF8FFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFF
FFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFC7E07E
FFFE07E3FFFF1FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFF
FFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFC7E38E
FFF007E07FFF1FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFF81FFFFFFC7FFF
FFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFC7E3FE
FFF03FFC0FFFE3FFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFC7FFF
FFFFFF000FFFFFFFF8007FFFFFFFFFFFFFF8FC7E
FC0000E0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFE07FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF80001F8FC7E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000007FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC703FE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0703FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F8FC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0703FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
it is evident that there is a close relationship between the DTFT and the z-transform.  In particular, if we replace z by e^jw, equation (1) reduces to equation (5).  		
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example:   z-Transform and DTFT of the Same Sequence
:[font = text; inactive; ]
		Try to evaluate the following input cells by placing the cursor in each cell and hitting the ENTER key (the result from the previous evaluation is shown).		
:[font = input; startGroup; ]
ZTransform[0.8^n Step[n],n, z]
:[font = output; inactive; output; endGroup; ]
ZTransData[(1 - 0.8/z)^(-1), Rminus[0.8], 
  Rplus[DirectedInfinity[1]], ZVariables[z]]
;[o]
              1
ZTransData[-------, Rminus[0.8], Rplus[Infinity], ZVariables[z]]
               0.8
           1 - ---
                z
:[font = input; startGroup; ]
DTFTransform[0.8^n Step[n], n, w]
:[font = output; inactive; output; endGroup; endGroup; ]
DTFTData[(1 - 0.8*E^(-I*w))^(-1), FVariables[w]]
;[o]
               1
DTFTData[-------------, FVariables[w]]
                  -I w
         1 - 0.8 E
:[font = text; inactive; ]
	So, it "seems" that the Fourier transform is just the z-transform evaluated on the unit circle in the complex z plane (since |z| = 1 for z = e^jw).  In general, however, this is NOT true, as seen in the next example.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example:   Sequence with a z-Transform but Not a DTFT
:[font = text; inactive; ]
		The following function calculates the z-transform and the DTFT and plots the pole-zero diagram with the ROC.  Note that the z-transform exists  but the DTFT does not !
:[font = input; startGroup; Cclosed; ]
DSPAnalyze[3^n Step[n], n, -1, 5]
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.18254 0.15873 0.01472 0.00242 [
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Msboxa
[(-1)] 0.02381 0.00222 0 1 Msboxa
[(1)] 0.34127 0.00222 0 1 Msboxa
[(2)] 0.5 0.00222 0 1 Msboxa
[(3)] 0.65873 0.00222 0 1 Msboxa
[(4)] 0.81746 0.00222 0 1 Msboxa
[(5)] 0.97619 0.00222 0 1 Msboxa
[(n)] 1.00625 0.01472 -1 0 Msboxa
[(50)] 0.17004 0.13583 1 0 Msboxa
[(100)] 0.17004 0.25694 1 0 Msboxa
[(150)] 0.17004 0.37805 1 0 Msboxa
[(200)] 0.17004 0.49916 1 0 Msboxa
[( )] 0.18254 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.02381 0.00847 moveto
0.02381 0.02097 lineto
stroke
0 setgray
[(-1)] 0.02381 0.00222 0 1 Mshowa
0.34127 0.00847 moveto
0.34127 0.02097 lineto
stroke
0 setgray
[(1)] 0.34127 0.00222 0 1 Mshowa
0.5 0.00847 moveto
0.5 0.02097 lineto
stroke
0 setgray
[(2)] 0.5 0.00222 0 1 Mshowa
0.65873 0.00847 moveto
0.65873 0.02097 lineto
stroke
0 setgray
[(3)] 0.65873 0.00222 0 1 Mshowa
0.81746 0.00847 moveto
0.81746 0.02097 lineto
stroke
0 setgray
[(4)] 0.81746 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(5)] 0.97619 0.00222 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.01472 -1 0 Mshowa
0.18254 0 moveto
0.18254 0.61803 lineto
stroke
0.17629 0.13583 moveto
0.18879 0.13583 lineto
stroke
0 setgray
[(50)] 0.17004 0.13583 1 0 Mshowa
0.17629 0.25694 moveto
0.18879 0.25694 lineto
stroke
0 setgray
[(100)] 0.17004 0.25694 1 0 Mshowa
0.17629 0.37805 moveto
0.18879 0.37805 lineto
stroke
0 setgray
[(150)] 0.17004 0.37805 1 0 Mshowa
0.17629 0.49916 moveto
0.18879 0.49916 lineto
stroke
0 setgray
[(200)] 0.17004 0.49916 1 0 Mshowa
0 setgray
[( )] 0.18254 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.02381 0.01472 lineto
stroke
0.008 setlinewidth
0.02381 0.01472 Mdot
0.004 setlinewidth
0.18254 0.01472 moveto
0.18254 0.01714 lineto
stroke
0.008 setlinewidth
0.18254 0.01714 Mdot
0.004 setlinewidth
0.34127 0.01472 moveto
0.34127 0.02198 lineto
stroke
0.008 setlinewidth
0.34127 0.02198 Mdot
0.004 setlinewidth
0.5 0.01472 moveto
0.5 0.03652 lineto
stroke
0.008 setlinewidth
0.5 0.03652 Mdot
0.004 setlinewidth
0.65873 0.01472 moveto
0.65873 0.08012 lineto
stroke
0.008 setlinewidth
0.65873 0.08012 Mdot
0.004 setlinewidth
0.81746 0.01472 moveto
0.81746 0.21092 lineto
stroke
0.008 setlinewidth
0.81746 0.21092 Mdot
0.004 setlinewidth
0.97619 0.01472 moveto
0.97619 0.60332 lineto
stroke
0.008 setlinewidth
0.97619 0.60332 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
 n
3  Step[n]
:[font = print; inactive; ]
has the following z-transform:
:[font = print; inactive; ]
  1
-----
    3
1 - -
    z
:[font = print; inactive; ]
The region of convergence is:
:[font = print; inactive; ]
3 < |z| < Infinity
:[font = print; inactive; ]
The system  is not stable.
:[font = print; inactive; ]

:[font = print; inactive; ]
The zeroes are:  {}
:[font = print; inactive; ]
The poles are:   {3.}
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.13333 0.5 0.13333 [
[(-3)] 0.1 0.4875 0 1 Msboxa
[(-2)] 0.23333 0.4875 0 1 Msboxa
[(-1)] 0.36667 0.4875 0 1 Msboxa
[(1)] 0.63333 0.4875 0 1 Msboxa
[(2)] 0.76667 0.4875 0 1 Msboxa
[(3)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-3)] 0.4875 0.1 1 0 Msboxa
[(-2)] 0.4875 0.23333 1 0 Msboxa
[(-1)] 0.4875 0.36667 1 0 Msboxa
[(1)] 0.4875 0.63333 1 0 Msboxa
[(2)] 0.4875 0.76667 1 0 Msboxa
[(3)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-3)] 0.1 0.4875 0 1 Mshowa
0.23333 0.49375 moveto
0.23333 0.50625 lineto
stroke
0 setgray
[(-2)] 0.23333 0.4875 0 1 Mshowa
0.36667 0.49375 moveto
0.36667 0.50625 lineto
stroke
0 setgray
[(-1)] 0.36667 0.4875 0 1 Mshowa
0.63333 0.49375 moveto
0.63333 0.50625 lineto
stroke
0 setgray
[(1)] 0.63333 0.4875 0 1 Mshowa
0.76667 0.49375 moveto
0.76667 0.50625 lineto
stroke
0 setgray
[(2)] 0.76667 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(3)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-3)] 0.4875 0.1 1 0 Mshowa
0.49375 0.23333 moveto
0.50625 0.23333 lineto
stroke
0 setgray
[(-2)] 0.4875 0.23333 1 0 Mshowa
0.49375 0.36667 moveto
0.50625 0.36667 lineto
stroke
0 setgray
[(-1)] 0.4875 0.36667 1 0 Mshowa
0.49375 0.63333 moveto
0.50625 0.63333 lineto
stroke
0 setgray
[(1)] 0.4875 0.63333 1 0 Mshowa
0.49375 0.76667 moveto
0.50625 0.76667 lineto
stroke
0 setgray
[(2)] 0.4875 0.76667 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(3)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.63333 0.5 moveto
0.63333 0.50109 lineto
0.63332 0.50218 lineto
0.63329 0.50327 lineto
0.63326 0.50436 lineto
0.63322 0.50545 lineto
0.63317 0.50654 lineto
0.63305 0.50872 lineto
0.63289 0.5109 lineto
0.63269 0.51307 lineto
0.63219 0.5174 lineto
0.63155 0.52172 lineto
0.63077 0.52601 lineto
0.62879 0.53451 lineto
0.62626 0.54286 lineto
0.62318 0.55102 lineto
0.61547 0.56667 lineto
0.60578 0.58117 lineto
0.59428 0.59428 lineto
0.58117 0.60578 lineto
0.56667 0.61547 lineto
0.55897 0.61958 lineto
0.55102 0.62318 lineto
0.54286 0.62626 lineto
0.53451 0.62879 lineto
0.52601 0.63077 lineto
0.52172 0.63155 lineto
0.5174 0.63219 lineto
0.51307 0.63269 lineto
0.5109 0.63289 lineto
0.50872 0.63305 lineto
0.50654 0.63317 lineto
0.50545 0.63322 lineto
0.50436 0.63326 lineto
0.50327 0.63329 lineto
0.50218 0.63332 lineto
0.50109 0.63333 lineto
0.5 0.63333 lineto
0.49891 0.63333 lineto
0.49782 0.63332 lineto
0.49673 0.63329 lineto
0.49564 0.63326 lineto
0.49346 0.63317 lineto
0.49128 0.63305 lineto
0.4891 0.63289 lineto
0.48693 0.63269 lineto
0.4826 0.63219 lineto
0.47828 0.63155 lineto
0.47399 0.63077 lineto
0.46549 0.62879 lineto
Mistroke
0.45714 0.62626 lineto
0.44898 0.62318 lineto
0.43333 0.61547 lineto
0.41883 0.60578 lineto
0.40572 0.59428 lineto
0.39422 0.58117 lineto
0.38453 0.56667 lineto
0.37682 0.55102 lineto
0.37374 0.54286 lineto
0.37121 0.53451 lineto
0.36923 0.52601 lineto
0.36845 0.52172 lineto
0.36781 0.5174 lineto
0.36731 0.51307 lineto
0.36711 0.5109 lineto
0.36695 0.50872 lineto
0.36683 0.50654 lineto
0.36678 0.50545 lineto
0.36674 0.50436 lineto
0.36671 0.50327 lineto
0.36668 0.50218 lineto
0.36667 0.50109 lineto
0.36667 0.5 lineto
0.36667 0.49891 lineto
0.36668 0.49782 lineto
0.36671 0.49673 lineto
0.36674 0.49564 lineto
0.36683 0.49346 lineto
0.36695 0.49128 lineto
0.36711 0.4891 lineto
0.36731 0.48693 lineto
0.36781 0.4826 lineto
0.36845 0.47828 lineto
0.36923 0.47399 lineto
0.37121 0.46549 lineto
0.37374 0.45714 lineto
0.37682 0.44898 lineto
0.38453 0.43333 lineto
0.39422 0.41883 lineto
0.40572 0.40572 lineto
0.41883 0.39422 lineto
0.43333 0.38453 lineto
0.44103 0.38042 lineto
0.44898 0.37682 lineto
0.45714 0.37374 lineto
0.46549 0.37121 lineto
0.47399 0.36923 lineto
0.47828 0.36845 lineto
0.4826 0.36781 lineto
0.48693 0.36731 lineto
Mistroke
0.4891 0.36711 lineto
0.49128 0.36695 lineto
0.49346 0.36683 lineto
0.49455 0.36678 lineto
0.49564 0.36674 lineto
0.49673 0.36671 lineto
0.49782 0.36668 lineto
0.49891 0.36667 lineto
0.5 0.36667 lineto
0.50109 0.36667 lineto
0.50218 0.36668 lineto
0.50327 0.36671 lineto
0.50436 0.36674 lineto
0.50654 0.36683 lineto
0.50872 0.36695 lineto
0.5109 0.36711 lineto
0.51307 0.36731 lineto
0.5174 0.36781 lineto
0.52172 0.36845 lineto
0.52601 0.36923 lineto
0.53451 0.37121 lineto
0.54286 0.37374 lineto
0.55102 0.37682 lineto
0.56667 0.38453 lineto
0.58117 0.39422 lineto
0.59428 0.40572 lineto
0.60578 0.41883 lineto
0.61547 0.43333 lineto
0.61958 0.44103 lineto
0.62318 0.44898 lineto
0.62626 0.45714 lineto
0.62879 0.46549 lineto
0.63077 0.47399 lineto
0.63155 0.47828 lineto
0.63219 0.4826 lineto
0.63269 0.48693 lineto
0.63289 0.4891 lineto
0.63305 0.49128 lineto
0.63317 0.49346 lineto
0.63322 0.49455 lineto
0.63326 0.49564 lineto
0.63329 0.49673 lineto
0.63332 0.49782 lineto
0.63333 0.49891 lineto
0.63333 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.87588 0.63681 lineto
stroke
0.11125 0.4058 moveto
-0.26579 0.26857 lineto
stroke
0.10312 0.45014 moveto
-0.2775 0.31161 lineto
stroke
0.10002 0.49631 moveto
-0.28684 0.3555 lineto
stroke
0.10248 0.5445 moveto
-0.29376 0.40028 lineto
stroke
0.11146 0.59507 moveto
-0.29817 0.44597 lineto
stroke
0.12863 0.64861 moveto
-0.29997 0.49262 lineto
stroke
0.15734 0.70636 moveto
-0.29899 0.54027 lineto
stroke
0.20619 0.77144 moveto
-0.29503 0.58901 lineto
stroke
0.36319 0.87588 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
0.63681 0.12412 moveto
-0.01423 -0.11284 lineto
stroke
0.44941 0.10321 moveto
-0.05182 -0.07922 lineto
stroke
0.37015 0.12166 moveto
-0.08617 -0.04443 lineto
stroke
0.31104 0.14744 moveto
-0.11756 -0.00855 lineto
stroke
0.26347 0.17743 moveto
-0.14616 0.02833 lineto
stroke
0.22409 0.21039 moveto
-0.17215 0.06617 lineto
stroke
0.19122 0.24572 moveto
-0.19564 0.10492 lineto
stroke
0.16392 0.28308 moveto
-0.2167 0.14455 lineto
stroke
0.14165 0.32227 moveto
-0.23539 0.18504 lineto
stroke
0.12412 0.36319 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.85835 0.67773 lineto
stroke
1.26579 0.73143 moveto
0.88875 0.5942 lineto
stroke
1.2167 0.85545 moveto
0.83608 0.71692 lineto
stroke
1.2775 0.68839 moveto
0.89688 0.54986 lineto
stroke
1.19564 0.89508 moveto
0.80878 0.75428 lineto
stroke
1.28684 0.6445 moveto
0.89998 0.50369 lineto
stroke
1.17215 0.93383 moveto
0.77591 0.78961 lineto
stroke
1.29376 0.59972 moveto
0.89752 0.4555 lineto
stroke
1.14616 0.97167 moveto
0.73653 0.82257 lineto
stroke
1.29817 0.55403 moveto
0.88854 0.40493 lineto
stroke
1.11756 1.00855 moveto
0.68896 0.85256 lineto
stroke
1.29997 0.50738 moveto
0.87137 0.35139 lineto
stroke
1.08617 1.04443 moveto
0.62985 0.87834 lineto
stroke
1.29899 0.45973 moveto
0.84266 0.29364 lineto
stroke
1.05182 1.07922 moveto
0.55059 0.89679 lineto
stroke
1.29503 0.41099 moveto
0.79381 0.22856 lineto
stroke
1.01423 1.11284 moveto
0.36319 0.87588 lineto
stroke
1.28785 0.36108 moveto
0.63681 0.12412 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.9 0.5 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
By substituting into the z-transform,
:[font = print; inactive; ]
the frequency response is
:[font = print; inactive; ]
     1
-----------
       -I w
1 - 3 E
:[font = print; inactive; ]

:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.01545 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-20)] 0.4875 0 1 0 Msboxa
[(-15)] 0.4875 0.07725 1 0 Msboxa
[(-10)] 0.4875 0.15451 1 0 Msboxa
[(-5)] 0.4875 0.23176 1 0 Msboxa
[(5)] 0.4875 0.38627 1 0 Msboxa
[(10)] 0.4875 0.46353 1 0 Msboxa
[(15)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0 moveto
0.50625 0 lineto
stroke
0 setgray
[(-20)] 0.4875 0 1 0 Mshowa
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(-15)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(-10)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(-5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(10)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(15)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.36343 moveto
0.02505 0.36342 lineto
0.02629 0.36338 lineto
0.02753 0.36331 lineto
0.02877 0.36322 lineto
0.03125 0.36295 lineto
0.03373 0.36258 lineto
0.03869 0.36153 lineto
0.04365 0.36009 lineto
0.05357 0.35618 lineto
0.06349 0.35114 lineto
0.10317 0.32588 lineto
0.14286 0.30195 lineto
0.1627 0.29226 lineto
0.18254 0.28434 lineto
0.20238 0.27822 lineto
0.2123 0.27582 lineto
0.22222 0.27387 lineto
0.23214 0.27235 lineto
0.2371 0.27176 lineto
0.24206 0.27127 lineto
0.24702 0.27089 lineto
0.2495 0.27075 lineto
0.25198 0.27062 lineto
0.25446 0.27053 lineto
0.2557 0.27049 lineto
0.25694 0.27046 lineto
0.25818 0.27044 lineto
0.25942 0.27042 lineto
0.26066 0.27041 lineto
0.2619 0.27041 lineto
0.26314 0.27041 lineto
0.26438 0.27042 lineto
0.26562 0.27044 lineto
0.26687 0.27046 lineto
0.26935 0.27053 lineto
0.27183 0.27062 lineto
0.27431 0.27075 lineto
0.27679 0.27089 lineto
0.28175 0.27127 lineto
0.28671 0.27176 lineto
0.29167 0.27235 lineto
0.30159 0.27387 lineto
0.31151 0.27582 lineto
0.32143 0.27822 lineto
0.34127 0.28434 lineto
0.36111 0.29226 lineto
0.38095 0.30195 lineto
0.42063 0.32588 lineto
0.44048 0.33899 lineto
Mistroke
0.46032 0.35114 lineto
0.47024 0.35618 lineto
0.4752 0.35829 lineto
0.48016 0.36009 lineto
0.48512 0.36153 lineto
0.4876 0.3621 lineto
0.49008 0.36258 lineto
0.49256 0.36295 lineto
0.4938 0.3631 lineto
0.49504 0.36322 lineto
0.49628 0.36331 lineto
0.49752 0.36338 lineto
0.49876 0.36342 lineto
0.5 0.36343 lineto
0.50124 0.36342 lineto
0.50248 0.36338 lineto
0.50372 0.36331 lineto
0.50496 0.36322 lineto
0.5062 0.3631 lineto
0.50744 0.36295 lineto
0.50992 0.36258 lineto
0.51488 0.36153 lineto
0.51984 0.36009 lineto
0.52976 0.35618 lineto
0.53968 0.35114 lineto
0.57937 0.32588 lineto
0.61905 0.30195 lineto
0.63889 0.29226 lineto
0.65873 0.28434 lineto
0.67857 0.27822 lineto
0.68849 0.27582 lineto
0.69841 0.27387 lineto
0.70833 0.27235 lineto
0.71329 0.27176 lineto
0.71825 0.27127 lineto
0.72321 0.27089 lineto
0.72569 0.27075 lineto
0.72817 0.27062 lineto
0.73065 0.27053 lineto
0.73189 0.27049 lineto
0.73313 0.27046 lineto
0.73438 0.27044 lineto
0.73562 0.27042 lineto
0.73686 0.27041 lineto
0.7381 0.27041 lineto
0.73934 0.27041 lineto
0.74058 0.27042 lineto
0.74182 0.27044 lineto
0.74306 0.27046 lineto
0.74554 0.27053 lineto
Mistroke
0.74802 0.27062 lineto
0.7505 0.27075 lineto
0.75298 0.27089 lineto
0.75794 0.27127 lineto
0.7629 0.27176 lineto
0.76786 0.27235 lineto
0.77778 0.27387 lineto
0.7877 0.27582 lineto
0.79762 0.27822 lineto
0.81746 0.28434 lineto
0.8373 0.29226 lineto
0.85714 0.30195 lineto
0.89683 0.32588 lineto
0.93651 0.35114 lineto
0.94643 0.35618 lineto
0.95635 0.36009 lineto
0.96131 0.36153 lineto
0.96379 0.3621 lineto
0.96627 0.36258 lineto
0.96875 0.36295 lineto
0.96999 0.3631 lineto
0.97123 0.36322 lineto
0.97247 0.36331 lineto
0.97371 0.36338 lineto
0.97495 0.36342 lineto
0.97619 0.36343 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-150)] 0.4875 0.06377 1 0 Msboxa
[(-100)] 0.4875 0.14552 1 0 Msboxa
[(-50)] 0.4875 0.22727 1 0 Msboxa
[(50)] 0.4875 0.39077 1 0 Msboxa
[(100)] 0.4875 0.47252 1 0 Msboxa
[(150)] 0.4875 0.55427 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.06377 moveto
0.50625 0.06377 lineto
stroke
0 setgray
[(-150)] 0.4875 0.06377 1 0 Mshowa
0.49375 0.14552 moveto
0.50625 0.14552 lineto
stroke
0 setgray
[(-100)] 0.4875 0.14552 1 0 Mshowa
0.49375 0.22727 moveto
0.50625 0.22727 lineto
stroke
0 setgray
[(-50)] 0.4875 0.22727 1 0 Mshowa
0.49375 0.39077 moveto
0.50625 0.39077 lineto
stroke
0 setgray
[(50)] 0.4875 0.39077 1 0 Mshowa
0.49375 0.47252 moveto
0.50625 0.47252 lineto
stroke
0 setgray
[(100)] 0.4875 0.47252 1 0 Mshowa
0.49375 0.55427 moveto
0.50625 0.55427 lineto
stroke
0 setgray
[(150)] 0.4875 0.55427 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.08533 lineto
0.10317 0.14406 lineto
0.14286 0.19201 lineto
0.18254 0.23364 lineto
0.22222 0.27202 lineto
0.2619 0.30902 lineto
0.30159 0.34602 lineto
0.34127 0.38439 lineto
0.38095 0.42603 lineto
0.42063 0.47398 lineto
0.46032 0.53271 lineto
0.48016 0.56694 lineto
0.49008 0.58498 lineto
0.49504 0.59413 lineto
0.49752 0.59872 lineto
0.49876 0.60102 lineto
0.5 0.60332 lineto
0.50124 0.01701 lineto
0.50248 0.01931 lineto
0.50496 0.02391 lineto
0.50992 0.03306 lineto
0.51984 0.0511 lineto
0.53968 0.08533 lineto
0.57937 0.14406 lineto
0.61905 0.19201 lineto
0.65873 0.23364 lineto
0.69841 0.27202 lineto
0.7381 0.30902 lineto
0.77778 0.34602 lineto
0.81746 0.38439 lineto
0.85714 0.42603 lineto
0.89683 0.47398 lineto
0.93651 0.53271 lineto
0.97619 0.60332 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; ]
ZTransData[(1 - 3/z)^(-1), Rminus[3], 
  Rplus[DirectedInfinity[1]], ZVariables[z]]
;[o]
             1
ZTransData[-----, Rminus[3], Rplus[Infinity], ZVariables[z]]
               3
           1 - -
               z
:[font = text; inactive; endGroup; ]
Note: The DSPAnalyze function does not give the correct answer for the DTFT. In fact, the  DTFT does not exist for the given sequence.  DSPAnalyze, as well as the DTFTransform, calculates the DTFT by simply replacing z by e^jw in the expression obtained for the z-transform.  This leads to a wrong result in this case since the unit circle is not included in the ROC, as it can be clearly seen from the pole-zero diagram.
:[font = text; inactive; ]
	What can you conclude from this example?  Despite the fact that the z-transform exists for a sequence, the DTFT of this same sequence does not exist!  This can be readily seen from the pole-zero diagram which does not contain the unit circle.  In fact, if the unit circle is contained in the ROC, the DTFT can be always obtained by direct evaluation of the z-transform on the unit circle in the z-plane (i.e. by setting z = e^jw in the z-transform equation).  However, if the unit circle is not in the ROC, setting z = e^jw in a z-transform closed-form expression will NOT give the correct result, as seen in next example. 
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example:   ROC  That Does Not Include the Unit Circle
:[font = text; inactive; ]
 		Try to evaluate the following input cells by placing the cursor in the corresponding cells and hitting the ENTER key.
:[font = input; startGroup; ]
ZTransform[3^n Step[n], n, z]
:[font = output; inactive; output; endGroup; ]
ZTransData[(1 - 3/z)^(-1), Rminus[3], 
  Rplus[DirectedInfinity[1]], ZVariables[z]]
;[o]
             1
ZTransData[-----, Rminus[3], Rplus[Infinity], ZVariables[z]]
               3
           1 - -
               z
:[font = input; startGroup; ]
DTFTransform[3^n Step[n], n, w]
:[font = output; inactive; output; endGroup; ]
DTFTData[(1 - 3*E^(-I*w))^(-1), FVariables[w]]
;[o]
              1
DTFTData[-----------, FVariables[w]]
                -I w
         1 - 3 E
:[font = text; inactive; endGroup; ]
Note that the  above  answer  is  NOT  valid. In fact, the  above  function  (i.e. DTFTransform) must be corrected so that it gives a "DOES NOT EXIST" message!!
:[font = text; inactive; ]
	It is important to note that having the unit circle (U.C.) in the ROC is equivalent to having an absolutely summable (i.e. stable) sequence. Hence, all absolutely summable or stable sequences have Fourier transforms.  However, absolute summability is only a sufficient condition, but not a necessary one, for the existence of the Fourier transform as shown by the following examples.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example:  Sequence with a DTFT but Not a z-Transform
:[font = text; inactive; ]
		The sequence given in this example is not absolutely summable, but it is square-summable; its DTFT exists but converges only in the mean-square sense.
:[font = text; inactive; ]
		Evaluate the following input cells by placing the cursor in each of the input cells and hitting the ENTER key.
:[font = input; startGroup; ]
ZTransform[ Sin[a n]/(Pi n), n, z ]
:[font = message; inactive; ]
Transform::incomplete: 
   The rule base could not compute the 
                           1
    forward z-transform of - with respect to n.
                           n
:[font = message; inactive; ]
Transform::incomplete: 
   The rule base could not compute the 
                           1
    forward z-transform of - with respect to n.
                           n
:[font = output; inactive; output; endGroup; ]
MakeZObject[ScaleT[ZForm, 
   SubT[ZForm, SubstituteForT[ZForm, 
     SignalProcessing`Digital`ZTransform`Private`forwar\
       dz[n^(-1), n, z, 
      {False, False, False, False, False}, {n}, {z}, 
      {Dialogue -> True}], z, E^(I*a)*z], 
    SubstituteForT[ZForm, 
     SignalProcessing`Digital`ZTransform`Private`forwar\
       dz[n^(-1), n, z, 
      {False, False, False, False, False}, {n}, {z}, 
      {Dialogue -> True}], z, E^(-I*a)*z]], I/2/Pi], z]
;[o]
-Incomplete z-Transform-
:[font = input; startGroup; ]
DTFTransform[Sin[a n]/(Pi n), n, w]
:[font = output; inactive; output; endGroup; ]
DTFTData[-CStep[-a + w] + CStep[a + w], FVariables[w]]
;[o]
DTFTData[-CStep[-a + w] + CStep[a + w], FVariables[w]]
:[font = text; inactive; ]
		The following function calculates the z-transform and the DTFT and plots the magnitude and phase of  the frequency response. Notice that the DTFT is well-defined whereas the z-transform is not !
:[font = input; startGroup; Cclosed; ]
DSPAnalyze[ Sin[a n]/(Pi n), n, -10, 10 ]
:[font = print; inactive; ]
For plotting only, these symbols will
:[font = print; inactive; ]
be assigned a value of 1:  {a}
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.04762 0.10943 1.55158 [
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Msboxa
[(-10)] 0.02381 0.09693 0 1 Msboxa
[(-5)] 0.2619 0.09693 0 1 Msboxa
[(5)] 0.7381 0.09693 0 1 Msboxa
[(10)] 0.97619 0.09693 0 1 Msboxa
[(n)] 1.00625 0.10943 -1 0 Msboxa
[(-0.05)] 0.4875 0.03186 1 0 Msboxa
[(0.05)] 0.4875 0.18701 1 0 Msboxa
[(0.1)] 0.4875 0.26459 1 0 Msboxa
[(0.15)] 0.4875 0.34217 1 0 Msboxa
[(0.2)] 0.4875 0.41975 1 0 Msboxa
[(0.25)] 0.4875 0.49733 1 0 Msboxa
[(0.3)] 0.4875 0.57491 1 0 Msboxa
[(Re{f[]})] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.10943 moveto
1 0.10943 lineto
stroke
0.02381 0.10318 moveto
0.02381 0.11568 lineto
stroke
0 setgray
[(-10)] 0.02381 0.09693 0 1 Mshowa
0.2619 0.10318 moveto
0.2619 0.11568 lineto
stroke
0 setgray
[(-5)] 0.2619 0.09693 0 1 Mshowa
0.7381 0.10318 moveto
0.7381 0.11568 lineto
stroke
0 setgray
[(5)] 0.7381 0.09693 0 1 Mshowa
0.97619 0.10318 moveto
0.97619 0.11568 lineto
stroke
0 setgray
[(10)] 0.97619 0.09693 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.10943 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.03186 moveto
0.50625 0.03186 lineto
stroke
0 setgray
[(-0.05)] 0.4875 0.03186 1 0 Mshowa
0.49375 0.18701 moveto
0.50625 0.18701 lineto
stroke
0 setgray
[(0.05)] 0.4875 0.18701 1 0 Mshowa
0.49375 0.26459 moveto
0.50625 0.26459 lineto
stroke
0 setgray
[(0.1)] 0.4875 0.26459 1 0 Mshowa
0.49375 0.34217 moveto
0.50625 0.34217 lineto
stroke
0 setgray
[(0.15)] 0.4875 0.34217 1 0 Mshowa
0.49375 0.41975 moveto
0.50625 0.41975 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.41975 1 0 Mshowa
0.49375 0.49733 moveto
0.50625 0.49733 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.49733 1 0 Mshowa
0.49375 0.57491 moveto
0.50625 0.57491 lineto
stroke
0 setgray
[(0.3)] 0.4875 0.57491 1 0 Mshowa
0 setgray
[(Re{f[]})] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.10943 moveto
0.02381 0.08257 lineto
stroke
0.008 setlinewidth
0.02381 0.08257 Mdot
0.004 setlinewidth
0.07143 0.10943 moveto
0.07143 0.13205 lineto
stroke
0.008 setlinewidth
0.07143 0.13205 Mdot
0.004 setlinewidth
0.11905 0.10943 moveto
0.11905 0.17051 lineto
stroke
0.008 setlinewidth
0.11905 0.17051 Mdot
0.004 setlinewidth
0.16667 0.10943 moveto
0.16667 0.15579 lineto
stroke
0.008 setlinewidth
0.16667 0.15579 Mdot
0.004 setlinewidth
0.21429 0.10943 moveto
0.21429 0.08643 lineto
stroke
0.008 setlinewidth
0.21429 0.08643 Mdot
0.004 setlinewidth
0.2619 0.10943 moveto
0.2619 0.01472 lineto
stroke
0.008 setlinewidth
0.2619 0.01472 Mdot
0.004 setlinewidth
0.30952 0.10943 moveto
0.30952 0.01599 lineto
stroke
0.008 setlinewidth
0.30952 0.01599 Mdot
0.004 setlinewidth
0.35714 0.10943 moveto
0.35714 0.13267 lineto
stroke
0.008 setlinewidth
0.35714 0.13267 Mdot
0.004 setlinewidth
0.40476 0.10943 moveto
0.40476 0.33398 lineto
stroke
0.008 setlinewidth
0.40476 0.33398 Mdot
0.004 setlinewidth
0.45238 0.10943 moveto
0.45238 0.52502 lineto
stroke
0.008 setlinewidth
0.45238 0.52502 Mdot
0.004 setlinewidth
0.5 0.10943 moveto
0.5 0.60332 lineto
stroke
0.008 setlinewidth
0.5 0.60332 Mdot
0.004 setlinewidth
0.54762 0.10943 moveto
0.54762 0.52502 lineto
stroke
0.008 setlinewidth
0.54762 0.52502 Mdot
0.004 setlinewidth
0.59524 0.10943 moveto
0.59524 0.33398 lineto
stroke
0.008 setlinewidth
0.59524 0.33398 Mdot
0.004 setlinewidth
0.64286 0.10943 moveto
0.64286 0.13267 lineto
stroke
0.008 setlinewidth
0.64286 0.13267 Mdot
0.004 setlinewidth
0.69048 0.10943 moveto
0.69048 0.01599 lineto
stroke
0.008 setlinewidth
0.69048 0.01599 Mdot
0.004 setlinewidth
0.7381 0.10943 moveto
0.7381 0.01472 lineto
stroke
0.008 setlinewidth
0.7381 0.01472 Mdot
0.004 setlinewidth
0.78571 0.10943 moveto
0.78571 0.08643 lineto
stroke
0.008 setlinewidth
0.78571 0.08643 Mdot
0.004 setlinewidth
0.83333 0.10943 moveto
0.83333 0.15579 lineto
stroke
0.008 setlinewidth
0.83333 0.15579 Mdot
0.004 setlinewidth
0.88095 0.10943 moveto
0.88095 0.17051 lineto
stroke
0.008 setlinewidth
0.88095 0.17051 Mdot
0.004 setlinewidth
0.92857 0.10943 moveto
0.92857 0.13205 lineto
stroke
0.008 setlinewidth
0.92857 0.13205 Mdot
0.004 setlinewidth
0.97619 0.10943 moveto
0.97619 0.08257 lineto
stroke
0.008 setlinewidth
0.97619 0.08257 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = message; inactive; ]
Transform::incomplete: 
   The rule base could not compute the 
                           1
    forward z-transform of - with respect to n.
                           n
:[font = message; inactive; ]
Transform::incomplete: 
   The rule base could not compute the 
                           1
    forward z-transform of - with respect to n.
                           n
:[font = message; inactive; ]
ZTransform::notvalid: 
   The forward z-transform could not be found.
:[font = print; inactive; ]
Sin[a n]
--------
  Pi n
:[font = print; inactive; ]
has the following frequency response:
:[font = print; inactive; ]
-CStep[-a + w] + CStep[a + w]
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.01472 0.5886 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.00222 0 1 Msboxa
[(-4)] 0.19685 0.00222 0 1 Msboxa
[(-2)] 0.34842 0.00222 0 1 Msboxa
[(2)] 0.65158 0.00222 0 1 Msboxa
[(4)] 0.80315 0.00222 0 1 Msboxa
[(6)] 0.95473 0.00222 0 1 Msboxa
[(w)] 1.00625 0.01472 -1 0 Msboxa
[(0.2)] 0.4875 0.13244 1 0 Msboxa
[(0.4)] 0.4875 0.25016 1 0 Msboxa
[(0.6)] 0.4875 0.36788 1 0 Msboxa
[(0.8)] 0.4875 0.4856 1 0 Msboxa
[(1)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.04527 0.00847 moveto
0.04527 0.02097 lineto
stroke
0 setgray
[(-6)] 0.04527 0.00222 0 1 Mshowa
0.19685 0.00847 moveto
0.19685 0.02097 lineto
stroke
0 setgray
[(-4)] 0.19685 0.00222 0 1 Mshowa
0.34842 0.00847 moveto
0.34842 0.02097 lineto
stroke
0 setgray
[(-2)] 0.34842 0.00222 0 1 Mshowa
0.65158 0.00847 moveto
0.65158 0.02097 lineto
stroke
0 setgray
[(2)] 0.65158 0.00222 0 1 Mshowa
0.80315 0.00847 moveto
0.80315 0.02097 lineto
stroke
0 setgray
[(4)] 0.80315 0.00222 0 1 Mshowa
0.95473 0.00847 moveto
0.95473 0.02097 lineto
stroke
0 setgray
[(6)] 0.95473 0.00222 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.01472 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.13244 moveto
0.50625 0.13244 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.13244 1 0 Mshowa
0.49375 0.25016 moveto
0.50625 0.25016 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.25016 1 0 Mshowa
0.49375 0.36788 moveto
0.50625 0.36788 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.36788 1 0 Mshowa
0.49375 0.4856 moveto
0.50625 0.4856 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.4856 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(1)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.60332 moveto
0.04365 0.60332 lineto
0.06349 0.60332 lineto
0.07341 0.60332 lineto
0.08333 0.60332 lineto
0.08829 0.60332 lineto
0.09325 0.60332 lineto
0.09573 0.60332 lineto
0.09697 0.60332 lineto
0.09821 0.60332 lineto
0.09945 0.60332 lineto
0.10069 0.01472 lineto
0.10193 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.38095 0.01472 lineto
0.40079 0.01472 lineto
0.41071 0.01472 lineto
0.41567 0.01472 lineto
0.41815 0.01472 lineto
0.42063 0.01472 lineto
0.42187 0.01472 lineto
0.42312 0.01472 lineto
0.42436 0.60332 lineto
0.4256 0.60332 lineto
0.42808 0.60332 lineto
0.43056 0.60332 lineto
0.44048 0.60332 lineto
0.46032 0.60332 lineto
0.5 0.60332 lineto
0.51984 0.60332 lineto
0.53968 0.60332 lineto
0.5496 0.60332 lineto
0.55952 0.60332 lineto
0.56448 0.60332 lineto
0.56944 0.60332 lineto
0.57192 0.60332 lineto
0.57316 0.60332 lineto
0.5744 0.60332 lineto
0.57564 0.60332 lineto
0.57688 0.01472 lineto
0.57937 0.01472 lineto
0.61905 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
Mistroke
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.87698 0.01472 lineto
0.8869 0.01472 lineto
0.89187 0.01472 lineto
0.89435 0.01472 lineto
0.89683 0.01472 lineto
0.89807 0.01472 lineto
0.89931 0.01472 lineto
0.90055 0.60332 lineto
0.90179 0.60332 lineto
0.90427 0.60332 lineto
0.90675 0.60332 lineto
0.91667 0.60332 lineto
0.93651 0.60332 lineto
0.97619 0.60332 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.5886 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-0.4)] 0.4875 0.07358 1 0 Msboxa
[(-0.2)] 0.4875 0.1913 1 0 Msboxa
[(0.2)] 0.4875 0.42674 1 0 Msboxa
[(0.4)] 0.4875 0.54446 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07358 moveto
0.50625 0.07358 lineto
stroke
0 setgray
[(-0.4)] 0.4875 0.07358 1 0 Mshowa
0.49375 0.1913 moveto
0.50625 0.1913 lineto
stroke
0 setgray
[(-0.2)] 0.4875 0.1913 1 0 Mshowa
0.49375 0.42674 moveto
0.50625 0.42674 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.42674 1 0 Mshowa
0.49375 0.54446 moveto
0.50625 0.54446 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.54446 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.06349 0.30902 lineto
0.10317 0.30902 lineto
0.14286 0.30902 lineto
0.18254 0.30902 lineto
0.22222 0.30902 lineto
0.2619 0.30902 lineto
0.30159 0.30902 lineto
0.34127 0.30902 lineto
0.38095 0.30902 lineto
0.42063 0.30902 lineto
0.46032 0.30902 lineto
0.5 0.30902 lineto
0.53968 0.30902 lineto
0.57937 0.30902 lineto
0.61905 0.30902 lineto
0.65873 0.30902 lineto
0.69841 0.30902 lineto
0.7381 0.30902 lineto
0.77778 0.30902 lineto
0.81746 0.30902 lineto
0.85714 0.30902 lineto
0.89683 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
MakeZObject[ScaleT[ZForm, 
   SubT[ZForm, SubstituteForT[ZForm, 
     SignalProcessing`Digital`ZTransform`Private`forwar\
       dz[n^(-1), n, z, 
      {False, False, False, False, False}, {n}, {z}, 
      {Dialogue -> True}], z, E^(I*a)*z], 
    SubstituteForT[ZForm, 
     SignalProcessing`Digital`ZTransform`Private`forwar\
       dz[n^(-1), n, z, 
      {False, False, False, False, False}, {n}, {z}, 
      {Dialogue -> True}], z, E^(-I*a)*z]], I/2/Pi], z]
;[o]
-Incomplete z-Transform-
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example:  DTFT of Sequences That Are Not Absolutely Summable
:[font = text; inactive; ]
		The following sequences are neither absolutely summable nor square-summable; however, they do possess DTFT's defined in terms of some special mathematical functions such as the impulse function (Dirac delta function).
:[font = text; inactive; ]
		Evaluate the following input cells by placing the cursor in each of the input cells and hitting the ENTER key.
:[font = input; startGroup; ]
ZTransform[Cos[a n], n, z]
:[font = message; inactive; startGroup; ]
Transform::incomplete: 
   The rule base could not compute the forward z-transform of 
    1 with respect to n.
:[font = message; inactive; ]
Transform::incomplete: 
   The rule base could not compute the forward z-transform of 
    1 with respect to n.
:[font = output; inactive; output; endGroup; endGroup; ]
MakeZObject[ScaleT[ZForm, 
   AddT[ZForm, SubstituteForT[ZForm, 
     SignalProcessing`Digital`ZTransform`Private`forwardz[1, 
      n, z, {True, False, False, False, False}, {n}, {z}, 
      {Dialogue -> True}], z, E^(I*a)*z], 
    SubstituteForT[ZForm, 
     SignalProcessing`Digital`ZTransform`Private`forwardz[1, 
      n, z, {True, False, False, False, False}, {n}, {z}, 
      {Dialogue -> True}], z, E^(-I*a)*z]], 1/2], z]
;[o]
-Incomplete z-Transform-
:[font = input; startGroup; ]
DTFTransform[Cos[a n], n, w]
:[font = output; inactive; output; endGroup; ]
DTFTData[Pi*Summation[l1, DirectedInfinity[-1], 
     DirectedInfinity[1], 1][Delta[-a + 2*Pi*l1 + w] + 
     Delta[a + 2*Pi*l1 + w]], FVariables[w]]
;[o]
DTFTData[Pi Summation[l1, -Infinity, Infinity, 1][Delta[-a + 
 
       2 Pi l1 + w] + Delta[a + 2 Pi l1 + w]], FVariables[w]]
:[font = text; inactive; ]
		The following function displays the results of the two other functions and plots the magnitude and phase of  the frequency response. Notice that the DTFT is well defined whereas the z-transform is not !
:[font = input; startGroup; Cclosed; ]
DSPAnalyze[Cos[a n], n, - 10, 10]
:[font = print; inactive; startGroup; ]
These variables were assigned a value of 1: {a}
Cos[n]
has the following frequency response:
Pi Summation[l2, -Infinity, Infinity, 1][Delta[-1 + 
 
      2 Pi l2 + w] + Delta[1 + 2 Pi l2 + w]]
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.04762 0.30754 0.29578 [
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Msboxa
[(-10)] 0.02381 0.29504 0 1 Msboxa
[(-5)] 0.2619 0.29504 0 1 Msboxa
[(5)] 0.7381 0.29504 0 1 Msboxa
[(10)] 0.97619 0.29504 0 1 Msboxa
[(n)] 1.00625 0.30754 -1 0 Msboxa
[(-1)] 0.4875 0.01176 1 0 Msboxa
[(-0.5)] 0.4875 0.15965 1 0 Msboxa
[(0.5)] 0.4875 0.45543 1 0 Msboxa
[(1)] 0.4875 0.60332 1 0 Msboxa
[(Re{f[]})] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30754 moveto
1 0.30754 lineto
stroke
0.02381 0.30129 moveto
0.02381 0.31379 lineto
stroke
0 setgray
[(-10)] 0.02381 0.29504 0 1 Mshowa
0.2619 0.30129 moveto
0.2619 0.31379 lineto
stroke
0 setgray
[(-5)] 0.2619 0.29504 0 1 Mshowa
0.7381 0.30129 moveto
0.7381 0.31379 lineto
stroke
0 setgray
[(5)] 0.7381 0.29504 0 1 Mshowa
0.97619 0.30129 moveto
0.97619 0.31379 lineto
stroke
0 setgray
[(10)] 0.97619 0.29504 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.30754 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.01176 moveto
0.50625 0.01176 lineto
stroke
0 setgray
[(-1)] 0.4875 0.01176 1 0 Mshowa
0.49375 0.15965 moveto
0.50625 0.15965 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.15965 1 0 Mshowa
0.49375 0.45543 moveto
0.50625 0.45543 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.45543 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(1)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[(Re{f[]})] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.30754 moveto
0.02381 0.05935 lineto
stroke
0.008 setlinewidth
0.02381 0.05935 Mdot
0.004 setlinewidth
0.07143 0.30754 moveto
0.07143 0.03804 lineto
stroke
0.008 setlinewidth
0.07143 0.03804 Mdot
0.004 setlinewidth
0.11905 0.30754 moveto
0.11905 0.2645 lineto
stroke
0.008 setlinewidth
0.11905 0.2645 Mdot
0.004 setlinewidth
0.16667 0.30754 moveto
0.16667 0.53053 lineto
stroke
0.008 setlinewidth
0.16667 0.53053 Mdot
0.004 setlinewidth
0.21429 0.30754 moveto
0.21429 0.59154 lineto
stroke
0.008 setlinewidth
0.21429 0.59154 Mdot
0.004 setlinewidth
0.2619 0.30754 moveto
0.2619 0.39144 lineto
stroke
0.008 setlinewidth
0.2619 0.39144 Mdot
0.004 setlinewidth
0.30952 0.30754 moveto
0.30952 0.1142 lineto
stroke
0.008 setlinewidth
0.30952 0.1142 Mdot
0.004 setlinewidth
0.35714 0.30754 moveto
0.35714 0.01472 lineto
stroke
0.008 setlinewidth
0.35714 0.01472 Mdot
0.004 setlinewidth
0.40476 0.30754 moveto
0.40476 0.18445 lineto
stroke
0.008 setlinewidth
0.40476 0.18445 Mdot
0.004 setlinewidth
0.45238 0.30754 moveto
0.45238 0.46735 lineto
stroke
0.008 setlinewidth
0.45238 0.46735 Mdot
0.004 setlinewidth
0.5 0.30754 moveto
0.5 0.60332 lineto
stroke
0.008 setlinewidth
0.5 0.60332 Mdot
0.004 setlinewidth
0.54762 0.30754 moveto
0.54762 0.46735 lineto
stroke
0.008 setlinewidth
0.54762 0.46735 Mdot
0.004 setlinewidth
0.59524 0.30754 moveto
0.59524 0.18445 lineto
stroke
0.008 setlinewidth
0.59524 0.18445 Mdot
0.004 setlinewidth
0.64286 0.30754 moveto
0.64286 0.01472 lineto
stroke
0.008 setlinewidth
0.64286 0.01472 Mdot
0.004 setlinewidth
0.69048 0.30754 moveto
0.69048 0.1142 lineto
stroke
0.008 setlinewidth
0.69048 0.1142 Mdot
0.004 setlinewidth
0.7381 0.30754 moveto
0.7381 0.39144 lineto
stroke
0.008 setlinewidth
0.7381 0.39144 Mdot
0.004 setlinewidth
0.78571 0.30754 moveto
0.78571 0.59154 lineto
stroke
0.008 setlinewidth
0.78571 0.59154 Mdot
0.004 setlinewidth
0.83333 0.30754 moveto
0.83333 0.53053 lineto
stroke
0.008 setlinewidth
0.83333 0.53053 Mdot
0.004 setlinewidth
0.88095 0.30754 moveto
0.88095 0.2645 lineto
stroke
0.008 setlinewidth
0.88095 0.2645 Mdot
0.004 setlinewidth
0.92857 0.30754 moveto
0.92857 0.03804 lineto
stroke
0.008 setlinewidth
0.92857 0.03804 Mdot
0.004 setlinewidth
0.97619 0.30754 moveto
0.97619 0.05935 lineto
stroke
0.008 setlinewidth
0.97619 0.05935 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = message; inactive; ]
Transform::incomplete: 
   The rule base could not compute the forward z-transform
     of 1 with respect to n.
:[font = message; inactive; ]
Transform::incomplete: 
   The rule base could not compute the forward z-transform
     of 1 with respect to n.
:[font = message; inactive; endGroup; ]
ZTransform::notvalid: 
   The forward z-transform could not be found.
:[font = text; inactive; endGroup; endGroup; ]
Note: It seems that the DSP analyze does not work on the given sequence; this is a limitation ! One must be able at least to display the magnitude and phase of the frequency response.
:[font = text; inactive; ]
	Note that none of the sequences given in the last examples are absolutely summable, even if these sequences are weighted by |z|^-n (c.f. equation 3).  This latter fact justifies the non-convergence of the z-transform of these sequences for any z in the complex plane.
:[font = text; inactive; endGroup; ]
	In general, while uniform convergence of the z-transform requires absolute summability of the exponentially weighted sequence (i.e. |x[n]| |z|^-n, as in equation (3)), the Fourier transform representation has been extended to include some non-absolutely summable functions of interest by relaxing the condition of uniform convergence of the infinite sum defining the DTFT (c.f. equation (5)) and by introducing special generalized functions (such as "impulses").  However, in this latter case, the obtained DTFT CANNOT result from the evaluation of the z-transform on the unit circle!  Hence, it becomes now clear why it is NOT ALWAYS correct to think of the DTFT as being the z-transform evaluated on the unit circle of the complex z-plane.
:[font = section; inactive; startGroup; Cclosed; ]
Frequency Responses of Stable Systems with a Rational Transfer Functions
:[font = text; inactive; ]
	As mentioned in the previous section, the frequency response of a stable discrete system (which is just the DTFT of the impulse response of this system) can be directly obtained by simply evaluating the system function (which is the z-transform of the impulse response of the system) on the unit circle in the complex z-plane.  As will be seen in this section, this latter fact is very important, especially in the case of a rational system function H(z), because it allows us to approximate the frequency response H(e^jw) by relying solely on the information given in the pole-zero diagram of the rational system function H(z). 
:[font = subsection; inactive; startGroup; Cclosed; ]
Why the DTFT can be obtained from the z-Transform
:[font = text; inactive; endGroup; ]
		As discussed previously, the poles of a rational z-transform play a major role in determining all of the possible ROC's for the transform. Moreover, the location of the zeros and poles of the rational system function H(z) can be used to construct an approximate sketch of the frequency-response function H(e^jw) simply by using the geometry of the pole-zero diagram of H(z) to investigate the relative positions of the zeros and poles and their closeness to the unit circle. This procedure is based on the fact that the frequency response corresponds to the system function evaluated on the unit circle and that the complex value of each zero or pole factor of the rational frequency response H(e^jw), i.e. factors in the numerator and denominator respectively, can be represented by a two-dimensional vector in the z-plane from the corresponding zero or pole to a point z = e^jw on the unit circle. 
:[font = subsection; inactive; startGroup; Cclosed; ]
How to obtain the DTFT from the z-Transform
:[font = text; inactive; endGroup; ]
		The continuous frequency response of a system characterized by a rational z-transform can be computed from the location of the poles and zeroes.  A vector from a zero to the unit circle is referred to as a "zero vector", and a vector from a pole to the unit circle is referred to as a "pole vector".   Such a vector representation is convenient since it greatly simplifies the construction of the frequency response from the corresponding pole-zero diagram by simply observing the change in the length of the zero / pole vectors (to construct the magnitude response) or the change in the angle (with respect to the Re{z} axis) of the zero / pole vectors (to construct the phase response), as the point z = e^jw moves around the unit circle.	
:[font = subsection; inactive; startGroup; Cclosed; ]
Systems with either a single pole or single zero
:[font = text; inactive; ]
		The following example illustrates the correspondence between the pole-zero plot and the frequency response.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example:  Animation of Single Pole System 
:[font = text; inactive; ]
		Animate the following cells by selecting the graphics cells to be animated and then choosing the Animation option from the Graph sub-menu. You can also set the desired animation speed by using the Preferences option in the main menu, or the options in the bottom right side of  the notebook border. 
		The black dot on the circle represents the point z = e^jw moving around the unit circle, while the symbol "X" represents a pole.
:[font = input; startGroup; ]
Do[VectorPoleZeroPlot[1/(z - 0.8 Exp[I Pi/4]), z, 0.8, Infinity, w, 
                      True, Dialogue -> False],
   {w,-Pi,Pi,Pi/4} ]
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.1 0.5 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.1 0.5 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.21716 0.21716 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.21716 0.21716 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.5 0.1 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.5 0.1 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.78284 0.21716 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.78284 0.21716 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.9 0.5 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.78284 0.78284 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.78284 0.78284 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.5 0.9 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.5 0.9 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.21716 0.78284 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.21716 0.78284 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.1 0.5 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.1 0.5 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = input; startGroup; ]
Do[MagPhasePlot[1/(Exp[I w] - 0.8 Exp[I Pi/4]),{w,-Pi-0.01,r},
                PhaseRangeScale -> Null, 
                PlotRange -> {{-Pi,Pi},{0,5.5}}],
   {r,-Pi,Pi,Pi/4}]                
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.11237 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(1)] 0.4875 0.11237 1 0 Msboxa
[(2)] 0.4875 0.22474 1 0 Msboxa
[(3)] 0.4875 0.33711 1 0 Msboxa
[(4)] 0.4875 0.44948 1 0 Msboxa
[(5)] 0.4875 0.56185 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.11237 moveto
0.50625 0.11237 lineto
stroke
0 setgray
[(1)] 0.4875 0.11237 1 0 Mshowa
0.49375 0.22474 moveto
0.50625 0.22474 lineto
stroke
0 setgray
[(2)] 0.4875 0.22474 1 0 Mshowa
0.49375 0.33711 moveto
0.50625 0.33711 lineto
stroke
0 setgray
[(3)] 0.4875 0.33711 1 0 Mshowa
0.49375 0.44948 moveto
0.50625 0.44948 lineto
stroke
0 setgray
[(4)] 0.4875 0.44948 1 0 Mshowa
0.49375 0.56185 moveto
0.50625 0.56185 lineto
stroke
0 setgray
[(5)] 0.4875 0.56185 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.06764 moveto
-0.00153 0.06763 lineto
-0.00146 0.06763 lineto
-0.00139 0.06762 lineto
-0.00133 0.06762 lineto
-0.00126 0.06761 lineto
-0.00119 0.0676 lineto
-0.00113 0.0676 lineto
-0.00106 0.06759 lineto
-0.00099 0.06759 lineto
-0.00093 0.06758 lineto
-0.00086 0.06757 lineto
-0.0008 0.06757 lineto
-0.00073 0.06756 lineto
-0.00066 0.06756 lineto
-0.0006 0.06755 lineto
-0.00053 0.06755 lineto
-0.00046 0.06754 lineto
-0.0004 0.06753 lineto
-0.00033 0.06753 lineto
-0.00027 0.06752 lineto
-0.0002 0.06752 lineto
-0.00013 0.06751 lineto
-7e-05 0.06751 lineto
0 0.0675 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.11237 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(1)] 0.4875 0.11237 1 0 Msboxa
[(2)] 0.4875 0.22474 1 0 Msboxa
[(3)] 0.4875 0.33711 1 0 Msboxa
[(4)] 0.4875 0.44948 1 0 Msboxa
[(5)] 0.4875 0.56185 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.11237 moveto
0.50625 0.11237 lineto
stroke
0 setgray
[(1)] 0.4875 0.11237 1 0 Mshowa
0.49375 0.22474 moveto
0.50625 0.22474 lineto
stroke
0 setgray
[(2)] 0.4875 0.22474 1 0 Mshowa
0.49375 0.33711 moveto
0.50625 0.33711 lineto
stroke
0 setgray
[(3)] 0.4875 0.33711 1 0 Mshowa
0.49375 0.44948 moveto
0.50625 0.44948 lineto
stroke
0 setgray
[(4)] 0.4875 0.44948 1 0 Mshowa
0.49375 0.56185 moveto
0.50625 0.56185 lineto
stroke
0 setgray
[(5)] 0.4875 0.56185 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.06764 moveto
0.00368 0.06719 lineto
0.00896 0.06676 lineto
0.01423 0.06635 lineto
0.01951 0.06597 lineto
0.02478 0.06561 lineto
0.03006 0.06527 lineto
0.03533 0.06496 lineto
0.04061 0.06466 lineto
0.04588 0.06438 lineto
0.05115 0.06412 lineto
0.05643 0.06389 lineto
0.0617 0.06367 lineto
0.06698 0.06347 lineto
0.07225 0.06328 lineto
0.07753 0.06312 lineto
0.0828 0.06297 lineto
0.08808 0.06284 lineto
0.09335 0.06273 lineto
0.09863 0.06264 lineto
0.1039 0.06256 lineto
0.10918 0.0625 lineto
0.11181 0.06248 lineto
0.11445 0.06246 lineto
0.11709 0.06245 lineto
0.11841 0.06244 lineto
0.11973 0.06244 lineto
0.12104 0.06243 lineto
0.1217 0.06243 lineto
0.12236 0.06243 lineto
0.12302 0.06243 lineto
0.12335 0.06243 lineto
0.12368 0.06243 lineto
0.12401 0.06243 lineto
0.12418 0.06243 lineto
0.12434 0.06243 lineto
0.12451 0.06243 lineto
0.12467 0.06243 lineto
0.125 0.06243 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.11237 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(1)] 0.4875 0.11237 1 0 Msboxa
[(2)] 0.4875 0.22474 1 0 Msboxa
[(3)] 0.4875 0.33711 1 0 Msboxa
[(4)] 0.4875 0.44948 1 0 Msboxa
[(5)] 0.4875 0.56185 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.11237 moveto
0.50625 0.11237 lineto
stroke
0 setgray
[(1)] 0.4875 0.11237 1 0 Mshowa
0.49375 0.22474 moveto
0.50625 0.22474 lineto
stroke
0 setgray
[(2)] 0.4875 0.22474 1 0 Mshowa
0.49375 0.33711 moveto
0.50625 0.33711 lineto
stroke
0 setgray
[(3)] 0.4875 0.33711 1 0 Mshowa
0.49375 0.44948 moveto
0.50625 0.44948 lineto
stroke
0 setgray
[(4)] 0.4875 0.44948 1 0 Mshowa
0.49375 0.56185 moveto
0.50625 0.56185 lineto
stroke
0 setgray
[(5)] 0.4875 0.56185 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.06764 moveto
0.00889 0.06676 lineto
0.01937 0.06598 lineto
0.02986 0.06529 lineto
0.04034 0.06467 lineto
0.05082 0.06414 lineto
0.06131 0.06368 lineto
0.07179 0.0633 lineto
0.08227 0.06299 lineto
0.09276 0.06275 lineto
0.098 0.06265 lineto
0.10324 0.06257 lineto
0.10848 0.06251 lineto
0.1111 0.06249 lineto
0.11372 0.06247 lineto
0.11634 0.06245 lineto
0.11765 0.06244 lineto
0.11896 0.06244 lineto
0.12027 0.06243 lineto
0.12093 0.06243 lineto
0.12158 0.06243 lineto
0.12224 0.06243 lineto
0.12289 0.06243 lineto
0.12322 0.06243 lineto
0.12355 0.06243 lineto
0.12388 0.06243 lineto
0.1242 0.06243 lineto
0.12453 0.06243 lineto
0.12486 0.06243 lineto
0.12519 0.06243 lineto
0.12551 0.06243 lineto
0.12584 0.06243 lineto
0.12617 0.06243 lineto
0.1265 0.06243 lineto
0.12682 0.06243 lineto
0.12748 0.06243 lineto
0.12814 0.06243 lineto
0.12945 0.06243 lineto
0.13076 0.06244 lineto
0.13207 0.06244 lineto
0.13469 0.06246 lineto
0.13731 0.06247 lineto
0.13993 0.0625 lineto
0.14517 0.06255 lineto
0.15041 0.06262 lineto
0.15565 0.06271 lineto
0.16614 0.06295 lineto
0.17662 0.06325 lineto
0.1871 0.06362 lineto
0.19759 0.06407 lineto
Mistroke
0.20807 0.06459 lineto
0.21855 0.06519 lineto
0.22903 0.06587 lineto
0.23952 0.06664 lineto
0.25 0.0675 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.11237 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(1)] 0.4875 0.11237 1 0 Msboxa
[(2)] 0.4875 0.22474 1 0 Msboxa
[(3)] 0.4875 0.33711 1 0 Msboxa
[(4)] 0.4875 0.44948 1 0 Msboxa
[(5)] 0.4875 0.56185 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.11237 moveto
0.50625 0.11237 lineto
stroke
0 setgray
[(1)] 0.4875 0.11237 1 0 Mshowa
0.49375 0.22474 moveto
0.50625 0.22474 lineto
stroke
0 setgray
[(2)] 0.4875 0.22474 1 0 Mshowa
0.49375 0.33711 moveto
0.50625 0.33711 lineto
stroke
0 setgray
[(3)] 0.4875 0.33711 1 0 Mshowa
0.49375 0.44948 moveto
0.50625 0.44948 lineto
stroke
0 setgray
[(4)] 0.4875 0.44948 1 0 Mshowa
0.49375 0.56185 moveto
0.50625 0.56185 lineto
stroke
0 setgray
[(5)] 0.4875 0.56185 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.06764 moveto
0.0141 0.06636 lineto
0.02979 0.06529 lineto
0.04548 0.0644 lineto
0.06117 0.06369 lineto
0.07687 0.06314 lineto
0.08471 0.06292 lineto
0.09256 0.06275 lineto
0.1004 0.06261 lineto
0.10432 0.06256 lineto
0.10825 0.06251 lineto
0.11217 0.06248 lineto
0.11413 0.06246 lineto
0.11609 0.06245 lineto
0.11805 0.06244 lineto
0.12002 0.06244 lineto
0.121 0.06243 lineto
0.12198 0.06243 lineto
0.12296 0.06243 lineto
0.12345 0.06243 lineto
0.12394 0.06243 lineto
0.12443 0.06243 lineto
0.12492 0.06243 lineto
0.12541 0.06243 lineto
0.1259 0.06243 lineto
0.12639 0.06243 lineto
0.12688 0.06243 lineto
0.12786 0.06243 lineto
0.12884 0.06243 lineto
0.12982 0.06243 lineto
0.13178 0.06244 lineto
0.13375 0.06245 lineto
0.13571 0.06246 lineto
0.13963 0.06249 lineto
0.14355 0.06253 lineto
0.14748 0.06258 lineto
0.15532 0.06271 lineto
0.16317 0.06287 lineto
0.17101 0.06308 lineto
0.1867 0.0636 lineto
0.2024 0.0643 lineto
0.21809 0.06516 lineto
0.23378 0.06621 lineto
0.24947 0.06745 lineto
0.26516 0.06892 lineto
0.28085 0.07062 lineto
0.29654 0.07258 lineto
0.31223 0.07483 lineto
0.32793 0.07743 lineto
0.34362 0.0804 lineto
Mistroke
0.35931 0.08381 lineto
0.375 0.08775 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.11237 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(1)] 0.4875 0.11237 1 0 Msboxa
[(2)] 0.4875 0.22474 1 0 Msboxa
[(3)] 0.4875 0.33711 1 0 Msboxa
[(4)] 0.4875 0.44948 1 0 Msboxa
[(5)] 0.4875 0.56185 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.11237 moveto
0.50625 0.11237 lineto
stroke
0 setgray
[(1)] 0.4875 0.11237 1 0 Mshowa
0.49375 0.22474 moveto
0.50625 0.22474 lineto
stroke
0 setgray
[(2)] 0.4875 0.22474 1 0 Mshowa
0.49375 0.33711 moveto
0.50625 0.33711 lineto
stroke
0 setgray
[(3)] 0.4875 0.33711 1 0 Mshowa
0.49375 0.44948 moveto
0.50625 0.44948 lineto
stroke
0 setgray
[(4)] 0.4875 0.44948 1 0 Mshowa
0.49375 0.56185 moveto
0.50625 0.56185 lineto
stroke
0 setgray
[(5)] 0.4875 0.56185 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.06764 moveto
0.01931 0.06599 lineto
0.04021 0.06468 lineto
0.05066 0.06415 lineto
0.06111 0.06369 lineto
0.07156 0.06331 lineto
0.08201 0.06299 lineto
0.09246 0.06275 lineto
0.09768 0.06266 lineto
0.10291 0.06258 lineto
0.10813 0.06251 lineto
0.11074 0.06249 lineto
0.11336 0.06247 lineto
0.11597 0.06245 lineto
0.11728 0.06245 lineto
0.11858 0.06244 lineto
0.11989 0.06244 lineto
0.12119 0.06243 lineto
0.12185 0.06243 lineto
0.1225 0.06243 lineto
0.12315 0.06243 lineto
0.12381 0.06243 lineto
0.12446 0.06243 lineto
0.12511 0.06243 lineto
0.12577 0.06243 lineto
0.12642 0.06243 lineto
0.12707 0.06243 lineto
0.12773 0.06243 lineto
0.12903 0.06243 lineto
0.13034 0.06244 lineto
0.13164 0.06244 lineto
0.13426 0.06245 lineto
0.13687 0.06247 lineto
0.13948 0.06249 lineto
0.14471 0.06255 lineto
0.14993 0.06262 lineto
0.15516 0.06271 lineto
0.16561 0.06293 lineto
0.17606 0.06323 lineto
0.18651 0.0636 lineto
0.2074 0.06455 lineto
0.2283 0.06582 lineto
0.2492 0.06743 lineto
0.2701 0.06942 lineto
0.291 0.07185 lineto
0.3119 0.07478 lineto
0.3328 0.07831 lineto
0.3537 0.08254 lineto
0.3746 0.08764 lineto
0.3955 0.09382 lineto
Mistroke
0.4164 0.10138 lineto
0.4373 0.11075 lineto
0.4582 0.12252 lineto
0.4791 0.13764 lineto
0.5 0.15756 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.11237 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(1)] 0.4875 0.11237 1 0 Msboxa
[(2)] 0.4875 0.22474 1 0 Msboxa
[(3)] 0.4875 0.33711 1 0 Msboxa
[(4)] 0.4875 0.44948 1 0 Msboxa
[(5)] 0.4875 0.56185 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.11237 moveto
0.50625 0.11237 lineto
stroke
0 setgray
[(1)] 0.4875 0.11237 1 0 Mshowa
0.49375 0.22474 moveto
0.50625 0.22474 lineto
stroke
0 setgray
[(2)] 0.4875 0.22474 1 0 Mshowa
0.49375 0.33711 moveto
0.50625 0.33711 lineto
stroke
0 setgray
[(3)] 0.4875 0.33711 1 0 Mshowa
0.49375 0.44948 moveto
0.50625 0.44948 lineto
stroke
0 setgray
[(4)] 0.4875 0.44948 1 0 Mshowa
0.49375 0.56185 moveto
0.50625 0.56185 lineto
stroke
0 setgray
[(5)] 0.4875 0.56185 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.06764 moveto
0.02452 0.06563 lineto
0.03757 0.06483 lineto
0.05062 0.06415 lineto
0.06368 0.06359 lineto
0.07673 0.06314 lineto
0.08979 0.06281 lineto
0.09631 0.06268 lineto
0.10284 0.06258 lineto
0.10937 0.0625 lineto
0.11263 0.06247 lineto
0.11426 0.06246 lineto
0.11589 0.06245 lineto
0.11753 0.06244 lineto
0.11916 0.06244 lineto
0.12079 0.06243 lineto
0.12161 0.06243 lineto
0.12242 0.06243 lineto
0.12324 0.06243 lineto
0.12405 0.06243 lineto
0.12487 0.06243 lineto
0.12568 0.06243 lineto
0.1265 0.06243 lineto
0.12732 0.06243 lineto
0.12813 0.06243 lineto
0.12895 0.06243 lineto
0.13058 0.06244 lineto
0.13221 0.06244 lineto
0.13548 0.06246 lineto
0.13874 0.06249 lineto
0.142 0.06252 lineto
0.14853 0.0626 lineto
0.15506 0.0627 lineto
0.16811 0.063 lineto
0.18116 0.0634 lineto
0.19422 0.06391 lineto
0.20727 0.06454 lineto
0.23338 0.06618 lineto
0.25949 0.06836 lineto
0.2856 0.07118 lineto
0.3117 0.07475 lineto
0.33781 0.07925 lineto
0.36392 0.08491 lineto
0.39003 0.09208 lineto
0.41614 0.10128 lineto
0.44224 0.11328 lineto
0.46835 0.12937 lineto
0.48141 0.13957 lineto
0.49446 0.1517 lineto
0.50751 0.16632 lineto
Mistroke
0.52057 0.18417 lineto
0.53362 0.20635 lineto
0.54668 0.23437 lineto
0.55973 0.27042 lineto
0.57278 0.3174 lineto
0.58584 0.37838 lineto
0.59889 0.45319 lineto
0.625 0.56185 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.11237 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(1)] 0.4875 0.11237 1 0 Msboxa
[(2)] 0.4875 0.22474 1 0 Msboxa
[(3)] 0.4875 0.33711 1 0 Msboxa
[(4)] 0.4875 0.44948 1 0 Msboxa
[(5)] 0.4875 0.56185 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.11237 moveto
0.50625 0.11237 lineto
stroke
0 setgray
[(1)] 0.4875 0.11237 1 0 Mshowa
0.49375 0.22474 moveto
0.50625 0.22474 lineto
stroke
0 setgray
[(2)] 0.4875 0.22474 1 0 Mshowa
0.49375 0.33711 moveto
0.50625 0.33711 lineto
stroke
0 setgray
[(3)] 0.4875 0.33711 1 0 Mshowa
0.49375 0.44948 moveto
0.50625 0.44948 lineto
stroke
0 setgray
[(4)] 0.4875 0.44948 1 0 Mshowa
0.49375 0.56185 moveto
0.50625 0.56185 lineto
stroke
0 setgray
[(5)] 0.4875 0.56185 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.06764 moveto
0.02972 0.06529 lineto
0.04538 0.06441 lineto
0.06104 0.06369 lineto
0.0767 0.06314 lineto
0.08453 0.06293 lineto
0.09236 0.06275 lineto
0.10019 0.06262 lineto
0.1041 0.06256 lineto
0.10802 0.06252 lineto
0.11193 0.06248 lineto
0.11389 0.06247 lineto
0.11584 0.06245 lineto
0.1178 0.06244 lineto
0.11976 0.06244 lineto
0.12074 0.06243 lineto
0.12172 0.06243 lineto
0.1227 0.06243 lineto
0.12367 0.06243 lineto
0.12465 0.06243 lineto
0.12563 0.06243 lineto
0.12661 0.06243 lineto
0.12759 0.06243 lineto
0.12857 0.06243 lineto
0.12955 0.06243 lineto
0.1315 0.06244 lineto
0.13346 0.06245 lineto
0.13542 0.06246 lineto
0.13933 0.06249 lineto
0.14325 0.06253 lineto
0.14716 0.06258 lineto
0.15499 0.0627 lineto
0.16282 0.06287 lineto
0.17065 0.06307 lineto
0.18631 0.06359 lineto
0.20196 0.06427 lineto
0.21762 0.06513 lineto
0.24894 0.06741 lineto
0.28026 0.07055 lineto
0.31157 0.07473 lineto
0.34289 0.08025 lineto
0.3742 0.08753 lineto
0.40552 0.09725 lineto
0.43684 0.11051 lineto
0.4525 0.11902 lineto
0.46815 0.12923 lineto
0.48381 0.14164 lineto
0.49947 0.15698 lineto
0.51513 0.17628 lineto
0.53079 0.20109 lineto
Mistroke
0.54644 0.23381 lineto
0.5621 0.27805 lineto
0.57776 0.33886 lineto
0.59342 0.42054 lineto
0.60908 0.51289 lineto
0.61299 0.53237 lineto
0.61691 0.54786 lineto
0.61886 0.55368 lineto
0.61984 0.55604 lineto
0.62082 0.55801 lineto
0.6218 0.55959 lineto
0.62278 0.56076 lineto
0.62376 0.56151 lineto
0.62473 0.56183 lineto
0.65605 0.42365 lineto
0.67171 0.34128 lineto
0.68737 0.2798 lineto
0.70303 0.2351 lineto
0.71868 0.20206 lineto
0.73434 0.17702 lineto
0.75 0.15756 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.11237 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(1)] 0.4875 0.11237 1 0 Msboxa
[(2)] 0.4875 0.22474 1 0 Msboxa
[(3)] 0.4875 0.33711 1 0 Msboxa
[(4)] 0.4875 0.44948 1 0 Msboxa
[(5)] 0.4875 0.56185 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.11237 moveto
0.50625 0.11237 lineto
stroke
0 setgray
[(1)] 0.4875 0.11237 1 0 Mshowa
0.49375 0.22474 moveto
0.50625 0.22474 lineto
stroke
0 setgray
[(2)] 0.4875 0.22474 1 0 Mshowa
0.49375 0.33711 moveto
0.50625 0.33711 lineto
stroke
0 setgray
[(3)] 0.4875 0.33711 1 0 Mshowa
0.49375 0.44948 moveto
0.50625 0.44948 lineto
stroke
0 setgray
[(4)] 0.4875 0.44948 1 0 Mshowa
0.49375 0.56185 moveto
0.50625 0.56185 lineto
stroke
0 setgray
[(5)] 0.4875 0.56185 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.06764 moveto
0.01667 0.06617 lineto
0.03493 0.06498 lineto
0.0532 0.06403 lineto
0.06233 0.06364 lineto
0.07146 0.06331 lineto
0.08059 0.06303 lineto
0.08972 0.06281 lineto
0.09429 0.06272 lineto
0.09885 0.06264 lineto
0.10342 0.06257 lineto
0.10798 0.06252 lineto
0.11027 0.06249 lineto
0.11255 0.06247 lineto
0.11483 0.06246 lineto
0.11711 0.06245 lineto
0.11825 0.06244 lineto
0.1194 0.06244 lineto
0.12054 0.06243 lineto
0.12168 0.06243 lineto
0.12282 0.06243 lineto
0.12396 0.06243 lineto
0.1251 0.06243 lineto
0.12624 0.06243 lineto
0.12739 0.06243 lineto
0.12853 0.06243 lineto
0.12967 0.06243 lineto
0.13081 0.06244 lineto
0.13309 0.06245 lineto
0.13538 0.06246 lineto
0.13994 0.0625 lineto
0.14451 0.06254 lineto
0.15364 0.06268 lineto
0.16277 0.06286 lineto
0.1719 0.0631 lineto
0.18103 0.0634 lineto
0.19929 0.06415 lineto
0.21756 0.06513 lineto
0.23582 0.06636 lineto
0.25408 0.06786 lineto
0.29061 0.0718 lineto
0.32713 0.07729 lineto
0.36365 0.08485 lineto
0.40018 0.09538 lineto
0.41844 0.10221 lineto
0.4367 0.11045 lineto
0.45497 0.12051 lineto
0.47323 0.13298 lineto
0.49149 0.14875 lineto
0.50975 0.16912 lineto
Mistroke
0.52802 0.19621 lineto
0.54628 0.23341 lineto
0.55541 0.25744 lineto
0.56454 0.28628 lineto
0.5828 0.36285 lineto
0.60107 0.46635 lineto
0.60563 0.49356 lineto
0.6102 0.51879 lineto
0.61248 0.53002 lineto
0.61476 0.53996 lineto
0.61704 0.54832 lineto
0.61819 0.55183 lineto
0.61933 0.55485 lineto
0.62047 0.55735 lineto
0.62161 0.55932 lineto
0.62275 0.56073 lineto
0.62389 0.56158 lineto
0.62503 0.56185 lineto
0.62618 0.56154 lineto
0.62732 0.56066 lineto
0.62846 0.55921 lineto
0.6296 0.55721 lineto
0.63074 0.55468 lineto
0.63302 0.54809 lineto
0.63759 0.5297 lineto
0.64672 0.47968 lineto
0.65585 0.42481 lineto
0.67411 0.33053 lineto
0.68325 0.29413 lineto
0.69238 0.26395 lineto
0.71064 0.21784 lineto
0.7289 0.18498 lineto
0.74716 0.16075 lineto
0.76543 0.14232 lineto
0.78369 0.12793 lineto
0.80195 0.11645 lineto
0.82021 0.10714 lineto
0.83848 0.09948 lineto
0.875 0.08775 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; endGroup; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.11237 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(1)] 0.4875 0.11237 1 0 Msboxa
[(2)] 0.4875 0.22474 1 0 Msboxa
[(3)] 0.4875 0.33711 1 0 Msboxa
[(4)] 0.4875 0.44948 1 0 Msboxa
[(5)] 0.4875 0.56185 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.11237 moveto
0.50625 0.11237 lineto
stroke
0 setgray
[(1)] 0.4875 0.11237 1 0 Mshowa
0.49375 0.22474 moveto
0.50625 0.22474 lineto
stroke
0 setgray
[(2)] 0.4875 0.22474 1 0 Mshowa
0.49375 0.33711 moveto
0.50625 0.33711 lineto
stroke
0 setgray
[(3)] 0.4875 0.33711 1 0 Mshowa
0.49375 0.44948 moveto
0.50625 0.44948 lineto
stroke
0 setgray
[(4)] 0.4875 0.44948 1 0 Mshowa
0.49375 0.56185 moveto
0.50625 0.56185 lineto
stroke
0 setgray
[(5)] 0.4875 0.56185 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.06764 moveto
0.01927 0.06599 lineto
0.04014 0.06468 lineto
0.06101 0.06369 lineto
0.07144 0.06331 lineto
0.08187 0.063 lineto
0.09231 0.06275 lineto
0.09752 0.06266 lineto
0.10274 0.06258 lineto
0.10796 0.06252 lineto
0.11057 0.06249 lineto
0.11317 0.06247 lineto
0.11578 0.06245 lineto
0.11839 0.06244 lineto
0.11969 0.06244 lineto
0.121 0.06243 lineto
0.1223 0.06243 lineto
0.12361 0.06243 lineto
0.12491 0.06243 lineto
0.12622 0.06243 lineto
0.12752 0.06243 lineto
0.12882 0.06243 lineto
0.13013 0.06244 lineto
0.13143 0.06244 lineto
0.13404 0.06245 lineto
0.13665 0.06247 lineto
0.13926 0.06249 lineto
0.14447 0.06254 lineto
0.14969 0.06261 lineto
0.15491 0.0627 lineto
0.16534 0.06293 lineto
0.17577 0.06322 lineto
0.18621 0.06358 lineto
0.20707 0.06453 lineto
0.22794 0.0658 lineto
0.24881 0.0674 lineto
0.26967 0.06938 lineto
0.29054 0.07179 lineto
0.31141 0.07471 lineto
0.33227 0.07821 lineto
0.35314 0.08241 lineto
0.37401 0.08748 lineto
0.39487 0.09362 lineto
0.41574 0.10112 lineto
0.4366 0.1104 lineto
0.45747 0.12206 lineto
0.47834 0.13702 lineto
0.4992 0.15669 lineto
0.52007 0.18342 lineto
0.5305 0.20059 lineto
Mistroke
0.54094 0.22121 lineto
0.55137 0.24628 lineto
0.5618 0.27707 lineto
0.58267 0.36219 lineto
0.5931 0.41871 lineto
0.60354 0.48122 lineto
0.60875 0.51115 lineto
0.61397 0.53667 lineto
0.61658 0.54675 lineto
0.61788 0.55094 lineto
0.61919 0.5545 lineto
0.62049 0.55739 lineto
0.62179 0.55958 lineto
0.6231 0.56105 lineto
0.6244 0.56177 lineto
0.66614 0.36818 lineto
0.67657 0.32007 lineto
0.687 0.28102 lineto
0.69744 0.24948 lineto
0.70787 0.22383 lineto
0.72874 0.18524 lineto
0.7496 0.158 lineto
0.77047 0.138 lineto
0.79134 0.12282 lineto
0.8122 0.11099 lineto
0.83307 0.1016 lineto
0.85393 0.09401 lineto
0.8748 0.0878 lineto
0.89567 0.08268 lineto
0.91653 0.07843 lineto
0.95827 0.07195 lineto
0.97913 0.06951 lineto
1 0.0675 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example:  Animation of Single Zero System
:[font = text; inactive; ]
		The following two input cells illustrate the case of a simple zero. Here also the black dot on the unit circle represents the point z = e^jw moving around the unit circle, while "o" represents a zero inside the unit circle.
:[font = input; startGroup; ]
Do[VectorPoleZeroPlot[(z - 0.8 Exp[I Pi/4]), z, 0, Infinity, w, 
                      True, Dialogue -> False],
   {w,-Pi,Pi,Pi/4} ]
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
0.1 0.5 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.1 0.5 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
0.21716 0.21716 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.21716 0.21716 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
0.5 0.1 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.5 0.1 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
0.78284 0.21716 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.78284 0.21716 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.9 0.5 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
0.78284 0.78284 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.78284 0.78284 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
0.5 0.9 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.5 0.9 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
0.21716 0.78284 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.21716 0.78284 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
0.1 0.5 moveto
0.72627 0.72627 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.1 0.5 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = input; startGroup; ]
Do[MagPhasePlot[(Exp[I w] - 0.8 Exp[I Pi/4]),{w,-Pi-0.01,r},
                PhaseRangeScale -> Null, 
                PlotRange -> {{-Pi,Pi},{0,2}}],
   {r,-Pi,Pi,Pi/4}]                
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.51338 moveto
-0.00153 0.51342 lineto
-0.00146 0.51347 lineto
-0.00139 0.51351 lineto
-0.00133 0.51355 lineto
-0.00126 0.5136 lineto
-0.00119 0.51364 lineto
-0.00113 0.51369 lineto
-0.00106 0.51373 lineto
-0.00099 0.51378 lineto
-0.00093 0.51382 lineto
-0.00086 0.51386 lineto
-0.0008 0.51391 lineto
-0.00073 0.51395 lineto
-0.00066 0.514 lineto
-0.0006 0.51404 lineto
-0.00053 0.51408 lineto
-0.00046 0.51413 lineto
-0.0004 0.51417 lineto
-0.00033 0.51421 lineto
-0.00027 0.51426 lineto
-0.0002 0.5143 lineto
-0.00013 0.51435 lineto
-7e-05 0.51439 lineto
0 0.51443 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.51338 moveto
0.00368 0.51683 lineto
0.00896 0.52014 lineto
0.01423 0.52332 lineto
0.01951 0.52635 lineto
0.02478 0.52923 lineto
0.03006 0.53198 lineto
0.03533 0.53458 lineto
0.04061 0.53704 lineto
0.04588 0.53935 lineto
0.05115 0.54152 lineto
0.05643 0.54353 lineto
0.0617 0.54541 lineto
0.06698 0.54713 lineto
0.07225 0.54871 lineto
0.07753 0.55013 lineto
0.0828 0.55141 lineto
0.08808 0.55254 lineto
0.09335 0.55352 lineto
0.09863 0.55435 lineto
0.1039 0.55502 lineto
0.10918 0.55555 lineto
0.11181 0.55576 lineto
0.11445 0.55593 lineto
0.11709 0.55606 lineto
0.11841 0.55611 lineto
0.11973 0.55616 lineto
0.12104 0.55619 lineto
0.1217 0.5562 lineto
0.12236 0.55621 lineto
0.12302 0.55622 lineto
0.12335 0.55622 lineto
0.12368 0.55623 lineto
0.12401 0.55623 lineto
0.12418 0.55623 lineto
0.12434 0.55623 lineto
0.12451 0.55623 lineto
0.12467 0.55623 lineto
0.125 0.55623 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.51338 moveto
0.00889 0.5201 lineto
0.01937 0.52627 lineto
0.02986 0.53188 lineto
0.04034 0.53692 lineto
0.05082 0.54138 lineto
0.06131 0.54527 lineto
0.07179 0.54857 lineto
0.08227 0.55129 lineto
0.09276 0.55341 lineto
0.098 0.55426 lineto
0.10324 0.55495 lineto
0.10848 0.55549 lineto
0.1111 0.55571 lineto
0.11372 0.55589 lineto
0.11634 0.55603 lineto
0.11765 0.55608 lineto
0.11896 0.55613 lineto
0.12027 0.55617 lineto
0.12093 0.55619 lineto
0.12158 0.5562 lineto
0.12224 0.55621 lineto
0.12289 0.55622 lineto
0.12322 0.55622 lineto
0.12355 0.55622 lineto
0.12388 0.55623 lineto
0.1242 0.55623 lineto
0.12453 0.55623 lineto
0.12486 0.55623 lineto
0.12519 0.55623 lineto
0.12551 0.55623 lineto
0.12584 0.55623 lineto
0.12617 0.55623 lineto
0.1265 0.55622 lineto
0.12682 0.55622 lineto
0.12748 0.55621 lineto
0.12814 0.5562 lineto
0.12945 0.55618 lineto
0.13076 0.55614 lineto
0.13207 0.5561 lineto
0.13469 0.55598 lineto
0.13731 0.55582 lineto
0.13993 0.55563 lineto
0.14517 0.55513 lineto
0.15041 0.55448 lineto
0.15565 0.55369 lineto
0.16614 0.55165 lineto
0.17662 0.54902 lineto
0.1871 0.54581 lineto
0.19759 0.54201 lineto
Mistroke
0.20807 0.53763 lineto
0.21855 0.53268 lineto
0.22903 0.52716 lineto
0.23952 0.52107 lineto
0.25 0.51443 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.51338 moveto
0.0141 0.52324 lineto
0.02979 0.53185 lineto
0.04548 0.53918 lineto
0.06117 0.54522 lineto
0.07687 0.54996 lineto
0.08471 0.55184 lineto
0.09256 0.55338 lineto
0.1004 0.55459 lineto
0.10432 0.55507 lineto
0.10825 0.55547 lineto
0.11217 0.55578 lineto
0.11413 0.55591 lineto
0.11609 0.55602 lineto
0.11805 0.5561 lineto
0.12002 0.55616 lineto
0.121 0.55619 lineto
0.12198 0.55621 lineto
0.12296 0.55622 lineto
0.12345 0.55622 lineto
0.12394 0.55623 lineto
0.12443 0.55623 lineto
0.12492 0.55623 lineto
0.12541 0.55623 lineto
0.1259 0.55623 lineto
0.12639 0.55623 lineto
0.12688 0.55622 lineto
0.12786 0.55621 lineto
0.12884 0.55619 lineto
0.12982 0.55617 lineto
0.13178 0.55611 lineto
0.13375 0.55602 lineto
0.13571 0.55592 lineto
0.13963 0.55565 lineto
0.14355 0.5553 lineto
0.14748 0.55486 lineto
0.15532 0.55374 lineto
0.16317 0.55229 lineto
0.17101 0.5505 lineto
0.1867 0.54594 lineto
0.2024 0.54007 lineto
0.21809 0.53291 lineto
0.23378 0.52448 lineto
0.24947 0.51478 lineto
0.26516 0.50386 lineto
0.28085 0.49174 lineto
0.29654 0.47845 lineto
0.31223 0.46402 lineto
0.32793 0.44849 lineto
0.34362 0.4319 lineto
Mistroke
0.35931 0.4143 lineto
0.375 0.39573 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.51338 moveto
0.01931 0.52623 lineto
0.04021 0.53686 lineto
0.06111 0.5452 lineto
0.07156 0.54851 lineto
0.08201 0.55123 lineto
0.09246 0.55336 lineto
0.09768 0.55421 lineto
0.10291 0.55491 lineto
0.10813 0.55546 lineto
0.11074 0.55568 lineto
0.11336 0.55586 lineto
0.11597 0.55601 lineto
0.11728 0.55607 lineto
0.11858 0.55612 lineto
0.11989 0.55616 lineto
0.12119 0.55619 lineto
0.12185 0.5562 lineto
0.1225 0.55621 lineto
0.12315 0.55622 lineto
0.12381 0.55623 lineto
0.12446 0.55623 lineto
0.12511 0.55623 lineto
0.12577 0.55623 lineto
0.12642 0.55623 lineto
0.12707 0.55622 lineto
0.12773 0.55621 lineto
0.12903 0.55619 lineto
0.13034 0.55615 lineto
0.13164 0.55611 lineto
0.13426 0.556 lineto
0.13687 0.55585 lineto
0.13948 0.55566 lineto
0.14471 0.55518 lineto
0.14993 0.55455 lineto
0.15516 0.55377 lineto
0.16561 0.55177 lineto
0.17606 0.54918 lineto
0.18651 0.54601 lineto
0.2074 0.53793 lineto
0.2283 0.52756 lineto
0.2492 0.51496 lineto
0.2701 0.50017 lineto
0.291 0.48327 lineto
0.3119 0.46433 lineto
0.3328 0.44344 lineto
0.3537 0.4207 lineto
0.3746 0.39622 lineto
0.3955 0.37011 lineto
0.4164 0.3425 lineto
Mistroke
0.4373 0.31355 lineto
0.4582 0.28341 lineto
0.4791 0.25228 lineto
0.5 0.22039 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.51338 moveto
0.02452 0.52909 lineto
0.05062 0.5413 lineto
0.06368 0.54607 lineto
0.07673 0.54993 lineto
0.08979 0.55287 lineto
0.09631 0.554 lineto
0.10284 0.5549 lineto
0.10937 0.55557 lineto
0.11263 0.55582 lineto
0.11426 0.55592 lineto
0.11589 0.55601 lineto
0.11753 0.55608 lineto
0.11916 0.55614 lineto
0.12079 0.55618 lineto
0.12161 0.5562 lineto
0.12242 0.55621 lineto
0.12324 0.55622 lineto
0.12405 0.55623 lineto
0.12487 0.55623 lineto
0.12568 0.55623 lineto
0.1265 0.55622 lineto
0.12732 0.55622 lineto
0.12813 0.5562 lineto
0.12895 0.55619 lineto
0.13058 0.55615 lineto
0.13221 0.55609 lineto
0.13548 0.55593 lineto
0.13874 0.55572 lineto
0.142 0.55545 lineto
0.14853 0.55473 lineto
0.15506 0.55378 lineto
0.16811 0.5512 lineto
0.18116 0.5477 lineto
0.20727 0.53799 lineto
0.23338 0.5247 lineto
0.25949 0.50795 lineto
0.2856 0.48784 lineto
0.3117 0.46452 lineto
0.33781 0.43816 lineto
0.36392 0.40894 lineto
0.39003 0.3771 lineto
0.41614 0.34286 lineto
0.44224 0.30652 lineto
0.46835 0.2684 lineto
0.49446 0.2289 lineto
0.52057 0.18854 lineto
0.54668 0.14816 lineto
0.57278 0.1094 lineto
0.58584 0.09177 lineto
Mistroke
0.59889 0.07662 lineto
0.60542 0.07053 lineto
0.61195 0.06583 lineto
0.61521 0.0641 lineto
0.61684 0.06341 lineto
0.61847 0.06283 lineto
0.6201 0.06239 lineto
0.62092 0.06221 lineto
0.62174 0.06206 lineto
0.62255 0.06195 lineto
0.62337 0.06187 lineto
0.625 0.0618 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.51338 moveto
0.02972 0.53181 lineto
0.04538 0.53914 lineto
0.06104 0.54518 lineto
0.0767 0.54992 lineto
0.08453 0.5518 lineto
0.09236 0.55334 lineto
0.10019 0.55456 lineto
0.1041 0.55505 lineto
0.10802 0.55545 lineto
0.11193 0.55577 lineto
0.11389 0.5559 lineto
0.11584 0.556 lineto
0.1178 0.55609 lineto
0.11976 0.55616 lineto
0.12074 0.55618 lineto
0.12172 0.5562 lineto
0.1227 0.55622 lineto
0.12367 0.55623 lineto
0.12465 0.55623 lineto
0.12563 0.55623 lineto
0.12661 0.55622 lineto
0.12759 0.55621 lineto
0.12857 0.5562 lineto
0.12955 0.55617 lineto
0.1315 0.55612 lineto
0.13346 0.55604 lineto
0.13542 0.55594 lineto
0.13933 0.55567 lineto
0.14325 0.55533 lineto
0.14716 0.5549 lineto
0.15499 0.55379 lineto
0.16282 0.55236 lineto
0.17065 0.55059 lineto
0.18631 0.54607 lineto
0.20196 0.54025 lineto
0.21762 0.53314 lineto
0.24894 0.51513 lineto
0.28026 0.49222 lineto
0.31157 0.46465 lineto
0.34289 0.43269 lineto
0.3742 0.3967 lineto
0.40552 0.35705 lineto
0.43684 0.31421 lineto
0.46815 0.2687 lineto
0.49947 0.2212 lineto
0.53079 0.17268 lineto
0.5621 0.12489 lineto
0.57776 0.10247 lineto
0.59342 0.08257 lineto
Mistroke
0.60125 0.07428 lineto
0.60516 0.07075 lineto
0.60908 0.0677 lineto
0.61299 0.06523 lineto
0.61691 0.06338 lineto
0.61886 0.06272 lineto
0.61984 0.06245 lineto
0.62082 0.06223 lineto
0.6218 0.06205 lineto
0.62278 0.06192 lineto
0.62376 0.06184 lineto
0.62473 0.06181 lineto
0.62571 0.06182 lineto
0.62669 0.06187 lineto
0.62767 0.06198 lineto
0.62865 0.06213 lineto
0.62963 0.06232 lineto
0.63061 0.06257 lineto
0.63256 0.06318 lineto
0.63648 0.06494 lineto
0.64039 0.06733 lineto
0.64822 0.07378 lineto
0.65605 0.08197 lineto
0.67171 0.10175 lineto
0.68737 0.1241 lineto
0.71868 0.17185 lineto
0.75 0.22039 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.51338 moveto
0.01667 0.52473 lineto
0.03493 0.53439 lineto
0.0532 0.54231 lineto
0.07146 0.54848 lineto
0.08059 0.55089 lineto
0.08972 0.55286 lineto
0.09429 0.55368 lineto
0.09885 0.55438 lineto
0.10342 0.55497 lineto
0.10798 0.55545 lineto
0.11027 0.55564 lineto
0.11255 0.55581 lineto
0.11483 0.55595 lineto
0.11711 0.55606 lineto
0.11825 0.55611 lineto
0.1194 0.55615 lineto
0.12054 0.55618 lineto
0.12168 0.5562 lineto
0.12282 0.55622 lineto
0.12396 0.55623 lineto
0.1251 0.55623 lineto
0.12624 0.55623 lineto
0.12739 0.55622 lineto
0.12853 0.5562 lineto
0.12967 0.55617 lineto
0.13081 0.55614 lineto
0.13309 0.55605 lineto
0.13538 0.55594 lineto
0.13994 0.55563 lineto
0.14451 0.5552 lineto
0.15364 0.55401 lineto
0.16277 0.55237 lineto
0.18103 0.54774 lineto
0.19929 0.54134 lineto
0.21756 0.53318 lineto
0.25408 0.5117 lineto
0.29061 0.48361 lineto
0.32713 0.4493 lineto
0.36365 0.40925 lineto
0.40018 0.36405 lineto
0.4367 0.31439 lineto
0.47323 0.26112 lineto
0.50975 0.20532 lineto
0.54628 0.14877 lineto
0.56454 0.12129 lineto
0.5828 0.0957 lineto
0.59193 0.08429 lineto
0.60107 0.07446 lineto
0.60563 0.07035 lineto
Mistroke
0.6102 0.06693 lineto
0.61248 0.06552 lineto
0.61476 0.06431 lineto
0.61704 0.06333 lineto
0.61819 0.06293 lineto
0.61933 0.06258 lineto
0.62047 0.0623 lineto
0.62161 0.06208 lineto
0.62275 0.06193 lineto
0.62389 0.06183 lineto
0.62503 0.0618 lineto
0.62618 0.06184 lineto
0.62732 0.06193 lineto
0.62846 0.06209 lineto
0.6296 0.06232 lineto
0.63074 0.0626 lineto
0.63302 0.06335 lineto
0.63531 0.06434 lineto
0.63759 0.06555 lineto
0.64672 0.07239 lineto
0.65585 0.08174 lineto
0.69238 0.13156 lineto
0.7289 0.18772 lineto
0.76543 0.24399 lineto
0.80195 0.29819 lineto
0.83848 0.34907 lineto
0.875 0.39573 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; endGroup; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.00159 0.51338 moveto
0.01927 0.52622 lineto
0.04014 0.53683 lineto
0.06101 0.54517 lineto
0.07144 0.54847 lineto
0.08187 0.5512 lineto
0.09231 0.55334 lineto
0.09752 0.55419 lineto
0.10274 0.55489 lineto
0.10796 0.55544 lineto
0.11057 0.55567 lineto
0.11317 0.55585 lineto
0.11578 0.556 lineto
0.11839 0.55611 lineto
0.11969 0.55615 lineto
0.121 0.55619 lineto
0.1223 0.55621 lineto
0.12361 0.55623 lineto
0.12491 0.55623 lineto
0.12622 0.55623 lineto
0.12752 0.55621 lineto
0.12882 0.55619 lineto
0.13013 0.55616 lineto
0.13143 0.55612 lineto
0.13404 0.55601 lineto
0.13665 0.55586 lineto
0.13926 0.55568 lineto
0.14447 0.5552 lineto
0.14969 0.55458 lineto
0.15491 0.55381 lineto
0.16534 0.55182 lineto
0.17577 0.54926 lineto
0.18621 0.54611 lineto
0.20707 0.53807 lineto
0.22794 0.52776 lineto
0.24881 0.51522 lineto
0.29054 0.48367 lineto
0.33227 0.444 lineto
0.37401 0.39694 lineto
0.41574 0.3434 lineto
0.45747 0.28448 lineto
0.4992 0.22161 lineto
0.54094 0.15697 lineto
0.5618 0.12533 lineto
0.58267 0.09587 lineto
0.5931 0.08293 lineto
0.59832 0.07721 lineto
0.60354 0.07216 lineto
0.60875 0.06793 lineto
0.61397 0.0647 lineto
Mistroke
0.61658 0.06351 lineto
0.61788 0.06303 lineto
0.61919 0.06262 lineto
0.62049 0.0623 lineto
0.62179 0.06205 lineto
0.6231 0.06189 lineto
0.6244 0.06181 lineto
0.62571 0.06182 lineto
0.62701 0.0619 lineto
0.62832 0.06207 lineto
0.62962 0.06232 lineto
0.63223 0.06307 lineto
0.63484 0.06412 lineto
0.64005 0.0671 lineto
0.64527 0.07111 lineto
0.6557 0.08157 lineto
0.66614 0.09431 lineto
0.70787 0.15514 lineto
0.7496 0.21977 lineto
0.79134 0.28273 lineto
0.83307 0.34178 lineto
0.8748 0.39549 lineto
0.91653 0.44275 lineto
0.95827 0.48264 lineto
1 0.51443 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = text; inactive; ]
		As can be seen in these two examples, a zero vector (which corresponds to a zero factor in the numerator) contributes to dips (or valleys) in the magnitude of the frequency response, whereas a pole vector (which corresponds to a pole factor in the denominator) contributes to peaks in the magnitude of the frequency response.  
:[font = text; inactive; ]
		The closeness of the poles (zeros) to the unit circle controls the  height (depth) and width of the peaks (valleys).  For example, as a pole (zero) becomes closer to the unit circle, the corresponding peak (valley) becomes higher (deeper) in magnitude and narrower in width (i.e. it becomes sharper). This is illustrated by the following example.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example:  Animation of Single Pole System (Pole's Radius Varies)
:[font = text; inactive; startGroup; ]
		Animate the following cells by selecting the graphics cells to be animated and then choosing the Animation option from the Graph sub-menu. You can also set the desired animation speed by using the Preferences option in the main menu, or the options in the bottom right side of  the notebook border.  
		Note that you can change the transfer function used in the input cells and obtain other desired graphics cells to be animated.
		The first two input cells illustrate the effect of a pole approaching the unit circle on the magnitude of the frequency response.  Notice that in this case we have a peak which becomes sharper and sharper as the pole approaches the unit circle.
:[font = input; startGroup; ]
Do[PoleZeroPlot[1/(z - r Exp[I Pi/4]), z, r, Infinity, True, 
                Dialogue -> False],
   {r,0.1,0.9,0.1} ]
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.54 0.5 moveto
0.54 0.50033 lineto
0.53999 0.50065 lineto
0.53999 0.50098 lineto
0.53998 0.50131 lineto
0.53997 0.50164 lineto
0.53995 0.50196 lineto
0.53991 0.50262 lineto
0.53987 0.50327 lineto
0.53981 0.50392 lineto
0.53966 0.50522 lineto
0.53947 0.50652 lineto
0.53923 0.5078 lineto
0.53864 0.51035 lineto
0.53788 0.51286 lineto
0.53696 0.51531 lineto
0.53464 0.52 lineto
0.53173 0.52435 lineto
0.52828 0.52828 lineto
0.52435 0.53173 lineto
0.52 0.53464 lineto
0.51769 0.53587 lineto
0.51531 0.53696 lineto
0.51286 0.53788 lineto
0.51035 0.53864 lineto
0.5078 0.53923 lineto
0.50652 0.53947 lineto
0.50522 0.53966 lineto
0.50392 0.53981 lineto
0.50327 0.53987 lineto
0.50262 0.53991 lineto
0.50196 0.53995 lineto
0.50164 0.53997 lineto
0.50131 0.53998 lineto
0.50098 0.53999 lineto
0.50065 0.53999 lineto
0.50033 0.54 lineto
0.5 0.54 lineto
0.49967 0.54 lineto
0.49935 0.53999 lineto
0.49902 0.53999 lineto
0.49869 0.53998 lineto
0.49804 0.53995 lineto
0.49738 0.53991 lineto
0.49673 0.53987 lineto
0.49608 0.53981 lineto
0.49478 0.53966 lineto
0.49348 0.53947 lineto
0.4922 0.53923 lineto
0.48965 0.53864 lineto
Mistroke
0.48714 0.53788 lineto
0.48469 0.53696 lineto
0.48 0.53464 lineto
0.47565 0.53173 lineto
0.47172 0.52828 lineto
0.46827 0.52435 lineto
0.46536 0.52 lineto
0.46304 0.51531 lineto
0.46212 0.51286 lineto
0.46136 0.51035 lineto
0.46077 0.5078 lineto
0.46053 0.50652 lineto
0.46034 0.50522 lineto
0.46019 0.50392 lineto
0.46013 0.50327 lineto
0.46009 0.50262 lineto
0.46005 0.50196 lineto
0.46003 0.50164 lineto
0.46002 0.50131 lineto
0.46001 0.50098 lineto
0.46001 0.50065 lineto
0.46 0.50033 lineto
0.46 0.5 lineto
0.46 0.49967 lineto
0.46001 0.49935 lineto
0.46001 0.49902 lineto
0.46002 0.49869 lineto
0.46005 0.49804 lineto
0.46009 0.49738 lineto
0.46013 0.49673 lineto
0.46019 0.49608 lineto
0.46034 0.49478 lineto
0.46053 0.49348 lineto
0.46077 0.4922 lineto
0.46136 0.48965 lineto
0.46212 0.48714 lineto
0.46304 0.48469 lineto
0.46536 0.48 lineto
0.46827 0.47565 lineto
0.47172 0.47172 lineto
0.47565 0.46827 lineto
0.48 0.46536 lineto
0.48231 0.46413 lineto
0.48469 0.46304 lineto
0.48714 0.46212 lineto
0.48965 0.46136 lineto
0.4922 0.46077 lineto
0.49348 0.46053 lineto
0.49478 0.46034 lineto
0.49608 0.46019 lineto
Mistroke
0.49673 0.46013 lineto
0.49738 0.46009 lineto
0.49804 0.46005 lineto
0.49836 0.46003 lineto
0.49869 0.46002 lineto
0.49902 0.46001 lineto
0.49935 0.46001 lineto
0.49967 0.46 lineto
0.5 0.46 lineto
0.50033 0.46 lineto
0.50065 0.46001 lineto
0.50098 0.46001 lineto
0.50131 0.46002 lineto
0.50196 0.46005 lineto
0.50262 0.46009 lineto
0.50327 0.46013 lineto
0.50392 0.46019 lineto
0.50522 0.46034 lineto
0.50652 0.46053 lineto
0.5078 0.46077 lineto
0.51035 0.46136 lineto
0.51286 0.46212 lineto
0.51531 0.46304 lineto
0.52 0.46536 lineto
0.52435 0.46827 lineto
0.52828 0.47172 lineto
0.53173 0.47565 lineto
0.53464 0.48 lineto
0.53587 0.48231 lineto
0.53696 0.48469 lineto
0.53788 0.48714 lineto
0.53864 0.48965 lineto
0.53923 0.4922 lineto
0.53947 0.49348 lineto
0.53966 0.49478 lineto
0.53981 0.49608 lineto
0.53987 0.49673 lineto
0.53991 0.49738 lineto
0.53995 0.49804 lineto
0.53997 0.49836 lineto
0.53998 0.49869 lineto
0.53999 0.49902 lineto
0.53999 0.49935 lineto
0.54 0.49967 lineto
0.54 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.53759 0.51368 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.46241 0.48632 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.52828 0.52828 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.58 0.5 moveto
0.58 0.50065 lineto
0.57999 0.50131 lineto
0.57998 0.50196 lineto
0.57996 0.50262 lineto
0.57993 0.50327 lineto
0.5799 0.50393 lineto
0.57983 0.50523 lineto
0.57973 0.50654 lineto
0.57961 0.50784 lineto
0.57932 0.51044 lineto
0.57893 0.51303 lineto
0.57846 0.51561 lineto
0.57727 0.52071 lineto
0.57575 0.52572 lineto
0.57391 0.53061 lineto
0.56928 0.54 lineto
0.56347 0.5487 lineto
0.55657 0.55657 lineto
0.5487 0.56347 lineto
0.54 0.56928 lineto
0.53538 0.57175 lineto
0.53061 0.57391 lineto
0.52572 0.57575 lineto
0.52071 0.57727 lineto
0.51561 0.57846 lineto
0.51303 0.57893 lineto
0.51044 0.57932 lineto
0.50784 0.57961 lineto
0.50654 0.57973 lineto
0.50523 0.57983 lineto
0.50393 0.5799 lineto
0.50327 0.57993 lineto
0.50262 0.57996 lineto
0.50196 0.57998 lineto
0.50131 0.57999 lineto
0.50065 0.58 lineto
0.5 0.58 lineto
0.49935 0.58 lineto
0.49869 0.57999 lineto
0.49804 0.57998 lineto
0.49738 0.57996 lineto
0.49607 0.5799 lineto
0.49477 0.57983 lineto
0.49346 0.57973 lineto
0.49216 0.57961 lineto
0.48956 0.57932 lineto
0.48697 0.57893 lineto
0.48439 0.57846 lineto
0.47929 0.57727 lineto
Mistroke
0.47428 0.57575 lineto
0.46939 0.57391 lineto
0.46 0.56928 lineto
0.4513 0.56347 lineto
0.44343 0.55657 lineto
0.43653 0.5487 lineto
0.43072 0.54 lineto
0.42609 0.53061 lineto
0.42425 0.52572 lineto
0.42273 0.52071 lineto
0.42154 0.51561 lineto
0.42107 0.51303 lineto
0.42068 0.51044 lineto
0.42039 0.50784 lineto
0.42027 0.50654 lineto
0.42017 0.50523 lineto
0.4201 0.50393 lineto
0.42007 0.50327 lineto
0.42004 0.50262 lineto
0.42002 0.50196 lineto
0.42001 0.50131 lineto
0.42 0.50065 lineto
0.42 0.5 lineto
0.42 0.49935 lineto
0.42001 0.49869 lineto
0.42002 0.49804 lineto
0.42004 0.49738 lineto
0.4201 0.49607 lineto
0.42017 0.49477 lineto
0.42027 0.49346 lineto
0.42039 0.49216 lineto
0.42068 0.48956 lineto
0.42107 0.48697 lineto
0.42154 0.48439 lineto
0.42273 0.47929 lineto
0.42425 0.47428 lineto
0.42609 0.46939 lineto
0.43072 0.46 lineto
0.43653 0.4513 lineto
0.44343 0.44343 lineto
0.4513 0.43653 lineto
0.46 0.43072 lineto
0.46462 0.42825 lineto
0.46939 0.42609 lineto
0.47428 0.42425 lineto
0.47929 0.42273 lineto
0.48439 0.42154 lineto
0.48697 0.42107 lineto
0.48956 0.42068 lineto
0.49216 0.42039 lineto
Mistroke
0.49346 0.42027 lineto
0.49477 0.42017 lineto
0.49607 0.4201 lineto
0.49673 0.42007 lineto
0.49738 0.42004 lineto
0.49804 0.42002 lineto
0.49869 0.42001 lineto
0.49935 0.42 lineto
0.5 0.42 lineto
0.50065 0.42 lineto
0.50131 0.42001 lineto
0.50196 0.42002 lineto
0.50262 0.42004 lineto
0.50393 0.4201 lineto
0.50523 0.42017 lineto
0.50654 0.42027 lineto
0.50784 0.42039 lineto
0.51044 0.42068 lineto
0.51303 0.42107 lineto
0.51561 0.42154 lineto
0.52071 0.42273 lineto
0.52572 0.42425 lineto
0.53061 0.42609 lineto
0.54 0.43072 lineto
0.5487 0.43653 lineto
0.55657 0.44343 lineto
0.56347 0.4513 lineto
0.56928 0.46 lineto
0.57175 0.46462 lineto
0.57391 0.46939 lineto
0.57575 0.47428 lineto
0.57727 0.47929 lineto
0.57846 0.48439 lineto
0.57893 0.48697 lineto
0.57932 0.48956 lineto
0.57961 0.49216 lineto
0.57973 0.49346 lineto
0.57983 0.49477 lineto
0.5799 0.49607 lineto
0.57993 0.49673 lineto
0.57996 0.49738 lineto
0.57998 0.49804 lineto
0.57999 0.49869 lineto
0.58 0.49935 lineto
0.58 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.57518 0.52736 lineto
stroke
0.42229 0.51901 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
0.45269 0.43549 moveto
-0.23539 0.18504 lineto
stroke
0.42482 0.47264 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.54731 0.56451 lineto
stroke
1.26579 0.73143 moveto
0.57771 0.48099 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.55657 0.55657 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.62 0.5 moveto
0.62 0.50098 lineto
0.61998 0.50196 lineto
0.61996 0.50294 lineto
0.61994 0.50393 lineto
0.6199 0.50491 lineto
0.61986 0.50589 lineto
0.61974 0.50785 lineto
0.6196 0.50981 lineto
0.61942 0.51176 lineto
0.61897 0.51566 lineto
0.6184 0.51955 lineto
0.61769 0.52341 lineto
0.61591 0.53106 lineto
0.61363 0.53857 lineto
0.61087 0.54592 lineto
0.60392 0.56 lineto
0.5952 0.57305 lineto
0.58485 0.58485 lineto
0.57305 0.5952 lineto
0.56 0.60392 lineto
0.55307 0.60762 lineto
0.54592 0.61087 lineto
0.53857 0.61363 lineto
0.53106 0.61591 lineto
0.52341 0.61769 lineto
0.51955 0.6184 lineto
0.51566 0.61897 lineto
0.51176 0.61942 lineto
0.50981 0.6196 lineto
0.50785 0.61974 lineto
0.50589 0.61986 lineto
0.50491 0.6199 lineto
0.50393 0.61994 lineto
0.50294 0.61996 lineto
0.50196 0.61998 lineto
0.50098 0.62 lineto
0.5 0.62 lineto
0.49902 0.62 lineto
0.49804 0.61998 lineto
0.49706 0.61996 lineto
0.49607 0.61994 lineto
0.49411 0.61986 lineto
0.49215 0.61974 lineto
0.49019 0.6196 lineto
0.48824 0.61942 lineto
0.48434 0.61897 lineto
0.48045 0.6184 lineto
0.47659 0.61769 lineto
0.46894 0.61591 lineto
Mistroke
0.46143 0.61363 lineto
0.45408 0.61087 lineto
0.44 0.60392 lineto
0.42695 0.5952 lineto
0.41515 0.58485 lineto
0.4048 0.57305 lineto
0.39608 0.56 lineto
0.38913 0.54592 lineto
0.38637 0.53857 lineto
0.38409 0.53106 lineto
0.38231 0.52341 lineto
0.3816 0.51955 lineto
0.38103 0.51566 lineto
0.38058 0.51176 lineto
0.3804 0.50981 lineto
0.38026 0.50785 lineto
0.38014 0.50589 lineto
0.3801 0.50491 lineto
0.38006 0.50393 lineto
0.38004 0.50294 lineto
0.38002 0.50196 lineto
0.38 0.50098 lineto
0.38 0.5 lineto
0.38 0.49902 lineto
0.38002 0.49804 lineto
0.38004 0.49706 lineto
0.38006 0.49607 lineto
0.38014 0.49411 lineto
0.38026 0.49215 lineto
0.3804 0.49019 lineto
0.38058 0.48824 lineto
0.38103 0.48434 lineto
0.3816 0.48045 lineto
0.38231 0.47659 lineto
0.38409 0.46894 lineto
0.38637 0.46143 lineto
0.38913 0.45408 lineto
0.39608 0.44 lineto
0.4048 0.42695 lineto
0.41515 0.41515 lineto
0.42695 0.4048 lineto
0.44 0.39608 lineto
0.44693 0.39238 lineto
0.45408 0.38913 lineto
0.46143 0.38637 lineto
0.46894 0.38409 lineto
0.47659 0.38231 lineto
0.48045 0.3816 lineto
0.48434 0.38103 lineto
0.48824 0.38058 lineto
Mistroke
0.49019 0.3804 lineto
0.49215 0.38026 lineto
0.49411 0.38014 lineto
0.49509 0.3801 lineto
0.49607 0.38006 lineto
0.49706 0.38004 lineto
0.49804 0.38002 lineto
0.49902 0.38 lineto
0.5 0.38 lineto
0.50098 0.38 lineto
0.50196 0.38002 lineto
0.50294 0.38004 lineto
0.50393 0.38006 lineto
0.50589 0.38014 lineto
0.50785 0.38026 lineto
0.50981 0.3804 lineto
0.51176 0.38058 lineto
0.51566 0.38103 lineto
0.51955 0.3816 lineto
0.52341 0.38231 lineto
0.53106 0.38409 lineto
0.53857 0.38637 lineto
0.54592 0.38913 lineto
0.56 0.39608 lineto
0.57305 0.4048 lineto
0.58485 0.41515 lineto
0.5952 0.42695 lineto
0.60392 0.44 lineto
0.60762 0.44693 lineto
0.61087 0.45408 lineto
0.61363 0.46143 lineto
0.61591 0.46894 lineto
0.61769 0.47659 lineto
0.6184 0.48045 lineto
0.61897 0.48434 lineto
0.61942 0.48824 lineto
0.6196 0.49019 lineto
0.61974 0.49215 lineto
0.61986 0.49411 lineto
0.6199 0.49509 lineto
0.61994 0.49607 lineto
0.61996 0.49706 lineto
0.61998 0.49804 lineto
0.62 0.49902 lineto
0.62 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.61276 0.54104 lineto
stroke
0.38006 0.50364 moveto
-0.26579 0.26857 lineto
stroke
0.39384 0.55596 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
0.45465 0.3889 moveto
-0.2167 0.14455 lineto
stroke
0.41046 0.42011 moveto
-0.23539 0.18504 lineto
stroke
0.38724 0.45896 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.58954 0.57989 lineto
stroke
1.26579 0.73143 moveto
0.61994 0.49636 lineto
stroke
1.2167 0.85545 moveto
0.54535 0.6111 lineto
stroke
1.2775 0.68839 moveto
0.60616 0.44404 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58485 0.58485 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.66 0.5 moveto
0.65999 0.50131 lineto
0.65998 0.50262 lineto
0.65995 0.50393 lineto
0.65991 0.50524 lineto
0.65987 0.50654 lineto
0.65981 0.50785 lineto
0.65966 0.51046 lineto
0.65946 0.51308 lineto
0.65923 0.51568 lineto
0.65863 0.52088 lineto
0.65786 0.52606 lineto
0.65693 0.53121 lineto
0.65455 0.54141 lineto
0.65151 0.55143 lineto
0.64782 0.56123 lineto
0.63856 0.58 lineto
0.62694 0.5974 lineto
0.61314 0.61314 lineto
0.5974 0.62694 lineto
0.58 0.63856 lineto
0.57077 0.6435 lineto
0.56123 0.64782 lineto
0.55143 0.65151 lineto
0.54141 0.65455 lineto
0.53121 0.65693 lineto
0.52606 0.65786 lineto
0.52088 0.65863 lineto
0.51568 0.65923 lineto
0.51308 0.65946 lineto
0.51046 0.65966 lineto
0.50785 0.65981 lineto
0.50654 0.65987 lineto
0.50524 0.65991 lineto
0.50393 0.65995 lineto
0.50262 0.65998 lineto
0.50131 0.65999 lineto
0.5 0.66 lineto
0.49869 0.65999 lineto
0.49738 0.65998 lineto
0.49607 0.65995 lineto
0.49476 0.65991 lineto
0.49215 0.65981 lineto
0.48954 0.65966 lineto
0.48692 0.65946 lineto
0.48432 0.65923 lineto
0.47912 0.65863 lineto
0.47394 0.65786 lineto
0.46879 0.65693 lineto
0.45859 0.65455 lineto
Mistroke
0.44857 0.65151 lineto
0.43877 0.64782 lineto
0.42 0.63856 lineto
0.4026 0.62694 lineto
0.38686 0.61314 lineto
0.37306 0.5974 lineto
0.36144 0.58 lineto
0.35218 0.56123 lineto
0.34849 0.55143 lineto
0.34545 0.54141 lineto
0.34307 0.53121 lineto
0.34214 0.52606 lineto
0.34137 0.52088 lineto
0.34077 0.51568 lineto
0.34054 0.51308 lineto
0.34034 0.51046 lineto
0.34019 0.50785 lineto
0.34013 0.50654 lineto
0.34009 0.50524 lineto
0.34005 0.50393 lineto
0.34002 0.50262 lineto
0.34001 0.50131 lineto
0.34 0.5 lineto
0.34001 0.49869 lineto
0.34002 0.49738 lineto
0.34005 0.49607 lineto
0.34009 0.49476 lineto
0.34019 0.49215 lineto
0.34034 0.48954 lineto
0.34054 0.48692 lineto
0.34077 0.48432 lineto
0.34137 0.47912 lineto
0.34214 0.47394 lineto
0.34307 0.46879 lineto
0.34545 0.45859 lineto
0.34849 0.44857 lineto
0.35218 0.43877 lineto
0.36144 0.42 lineto
0.37306 0.4026 lineto
0.38686 0.38686 lineto
0.4026 0.37306 lineto
0.42 0.36144 lineto
0.42923 0.3565 lineto
0.43877 0.35218 lineto
0.44857 0.34849 lineto
0.45859 0.34545 lineto
0.46879 0.34307 lineto
0.47394 0.34214 lineto
0.47912 0.34137 lineto
0.48432 0.34077 lineto
Mistroke
0.48692 0.34054 lineto
0.48954 0.34034 lineto
0.49215 0.34019 lineto
0.49346 0.34013 lineto
0.49476 0.34009 lineto
0.49607 0.34005 lineto
0.49738 0.34002 lineto
0.49869 0.34001 lineto
0.5 0.34 lineto
0.50131 0.34001 lineto
0.50262 0.34002 lineto
0.50393 0.34005 lineto
0.50524 0.34009 lineto
0.50785 0.34019 lineto
0.51046 0.34034 lineto
0.51308 0.34054 lineto
0.51568 0.34077 lineto
0.52088 0.34137 lineto
0.52606 0.34214 lineto
0.53121 0.34307 lineto
0.54141 0.34545 lineto
0.55143 0.34849 lineto
0.56123 0.35218 lineto
0.58 0.36144 lineto
0.5974 0.37306 lineto
0.61314 0.38686 lineto
0.62694 0.4026 lineto
0.63856 0.42 lineto
0.6435 0.42923 lineto
0.64782 0.43877 lineto
0.65151 0.44857 lineto
0.65455 0.45859 lineto
0.65693 0.46879 lineto
0.65786 0.47394 lineto
0.65863 0.47912 lineto
0.65923 0.48432 lineto
0.65946 0.48692 lineto
0.65966 0.48954 lineto
0.65981 0.49215 lineto
0.65987 0.49346 lineto
0.65991 0.49476 lineto
0.65995 0.49607 lineto
0.65998 0.49738 lineto
0.65999 0.49869 lineto
0.66 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.65035 0.55472 lineto
stroke
0.34037 0.48919 moveto
-0.26579 0.26857 lineto
stroke
0.34458 0.53803 moveto
-0.2775 0.31161 lineto
stroke
0.37129 0.59504 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
0.46249 0.34446 moveto
-0.19564 0.10492 lineto
stroke
0.40539 0.37097 moveto
-0.2167 0.14455 lineto
stroke
0.37077 0.40567 moveto
-0.23539 0.18504 lineto
stroke
0.34965 0.44528 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.62923 0.59433 lineto
stroke
1.26579 0.73143 moveto
0.65963 0.51081 lineto
stroke
1.2167 0.85545 moveto
0.59461 0.62903 lineto
stroke
1.2775 0.68839 moveto
0.65542 0.46197 lineto
stroke
1.19564 0.89508 moveto
0.53751 0.65554 lineto
stroke
1.28684 0.6445 moveto
0.62871 0.40496 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.61314 0.61314 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.7 0.5 moveto
0.69999 0.50164 lineto
0.69997 0.50327 lineto
0.69994 0.50491 lineto
0.69989 0.50654 lineto
0.69983 0.50818 lineto
0.69976 0.50981 lineto
0.69957 0.51308 lineto
0.69933 0.51634 lineto
0.69904 0.5196 lineto
0.69829 0.52611 lineto
0.69733 0.53258 lineto
0.69616 0.53902 lineto
0.69319 0.55176 lineto
0.68939 0.56429 lineto
0.68478 0.57654 lineto
0.67321 0.6 lineto
0.65867 0.62175 lineto
0.64142 0.64142 lineto
0.62175 0.65867 lineto
0.6 0.67321 lineto
0.58846 0.67937 lineto
0.57654 0.68478 lineto
0.56429 0.68939 lineto
0.55176 0.69319 lineto
0.53902 0.69616 lineto
0.53258 0.69733 lineto
0.52611 0.69829 lineto
0.5196 0.69904 lineto
0.51634 0.69933 lineto
0.51308 0.69957 lineto
0.50981 0.69976 lineto
0.50818 0.69983 lineto
0.50654 0.69989 lineto
0.50491 0.69994 lineto
0.50327 0.69997 lineto
0.50164 0.69999 lineto
0.5 0.7 lineto
0.49836 0.69999 lineto
0.49673 0.69997 lineto
0.49509 0.69994 lineto
0.49346 0.69989 lineto
0.49019 0.69976 lineto
0.48692 0.69957 lineto
0.48366 0.69933 lineto
0.4804 0.69904 lineto
0.47389 0.69829 lineto
0.46742 0.69733 lineto
0.46098 0.69616 lineto
0.44824 0.69319 lineto
Mistroke
0.43571 0.68939 lineto
0.42346 0.68478 lineto
0.4 0.67321 lineto
0.37825 0.65867 lineto
0.35858 0.64142 lineto
0.34133 0.62175 lineto
0.32679 0.6 lineto
0.31522 0.57654 lineto
0.31061 0.56429 lineto
0.30681 0.55176 lineto
0.30384 0.53902 lineto
0.30267 0.53258 lineto
0.30171 0.52611 lineto
0.30096 0.5196 lineto
0.30067 0.51634 lineto
0.30043 0.51308 lineto
0.30024 0.50981 lineto
0.30017 0.50818 lineto
0.30011 0.50654 lineto
0.30006 0.50491 lineto
0.30003 0.50327 lineto
0.30001 0.50164 lineto
0.3 0.5 lineto
0.30001 0.49836 lineto
0.30003 0.49673 lineto
0.30006 0.49509 lineto
0.30011 0.49346 lineto
0.30024 0.49019 lineto
0.30043 0.48692 lineto
0.30067 0.48366 lineto
0.30096 0.4804 lineto
0.30171 0.47389 lineto
0.30267 0.46742 lineto
0.30384 0.46098 lineto
0.30681 0.44824 lineto
0.31061 0.43571 lineto
0.31522 0.42346 lineto
0.32679 0.4 lineto
0.34133 0.37825 lineto
0.35858 0.35858 lineto
0.37825 0.34133 lineto
0.4 0.32679 lineto
0.41154 0.32063 lineto
0.42346 0.31522 lineto
0.43571 0.31061 lineto
0.44824 0.30681 lineto
0.46098 0.30384 lineto
0.46742 0.30267 lineto
0.47389 0.30171 lineto
0.4804 0.30096 lineto
Mistroke
0.48366 0.30067 lineto
0.48692 0.30043 lineto
0.49019 0.30024 lineto
0.49182 0.30017 lineto
0.49346 0.30011 lineto
0.49509 0.30006 lineto
0.49673 0.30003 lineto
0.49836 0.30001 lineto
0.5 0.3 lineto
0.50164 0.30001 lineto
0.50327 0.30003 lineto
0.50491 0.30006 lineto
0.50654 0.30011 lineto
0.50981 0.30024 lineto
0.51308 0.30043 lineto
0.51634 0.30067 lineto
0.5196 0.30096 lineto
0.52611 0.30171 lineto
0.53258 0.30267 lineto
0.53902 0.30384 lineto
0.55176 0.30681 lineto
0.56429 0.31061 lineto
0.57654 0.31522 lineto
0.6 0.32679 lineto
0.62175 0.34133 lineto
0.64142 0.35858 lineto
0.65867 0.37825 lineto
0.67321 0.4 lineto
0.67937 0.41154 lineto
0.68478 0.42346 lineto
0.68939 0.43571 lineto
0.69319 0.44824 lineto
0.69616 0.46098 lineto
0.69733 0.46742 lineto
0.69829 0.47389 lineto
0.69904 0.4804 lineto
0.69933 0.48366 lineto
0.69957 0.48692 lineto
0.69976 0.49019 lineto
0.69983 0.49182 lineto
0.69989 0.49346 lineto
0.69994 0.49509 lineto
0.69997 0.49673 lineto
0.69999 0.49836 lineto
0.7 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.68794 0.5684 lineto
stroke
0.30156 0.47507 moveto
-0.26579 0.26857 lineto
stroke
0.30124 0.52225 moveto
-0.2775 0.31161 lineto
stroke
0.31432 0.57431 moveto
-0.28684 0.3555 lineto
stroke
0.3531 0.63572 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
0.4747 0.30161 moveto
-0.17215 0.06617 lineto
stroke
0.40552 0.32372 moveto
-0.19564 0.10492 lineto
stroke
0.36205 0.35519 moveto
-0.2167 0.14455 lineto
stroke
0.33196 0.39154 moveto
-0.23539 0.18504 lineto
stroke
0.31206 0.4316 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.66804 0.60846 lineto
stroke
1.26579 0.73143 moveto
0.69844 0.52493 lineto
stroke
1.2167 0.85545 moveto
0.63795 0.64481 lineto
stroke
1.2775 0.68839 moveto
0.69876 0.47775 lineto
stroke
1.19564 0.89508 moveto
0.59448 0.67628 lineto
stroke
1.28684 0.6445 moveto
0.68568 0.42569 lineto
stroke
1.17215 0.93383 moveto
0.5253 0.69839 lineto
stroke
1.29376 0.59972 moveto
0.6469 0.36428 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.64142 0.64142 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.74 0.5 moveto
0.73999 0.50196 lineto
0.73997 0.50393 lineto
0.73993 0.50589 lineto
0.73987 0.50785 lineto
0.7398 0.50981 lineto
0.73971 0.51178 lineto
0.73949 0.5157 lineto
0.7392 0.51961 lineto
0.73884 0.52352 lineto
0.73795 0.53133 lineto
0.73679 0.53909 lineto
0.73539 0.54682 lineto
0.73182 0.56212 lineto
0.72726 0.57715 lineto
0.72173 0.59184 lineto
0.70785 0.62 lineto
0.6904 0.6461 lineto
0.66971 0.66971 lineto
0.6461 0.6904 lineto
0.62 0.70785 lineto
0.60615 0.71525 lineto
0.59184 0.72173 lineto
0.57715 0.72726 lineto
0.56212 0.73182 lineto
0.54682 0.73539 lineto
0.53909 0.73679 lineto
0.53133 0.73795 lineto
0.52352 0.73884 lineto
0.51961 0.7392 lineto
0.5157 0.73949 lineto
0.51178 0.73971 lineto
0.50981 0.7398 lineto
0.50785 0.73987 lineto
0.50589 0.73993 lineto
0.50393 0.73997 lineto
0.50196 0.73999 lineto
0.5 0.74 lineto
0.49804 0.73999 lineto
0.49607 0.73997 lineto
0.49411 0.73993 lineto
0.49215 0.73987 lineto
0.48822 0.73971 lineto
0.4843 0.73949 lineto
0.48039 0.7392 lineto
0.47648 0.73884 lineto
0.46867 0.73795 lineto
0.46091 0.73679 lineto
0.45318 0.73539 lineto
0.43788 0.73182 lineto
Mistroke
0.42285 0.72726 lineto
0.40816 0.72173 lineto
0.38 0.70785 lineto
0.3539 0.6904 lineto
0.33029 0.66971 lineto
0.3096 0.6461 lineto
0.29215 0.62 lineto
0.27827 0.59184 lineto
0.27274 0.57715 lineto
0.26818 0.56212 lineto
0.26461 0.54682 lineto
0.26321 0.53909 lineto
0.26205 0.53133 lineto
0.26116 0.52352 lineto
0.2608 0.51961 lineto
0.26051 0.5157 lineto
0.26029 0.51178 lineto
0.2602 0.50981 lineto
0.26013 0.50785 lineto
0.26007 0.50589 lineto
0.26003 0.50393 lineto
0.26001 0.50196 lineto
0.26 0.5 lineto
0.26001 0.49804 lineto
0.26003 0.49607 lineto
0.26007 0.49411 lineto
0.26013 0.49215 lineto
0.26029 0.48822 lineto
0.26051 0.4843 lineto
0.2608 0.48039 lineto
0.26116 0.47648 lineto
0.26205 0.46867 lineto
0.26321 0.46091 lineto
0.26461 0.45318 lineto
0.26818 0.43788 lineto
0.27274 0.42285 lineto
0.27827 0.40816 lineto
0.29215 0.38 lineto
0.3096 0.3539 lineto
0.33029 0.33029 lineto
0.3539 0.3096 lineto
0.38 0.29215 lineto
0.39385 0.28475 lineto
0.40816 0.27827 lineto
0.42285 0.27274 lineto
0.43788 0.26818 lineto
0.45318 0.26461 lineto
0.46091 0.26321 lineto
0.46867 0.26205 lineto
0.47648 0.26116 lineto
Mistroke
0.48039 0.2608 lineto
0.4843 0.26051 lineto
0.48822 0.26029 lineto
0.49019 0.2602 lineto
0.49215 0.26013 lineto
0.49411 0.26007 lineto
0.49607 0.26003 lineto
0.49804 0.26001 lineto
0.5 0.26 lineto
0.50196 0.26001 lineto
0.50393 0.26003 lineto
0.50589 0.26007 lineto
0.50785 0.26013 lineto
0.51178 0.26029 lineto
0.5157 0.26051 lineto
0.51961 0.2608 lineto
0.52352 0.26116 lineto
0.53133 0.26205 lineto
0.53909 0.26321 lineto
0.54682 0.26461 lineto
0.56212 0.26818 lineto
0.57715 0.27274 lineto
0.59184 0.27827 lineto
0.62 0.29215 lineto
0.6461 0.3096 lineto
0.66971 0.33029 lineto
0.6904 0.3539 lineto
0.70785 0.38 lineto
0.71525 0.39385 lineto
0.72173 0.40816 lineto
0.72726 0.42285 lineto
0.73182 0.43788 lineto
0.73539 0.45318 lineto
0.73679 0.46091 lineto
0.73795 0.46867 lineto
0.73884 0.47648 lineto
0.7392 0.48039 lineto
0.73949 0.4843 lineto
0.73971 0.48822 lineto
0.7398 0.49019 lineto
0.73987 0.49215 lineto
0.73993 0.49411 lineto
0.73997 0.49607 lineto
0.73999 0.49804 lineto
0.74 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.72553 0.58208 lineto
stroke
0.26317 0.4611 moveto
-0.26579 0.26857 lineto
stroke
0.26011 0.50728 moveto
-0.2775 0.31161 lineto
stroke
0.26688 0.55704 moveto
-0.28684 0.3555 lineto
stroke
0.28769 0.61191 moveto
-0.29376 0.40028 lineto
stroke
0.33881 0.67782 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
0.49082 0.26018 moveto
-0.14616 0.02833 lineto
stroke
0.4093 0.2778 moveto
-0.17215 0.06617 lineto
stroke
0.35808 0.30646 moveto
-0.19564 0.10492 lineto
stroke
0.32091 0.34022 moveto
-0.2167 0.14455 lineto
stroke
0.29358 0.37757 moveto
-0.23539 0.18504 lineto
stroke
0.27447 0.41792 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.70642 0.62243 lineto
stroke
1.26579 0.73143 moveto
0.73683 0.5389 lineto
stroke
1.2167 0.85545 moveto
0.67909 0.65978 lineto
stroke
1.2775 0.68839 moveto
0.73989 0.49272 lineto
stroke
1.19564 0.89508 moveto
0.64192 0.69354 lineto
stroke
1.28684 0.6445 moveto
0.73312 0.44296 lineto
stroke
1.17215 0.93383 moveto
0.5907 0.7222 lineto
stroke
1.29376 0.59972 moveto
0.71231 0.38809 lineto
stroke
1.14616 0.97167 moveto
0.50918 0.73982 lineto
stroke
1.29817 0.55403 moveto
0.66119 0.32218 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.66971 0.66971 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.78 0.5 moveto
0.77999 0.50229 lineto
0.77996 0.50458 lineto
0.77992 0.50687 lineto
0.77985 0.50916 lineto
0.77977 0.51145 lineto
0.77966 0.51374 lineto
0.7794 0.51831 lineto
0.77906 0.52288 lineto
0.77865 0.52744 lineto
0.7776 0.53655 lineto
0.77626 0.54561 lineto
0.77462 0.55463 lineto
0.77046 0.57247 lineto
0.76514 0.59 lineto
0.75869 0.60715 lineto
0.74249 0.64 lineto
0.72214 0.67045 lineto
0.69799 0.69799 lineto
0.67045 0.72214 lineto
0.64 0.74249 lineto
0.62384 0.75112 lineto
0.60715 0.75869 lineto
0.59 0.76514 lineto
0.57247 0.77046 lineto
0.55463 0.77462 lineto
0.54561 0.77626 lineto
0.53655 0.7776 lineto
0.52744 0.77865 lineto
0.52288 0.77906 lineto
0.51831 0.7794 lineto
0.51374 0.77966 lineto
0.51145 0.77977 lineto
0.50916 0.77985 lineto
0.50687 0.77992 lineto
0.50458 0.77996 lineto
0.50229 0.77999 lineto
0.5 0.78 lineto
0.49771 0.77999 lineto
0.49542 0.77996 lineto
0.49313 0.77992 lineto
0.49084 0.77985 lineto
0.48626 0.77966 lineto
0.48169 0.7794 lineto
0.47712 0.77906 lineto
0.47256 0.77865 lineto
0.46345 0.7776 lineto
0.45439 0.77626 lineto
0.44537 0.77462 lineto
0.42753 0.77046 lineto
Mistroke
0.41 0.76514 lineto
0.39285 0.75869 lineto
0.36 0.74249 lineto
0.32955 0.72214 lineto
0.30201 0.69799 lineto
0.27786 0.67045 lineto
0.25751 0.64 lineto
0.24131 0.60715 lineto
0.23486 0.59 lineto
0.22954 0.57247 lineto
0.22538 0.55463 lineto
0.22374 0.54561 lineto
0.2224 0.53655 lineto
0.22135 0.52744 lineto
0.22094 0.52288 lineto
0.2206 0.51831 lineto
0.22034 0.51374 lineto
0.22023 0.51145 lineto
0.22015 0.50916 lineto
0.22008 0.50687 lineto
0.22004 0.50458 lineto
0.22001 0.50229 lineto
0.22 0.5 lineto
0.22001 0.49771 lineto
0.22004 0.49542 lineto
0.22008 0.49313 lineto
0.22015 0.49084 lineto
0.22034 0.48626 lineto
0.2206 0.48169 lineto
0.22094 0.47712 lineto
0.22135 0.47256 lineto
0.2224 0.46345 lineto
0.22374 0.45439 lineto
0.22538 0.44537 lineto
0.22954 0.42753 lineto
0.23486 0.41 lineto
0.24131 0.39285 lineto
0.25751 0.36 lineto
0.27786 0.32955 lineto
0.30201 0.30201 lineto
0.32955 0.27786 lineto
0.36 0.25751 lineto
0.37616 0.24888 lineto
0.39285 0.24131 lineto
0.41 0.23486 lineto
0.42753 0.22954 lineto
0.44537 0.22538 lineto
0.45439 0.22374 lineto
0.46345 0.2224 lineto
0.47256 0.22135 lineto
Mistroke
0.47712 0.22094 lineto
0.48169 0.2206 lineto
0.48626 0.22034 lineto
0.48855 0.22023 lineto
0.49084 0.22015 lineto
0.49313 0.22008 lineto
0.49542 0.22004 lineto
0.49771 0.22001 lineto
0.5 0.22 lineto
0.50229 0.22001 lineto
0.50458 0.22004 lineto
0.50687 0.22008 lineto
0.50916 0.22015 lineto
0.51374 0.22034 lineto
0.51831 0.2206 lineto
0.52288 0.22094 lineto
0.52744 0.22135 lineto
0.53655 0.2224 lineto
0.54561 0.22374 lineto
0.55463 0.22538 lineto
0.57247 0.22954 lineto
0.59 0.23486 lineto
0.60715 0.24131 lineto
0.64 0.25751 lineto
0.67045 0.27786 lineto
0.69799 0.30201 lineto
0.72214 0.32955 lineto
0.74249 0.36 lineto
0.75112 0.37616 lineto
0.75869 0.39285 lineto
0.76514 0.41 lineto
0.77046 0.42753 lineto
0.77462 0.44537 lineto
0.77626 0.45439 lineto
0.7776 0.46345 lineto
0.77865 0.47256 lineto
0.77906 0.47712 lineto
0.7794 0.48169 lineto
0.77966 0.48626 lineto
0.77977 0.48855 lineto
0.77985 0.49084 lineto
0.77992 0.49313 lineto
0.77996 0.49542 lineto
0.77999 0.49771 lineto
0.78 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.76311 0.59577 lineto
stroke
0.22502 0.44721 moveto
-0.26579 0.26857 lineto
stroke
0.22009 0.49272 moveto
-0.2775 0.31161 lineto
stroke
0.22303 0.54108 moveto
-0.28684 0.3555 lineto
stroke
0.23592 0.59307 moveto
-0.29376 0.40028 lineto
stroke
0.26392 0.65056 moveto
-0.29817 0.44597 lineto
stroke
0.32857 0.72138 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
0.51098 0.22022 moveto
-0.11756 -0.00855 lineto
stroke
0.41593 0.23292 moveto
-0.14616 0.02833 lineto
stroke
0.35753 0.25896 moveto
-0.17215 0.06617 lineto
stroke
0.31424 0.2905 moveto
-0.19564 0.10492 lineto
stroke
0.2809 0.32566 moveto
-0.2167 0.14455 lineto
stroke
0.25542 0.36368 moveto
-0.23539 0.18504 lineto
stroke
0.23689 0.40423 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.74458 0.63632 lineto
stroke
1.26579 0.73143 moveto
0.77498 0.55279 lineto
stroke
1.2167 0.85545 moveto
0.7191 0.67434 lineto
stroke
1.2775 0.68839 moveto
0.77991 0.50728 lineto
stroke
1.19564 0.89508 moveto
0.68576 0.7095 lineto
stroke
1.28684 0.6445 moveto
0.77697 0.45892 lineto
stroke
1.17215 0.93383 moveto
0.64247 0.74104 lineto
stroke
1.29376 0.59972 moveto
0.76408 0.40693 lineto
stroke
1.14616 0.97167 moveto
0.58407 0.76708 lineto
stroke
1.29817 0.55403 moveto
0.73608 0.34944 lineto
stroke
1.11756 1.00855 moveto
0.48902 0.77978 lineto
stroke
1.29997 0.50738 moveto
0.67143 0.27862 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.69799 0.69799 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = input; startGroup; ]
Do[MagPhasePlot[1/(Exp[I w] - r Exp[I Pi/4]), {w, -Pi, Pi}, 
                PhaseRangeScale -> Null, PlotRange -> {0,9.7}],
   {r,0.1,0.9,0.1}]
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.06371 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2)] 0.4875 0.12743 1 0 Msboxa
[(4)] 0.4875 0.25486 1 0 Msboxa
[(6)] 0.4875 0.38229 1 0 Msboxa
[(8)] 0.4875 0.50972 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12743 moveto
0.50625 0.12743 lineto
stroke
0 setgray
[(2)] 0.4875 0.12743 1 0 Mshowa
0.49375 0.25486 moveto
0.50625 0.25486 lineto
stroke
0 setgray
[(4)] 0.4875 0.25486 1 0 Mshowa
0.49375 0.38229 moveto
0.50625 0.38229 lineto
stroke
0 setgray
[(6)] 0.4875 0.38229 1 0 Mshowa
0.49375 0.50972 moveto
0.50625 0.50972 lineto
stroke
0 setgray
[(8)] 0.4875 0.50972 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.05938 moveto
0.04365 0.05894 lineto
0.06349 0.05857 lineto
0.08333 0.05829 lineto
0.09325 0.05818 lineto
0.10317 0.05809 lineto
0.1131 0.05801 lineto
0.11806 0.05799 lineto
0.12302 0.05796 lineto
0.12798 0.05795 lineto
0.13046 0.05794 lineto
0.13294 0.05793 lineto
0.13542 0.05793 lineto
0.13666 0.05793 lineto
0.1379 0.05793 lineto
0.13914 0.05792 lineto
0.14038 0.05792 lineto
0.14162 0.05792 lineto
0.14286 0.05792 lineto
0.1441 0.05792 lineto
0.14534 0.05792 lineto
0.14658 0.05792 lineto
0.14782 0.05793 lineto
0.1503 0.05793 lineto
0.15278 0.05793 lineto
0.15526 0.05794 lineto
0.15774 0.05795 lineto
0.1627 0.05796 lineto
0.16766 0.05799 lineto
0.17262 0.05801 lineto
0.18254 0.05809 lineto
0.19246 0.05818 lineto
0.20238 0.05829 lineto
0.22222 0.05857 lineto
0.2619 0.05938 lineto
0.30159 0.06048 lineto
0.34127 0.06183 lineto
0.38095 0.0634 lineto
0.42063 0.06509 lineto
0.46032 0.06679 lineto
0.5 0.06837 lineto
0.51984 0.06905 lineto
0.53968 0.06965 lineto
0.55952 0.07014 lineto
0.56944 0.07033 lineto
0.57937 0.0705 lineto
0.58929 0.07063 lineto
0.59921 0.07072 lineto
0.60417 0.07075 lineto
0.60665 0.07077 lineto
Mistroke
0.60913 0.07078 lineto
0.61161 0.07078 lineto
0.61285 0.07079 lineto
0.61409 0.07079 lineto
0.61533 0.07079 lineto
0.61657 0.07079 lineto
0.61781 0.07079 lineto
0.61905 0.07079 lineto
0.62029 0.07079 lineto
0.62153 0.07079 lineto
0.62277 0.07079 lineto
0.62401 0.07079 lineto
0.62649 0.07078 lineto
0.62897 0.07078 lineto
0.63145 0.07077 lineto
0.63393 0.07075 lineto
0.63889 0.07072 lineto
0.64881 0.07063 lineto
0.65873 0.0705 lineto
0.67857 0.07014 lineto
0.69841 0.06965 lineto
0.7381 0.06837 lineto
0.77778 0.06679 lineto
0.81746 0.06509 lineto
0.85714 0.0634 lineto
0.89683 0.06183 lineto
0.93651 0.06048 lineto
0.97619 0.05938 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.06371 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2)] 0.4875 0.12743 1 0 Msboxa
[(4)] 0.4875 0.25486 1 0 Msboxa
[(6)] 0.4875 0.38229 1 0 Msboxa
[(8)] 0.4875 0.50972 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12743 moveto
0.50625 0.12743 lineto
stroke
0 setgray
[(2)] 0.4875 0.12743 1 0 Mshowa
0.49375 0.25486 moveto
0.50625 0.25486 lineto
stroke
0 setgray
[(4)] 0.4875 0.25486 1 0 Mshowa
0.49375 0.38229 moveto
0.50625 0.38229 lineto
stroke
0 setgray
[(6)] 0.4875 0.38229 1 0 Mshowa
0.49375 0.50972 moveto
0.50625 0.50972 lineto
stroke
0 setgray
[(8)] 0.4875 0.50972 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.0554 moveto
0.04365 0.05469 lineto
0.06349 0.05411 lineto
0.08333 0.05367 lineto
0.09325 0.05349 lineto
0.10317 0.05335 lineto
0.1131 0.05324 lineto
0.11806 0.05319 lineto
0.12302 0.05316 lineto
0.12798 0.05313 lineto
0.13046 0.05312 lineto
0.13294 0.05311 lineto
0.13542 0.0531 lineto
0.13666 0.0531 lineto
0.1379 0.0531 lineto
0.13914 0.0531 lineto
0.14038 0.0531 lineto
0.14162 0.0531 lineto
0.14286 0.0531 lineto
0.1441 0.0531 lineto
0.14534 0.0531 lineto
0.14658 0.0531 lineto
0.14782 0.0531 lineto
0.1503 0.0531 lineto
0.15278 0.05311 lineto
0.15526 0.05312 lineto
0.15774 0.05313 lineto
0.1627 0.05316 lineto
0.16766 0.05319 lineto
0.17262 0.05324 lineto
0.18254 0.05335 lineto
0.19246 0.05349 lineto
0.20238 0.05367 lineto
0.22222 0.05411 lineto
0.24206 0.05469 lineto
0.2619 0.0554 lineto
0.30159 0.05722 lineto
0.34127 0.05958 lineto
0.38095 0.06248 lineto
0.42063 0.06584 lineto
0.46032 0.06952 lineto
0.5 0.07322 lineto
0.51984 0.07495 lineto
0.53968 0.0765 lineto
0.55952 0.07781 lineto
0.56944 0.07835 lineto
0.57937 0.07881 lineto
0.58929 0.07917 lineto
0.59921 0.07943 lineto
0.60417 0.07952 lineto
Mistroke
0.60665 0.07956 lineto
0.60913 0.07959 lineto
0.61161 0.07961 lineto
0.61285 0.07962 lineto
0.61409 0.07963 lineto
0.61533 0.07964 lineto
0.61657 0.07964 lineto
0.61781 0.07964 lineto
0.61905 0.07964 lineto
0.62029 0.07964 lineto
0.62153 0.07964 lineto
0.62277 0.07964 lineto
0.62401 0.07963 lineto
0.62649 0.07961 lineto
0.62897 0.07959 lineto
0.63145 0.07956 lineto
0.63393 0.07952 lineto
0.63889 0.07943 lineto
0.64881 0.07917 lineto
0.65873 0.07881 lineto
0.67857 0.07781 lineto
0.69841 0.0765 lineto
0.7381 0.07322 lineto
0.77778 0.06952 lineto
0.81746 0.06584 lineto
0.85714 0.06248 lineto
0.89683 0.05958 lineto
0.93651 0.05722 lineto
0.97619 0.0554 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.06371 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2)] 0.4875 0.12743 1 0 Msboxa
[(4)] 0.4875 0.25486 1 0 Msboxa
[(6)] 0.4875 0.38229 1 0 Msboxa
[(8)] 0.4875 0.50972 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12743 moveto
0.50625 0.12743 lineto
stroke
0 setgray
[(2)] 0.4875 0.12743 1 0 Mshowa
0.49375 0.25486 moveto
0.50625 0.25486 lineto
stroke
0 setgray
[(4)] 0.4875 0.25486 1 0 Mshowa
0.49375 0.38229 moveto
0.50625 0.38229 lineto
stroke
0 setgray
[(6)] 0.4875 0.38229 1 0 Mshowa
0.49375 0.50972 moveto
0.50625 0.50972 lineto
stroke
0 setgray
[(8)] 0.4875 0.50972 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.05178 moveto
0.04365 0.05091 lineto
0.06349 0.05022 lineto
0.08333 0.04969 lineto
0.09325 0.04948 lineto
0.10317 0.04931 lineto
0.1131 0.04918 lineto
0.11806 0.04913 lineto
0.12302 0.04909 lineto
0.12798 0.04905 lineto
0.13046 0.04904 lineto
0.13294 0.04903 lineto
0.13542 0.04902 lineto
0.13666 0.04902 lineto
0.1379 0.04902 lineto
0.13914 0.04901 lineto
0.14038 0.04901 lineto
0.14162 0.04901 lineto
0.14286 0.04901 lineto
0.1441 0.04901 lineto
0.14534 0.04901 lineto
0.14658 0.04901 lineto
0.14782 0.04902 lineto
0.1503 0.04902 lineto
0.15278 0.04903 lineto
0.15526 0.04904 lineto
0.15774 0.04905 lineto
0.1627 0.04909 lineto
0.16766 0.04913 lineto
0.17262 0.04918 lineto
0.18254 0.04931 lineto
0.19246 0.04948 lineto
0.20238 0.04969 lineto
0.22222 0.05022 lineto
0.24206 0.05091 lineto
0.2619 0.05178 lineto
0.30159 0.05404 lineto
0.34127 0.0571 lineto
0.38095 0.06103 lineto
0.42063 0.0659 lineto
0.46032 0.07168 lineto
0.5 0.07809 lineto
0.53968 0.08436 lineto
0.55952 0.08705 lineto
0.56944 0.0882 lineto
0.57937 0.08918 lineto
0.58929 0.08997 lineto
0.59921 0.09055 lineto
0.60417 0.09075 lineto
0.60665 0.09084 lineto
Mistroke
0.60913 0.0909 lineto
0.61161 0.09095 lineto
0.61285 0.09097 lineto
0.61409 0.09099 lineto
0.61533 0.091 lineto
0.61657 0.09101 lineto
0.61781 0.09102 lineto
0.61905 0.09102 lineto
0.62029 0.09102 lineto
0.62153 0.09101 lineto
0.62277 0.091 lineto
0.62401 0.09099 lineto
0.62649 0.09095 lineto
0.62897 0.0909 lineto
0.63145 0.09084 lineto
0.63393 0.09075 lineto
0.63889 0.09055 lineto
0.64881 0.08997 lineto
0.65873 0.08918 lineto
0.67857 0.08705 lineto
0.69841 0.08436 lineto
0.7381 0.07809 lineto
0.77778 0.07168 lineto
0.81746 0.0659 lineto
0.85714 0.06103 lineto
0.89683 0.0571 lineto
0.93651 0.05404 lineto
0.97619 0.05178 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.06371 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2)] 0.4875 0.12743 1 0 Msboxa
[(4)] 0.4875 0.25486 1 0 Msboxa
[(6)] 0.4875 0.38229 1 0 Msboxa
[(8)] 0.4875 0.50972 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12743 moveto
0.50625 0.12743 lineto
stroke
0 setgray
[(2)] 0.4875 0.12743 1 0 Mshowa
0.49375 0.25486 moveto
0.50625 0.25486 lineto
stroke
0 setgray
[(4)] 0.4875 0.25486 1 0 Mshowa
0.49375 0.38229 moveto
0.50625 0.38229 lineto
stroke
0 setgray
[(6)] 0.4875 0.38229 1 0 Mshowa
0.49375 0.50972 moveto
0.50625 0.50972 lineto
stroke
0 setgray
[(8)] 0.4875 0.50972 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.0485 moveto
0.04365 0.04756 lineto
0.06349 0.04681 lineto
0.08333 0.04623 lineto
0.09325 0.04601 lineto
0.10317 0.04583 lineto
0.1131 0.04569 lineto
0.11806 0.04564 lineto
0.12302 0.04559 lineto
0.12798 0.04556 lineto
0.13046 0.04554 lineto
0.13294 0.04553 lineto
0.13542 0.04552 lineto
0.13666 0.04552 lineto
0.1379 0.04552 lineto
0.13914 0.04551 lineto
0.14038 0.04551 lineto
0.14162 0.04551 lineto
0.14286 0.04551 lineto
0.1441 0.04551 lineto
0.14534 0.04551 lineto
0.14658 0.04551 lineto
0.14782 0.04552 lineto
0.1503 0.04552 lineto
0.15278 0.04553 lineto
0.15526 0.04554 lineto
0.15774 0.04556 lineto
0.1627 0.04559 lineto
0.16766 0.04564 lineto
0.17262 0.04569 lineto
0.18254 0.04583 lineto
0.19246 0.04601 lineto
0.20238 0.04623 lineto
0.22222 0.04681 lineto
0.24206 0.04756 lineto
0.2619 0.0485 lineto
0.30159 0.05101 lineto
0.34127 0.05449 lineto
0.38095 0.05916 lineto
0.42063 0.06527 lineto
0.46032 0.07309 lineto
0.5 0.08265 lineto
0.53968 0.09322 lineto
0.55952 0.09821 lineto
0.56944 0.10043 lineto
0.57937 0.10239 lineto
0.58929 0.10399 lineto
0.59921 0.1052 lineto
0.60417 0.10563 lineto
0.60665 0.1058 lineto
Mistroke
0.60913 0.10594 lineto
0.61161 0.10605 lineto
0.61285 0.10609 lineto
0.61409 0.10613 lineto
0.61533 0.10616 lineto
0.61657 0.10618 lineto
0.61781 0.10619 lineto
0.61905 0.10619 lineto
0.62029 0.10619 lineto
0.62153 0.10618 lineto
0.62277 0.10616 lineto
0.62401 0.10613 lineto
0.62649 0.10605 lineto
0.62897 0.10594 lineto
0.63393 0.10563 lineto
0.63889 0.1052 lineto
0.64881 0.10399 lineto
0.65873 0.10239 lineto
0.67857 0.09821 lineto
0.69841 0.09322 lineto
0.7381 0.08265 lineto
0.77778 0.07309 lineto
0.81746 0.06527 lineto
0.85714 0.05916 lineto
0.89683 0.05449 lineto
0.93651 0.05101 lineto
0.97619 0.0485 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.06371 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2)] 0.4875 0.12743 1 0 Msboxa
[(4)] 0.4875 0.25486 1 0 Msboxa
[(6)] 0.4875 0.38229 1 0 Msboxa
[(8)] 0.4875 0.50972 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12743 moveto
0.50625 0.12743 lineto
stroke
0 setgray
[(2)] 0.4875 0.12743 1 0 Mshowa
0.49375 0.25486 moveto
0.50625 0.25486 lineto
stroke
0 setgray
[(4)] 0.4875 0.25486 1 0 Mshowa
0.49375 0.38229 moveto
0.50625 0.38229 lineto
stroke
0 setgray
[(6)] 0.4875 0.38229 1 0 Mshowa
0.49375 0.50972 moveto
0.50625 0.50972 lineto
stroke
0 setgray
[(8)] 0.4875 0.50972 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.04554 moveto
0.04365 0.04457 lineto
0.06349 0.0438 lineto
0.07341 0.04348 lineto
0.08333 0.04321 lineto
0.09325 0.04299 lineto
0.10317 0.0428 lineto
0.1131 0.04266 lineto
0.11806 0.0426 lineto
0.12302 0.04256 lineto
0.12798 0.04252 lineto
0.13046 0.04251 lineto
0.13294 0.0425 lineto
0.13542 0.04249 lineto
0.13666 0.04248 lineto
0.1379 0.04248 lineto
0.13914 0.04248 lineto
0.14038 0.04248 lineto
0.14162 0.04248 lineto
0.14286 0.04248 lineto
0.1441 0.04248 lineto
0.14534 0.04248 lineto
0.14658 0.04248 lineto
0.14782 0.04248 lineto
0.1503 0.04249 lineto
0.15278 0.0425 lineto
0.15526 0.04251 lineto
0.15774 0.04252 lineto
0.1627 0.04256 lineto
0.16766 0.0426 lineto
0.17262 0.04266 lineto
0.18254 0.0428 lineto
0.19246 0.04299 lineto
0.20238 0.04321 lineto
0.22222 0.0438 lineto
0.24206 0.04457 lineto
0.2619 0.04554 lineto
0.30159 0.04816 lineto
0.34127 0.05187 lineto
0.38095 0.05699 lineto
0.42063 0.064 lineto
0.46032 0.07357 lineto
0.5 0.08647 lineto
0.53968 0.10282 lineto
0.55952 0.11157 lineto
0.57937 0.11954 lineto
0.58929 0.1228 lineto
0.59921 0.1253 lineto
0.60417 0.12622 lineto
0.60665 0.12659 lineto
Mistroke
0.60913 0.12689 lineto
0.61161 0.12712 lineto
0.61285 0.12722 lineto
0.61409 0.12729 lineto
0.61533 0.12735 lineto
0.61657 0.1274 lineto
0.61781 0.12742 lineto
0.61905 0.12743 lineto
0.62029 0.12742 lineto
0.62153 0.1274 lineto
0.62277 0.12735 lineto
0.62401 0.12729 lineto
0.62649 0.12712 lineto
0.62897 0.12689 lineto
0.63393 0.12622 lineto
0.63889 0.1253 lineto
0.64881 0.1228 lineto
0.65873 0.11954 lineto
0.69841 0.10282 lineto
0.7381 0.08647 lineto
0.77778 0.07357 lineto
0.81746 0.064 lineto
0.85714 0.05699 lineto
0.89683 0.05187 lineto
0.93651 0.04816 lineto
0.97619 0.04554 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.06371 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2)] 0.4875 0.12743 1 0 Msboxa
[(4)] 0.4875 0.25486 1 0 Msboxa
[(6)] 0.4875 0.38229 1 0 Msboxa
[(8)] 0.4875 0.50972 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12743 moveto
0.50625 0.12743 lineto
stroke
0 setgray
[(2)] 0.4875 0.12743 1 0 Mshowa
0.49375 0.25486 moveto
0.50625 0.25486 lineto
stroke
0 setgray
[(4)] 0.4875 0.25486 1 0 Mshowa
0.49375 0.38229 moveto
0.50625 0.38229 lineto
stroke
0 setgray
[(6)] 0.4875 0.38229 1 0 Mshowa
0.49375 0.50972 moveto
0.50625 0.50972 lineto
stroke
0 setgray
[(8)] 0.4875 0.50972 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.04287 moveto
0.04365 0.0419 lineto
0.06349 0.04113 lineto
0.07341 0.04082 lineto
0.08333 0.04055 lineto
0.09325 0.04033 lineto
0.10317 0.04014 lineto
0.1131 0.04 lineto
0.11806 0.03995 lineto
0.12302 0.0399 lineto
0.12798 0.03987 lineto
0.13046 0.03985 lineto
0.13294 0.03984 lineto
0.13542 0.03983 lineto
0.13666 0.03983 lineto
0.1379 0.03983 lineto
0.13914 0.03982 lineto
0.14038 0.03982 lineto
0.14162 0.03982 lineto
0.14286 0.03982 lineto
0.1441 0.03982 lineto
0.14534 0.03982 lineto
0.14658 0.03982 lineto
0.14782 0.03983 lineto
0.1503 0.03983 lineto
0.15278 0.03984 lineto
0.15526 0.03985 lineto
0.15774 0.03987 lineto
0.1627 0.0399 lineto
0.16766 0.03995 lineto
0.17262 0.04 lineto
0.18254 0.04014 lineto
0.19246 0.04033 lineto
0.20238 0.04055 lineto
0.22222 0.04113 lineto
0.24206 0.0419 lineto
0.2619 0.04287 lineto
0.28175 0.04407 lineto
0.30159 0.04551 lineto
0.34127 0.0493 lineto
0.38095 0.05464 lineto
0.40079 0.05808 lineto
0.42063 0.0622 lineto
0.44048 0.06713 lineto
0.46032 0.07309 lineto
0.48016 0.08031 lineto
0.5 0.08909 lineto
0.53968 0.1125 lineto
0.57937 0.14216 lineto
0.58929 0.14892 lineto
Mistroke
0.59921 0.15441 lineto
0.60417 0.15649 lineto
0.60665 0.15733 lineto
0.60913 0.15802 lineto
0.61161 0.15857 lineto
0.61285 0.15879 lineto
0.61409 0.15897 lineto
0.61533 0.15911 lineto
0.61657 0.15921 lineto
0.61781 0.15927 lineto
0.61905 0.15929 lineto
0.62029 0.15927 lineto
0.62153 0.15921 lineto
0.62277 0.15911 lineto
0.62401 0.15897 lineto
0.62649 0.15857 lineto
0.62897 0.15802 lineto
0.63393 0.15649 lineto
0.63889 0.15441 lineto
0.64881 0.14892 lineto
0.65873 0.14216 lineto
0.69841 0.1125 lineto
0.7381 0.08909 lineto
0.75794 0.08031 lineto
0.77778 0.07309 lineto
0.81746 0.0622 lineto
0.8373 0.05808 lineto
0.85714 0.05464 lineto
0.89683 0.0493 lineto
0.93651 0.04551 lineto
0.95635 0.04407 lineto
0.97619 0.04287 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.06371 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2)] 0.4875 0.12743 1 0 Msboxa
[(4)] 0.4875 0.25486 1 0 Msboxa
[(6)] 0.4875 0.38229 1 0 Msboxa
[(8)] 0.4875 0.50972 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12743 moveto
0.50625 0.12743 lineto
stroke
0 setgray
[(2)] 0.4875 0.12743 1 0 Mshowa
0.49375 0.25486 moveto
0.50625 0.25486 lineto
stroke
0 setgray
[(4)] 0.4875 0.25486 1 0 Mshowa
0.49375 0.38229 moveto
0.50625 0.38229 lineto
stroke
0 setgray
[(6)] 0.4875 0.38229 1 0 Mshowa
0.49375 0.50972 moveto
0.50625 0.50972 lineto
stroke
0 setgray
[(8)] 0.4875 0.50972 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.04046 moveto
0.04365 0.03951 lineto
0.06349 0.03876 lineto
0.07341 0.03845 lineto
0.08333 0.03819 lineto
0.09325 0.03797 lineto
0.10317 0.03779 lineto
0.1131 0.03765 lineto
0.11806 0.0376 lineto
0.12302 0.03756 lineto
0.12798 0.03752 lineto
0.13046 0.03751 lineto
0.13294 0.0375 lineto
0.13542 0.03749 lineto
0.13666 0.03749 lineto
0.1379 0.03748 lineto
0.13914 0.03748 lineto
0.14038 0.03748 lineto
0.14162 0.03748 lineto
0.14286 0.03748 lineto
0.1441 0.03748 lineto
0.14534 0.03748 lineto
0.14658 0.03748 lineto
0.14782 0.03748 lineto
0.1503 0.03749 lineto
0.15278 0.0375 lineto
0.15526 0.03751 lineto
0.15774 0.03752 lineto
0.1627 0.03756 lineto
0.16766 0.0376 lineto
0.17262 0.03765 lineto
0.18254 0.03779 lineto
0.19246 0.03797 lineto
0.20238 0.03819 lineto
0.22222 0.03876 lineto
0.24206 0.03951 lineto
0.2619 0.04046 lineto
0.28175 0.04163 lineto
0.30159 0.04305 lineto
0.32143 0.04477 lineto
0.34127 0.04681 lineto
0.38095 0.0522 lineto
0.40079 0.05573 lineto
0.42063 0.06 lineto
0.44048 0.06522 lineto
0.46032 0.07168 lineto
0.48016 0.07978 lineto
0.5 0.0901 lineto
0.51984 0.10345 lineto
0.53968 0.12094 lineto
Mistroke
0.55952 0.14371 lineto
0.57937 0.1717 lineto
0.58929 0.18635 lineto
0.59921 0.19952 lineto
0.60417 0.20485 lineto
0.60665 0.20706 lineto
0.60913 0.20893 lineto
0.61161 0.21042 lineto
0.61285 0.21101 lineto
0.61409 0.2115 lineto
0.61533 0.21189 lineto
0.61657 0.21216 lineto
0.61781 0.21233 lineto
0.61905 0.21238 lineto
0.62029 0.21233 lineto
0.62153 0.21216 lineto
0.62277 0.21189 lineto
0.62401 0.2115 lineto
0.62649 0.21042 lineto
0.62897 0.20893 lineto
0.63393 0.20485 lineto
0.63889 0.19952 lineto
0.65873 0.1717 lineto
0.67857 0.14371 lineto
0.69841 0.12094 lineto
0.71825 0.10345 lineto
0.7381 0.0901 lineto
0.75794 0.07978 lineto
0.77778 0.07168 lineto
0.81746 0.06 lineto
0.8373 0.05573 lineto
0.85714 0.0522 lineto
0.87698 0.04926 lineto
0.89683 0.04681 lineto
0.93651 0.04305 lineto
0.95635 0.04163 lineto
0.97619 0.04046 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.06371 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2)] 0.4875 0.12743 1 0 Msboxa
[(4)] 0.4875 0.25486 1 0 Msboxa
[(6)] 0.4875 0.38229 1 0 Msboxa
[(8)] 0.4875 0.50972 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12743 moveto
0.50625 0.12743 lineto
stroke
0 setgray
[(2)] 0.4875 0.12743 1 0 Mshowa
0.49375 0.25486 moveto
0.50625 0.25486 lineto
stroke
0 setgray
[(4)] 0.4875 0.25486 1 0 Mshowa
0.49375 0.38229 moveto
0.50625 0.38229 lineto
stroke
0 setgray
[(6)] 0.4875 0.38229 1 0 Mshowa
0.49375 0.50972 moveto
0.50625 0.50972 lineto
stroke
0 setgray
[(8)] 0.4875 0.50972 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.03827 moveto
0.04365 0.03735 lineto
0.06349 0.03663 lineto
0.07341 0.03633 lineto
0.08333 0.03608 lineto
0.09325 0.03587 lineto
0.10317 0.0357 lineto
0.1131 0.03557 lineto
0.11806 0.03551 lineto
0.12302 0.03547 lineto
0.12798 0.03544 lineto
0.13046 0.03543 lineto
0.13294 0.03542 lineto
0.13542 0.03541 lineto
0.13666 0.0354 lineto
0.1379 0.0354 lineto
0.13914 0.0354 lineto
0.14038 0.0354 lineto
0.14162 0.0354 lineto
0.14286 0.0354 lineto
0.1441 0.0354 lineto
0.14534 0.0354 lineto
0.14658 0.0354 lineto
0.14782 0.0354 lineto
0.1503 0.03541 lineto
0.15278 0.03542 lineto
0.15526 0.03543 lineto
0.15774 0.03544 lineto
0.1627 0.03547 lineto
0.16766 0.03551 lineto
0.17262 0.03557 lineto
0.18254 0.0357 lineto
0.19246 0.03587 lineto
0.20238 0.03608 lineto
0.22222 0.03663 lineto
0.24206 0.03735 lineto
0.2619 0.03827 lineto
0.28175 0.03941 lineto
0.30159 0.04079 lineto
0.32143 0.04245 lineto
0.34127 0.04446 lineto
0.38095 0.04975 lineto
0.40079 0.05326 lineto
0.42063 0.05755 lineto
0.44048 0.06285 lineto
0.46032 0.06952 lineto
0.48016 0.07807 lineto
0.5 0.08934 lineto
0.51984 0.10466 lineto
0.53968 0.12633 lineto
Mistroke
0.5496 0.14072 lineto
0.55952 0.1584 lineto
0.57937 0.20724 lineto
0.59921 0.27498 lineto
0.60417 0.29172 lineto
0.60665 0.29919 lineto
0.60913 0.30575 lineto
0.61161 0.31117 lineto
0.61285 0.31337 lineto
0.61409 0.31522 lineto
0.61533 0.31667 lineto
0.61657 0.31772 lineto
0.61781 0.31836 lineto
0.61905 0.31857 lineto
0.62029 0.31836 lineto
0.62153 0.31772 lineto
0.62277 0.31667 lineto
0.62401 0.31522 lineto
0.62649 0.31117 lineto
0.62897 0.30575 lineto
0.63889 0.27498 lineto
0.65873 0.20724 lineto
0.67857 0.1584 lineto
0.68849 0.14072 lineto
0.69841 0.12633 lineto
0.71825 0.10466 lineto
0.7381 0.08934 lineto
0.75794 0.07807 lineto
0.77778 0.06952 lineto
0.79762 0.06285 lineto
0.81746 0.05755 lineto
0.8373 0.05326 lineto
0.85714 0.04975 lineto
0.87698 0.04686 lineto
0.89683 0.04446 lineto
0.93651 0.04079 lineto
0.95635 0.03941 lineto
0.97619 0.03827 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; endGroup; endGroup; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.06371 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2)] 0.4875 0.12743 1 0 Msboxa
[(4)] 0.4875 0.25486 1 0 Msboxa
[(6)] 0.4875 0.38229 1 0 Msboxa
[(8)] 0.4875 0.50972 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12743 moveto
0.50625 0.12743 lineto
stroke
0 setgray
[(2)] 0.4875 0.12743 1 0 Mshowa
0.49375 0.25486 moveto
0.50625 0.25486 lineto
stroke
0 setgray
[(4)] 0.4875 0.25486 1 0 Mshowa
0.49375 0.38229 moveto
0.50625 0.38229 lineto
stroke
0 setgray
[(6)] 0.4875 0.38229 1 0 Mshowa
0.49375 0.50972 moveto
0.50625 0.50972 lineto
stroke
0 setgray
[(8)] 0.4875 0.50972 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.03629 moveto
0.04365 0.03541 lineto
0.06349 0.03471 lineto
0.07341 0.03443 lineto
0.08333 0.03419 lineto
0.09325 0.03399 lineto
0.10317 0.03382 lineto
0.1131 0.0337 lineto
0.11806 0.03365 lineto
0.12302 0.03361 lineto
0.12798 0.03357 lineto
0.13046 0.03356 lineto
0.13294 0.03355 lineto
0.13542 0.03354 lineto
0.13666 0.03354 lineto
0.1379 0.03354 lineto
0.13914 0.03354 lineto
0.14038 0.03354 lineto
0.14162 0.03353 lineto
0.14286 0.03353 lineto
0.1441 0.03353 lineto
0.14534 0.03354 lineto
0.14658 0.03354 lineto
0.14782 0.03354 lineto
0.1503 0.03354 lineto
0.15278 0.03355 lineto
0.15526 0.03356 lineto
0.15774 0.03357 lineto
0.1627 0.03361 lineto
0.16766 0.03365 lineto
0.17262 0.0337 lineto
0.18254 0.03382 lineto
0.19246 0.03399 lineto
0.20238 0.03419 lineto
0.22222 0.03471 lineto
0.24206 0.03541 lineto
0.2619 0.03629 lineto
0.28175 0.03738 lineto
0.30159 0.0387 lineto
0.32143 0.04031 lineto
0.34127 0.04223 lineto
0.38095 0.04736 lineto
0.40079 0.05077 lineto
0.42063 0.05496 lineto
0.44048 0.06017 lineto
0.46032 0.06679 lineto
0.48016 0.07539 lineto
0.5 0.08693 lineto
0.50992 0.09428 lineto
0.51984 0.10309 lineto
Mistroke
0.53968 0.12714 lineto
0.5496 0.14405 lineto
0.55952 0.16617 lineto
0.56944 0.19614 lineto
0.57937 0.23856 lineto
0.58433 0.26682 lineto
0.58929 0.30174 lineto
0.59921 0.39979 lineto
0.60417 0.46633 lineto
0.60913 0.54132 lineto
0.61161 0.5776 lineto
0.61285 0.59399 lineto
0.61409 0.6085 lineto
0.61533 0.62055 lineto
0.61657 0.62961 lineto
0.61781 0.63524 lineto
0.61905 0.63715 lineto
0.62029 0.63524 lineto
0.62153 0.62961 lineto
0.62277 0.62055 lineto
0.62401 0.6085 lineto
0.62649 0.5776 lineto
0.62897 0.54132 lineto
0.63393 0.46633 lineto
0.63889 0.39979 lineto
0.64385 0.34533 lineto
0.64881 0.30174 lineto
0.65377 0.26682 lineto
0.65873 0.23856 lineto
0.66865 0.19614 lineto
0.67857 0.16617 lineto
0.68849 0.14405 lineto
0.69841 0.12714 lineto
0.70833 0.11382 lineto
0.71825 0.10309 lineto
0.7381 0.08693 lineto
0.75794 0.07539 lineto
0.77778 0.06679 lineto
0.79762 0.06017 lineto
0.81746 0.05496 lineto
0.8373 0.05077 lineto
0.85714 0.04736 lineto
0.87698 0.04456 lineto
0.89683 0.04223 lineto
0.93651 0.0387 lineto
0.95635 0.03738 lineto
0.97619 0.03629 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example:  Animation of Single Zero System (Zero's Radius Varies)
:[font = text; inactive; ]
		The following two input cells illustrate the effect of a zero approaching the unit circle on the magnitude of the frequency response. Notice that in this case we have a valley which becomes sharper and sharper as the zero approaches the unit circle.
:[font = input; startGroup; ]
Do[PoleZeroPlot[(z - r Exp[I Pi/4]), z, 0, Infinity, True,
                Dialogue -> False],
   {r, 0.1, 0.9, 0.1}]
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.52828 0.52828 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.55657 0.55657 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.58485 0.58485 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.61314 0.61314 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.64142 0.64142 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.66971 0.66971 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.69799 0.69799 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.72627 0.72627 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.75456 0.75456 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = input; startGroup; ]
Do[MagPhasePlot[(Exp[I w] - r Exp[I Pi/4]), {w,-Pi,Pi},
                 PhaseRangeScale -> Null, PlotRange -> {0,1}],
   {r, 0.1, 0.9, 0.1}]              
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 119; pictureTop = 1; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.61803 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.12361 1 0 Msboxa
[(0.4)] 0.4875 0.24721 1 0 Msboxa
[(0.6)] 0.4875 0.37082 1 0 Msboxa
[(0.8)] 0.4875 0.49443 1 0 Msboxa
[(1)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12361 moveto
0.50625 0.12361 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.12361 1 0 Mshowa
0.49375 0.24721 moveto
0.50625 0.24721 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.24721 1 0 Mshowa
0.49375 0.37082 moveto
0.50625 0.37082 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.37082 1 0 Mshowa
0.49375 0.49443 moveto
0.50625 0.49443 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.49443 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(1)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.66318 moveto
0.04365 0.66813 lineto
0.06349 0.67227 lineto
0.08333 0.67555 lineto
0.10317 0.67792 lineto
0.1131 0.67876 lineto
0.11806 0.67909 lineto
0.12302 0.67936 lineto
0.12798 0.67957 lineto
0.13046 0.67965 lineto
0.13294 0.67972 lineto
0.13542 0.67977 lineto
0.13666 0.67979 lineto
0.1379 0.67981 lineto
0.13914 0.67982 lineto
0.14038 0.67983 lineto
0.14162 0.67984 lineto
0.14286 0.67984 lineto
0.1441 0.67984 lineto
0.14534 0.67983 lineto
0.14658 0.67982 lineto
0.14782 0.67981 lineto
0.1503 0.67977 lineto
0.15278 0.67972 lineto
0.15526 0.67965 lineto
0.15774 0.67957 lineto
0.1627 0.67936 lineto
0.16766 0.67909 lineto
0.17262 0.67876 lineto
0.18254 0.67792 lineto
0.20238 0.67555 lineto
0.22222 0.67227 lineto
0.2619 0.66318 lineto
0.30159 0.65114 lineto
0.34127 0.63683 lineto
0.38095 0.62112 lineto
0.42063 0.60499 lineto
0.46032 0.58957 lineto
0.5 0.57599 lineto
0.51984 0.57024 lineto
0.53968 0.56536 lineto
0.55952 0.56143 lineto
0.56944 0.55986 lineto
0.57937 0.55857 lineto
0.58929 0.55755 lineto
0.59425 0.55715 lineto
0.59921 0.55682 lineto
0.60417 0.55656 lineto
0.60665 0.55646 lineto
0.60913 0.55638 lineto
Mistroke
0.61161 0.55631 lineto
0.61285 0.55629 lineto
0.61409 0.55627 lineto
0.61533 0.55625 lineto
0.61657 0.55624 lineto
0.61781 0.55623 lineto
0.61905 0.55623 lineto
0.62029 0.55623 lineto
0.62153 0.55624 lineto
0.62277 0.55625 lineto
0.62401 0.55627 lineto
0.62649 0.55631 lineto
0.62897 0.55638 lineto
0.63145 0.55646 lineto
0.63393 0.55656 lineto
0.63889 0.55682 lineto
0.64385 0.55715 lineto
0.64881 0.55755 lineto
0.65873 0.55857 lineto
0.67857 0.56143 lineto
0.69841 0.56536 lineto
0.7381 0.57599 lineto
0.77778 0.58957 lineto
0.81746 0.60499 lineto
0.85714 0.62112 lineto
0.89683 0.63683 lineto
0.93651 0.65114 lineto
0.97619 0.66318 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.61803 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.12361 1 0 Msboxa
[(0.4)] 0.4875 0.24721 1 0 Msboxa
[(0.6)] 0.4875 0.37082 1 0 Msboxa
[(0.8)] 0.4875 0.49443 1 0 Msboxa
[(1)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12361 moveto
0.50625 0.12361 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.12361 1 0 Mshowa
0.49375 0.24721 moveto
0.50625 0.24721 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.24721 1 0 Mshowa
0.49375 0.37082 moveto
0.50625 0.37082 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.37082 1 0 Mshowa
0.49375 0.49443 moveto
0.50625 0.49443 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.49443 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(1)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.71083 moveto
0.04365 0.72004 lineto
0.06349 0.72771 lineto
0.08333 0.73376 lineto
0.10317 0.73812 lineto
0.1131 0.73966 lineto
0.11806 0.74026 lineto
0.12302 0.74076 lineto
0.12798 0.74114 lineto
0.13046 0.7413 lineto
0.13294 0.74142 lineto
0.13542 0.74152 lineto
0.13666 0.74155 lineto
0.1379 0.74159 lineto
0.13914 0.74161 lineto
0.14038 0.74163 lineto
0.14162 0.74164 lineto
0.14286 0.74164 lineto
0.1441 0.74164 lineto
0.14534 0.74163 lineto
0.14658 0.74161 lineto
0.14782 0.74159 lineto
0.1503 0.74152 lineto
0.15278 0.74142 lineto
0.15526 0.7413 lineto
0.15774 0.74114 lineto
0.1627 0.74076 lineto
0.16766 0.74026 lineto
0.17262 0.73966 lineto
0.18254 0.73812 lineto
0.20238 0.73376 lineto
0.22222 0.72771 lineto
0.2619 0.71083 lineto
0.30159 0.68821 lineto
0.34127 0.6609 lineto
0.38095 0.63027 lineto
0.42063 0.59808 lineto
0.46032 0.56644 lineto
0.5 0.53778 lineto
0.51984 0.52539 lineto
0.53968 0.51471 lineto
0.55952 0.50605 lineto
0.56944 0.50256 lineto
0.57937 0.49966 lineto
0.58929 0.49739 lineto
0.59425 0.49649 lineto
0.59921 0.49575 lineto
0.60417 0.49517 lineto
0.60665 0.49494 lineto
0.60913 0.49476 lineto
Mistroke
0.61161 0.49461 lineto
0.61285 0.49456 lineto
0.61409 0.49451 lineto
0.61533 0.49447 lineto
0.61657 0.49445 lineto
0.61781 0.49443 lineto
0.61905 0.49443 lineto
0.62029 0.49443 lineto
0.62153 0.49445 lineto
0.62277 0.49447 lineto
0.62401 0.49451 lineto
0.62649 0.49461 lineto
0.62897 0.49476 lineto
0.63145 0.49494 lineto
0.63393 0.49517 lineto
0.63889 0.49575 lineto
0.64385 0.49649 lineto
0.64881 0.49739 lineto
0.65873 0.49966 lineto
0.67857 0.50605 lineto
0.69841 0.51471 lineto
0.7381 0.53778 lineto
0.77778 0.56644 lineto
0.81746 0.59808 lineto
0.85714 0.63027 lineto
0.89683 0.6609 lineto
0.93651 0.68821 lineto
0.97619 0.71083 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.61803 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.12361 1 0 Msboxa
[(0.4)] 0.4875 0.24721 1 0 Msboxa
[(0.6)] 0.4875 0.37082 1 0 Msboxa
[(0.8)] 0.4875 0.49443 1 0 Msboxa
[(1)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12361 moveto
0.50625 0.12361 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.12361 1 0 Mshowa
0.49375 0.24721 moveto
0.50625 0.24721 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.24721 1 0 Mshowa
0.49375 0.37082 moveto
0.50625 0.37082 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.37082 1 0 Mshowa
0.49375 0.49443 moveto
0.50625 0.49443 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.49443 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(1)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.76052 moveto
0.04365 0.77341 lineto
0.06349 0.7841 lineto
0.08333 0.79251 lineto
0.09325 0.79584 lineto
0.10317 0.79857 lineto
0.1131 0.8007 lineto
0.11806 0.80154 lineto
0.12302 0.80222 lineto
0.12798 0.80276 lineto
0.13046 0.80297 lineto
0.13294 0.80314 lineto
0.13542 0.80327 lineto
0.13666 0.80332 lineto
0.1379 0.80337 lineto
0.13914 0.8034 lineto
0.14038 0.80343 lineto
0.14162 0.80344 lineto
0.14286 0.80344 lineto
0.1441 0.80344 lineto
0.14534 0.80343 lineto
0.14658 0.8034 lineto
0.14782 0.80337 lineto
0.1503 0.80327 lineto
0.15278 0.80314 lineto
0.15526 0.80297 lineto
0.15774 0.80276 lineto
0.1627 0.80222 lineto
0.16766 0.80154 lineto
0.17262 0.8007 lineto
0.18254 0.79857 lineto
0.19246 0.79584 lineto
0.20238 0.79251 lineto
0.22222 0.7841 lineto
0.2619 0.76052 lineto
0.30159 0.72865 lineto
0.34127 0.68968 lineto
0.38095 0.64525 lineto
0.42063 0.59752 lineto
0.46032 0.54932 lineto
0.5 0.50427 lineto
0.51984 0.48428 lineto
0.53968 0.46676 lineto
0.55952 0.45234 lineto
0.56944 0.44646 lineto
0.57937 0.44156 lineto
0.58929 0.43768 lineto
0.59921 0.43488 lineto
0.60417 0.4339 lineto
0.60665 0.43351 lineto
Mistroke
0.60913 0.43319 lineto
0.61161 0.43294 lineto
0.61285 0.43285 lineto
0.61409 0.43277 lineto
0.61533 0.4327 lineto
0.61657 0.43266 lineto
0.61781 0.43263 lineto
0.61905 0.43262 lineto
0.62029 0.43263 lineto
0.62153 0.43266 lineto
0.62277 0.4327 lineto
0.62401 0.43277 lineto
0.62649 0.43294 lineto
0.62897 0.43319 lineto
0.63145 0.43351 lineto
0.63393 0.4339 lineto
0.63889 0.43488 lineto
0.64881 0.43768 lineto
0.65873 0.44156 lineto
0.67857 0.45234 lineto
0.69841 0.46676 lineto
0.7381 0.50427 lineto
0.77778 0.54932 lineto
0.81746 0.59752 lineto
0.85714 0.64525 lineto
0.89683 0.68968 lineto
0.93651 0.72865 lineto
0.97619 0.76052 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.61803 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.12361 1 0 Msboxa
[(0.4)] 0.4875 0.24721 1 0 Msboxa
[(0.6)] 0.4875 0.37082 1 0 Msboxa
[(0.8)] 0.4875 0.49443 1 0 Msboxa
[(1)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12361 moveto
0.50625 0.12361 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.12361 1 0 Mshowa
0.49375 0.24721 moveto
0.50625 0.24721 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.24721 1 0 Mshowa
0.49375 0.37082 moveto
0.50625 0.37082 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.37082 1 0 Mshowa
0.49375 0.49443 moveto
0.50625 0.49443 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.49443 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(1)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.81188 moveto
0.04365 0.82795 lineto
0.06349 0.84126 lineto
0.08333 0.8517 lineto
0.09325 0.85583 lineto
0.10317 0.85921 lineto
0.1131 0.86185 lineto
0.11806 0.86289 lineto
0.12302 0.86374 lineto
0.12798 0.8644 lineto
0.13046 0.86466 lineto
0.13294 0.86487 lineto
0.13542 0.86503 lineto
0.13666 0.8651 lineto
0.1379 0.86515 lineto
0.13914 0.86519 lineto
0.14038 0.86522 lineto
0.14162 0.86524 lineto
0.14286 0.86525 lineto
0.1441 0.86524 lineto
0.14534 0.86522 lineto
0.14658 0.86519 lineto
0.14782 0.86515 lineto
0.1503 0.86503 lineto
0.15278 0.86487 lineto
0.15526 0.86466 lineto
0.15774 0.8644 lineto
0.1627 0.86374 lineto
0.16766 0.86289 lineto
0.17262 0.86185 lineto
0.18254 0.85921 lineto
0.19246 0.85583 lineto
0.20238 0.8517 lineto
0.22222 0.84126 lineto
0.2619 0.81188 lineto
0.30159 0.77192 lineto
0.34127 0.72261 lineto
0.38095 0.66564 lineto
0.42063 0.60332 lineto
0.46032 0.53879 lineto
0.5 0.47645 lineto
0.51984 0.44794 lineto
0.53968 0.42243 lineto
0.55952 0.40096 lineto
0.56944 0.39208 lineto
0.57937 0.3846 lineto
0.58929 0.37865 lineto
0.59921 0.37433 lineto
0.60417 0.3728 lineto
0.60665 0.3722 lineto
Mistroke
0.60913 0.3717 lineto
0.61161 0.37132 lineto
0.61285 0.37116 lineto
0.61409 0.37104 lineto
0.61533 0.37094 lineto
0.61657 0.37088 lineto
0.61781 0.37083 lineto
0.61905 0.37082 lineto
0.62029 0.37083 lineto
0.62153 0.37088 lineto
0.62277 0.37094 lineto
0.62401 0.37104 lineto
0.62649 0.37132 lineto
0.62897 0.3717 lineto
0.63145 0.3722 lineto
0.63393 0.3728 lineto
0.63889 0.37433 lineto
0.64881 0.37865 lineto
0.65873 0.3846 lineto
0.67857 0.40096 lineto
0.69841 0.42243 lineto
0.7381 0.47645 lineto
0.77778 0.53879 lineto
0.81746 0.60332 lineto
0.85714 0.66564 lineto
0.89683 0.72261 lineto
0.93651 0.77192 lineto
0.97619 0.81188 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.61803 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.12361 1 0 Msboxa
[(0.4)] 0.4875 0.24721 1 0 Msboxa
[(0.6)] 0.4875 0.37082 1 0 Msboxa
[(0.8)] 0.4875 0.49443 1 0 Msboxa
[(1)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12361 moveto
0.50625 0.12361 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.12361 1 0 Mshowa
0.49375 0.24721 moveto
0.50625 0.24721 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.24721 1 0 Mshowa
0.49375 0.37082 moveto
0.50625 0.37082 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.37082 1 0 Mshowa
0.49375 0.49443 moveto
0.50625 0.49443 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.49443 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(1)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.86461 moveto
0.04365 0.88345 lineto
0.06349 0.89903 lineto
0.08333 0.91123 lineto
0.09325 0.91605 lineto
0.10317 0.92 lineto
0.1131 0.92308 lineto
0.11806 0.9243 lineto
0.12302 0.92529 lineto
0.12798 0.92606 lineto
0.13046 0.92636 lineto
0.13294 0.92661 lineto
0.13542 0.9268 lineto
0.13666 0.92688 lineto
0.1379 0.92694 lineto
0.13914 0.92699 lineto
0.14038 0.92702 lineto
0.14162 0.92704 lineto
0.14286 0.92705 lineto
0.1441 0.92704 lineto
0.14534 0.92702 lineto
0.14658 0.92699 lineto
0.14782 0.92694 lineto
0.1503 0.9268 lineto
0.15278 0.92661 lineto
0.15526 0.92636 lineto
0.15774 0.92606 lineto
0.1627 0.92529 lineto
0.16766 0.9243 lineto
0.17262 0.92308 lineto
0.18254 0.92 lineto
0.19246 0.91605 lineto
0.20238 0.91123 lineto
0.22222 0.89903 lineto
0.2619 0.86461 lineto
0.30159 0.81758 lineto
0.34127 0.75916 lineto
0.38095 0.69098 lineto
0.42063 0.6153 lineto
0.46032 0.53523 lineto
0.5 0.45538 lineto
0.53968 0.38297 lineto
0.55952 0.35294 lineto
0.56944 0.34024 lineto
0.57937 0.3294 lineto
0.58929 0.32067 lineto
0.59921 0.31426 lineto
0.60417 0.31198 lineto
0.60665 0.31108 lineto
0.60913 0.31034 lineto
Mistroke
0.61161 0.30976 lineto
0.61285 0.30953 lineto
0.61409 0.30935 lineto
0.61533 0.3092 lineto
0.61657 0.3091 lineto
0.61781 0.30904 lineto
0.61905 0.30902 lineto
0.62029 0.30904 lineto
0.62153 0.3091 lineto
0.62277 0.3092 lineto
0.62401 0.30935 lineto
0.62649 0.30976 lineto
0.62897 0.31034 lineto
0.63145 0.31108 lineto
0.63393 0.31198 lineto
0.63889 0.31426 lineto
0.64881 0.32067 lineto
0.65873 0.3294 lineto
0.67857 0.35294 lineto
0.69841 0.38297 lineto
0.7381 0.45538 lineto
0.77778 0.53523 lineto
0.81746 0.6153 lineto
0.85714 0.69098 lineto
0.89683 0.75916 lineto
0.93651 0.81758 lineto
0.97619 0.86461 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.61803 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.12361 1 0 Msboxa
[(0.4)] 0.4875 0.24721 1 0 Msboxa
[(0.6)] 0.4875 0.37082 1 0 Msboxa
[(0.8)] 0.4875 0.49443 1 0 Msboxa
[(1)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12361 moveto
0.50625 0.12361 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.12361 1 0 Mshowa
0.49375 0.24721 moveto
0.50625 0.24721 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.24721 1 0 Mshowa
0.49375 0.37082 moveto
0.50625 0.37082 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.37082 1 0 Mshowa
0.49375 0.49443 moveto
0.50625 0.49443 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.49443 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(1)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.91847 moveto
0.04365 0.93974 lineto
0.06349 0.9573 lineto
0.08333 0.97105 lineto
0.09325 0.97648 lineto
0.10317 0.98093 lineto
0.1131 0.98439 lineto
0.11806 0.98575 lineto
0.12302 0.98687 lineto
0.12798 0.98774 lineto
0.13046 0.98808 lineto
0.13294 0.98836 lineto
0.13542 0.98858 lineto
0.13666 0.98866 lineto
0.1379 0.98873 lineto
0.13914 0.98878 lineto
0.14038 0.98882 lineto
0.14162 0.98885 lineto
0.14286 0.98885 lineto
0.1441 0.98885 lineto
0.14534 0.98882 lineto
0.14658 0.98878 lineto
0.14782 0.98873 lineto
0.1503 0.98858 lineto
0.15278 0.98836 lineto
0.15526 0.98808 lineto
0.15774 0.98774 lineto
0.1627 0.98687 lineto
0.16766 0.98575 lineto
0.17262 0.98439 lineto
0.18254 0.98093 lineto
0.19246 0.97648 lineto
0.20238 0.97105 lineto
0.22222 0.9573 lineto
0.2619 0.91847 lineto
0.30159 0.86525 lineto
0.34127 0.79882 lineto
0.38095 0.72075 lineto
0.42063 0.63312 lineto
0.46032 0.53879 lineto
0.5 0.442 lineto
0.53968 0.35003 lineto
0.55952 0.30985 lineto
0.56944 0.2923 lineto
0.57937 0.27701 lineto
0.58929 0.26443 lineto
0.59921 0.25502 lineto
0.60417 0.25164 lineto
0.60665 0.2503 lineto
0.60913 0.24919 lineto
Mistroke
0.61161 0.24833 lineto
0.61285 0.24799 lineto
0.61409 0.24771 lineto
0.61533 0.24749 lineto
0.61657 0.24734 lineto
0.61781 0.24724 lineto
0.61905 0.24721 lineto
0.62029 0.24724 lineto
0.62153 0.24734 lineto
0.62277 0.24749 lineto
0.62401 0.24771 lineto
0.62649 0.24833 lineto
0.62897 0.24919 lineto
0.63393 0.25164 lineto
0.63889 0.25502 lineto
0.64881 0.26443 lineto
0.65873 0.27701 lineto
0.67857 0.30985 lineto
0.69841 0.35003 lineto
0.7381 0.442 lineto
0.77778 0.53879 lineto
0.81746 0.63312 lineto
0.85714 0.72075 lineto
0.89683 0.79882 lineto
0.93651 0.86525 lineto
0.97619 0.91847 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.61803 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.12361 1 0 Msboxa
[(0.4)] 0.4875 0.24721 1 0 Msboxa
[(0.6)] 0.4875 0.37082 1 0 Msboxa
[(0.8)] 0.4875 0.49443 1 0 Msboxa
[(1)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12361 moveto
0.50625 0.12361 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.12361 1 0 Mshowa
0.49375 0.24721 moveto
0.50625 0.24721 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.24721 1 0 Mshowa
0.49375 0.37082 moveto
0.50625 0.37082 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.37082 1 0 Mshowa
0.49375 0.49443 moveto
0.50625 0.49443 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.49443 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(1)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.97327 moveto
0.04365 0.99668 lineto
0.06349 1.01599 lineto
0.08333 1.0311 lineto
0.09325 1.03706 lineto
0.10317 1.04195 lineto
0.1131 1.04576 lineto
0.11806 1.04725 lineto
0.12302 1.04848 lineto
0.12798 1.04943 lineto
0.13046 1.04981 lineto
0.13294 1.05011 lineto
0.13542 1.05035 lineto
0.13666 1.05044 lineto
0.1379 1.05052 lineto
0.13914 1.05058 lineto
0.14038 1.05062 lineto
0.14162 1.05065 lineto
0.14286 1.05066 lineto
0.1441 1.05065 lineto
0.14534 1.05062 lineto
0.14658 1.05058 lineto
0.14782 1.05052 lineto
0.1503 1.05035 lineto
0.15278 1.05011 lineto
0.15526 1.04981 lineto
0.15774 1.04943 lineto
0.1627 1.04848 lineto
0.16766 1.04725 lineto
0.17262 1.04576 lineto
0.18254 1.04195 lineto
0.19246 1.03706 lineto
0.20238 1.0311 lineto
0.22222 1.01599 lineto
0.2619 0.97327 lineto
0.30159 0.91461 lineto
0.34127 0.84115 lineto
0.38095 0.75441 lineto
0.42063 0.6563 lineto
0.46032 0.54932 lineto
0.5 0.43704 lineto
0.53968 0.32561 lineto
0.55952 0.27401 lineto
0.57937 0.22934 lineto
0.58929 0.21131 lineto
0.59921 0.19736 lineto
0.60417 0.19223 lineto
0.60665 0.19017 lineto
0.60913 0.18847 lineto
0.61161 0.18714 lineto
Mistroke
0.61285 0.18661 lineto
0.61409 0.18618 lineto
0.61533 0.18584 lineto
0.61657 0.1856 lineto
0.61781 0.18546 lineto
0.61905 0.18541 lineto
0.62029 0.18546 lineto
0.62153 0.1856 lineto
0.62277 0.18584 lineto
0.62401 0.18618 lineto
0.62649 0.18714 lineto
0.62897 0.18847 lineto
0.63393 0.19223 lineto
0.63889 0.19736 lineto
0.64881 0.21131 lineto
0.65873 0.22934 lineto
0.69841 0.32561 lineto
0.7381 0.43704 lineto
0.77778 0.54932 lineto
0.81746 0.6563 lineto
0.85714 0.75441 lineto
0.89683 0.84115 lineto
0.93651 0.91461 lineto
0.97619 0.97327 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.61803 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.12361 1 0 Msboxa
[(0.4)] 0.4875 0.24721 1 0 Msboxa
[(0.6)] 0.4875 0.37082 1 0 Msboxa
[(0.8)] 0.4875 0.49443 1 0 Msboxa
[(1)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12361 moveto
0.50625 0.12361 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.12361 1 0 Mshowa
0.49375 0.24721 moveto
0.50625 0.24721 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.24721 1 0 Mshowa
0.49375 0.37082 moveto
0.50625 0.37082 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.37082 1 0 Mshowa
0.49375 0.49443 moveto
0.50625 0.49443 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.49443 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(1)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 1.02887 moveto
0.04365 1.05417 lineto
0.06349 1.07503 lineto
0.08333 1.09135 lineto
0.09325 1.09779 lineto
0.10317 1.10306 lineto
0.1131 1.10717 lineto
0.11806 1.10879 lineto
0.12302 1.11011 lineto
0.12798 1.11114 lineto
0.13046 1.11154 lineto
0.13294 1.11187 lineto
0.13542 1.11213 lineto
0.13666 1.11223 lineto
0.1379 1.11231 lineto
0.13914 1.11238 lineto
0.14038 1.11242 lineto
0.14162 1.11245 lineto
0.14286 1.11246 lineto
0.1441 1.11245 lineto
0.14534 1.11242 lineto
0.14658 1.11238 lineto
0.14782 1.11231 lineto
0.1503 1.11213 lineto
0.15278 1.11187 lineto
0.15526 1.11154 lineto
0.15774 1.11114 lineto
0.1627 1.11011 lineto
0.16766 1.10879 lineto
0.17262 1.10717 lineto
0.18254 1.10306 lineto
0.19246 1.09779 lineto
0.20238 1.09135 lineto
0.22222 1.07503 lineto
0.2619 1.02887 lineto
0.30159 0.9654 lineto
0.34127 0.88578 lineto
0.38095 0.79147 lineto
0.42063 0.68429 lineto
0.46032 0.56644 lineto
0.5 0.44077 lineto
0.53968 0.3117 lineto
0.57937 0.19001 lineto
0.58929 0.16438 lineto
0.59921 0.1432 lineto
0.60417 0.13499 lineto
0.60665 0.13162 lineto
0.60913 0.12879 lineto
0.61161 0.12655 lineto
0.61285 0.12566 lineto
Mistroke
0.61409 0.12492 lineto
0.61533 0.12435 lineto
0.61657 0.12394 lineto
0.61781 0.12369 lineto
0.61905 0.12361 lineto
0.62029 0.12369 lineto
0.62153 0.12394 lineto
0.62277 0.12435 lineto
0.62401 0.12492 lineto
0.62649 0.12655 lineto
0.62897 0.12879 lineto
0.63393 0.13499 lineto
0.63889 0.1432 lineto
0.64881 0.16438 lineto
0.65873 0.19001 lineto
0.69841 0.3117 lineto
0.7381 0.44077 lineto
0.77778 0.56644 lineto
0.81746 0.68429 lineto
0.85714 0.79147 lineto
0.89683 0.88578 lineto
0.93651 0.9654 lineto
0.97619 1.02887 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; endGroup; endGroup; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.61803 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.12361 1 0 Msboxa
[(0.4)] 0.4875 0.24721 1 0 Msboxa
[(0.6)] 0.4875 0.37082 1 0 Msboxa
[(0.8)] 0.4875 0.49443 1 0 Msboxa
[(1)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12361 moveto
0.50625 0.12361 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.12361 1 0 Mshowa
0.49375 0.24721 moveto
0.50625 0.24721 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.24721 1 0 Mshowa
0.49375 0.37082 moveto
0.50625 0.37082 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.37082 1 0 Mshowa
0.49375 0.49443 moveto
0.50625 0.49443 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.49443 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(1)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 1.08514 moveto
0.04365 1.11212 lineto
0.06349 1.13437 lineto
0.08333 1.15176 lineto
0.09325 1.15862 lineto
0.10317 1.16425 lineto
0.1131 1.16863 lineto
0.11806 1.17035 lineto
0.12302 1.17176 lineto
0.12798 1.17285 lineto
0.13046 1.17328 lineto
0.13294 1.17364 lineto
0.13542 1.17391 lineto
0.13666 1.17402 lineto
0.1379 1.17411 lineto
0.13914 1.17418 lineto
0.14038 1.17423 lineto
0.14162 1.17425 lineto
0.14286 1.17426 lineto
0.1441 1.17425 lineto
0.14534 1.17423 lineto
0.14658 1.17418 lineto
0.14782 1.17411 lineto
0.1503 1.17391 lineto
0.15278 1.17364 lineto
0.15526 1.17328 lineto
0.15774 1.17285 lineto
0.1627 1.17176 lineto
0.16766 1.17035 lineto
0.17262 1.16863 lineto
0.18254 1.16425 lineto
0.19246 1.15862 lineto
0.20238 1.15176 lineto
0.22222 1.13437 lineto
0.2619 1.08514 lineto
0.30159 1.01741 lineto
0.34127 0.93237 lineto
0.38095 0.83148 lineto
0.42063 0.71653 lineto
0.46032 0.58957 lineto
0.5 0.45298 lineto
0.53968 0.30973 lineto
0.57937 0.16507 lineto
0.59921 0.0985 lineto
0.60417 0.08444 lineto
0.60665 0.07823 lineto
0.60913 0.07274 lineto
0.61161 0.06818 lineto
0.61285 0.06629 lineto
0.61409 0.06471 lineto
Mistroke
0.61533 0.06346 lineto
0.61657 0.06254 lineto
0.61781 0.06199 lineto
0.61905 0.0618 lineto
0.62029 0.06199 lineto
0.62153 0.06254 lineto
0.62277 0.06346 lineto
0.62401 0.06471 lineto
0.62649 0.06818 lineto
0.62897 0.07274 lineto
0.63889 0.0985 lineto
0.65873 0.16507 lineto
0.69841 0.30973 lineto
0.7381 0.45298 lineto
0.77778 0.58957 lineto
0.81746 0.71653 lineto
0.85714 0.83148 lineto
0.89683 0.93237 lineto
0.93651 1.01741 lineto
0.97619 1.08514 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = subsection; inactive; startGroup; Cclosed; ]
Systems with multiple poles and zeroes
:[font = text; inactive; ]
		The previous examples of single pole and single zero systems illustrate the close relationship between the radius (i.e. magnitude) of a pole (zero) and the width (a.k.a. bandwidth) of the peak (valley).  Alternatively, the width of the peak (valley) can be used to determine the radius of the corresponding pole (zero), while the frequency at which the peak (valley) is located corresponds to the phase of the corresponding pole (zero).
:[font = text; inactive; ]
		It is important to note that, in the case of multiple poles and zeros (i.e. several poles and zeros in the same pole-zero plot), the above relations between peak (valley) width and location and the corresponding pole (zero) still hold if and only if the poles and zeros are sufficiently close to the unit circle and sufficiently far apart. In fact, in this latter case, when we are in the vicinity of a pole or zero, we can simply neglect the effect of the other existing poles and zeros which will have a negligible influence.
		While the last example illustrates the relation between the height (depth) and width of a peak (valley) and the corresponding pole (zero), the following example illustrates the relation between the location of the peak (valley) and the corresponding pole (zero).
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example:  Animation of Single Pole System (Pole's Phase Varies)
:[font = text; inactive; ]
		Animate the following cells by selecting the graphics cells to be animated and then choosing the Animation option from the Graph submenu. You can also set the desired animation speed by using the Preferences option in the main menu, or the options in the bottom right side of  the notebook border.  
		Note that you can change the transfer function used in the input cells and obtain other desired graphics cells to be animated.
:[font = input; startGroup; ]
Do[PoleZeroPlot[1/(z - 0.8 Exp[I A]), z, 0.8, Infinity, True,
                Dialogue -> False],
   {A,-Pi,Pi,Pi/3}]              
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.18 0.5 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.34 0.22287 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.66 0.22287 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.66 0.77713 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.34 0.77713 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.82 0.5 moveto
0.81999 0.50262 lineto
0.81996 0.50524 lineto
0.8199 0.50785 lineto
0.81983 0.51047 lineto
0.81973 0.51309 lineto
0.81961 0.5157 lineto
0.81931 0.52093 lineto
0.81893 0.52615 lineto
0.81846 0.53137 lineto
0.81726 0.54177 lineto
0.81573 0.55213 lineto
0.81385 0.56243 lineto
0.8091 0.58282 lineto
0.80302 0.60286 lineto
0.79564 0.62246 lineto
0.77713 0.66 lineto
0.75387 0.6948 lineto
0.72627 0.72627 lineto
0.6948 0.75387 lineto
0.66 0.77713 lineto
0.64153 0.787 lineto
0.62246 0.79564 lineto
0.60286 0.80302 lineto
0.58282 0.8091 lineto
0.56243 0.81385 lineto
0.55213 0.81573 lineto
0.54177 0.81726 lineto
0.53137 0.81846 lineto
0.52615 0.81893 lineto
0.52093 0.81931 lineto
0.5157 0.81961 lineto
0.51309 0.81973 lineto
0.51047 0.81983 lineto
0.50785 0.8199 lineto
0.50524 0.81996 lineto
0.50262 0.81999 lineto
0.5 0.82 lineto
0.49738 0.81999 lineto
0.49476 0.81996 lineto
0.49215 0.8199 lineto
0.48953 0.81983 lineto
0.4843 0.81961 lineto
0.47907 0.81931 lineto
0.47385 0.81893 lineto
0.46863 0.81846 lineto
0.45823 0.81726 lineto
0.44787 0.81573 lineto
0.43757 0.81385 lineto
0.41718 0.8091 lineto
Mistroke
0.39714 0.80302 lineto
0.37754 0.79564 lineto
0.34 0.77713 lineto
0.3052 0.75387 lineto
0.27373 0.72627 lineto
0.24613 0.6948 lineto
0.22287 0.66 lineto
0.20436 0.62246 lineto
0.19698 0.60286 lineto
0.1909 0.58282 lineto
0.18615 0.56243 lineto
0.18427 0.55213 lineto
0.18274 0.54177 lineto
0.18154 0.53137 lineto
0.18107 0.52615 lineto
0.18069 0.52093 lineto
0.18039 0.5157 lineto
0.18027 0.51309 lineto
0.18017 0.51047 lineto
0.1801 0.50785 lineto
0.18004 0.50524 lineto
0.18001 0.50262 lineto
0.18 0.5 lineto
0.18001 0.49738 lineto
0.18004 0.49476 lineto
0.1801 0.49215 lineto
0.18017 0.48953 lineto
0.18039 0.4843 lineto
0.18069 0.47907 lineto
0.18107 0.47385 lineto
0.18154 0.46863 lineto
0.18274 0.45823 lineto
0.18427 0.44787 lineto
0.18615 0.43757 lineto
0.1909 0.41718 lineto
0.19698 0.39714 lineto
0.20436 0.37754 lineto
0.22287 0.34 lineto
0.24613 0.3052 lineto
0.27373 0.27373 lineto
0.3052 0.24613 lineto
0.34 0.22287 lineto
0.35847 0.213 lineto
0.37754 0.20436 lineto
0.39714 0.19698 lineto
0.41718 0.1909 lineto
0.43757 0.18615 lineto
0.44787 0.18427 lineto
0.45823 0.18274 lineto
0.46863 0.18154 lineto
Mistroke
0.47385 0.18107 lineto
0.47907 0.18069 lineto
0.4843 0.18039 lineto
0.48691 0.18027 lineto
0.48953 0.18017 lineto
0.49215 0.1801 lineto
0.49476 0.18004 lineto
0.49738 0.18001 lineto
0.5 0.18 lineto
0.50262 0.18001 lineto
0.50524 0.18004 lineto
0.50785 0.1801 lineto
0.51047 0.18017 lineto
0.5157 0.18039 lineto
0.52093 0.18069 lineto
0.52615 0.18107 lineto
0.53137 0.18154 lineto
0.54177 0.18274 lineto
0.55213 0.18427 lineto
0.56243 0.18615 lineto
0.58282 0.1909 lineto
0.60286 0.19698 lineto
0.62246 0.20436 lineto
0.66 0.22287 lineto
0.6948 0.24613 lineto
0.72627 0.27373 lineto
0.75387 0.3052 lineto
0.77713 0.34 lineto
0.787 0.35847 lineto
0.79564 0.37754 lineto
0.80302 0.39714 lineto
0.8091 0.41718 lineto
0.81385 0.43757 lineto
0.81573 0.44787 lineto
0.81726 0.45823 lineto
0.81846 0.46863 lineto
0.81893 0.47385 lineto
0.81931 0.47907 lineto
0.81961 0.4843 lineto
0.81973 0.48691 lineto
0.81983 0.48953 lineto
0.8199 0.49215 lineto
0.81996 0.49476 lineto
0.81999 0.49738 lineto
0.82 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8007 0.60945 lineto
stroke
0.18701 0.43338 moveto
-0.26579 0.26857 lineto
stroke
0.18073 0.47839 moveto
-0.2775 0.31161 lineto
stroke
0.18104 0.5258 moveto
-0.28684 0.3555 lineto
stroke
0.18917 0.57605 moveto
-0.29376 0.40028 lineto
stroke
0.20763 0.63007 moveto
-0.29817 0.44597 lineto
stroke
0.24258 0.69009 moveto
-0.29997 0.49262 lineto
stroke
0.32321 0.76673 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
0.53602 0.18203 moveto
-0.08617 -0.04443 lineto
stroke
0.42499 0.18892 moveto
-0.11756 -0.00855 lineto
stroke
0.35964 0.21243 moveto
-0.14616 0.02833 lineto
stroke
0.31078 0.24194 moveto
-0.17215 0.06617 lineto
stroke
0.27225 0.27521 moveto
-0.19564 0.10492 lineto
stroke
0.24153 0.31133 moveto
-0.2167 0.14455 lineto
stroke
0.21741 0.34985 moveto
-0.23539 0.18504 lineto
stroke
0.1993 0.39055 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.78259 0.65015 lineto
stroke
1.26579 0.73143 moveto
0.81299 0.56662 lineto
stroke
1.2167 0.85545 moveto
0.75847 0.68867 lineto
stroke
1.2775 0.68839 moveto
0.81927 0.52161 lineto
stroke
1.19564 0.89508 moveto
0.72775 0.72479 lineto
stroke
1.28684 0.6445 moveto
0.81896 0.4742 lineto
stroke
1.17215 0.93383 moveto
0.68922 0.75806 lineto
stroke
1.29376 0.59972 moveto
0.81083 0.42395 lineto
stroke
1.14616 0.97167 moveto
0.64036 0.78757 lineto
stroke
1.29817 0.55403 moveto
0.79237 0.36993 lineto
stroke
1.11756 1.00855 moveto
0.57501 0.81108 lineto
stroke
1.29997 0.50738 moveto
0.75742 0.30991 lineto
stroke
1.08617 1.04443 moveto
0.46398 0.81797 lineto
stroke
1.29899 0.45973 moveto
0.67679 0.23327 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.18 0.5 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = input; startGroup; ]

Do[MagPhasePlot[1/(Exp[I w] - 0.8 Exp[I A]), {w,-Pi,Pi},
                PhaseRangeScale -> Null, PlotRange -> {0, 6}],
   {A,-Pi,Pi,Pi/3}]
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.10301 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(1)] 0.4875 0.10301 1 0 Msboxa
[(2)] 0.4875 0.20601 1 0 Msboxa
[(3)] 0.4875 0.30902 1 0 Msboxa
[(4)] 0.4875 0.41202 1 0 Msboxa
[(5)] 0.4875 0.51503 1 0 Msboxa
[(6)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(1)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(2)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(3)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(4)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(5)] 0.4875 0.51503 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(6)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.51503 moveto
0.06349 0.33504 lineto
0.07341 0.29145 lineto
0.08333 0.25608 lineto
0.10317 0.20424 lineto
0.1131 0.18511 lineto
0.12302 0.1692 lineto
0.14286 0.14443 lineto
0.1627 0.12622 lineto
0.18254 0.11239 lineto
0.20238 0.10161 lineto
0.22222 0.09303 lineto
0.24206 0.0861 lineto
0.2619 0.08043 lineto
0.28175 0.07575 lineto
0.30159 0.07187 lineto
0.32143 0.06864 lineto
0.34127 0.06594 lineto
0.38095 0.06187 lineto
0.40079 0.06039 lineto
0.42063 0.05922 lineto
0.44048 0.05833 lineto
0.4504 0.05799 lineto
0.46032 0.05771 lineto
0.47024 0.0575 lineto
0.4752 0.05742 lineto
0.48016 0.05735 lineto
0.48512 0.05729 lineto
0.4876 0.05727 lineto
0.49008 0.05726 lineto
0.49256 0.05724 lineto
0.4938 0.05724 lineto
0.49504 0.05723 lineto
0.49628 0.05723 lineto
0.49752 0.05723 lineto
0.49876 0.05723 lineto
0.5 0.05723 lineto
0.50124 0.05723 lineto
0.50248 0.05723 lineto
0.50372 0.05723 lineto
0.50496 0.05723 lineto
0.5062 0.05724 lineto
0.50744 0.05724 lineto
0.50992 0.05726 lineto
0.5124 0.05727 lineto
0.51488 0.05729 lineto
0.51984 0.05735 lineto
0.5248 0.05742 lineto
0.52976 0.0575 lineto
0.53968 0.05771 lineto
Mistroke
0.5496 0.05799 lineto
0.55952 0.05833 lineto
0.57937 0.05922 lineto
0.59921 0.06039 lineto
0.61905 0.06187 lineto
0.63889 0.06371 lineto
0.65873 0.06594 lineto
0.67857 0.06864 lineto
0.69841 0.07187 lineto
0.7381 0.08043 lineto
0.75794 0.0861 lineto
0.77778 0.09303 lineto
0.79762 0.10161 lineto
0.81746 0.11239 lineto
0.8373 0.12622 lineto
0.85714 0.14443 lineto
0.87698 0.1692 lineto
0.8869 0.18511 lineto
0.89683 0.20424 lineto
0.90675 0.2275 lineto
0.91667 0.25608 lineto
0.93651 0.33504 lineto
0.97619 0.51503 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.10301 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(1)] 0.4875 0.10301 1 0 Msboxa
[(2)] 0.4875 0.20601 1 0 Msboxa
[(3)] 0.4875 0.30902 1 0 Msboxa
[(4)] 0.4875 0.41202 1 0 Msboxa
[(5)] 0.4875 0.51503 1 0 Msboxa
[(6)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(1)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(2)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(3)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(4)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(5)] 0.4875 0.51503 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(6)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.11239 moveto
0.04365 0.12622 lineto
0.06349 0.14443 lineto
0.08333 0.1692 lineto
0.10317 0.20424 lineto
0.1131 0.2275 lineto
0.12302 0.25608 lineto
0.14286 0.33504 lineto
0.15278 0.38727 lineto
0.1627 0.44455 lineto
0.16766 0.47161 lineto
0.17014 0.48369 lineto
0.17262 0.4943 lineto
0.1751 0.50305 lineto
0.17758 0.5096 lineto
0.17882 0.51195 lineto
0.18006 0.51365 lineto
0.1813 0.51468 lineto
0.18254 0.51503 lineto
0.18378 0.51468 lineto
0.18502 0.51365 lineto
0.18626 0.51195 lineto
0.1875 0.5096 lineto
0.18998 0.50305 lineto
0.19246 0.4943 lineto
0.20238 0.44455 lineto
0.22222 0.33504 lineto
0.23214 0.29145 lineto
0.24206 0.25608 lineto
0.25198 0.2275 lineto
0.2619 0.20424 lineto
0.28175 0.1692 lineto
0.30159 0.14443 lineto
0.32143 0.12622 lineto
0.34127 0.11239 lineto
0.36111 0.10161 lineto
0.38095 0.09303 lineto
0.40079 0.0861 lineto
0.42063 0.08043 lineto
0.44048 0.07575 lineto
0.46032 0.07187 lineto
0.48016 0.06864 lineto
0.5 0.06594 lineto
0.51984 0.06371 lineto
0.53968 0.06187 lineto
0.55952 0.06039 lineto
0.57937 0.05922 lineto
0.59921 0.05833 lineto
0.60913 0.05799 lineto
0.61905 0.05771 lineto
Mistroke
0.62897 0.0575 lineto
0.63393 0.05742 lineto
0.63889 0.05735 lineto
0.64385 0.05729 lineto
0.64633 0.05727 lineto
0.64881 0.05726 lineto
0.65129 0.05724 lineto
0.65253 0.05724 lineto
0.65377 0.05723 lineto
0.65501 0.05723 lineto
0.65625 0.05723 lineto
0.65749 0.05723 lineto
0.65873 0.05723 lineto
0.65997 0.05723 lineto
0.66121 0.05723 lineto
0.66245 0.05723 lineto
0.66369 0.05723 lineto
0.66617 0.05724 lineto
0.66865 0.05726 lineto
0.67113 0.05727 lineto
0.67361 0.05729 lineto
0.67857 0.05735 lineto
0.68353 0.05742 lineto
0.68849 0.0575 lineto
0.69841 0.05771 lineto
0.70833 0.05799 lineto
0.71825 0.05833 lineto
0.7381 0.05922 lineto
0.75794 0.06039 lineto
0.77778 0.06187 lineto
0.81746 0.06594 lineto
0.8373 0.06864 lineto
0.85714 0.07187 lineto
0.87698 0.07575 lineto
0.89683 0.08043 lineto
0.93651 0.09303 lineto
0.95635 0.10161 lineto
0.97619 0.11239 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.10301 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(1)] 0.4875 0.10301 1 0 Msboxa
[(2)] 0.4875 0.20601 1 0 Msboxa
[(3)] 0.4875 0.30902 1 0 Msboxa
[(4)] 0.4875 0.41202 1 0 Msboxa
[(5)] 0.4875 0.51503 1 0 Msboxa
[(6)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(1)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(2)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(3)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(4)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(5)] 0.4875 0.51503 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(6)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.06594 moveto
0.04365 0.06864 lineto
0.06349 0.07187 lineto
0.10317 0.08043 lineto
0.12302 0.0861 lineto
0.14286 0.09303 lineto
0.1627 0.10161 lineto
0.18254 0.11239 lineto
0.20238 0.12622 lineto
0.22222 0.14443 lineto
0.24206 0.1692 lineto
0.25198 0.18511 lineto
0.2619 0.20424 lineto
0.28175 0.25608 lineto
0.29167 0.29145 lineto
0.30159 0.33504 lineto
0.31151 0.38727 lineto
0.32143 0.44455 lineto
0.32639 0.47161 lineto
0.32887 0.48369 lineto
0.33135 0.4943 lineto
0.33383 0.50305 lineto
0.33507 0.50662 lineto
0.33631 0.5096 lineto
0.33755 0.51195 lineto
0.33879 0.51365 lineto
0.34003 0.51468 lineto
0.34127 0.51503 lineto
0.38095 0.33504 lineto
0.39087 0.29145 lineto
0.40079 0.25608 lineto
0.41071 0.2275 lineto
0.42063 0.20424 lineto
0.44048 0.1692 lineto
0.46032 0.14443 lineto
0.48016 0.12622 lineto
0.5 0.11239 lineto
0.51984 0.10161 lineto
0.53968 0.09303 lineto
0.57937 0.08043 lineto
0.59921 0.07575 lineto
0.61905 0.07187 lineto
0.63889 0.06864 lineto
0.65873 0.06594 lineto
0.67857 0.06371 lineto
0.69841 0.06187 lineto
0.71825 0.06039 lineto
0.7381 0.05922 lineto
0.74802 0.05874 lineto
0.75794 0.05833 lineto
Mistroke
0.76786 0.05799 lineto
0.77778 0.05771 lineto
0.7877 0.0575 lineto
0.79266 0.05742 lineto
0.79762 0.05735 lineto
0.80258 0.05729 lineto
0.80506 0.05727 lineto
0.80754 0.05726 lineto
0.81002 0.05724 lineto
0.81126 0.05724 lineto
0.8125 0.05723 lineto
0.81374 0.05723 lineto
0.81498 0.05723 lineto
0.81622 0.05723 lineto
0.81746 0.05723 lineto
0.8187 0.05723 lineto
0.81994 0.05723 lineto
0.82118 0.05723 lineto
0.82242 0.05723 lineto
0.8249 0.05724 lineto
0.82738 0.05726 lineto
0.82986 0.05727 lineto
0.83234 0.05729 lineto
0.8373 0.05735 lineto
0.84226 0.05742 lineto
0.84722 0.0575 lineto
0.85714 0.05771 lineto
0.86706 0.05799 lineto
0.87698 0.05833 lineto
0.89683 0.05922 lineto
0.91667 0.06039 lineto
0.93651 0.06187 lineto
0.97619 0.06594 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.10301 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(1)] 0.4875 0.10301 1 0 Msboxa
[(2)] 0.4875 0.20601 1 0 Msboxa
[(3)] 0.4875 0.30902 1 0 Msboxa
[(4)] 0.4875 0.41202 1 0 Msboxa
[(5)] 0.4875 0.51503 1 0 Msboxa
[(6)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(1)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(2)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(3)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(4)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(5)] 0.4875 0.51503 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(6)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.05723 moveto
0.02505 0.05723 lineto
0.02629 0.05723 lineto
0.02753 0.05723 lineto
0.02877 0.05723 lineto
0.03125 0.05724 lineto
0.03373 0.05726 lineto
0.03621 0.05727 lineto
0.03869 0.05729 lineto
0.04365 0.05735 lineto
0.04861 0.05742 lineto
0.05357 0.0575 lineto
0.06349 0.05771 lineto
0.07341 0.05799 lineto
0.08333 0.05833 lineto
0.10317 0.05922 lineto
0.12302 0.06039 lineto
0.14286 0.06187 lineto
0.18254 0.06594 lineto
0.20238 0.06864 lineto
0.22222 0.07187 lineto
0.24206 0.07575 lineto
0.2619 0.08043 lineto
0.28175 0.0861 lineto
0.30159 0.09303 lineto
0.32143 0.10161 lineto
0.34127 0.11239 lineto
0.36111 0.12622 lineto
0.38095 0.14443 lineto
0.40079 0.1692 lineto
0.41071 0.18511 lineto
0.42063 0.20424 lineto
0.44048 0.25608 lineto
0.4504 0.29145 lineto
0.46032 0.33504 lineto
0.47024 0.38727 lineto
0.48016 0.44455 lineto
0.48512 0.47161 lineto
0.4876 0.48369 lineto
0.49008 0.4943 lineto
0.49256 0.50305 lineto
0.4938 0.50662 lineto
0.49504 0.5096 lineto
0.49628 0.51195 lineto
0.49752 0.51365 lineto
0.49876 0.51468 lineto
0.5 0.51503 lineto
0.50124 0.51468 lineto
0.50248 0.51365 lineto
0.50372 0.51195 lineto
Mistroke
0.50496 0.5096 lineto
0.5062 0.50662 lineto
0.50744 0.50305 lineto
0.50992 0.4943 lineto
0.51984 0.44455 lineto
0.53968 0.33504 lineto
0.5496 0.29145 lineto
0.55952 0.25608 lineto
0.56944 0.2275 lineto
0.57937 0.20424 lineto
0.59921 0.1692 lineto
0.61905 0.14443 lineto
0.63889 0.12622 lineto
0.65873 0.11239 lineto
0.67857 0.10161 lineto
0.69841 0.09303 lineto
0.7381 0.08043 lineto
0.75794 0.07575 lineto
0.77778 0.07187 lineto
0.81746 0.06594 lineto
0.8373 0.06371 lineto
0.85714 0.06187 lineto
0.87698 0.06039 lineto
0.89683 0.05922 lineto
0.90675 0.05874 lineto
0.91667 0.05833 lineto
0.92659 0.05799 lineto
0.93651 0.05771 lineto
0.94643 0.0575 lineto
0.95139 0.05742 lineto
0.95635 0.05735 lineto
0.96131 0.05729 lineto
0.96379 0.05727 lineto
0.96627 0.05726 lineto
0.96875 0.05724 lineto
0.96999 0.05724 lineto
0.97123 0.05723 lineto
0.97247 0.05723 lineto
0.97371 0.05723 lineto
0.97495 0.05723 lineto
0.97619 0.05723 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.10301 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(1)] 0.4875 0.10301 1 0 Msboxa
[(2)] 0.4875 0.20601 1 0 Msboxa
[(3)] 0.4875 0.30902 1 0 Msboxa
[(4)] 0.4875 0.41202 1 0 Msboxa
[(5)] 0.4875 0.51503 1 0 Msboxa
[(6)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(1)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(2)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(3)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(4)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(5)] 0.4875 0.51503 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(6)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.06594 moveto
0.04365 0.06371 lineto
0.06349 0.06187 lineto
0.08333 0.06039 lineto
0.10317 0.05922 lineto
0.1131 0.05874 lineto
0.12302 0.05833 lineto
0.13294 0.05799 lineto
0.14286 0.05771 lineto
0.15278 0.0575 lineto
0.15774 0.05742 lineto
0.1627 0.05735 lineto
0.16766 0.05729 lineto
0.17014 0.05727 lineto
0.17262 0.05726 lineto
0.1751 0.05724 lineto
0.17634 0.05724 lineto
0.17758 0.05723 lineto
0.17882 0.05723 lineto
0.18006 0.05723 lineto
0.1813 0.05723 lineto
0.18254 0.05723 lineto
0.18378 0.05723 lineto
0.18502 0.05723 lineto
0.18626 0.05723 lineto
0.1875 0.05723 lineto
0.18998 0.05724 lineto
0.19246 0.05726 lineto
0.19494 0.05727 lineto
0.19742 0.05729 lineto
0.20238 0.05735 lineto
0.20734 0.05742 lineto
0.2123 0.0575 lineto
0.22222 0.05771 lineto
0.23214 0.05799 lineto
0.24206 0.05833 lineto
0.2619 0.05922 lineto
0.28175 0.06039 lineto
0.30159 0.06187 lineto
0.32143 0.06371 lineto
0.34127 0.06594 lineto
0.38095 0.07187 lineto
0.40079 0.07575 lineto
0.42063 0.08043 lineto
0.44048 0.0861 lineto
0.46032 0.09303 lineto
0.48016 0.10161 lineto
0.5 0.11239 lineto
0.51984 0.12622 lineto
0.53968 0.14443 lineto
Mistroke
0.55952 0.1692 lineto
0.56944 0.18511 lineto
0.57937 0.20424 lineto
0.59921 0.25608 lineto
0.60913 0.29145 lineto
0.61905 0.33504 lineto
0.62897 0.38727 lineto
0.63889 0.44455 lineto
0.64385 0.47161 lineto
0.64633 0.48369 lineto
0.64881 0.4943 lineto
0.65129 0.50305 lineto
0.65253 0.50662 lineto
0.65377 0.5096 lineto
0.65501 0.51195 lineto
0.65625 0.51365 lineto
0.65749 0.51468 lineto
0.65873 0.51503 lineto
0.69841 0.33504 lineto
0.70833 0.29145 lineto
0.71825 0.25608 lineto
0.7381 0.20424 lineto
0.74802 0.18511 lineto
0.75794 0.1692 lineto
0.77778 0.14443 lineto
0.79762 0.12622 lineto
0.81746 0.11239 lineto
0.8373 0.10161 lineto
0.85714 0.09303 lineto
0.87698 0.0861 lineto
0.89683 0.08043 lineto
0.93651 0.07187 lineto
0.95635 0.06864 lineto
0.97619 0.06594 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.10301 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(1)] 0.4875 0.10301 1 0 Msboxa
[(2)] 0.4875 0.20601 1 0 Msboxa
[(3)] 0.4875 0.30902 1 0 Msboxa
[(4)] 0.4875 0.41202 1 0 Msboxa
[(5)] 0.4875 0.51503 1 0 Msboxa
[(6)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(1)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(2)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(3)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(4)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(5)] 0.4875 0.51503 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(6)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.11239 moveto
0.04365 0.10161 lineto
0.06349 0.09303 lineto
0.10317 0.08043 lineto
0.12302 0.07575 lineto
0.14286 0.07187 lineto
0.18254 0.06594 lineto
0.20238 0.06371 lineto
0.22222 0.06187 lineto
0.24206 0.06039 lineto
0.2619 0.05922 lineto
0.28175 0.05833 lineto
0.29167 0.05799 lineto
0.30159 0.05771 lineto
0.31151 0.0575 lineto
0.31647 0.05742 lineto
0.32143 0.05735 lineto
0.32639 0.05729 lineto
0.32887 0.05727 lineto
0.33135 0.05726 lineto
0.33383 0.05724 lineto
0.33507 0.05724 lineto
0.33631 0.05723 lineto
0.33755 0.05723 lineto
0.33879 0.05723 lineto
0.34003 0.05723 lineto
0.34127 0.05723 lineto
0.34251 0.05723 lineto
0.34375 0.05723 lineto
0.34499 0.05723 lineto
0.34623 0.05723 lineto
0.34747 0.05724 lineto
0.34871 0.05724 lineto
0.35119 0.05726 lineto
0.35367 0.05727 lineto
0.35615 0.05729 lineto
0.36111 0.05735 lineto
0.36607 0.05742 lineto
0.37103 0.0575 lineto
0.38095 0.05771 lineto
0.39087 0.05799 lineto
0.40079 0.05833 lineto
0.42063 0.05922 lineto
0.44048 0.06039 lineto
0.46032 0.06187 lineto
0.48016 0.06371 lineto
0.5 0.06594 lineto
0.51984 0.06864 lineto
0.53968 0.07187 lineto
0.57937 0.08043 lineto
Mistroke
0.59921 0.0861 lineto
0.61905 0.09303 lineto
0.63889 0.10161 lineto
0.65873 0.11239 lineto
0.67857 0.12622 lineto
0.69841 0.14443 lineto
0.71825 0.1692 lineto
0.7381 0.20424 lineto
0.74802 0.2275 lineto
0.75794 0.25608 lineto
0.77778 0.33504 lineto
0.7877 0.38727 lineto
0.79762 0.44455 lineto
0.80258 0.47161 lineto
0.80506 0.48369 lineto
0.80754 0.4943 lineto
0.81002 0.50305 lineto
0.8125 0.5096 lineto
0.81374 0.51195 lineto
0.81498 0.51365 lineto
0.81622 0.51468 lineto
0.81746 0.51503 lineto
0.8187 0.51468 lineto
0.81994 0.51365 lineto
0.82118 0.51195 lineto
0.82242 0.5096 lineto
0.8249 0.50305 lineto
0.82738 0.4943 lineto
0.8373 0.44455 lineto
0.85714 0.33504 lineto
0.86706 0.29145 lineto
0.87698 0.25608 lineto
0.8869 0.2275 lineto
0.89683 0.20424 lineto
0.91667 0.1692 lineto
0.93651 0.14443 lineto
0.95635 0.12622 lineto
0.97619 0.11239 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; endGroup; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.10301 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(1)] 0.4875 0.10301 1 0 Msboxa
[(2)] 0.4875 0.20601 1 0 Msboxa
[(3)] 0.4875 0.30902 1 0 Msboxa
[(4)] 0.4875 0.41202 1 0 Msboxa
[(5)] 0.4875 0.51503 1 0 Msboxa
[(6)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(1)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(2)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(3)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(4)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(5)] 0.4875 0.51503 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(6)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.51503 moveto
0.06349 0.33504 lineto
0.07341 0.29145 lineto
0.08333 0.25608 lineto
0.10317 0.20424 lineto
0.1131 0.18511 lineto
0.12302 0.1692 lineto
0.14286 0.14443 lineto
0.1627 0.12622 lineto
0.18254 0.11239 lineto
0.20238 0.10161 lineto
0.22222 0.09303 lineto
0.24206 0.0861 lineto
0.2619 0.08043 lineto
0.28175 0.07575 lineto
0.30159 0.07187 lineto
0.32143 0.06864 lineto
0.34127 0.06594 lineto
0.38095 0.06187 lineto
0.40079 0.06039 lineto
0.42063 0.05922 lineto
0.44048 0.05833 lineto
0.4504 0.05799 lineto
0.46032 0.05771 lineto
0.47024 0.0575 lineto
0.4752 0.05742 lineto
0.48016 0.05735 lineto
0.48512 0.05729 lineto
0.4876 0.05727 lineto
0.49008 0.05726 lineto
0.49256 0.05724 lineto
0.4938 0.05724 lineto
0.49504 0.05723 lineto
0.49628 0.05723 lineto
0.49752 0.05723 lineto
0.49876 0.05723 lineto
0.5 0.05723 lineto
0.50124 0.05723 lineto
0.50248 0.05723 lineto
0.50372 0.05723 lineto
0.50496 0.05723 lineto
0.5062 0.05724 lineto
0.50744 0.05724 lineto
0.50992 0.05726 lineto
0.5124 0.05727 lineto
0.51488 0.05729 lineto
0.51984 0.05735 lineto
0.5248 0.05742 lineto
0.52976 0.0575 lineto
0.53968 0.05771 lineto
Mistroke
0.5496 0.05799 lineto
0.55952 0.05833 lineto
0.57937 0.05922 lineto
0.59921 0.06039 lineto
0.61905 0.06187 lineto
0.63889 0.06371 lineto
0.65873 0.06594 lineto
0.67857 0.06864 lineto
0.69841 0.07187 lineto
0.7381 0.08043 lineto
0.75794 0.0861 lineto
0.77778 0.09303 lineto
0.79762 0.10161 lineto
0.81746 0.11239 lineto
0.8373 0.12622 lineto
0.85714 0.14443 lineto
0.87698 0.1692 lineto
0.8869 0.18511 lineto
0.89683 0.20424 lineto
0.90675 0.2275 lineto
0.91667 0.25608 lineto
0.93651 0.33504 lineto
0.97619 0.51503 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example:  Animation of System with Multiple Poles and Zeroes
:[font = text; inactive; ]
		Animate the following cells by selecting the graphics cells to be animated and then choosing the Animation option from the Graph submenu. You can also set the desired animation speed by using the Preferences option in the main menu, or the options in the bottom right side of  the notebook border. 
		The black dot on the circle represents the point z = e^jw moving around the unit circle, while the symbol "x" represents a pole and the symbol "o" represents a zero.
		 Note that the frequency response becomes zero whenever the black dot crosses a zero located on the unit circle. Also, the resulting frequency response corresponds to a low-pass filter. The more poles we will have in the right part of the unit circle the flatter the response can become around the low frequencies if these poles are placed appropriately.
:[font = input; startGroup; ]
Do[VectorPoleZeroPlot[
          (z^2 + 1)/((z-0.8)(z-0.9 Exp[I Pi/4])(z-0.9 Exp[-I  Pi/4])), 
           z, 0.9, Infinity, w, True,
                Dialogue -> False],
   {w,-Pi,Pi,Pi/4}] 
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.1 0.5 moveto
0.5 0.9 lineto
stroke
0.1 0.5 moveto
0.5 0.1 lineto
stroke
0.1 0.5 moveto
0.82 0.5 lineto
stroke
0.1 0.5 moveto
0.75456 0.75456 lineto
stroke
0.1 0.5 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.1 0.5 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.21716 0.21716 moveto
0.5 0.9 lineto
stroke
0.21716 0.21716 moveto
0.5 0.1 lineto
stroke
0.21716 0.21716 moveto
0.82 0.5 lineto
stroke
0.21716 0.21716 moveto
0.75456 0.75456 lineto
stroke
0.21716 0.21716 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.21716 0.21716 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.5 0.1 moveto
0.5 0.9 lineto
stroke
0.5 0.1 moveto
0.5 0.1 lineto
stroke
0.5 0.1 moveto
0.82 0.5 lineto
stroke
0.5 0.1 moveto
0.75456 0.75456 lineto
stroke
0.5 0.1 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.5 0.1 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.78284 0.21716 moveto
0.5 0.9 lineto
stroke
0.78284 0.21716 moveto
0.5 0.1 lineto
stroke
0.78284 0.21716 moveto
0.82 0.5 lineto
stroke
0.78284 0.21716 moveto
0.75456 0.75456 lineto
stroke
0.78284 0.21716 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.78284 0.21716 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.5 0.9 lineto
stroke
0.9 0.5 moveto
0.5 0.1 lineto
stroke
0.9 0.5 moveto
0.82 0.5 lineto
stroke
0.9 0.5 moveto
0.75456 0.75456 lineto
stroke
0.9 0.5 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.9 0.5 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.78284 0.78284 moveto
0.5 0.9 lineto
stroke
0.78284 0.78284 moveto
0.5 0.1 lineto
stroke
0.78284 0.78284 moveto
0.82 0.5 lineto
stroke
0.78284 0.78284 moveto
0.75456 0.75456 lineto
stroke
0.78284 0.78284 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.78284 0.78284 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.5 0.9 moveto
0.5 0.9 lineto
stroke
0.5 0.9 moveto
0.5 0.1 lineto
stroke
0.5 0.9 moveto
0.82 0.5 lineto
stroke
0.5 0.9 moveto
0.75456 0.75456 lineto
stroke
0.5 0.9 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.5 0.9 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.21716 0.78284 moveto
0.5 0.9 lineto
stroke
0.21716 0.78284 moveto
0.5 0.1 lineto
stroke
0.21716 0.78284 moveto
0.82 0.5 lineto
stroke
0.21716 0.78284 moveto
0.75456 0.75456 lineto
stroke
0.21716 0.78284 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.21716 0.78284 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.1 0.5 moveto
0.5 0.9 lineto
stroke
0.1 0.5 moveto
0.5 0.1 lineto
stroke
0.1 0.5 moveto
0.82 0.5 lineto
stroke
0.1 0.5 moveto
0.75456 0.75456 lineto
stroke
0.1 0.5 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.1 0.5 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = input; startGroup; ]
Do[MagPhasePlot[(z^2 + 1)/((z-0.8)(z-0.9 Exp[I Pi/4])(z-0.9 Exp[-I  Pi/4])) 
                /. z -> Exp[I w], {w,-Pi-0.1,r}, PhaseRangeScale -> Null, 
                PlotRange -> {{-Pi,Pi},{0,20}}],
   {r,-Pi,Pi,Pi/4}]              
          
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.01525 0.01113 lineto
-0.01459 0.01113 lineto
-0.01393 0.01113 lineto
-0.01326 0.01113 lineto
-0.0126 0.01113 lineto
-0.01194 0.01113 lineto
-0.01127 0.01113 lineto
-0.01061 0.01113 lineto
-0.00995 0.01113 lineto
-0.00928 0.01113 lineto
-0.00862 0.01113 lineto
-0.00796 0.01114 lineto
-0.00729 0.01114 lineto
-0.00663 0.01114 lineto
-0.00597 0.01114 lineto
-0.00531 0.01114 lineto
-0.00464 0.01114 lineto
-0.00398 0.01114 lineto
-0.00332 0.01114 lineto
-0.00265 0.01114 lineto
-0.00199 0.01114 lineto
-0.00166 0.01114 lineto
-0.00133 0.01114 lineto
-0.00099 0.01114 lineto
-0.00083 0.01114 lineto
-0.00066 0.01114 lineto
-0.0005 0.01114 lineto
-0.00041 0.01114 lineto
-0.00033 0.01114 lineto
-0.00025 0.01114 lineto
-0.00021 0.01114 lineto
-0.00017 0.01114 lineto
-0.00012 0.01114 lineto
-0.0001 0.01114 lineto
-8e-05 0.01114 lineto
-6e-05 0.01114 lineto
-4e-05 0.01114 lineto
0 0.01114 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.01298 0.01113 lineto
-0.01004 0.01113 lineto
-0.00858 0.01113 lineto
-0.00711 0.01114 lineto
-0.00564 0.01114 lineto
-0.00491 0.01114 lineto
-0.00417 0.01114 lineto
-0.00344 0.01114 lineto
-0.0027 0.01114 lineto
-0.00234 0.01114 lineto
-0.00197 0.01114 lineto
-0.0016 0.01114 lineto
-0.00124 0.01114 lineto
-0.00105 0.01114 lineto
-0.00087 0.01114 lineto
-0.00069 0.01114 lineto
-0.0005 0.01114 lineto
-0.00032 0.01114 lineto
-0.00014 0.01114 lineto
5e-05 0.01114 lineto
0.00023 0.01114 lineto
0.00041 0.01114 lineto
0.0006 0.01114 lineto
0.00097 0.01114 lineto
0.00115 0.01114 lineto
0.00133 0.01114 lineto
0.0017 0.01114 lineto
0.00243 0.01114 lineto
0.00317 0.01114 lineto
0.00463 0.01114 lineto
0.0061 0.01114 lineto
0.00757 0.01114 lineto
0.01051 0.01113 lineto
0.01344 0.01113 lineto
0.01931 0.01112 lineto
0.02518 0.01111 lineto
0.03106 0.0111 lineto
0.03693 0.01108 lineto
0.0428 0.01107 lineto
0.04867 0.01104 lineto
0.05454 0.01102 lineto
0.06041 0.01099 lineto
0.06629 0.01095 lineto
0.07216 0.01092 lineto
0.07803 0.01087 lineto
0.0839 0.01082 lineto
0.08977 0.01077 lineto
0.09564 0.01071 lineto
0.10151 0.01064 lineto
Mistroke
0.10739 0.01056 lineto
0.11326 0.01047 lineto
0.11913 0.01038 lineto
0.125 0.01027 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.01315 0.01113 lineto
-0.01038 0.01113 lineto
-0.00899 0.01113 lineto
-0.00761 0.01114 lineto
-0.00622 0.01114 lineto
-0.00484 0.01114 lineto
-0.00414 0.01114 lineto
-0.00345 0.01114 lineto
-0.00276 0.01114 lineto
-0.00207 0.01114 lineto
-0.00172 0.01114 lineto
-0.00137 0.01114 lineto
-0.00103 0.01114 lineto
-0.00068 0.01114 lineto
-0.00033 0.01114 lineto
1e-05 0.01114 lineto
0.00036 0.01114 lineto
0.0007 0.01114 lineto
0.00105 0.01114 lineto
0.0014 0.01114 lineto
0.00209 0.01114 lineto
0.00278 0.01114 lineto
0.00347 0.01114 lineto
0.00486 0.01114 lineto
0.00624 0.01114 lineto
0.00901 0.01113 lineto
0.01178 0.01113 lineto
0.01732 0.01113 lineto
0.02286 0.01112 lineto
0.0284 0.01111 lineto
0.03948 0.01108 lineto
0.05056 0.01104 lineto
0.06164 0.01098 lineto
0.07272 0.01091 lineto
0.0838 0.01082 lineto
0.09488 0.01071 lineto
0.10596 0.01058 lineto
0.11704 0.01041 lineto
0.12812 0.01021 lineto
0.1392 0.00996 lineto
0.15028 0.00965 lineto
0.16136 0.00927 lineto
0.17244 0.0088 lineto
0.18352 0.00823 lineto
0.1946 0.00751 lineto
0.20568 0.00662 lineto
0.21676 0.0055 lineto
0.22784 0.00409 lineto
0.23892 0.0023 lineto
Mistroke
0.25 0 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.01388 0.01113 lineto
-0.01184 0.01113 lineto
-0.00981 0.01113 lineto
-0.00777 0.01114 lineto
-0.00675 0.01114 lineto
-0.00574 0.01114 lineto
-0.00472 0.01114 lineto
-0.0037 0.01114 lineto
-0.00319 0.01114 lineto
-0.00268 0.01114 lineto
-0.00217 0.01114 lineto
-0.00166 0.01114 lineto
-0.00115 0.01114 lineto
-0.00065 0.01114 lineto
-0.00014 0.01114 lineto
0.00037 0.01114 lineto
0.00088 0.01114 lineto
0.00139 0.01114 lineto
0.0019 0.01114 lineto
0.00241 0.01114 lineto
0.00343 0.01114 lineto
0.00444 0.01114 lineto
0.00648 0.01114 lineto
0.00852 0.01113 lineto
0.01259 0.01113 lineto
0.01666 0.01113 lineto
0.02073 0.01112 lineto
0.0248 0.01111 lineto
0.03295 0.0111 lineto
0.04109 0.01107 lineto
0.04924 0.01104 lineto
0.06553 0.01096 lineto
0.07367 0.0109 lineto
0.08181 0.01084 lineto
0.0981 0.01068 lineto
0.11439 0.01046 lineto
0.13068 0.01015 lineto
0.14697 0.00975 lineto
0.16325 0.0092 lineto
0.17954 0.00845 lineto
0.19583 0.00742 lineto
0.21212 0.006 lineto
0.22841 0.00401 lineto
0.23655 0.00272 lineto
0.24062 0.00198 lineto
0.24469 0.00118 lineto
0.24673 0.00074 lineto
0.24775 0.00052 lineto
0.24877 0.00029 lineto
Mistroke
0.24928 0.00017 lineto
0.24978 5e-05 lineto
0.25029 7e-05 lineto
0.2508 0.00019 lineto
0.25182 0.00044 lineto
0.25284 0.00069 lineto
0.26098 0.00296 lineto
0.27727 0.00918 lineto
0.28542 0.01347 lineto
0.29356 0.01889 lineto
0.3017 0.02585 lineto
0.30985 0.03494 lineto
0.31799 0.04704 lineto
0.32614 0.06357 lineto
0.33428 0.08683 lineto
0.33835 0.10211 lineto
0.34242 0.12071 lineto
0.3465 0.14355 lineto
0.35057 0.17177 lineto
0.35871 0.24974 lineto
0.375 0.45547 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.01323 0.01113 lineto
-0.01054 0.01113 lineto
-0.00785 0.01114 lineto
-0.00651 0.01114 lineto
-0.00517 0.01114 lineto
-0.0045 0.01114 lineto
-0.00382 0.01114 lineto
-0.00315 0.01114 lineto
-0.00248 0.01114 lineto
-0.00181 0.01114 lineto
-0.00114 0.01114 lineto
-0.00046 0.01114 lineto
0.00021 0.01114 lineto
0.00088 0.01114 lineto
0.00155 0.01114 lineto
0.00222 0.01114 lineto
0.00289 0.01114 lineto
0.00424 0.01114 lineto
0.00558 0.01114 lineto
0.00827 0.01114 lineto
0.01096 0.01113 lineto
0.01364 0.01113 lineto
0.01633 0.01113 lineto
0.0217 0.01112 lineto
0.02708 0.01111 lineto
0.03783 0.01108 lineto
0.04857 0.01104 lineto
0.05932 0.01099 lineto
0.07007 0.01093 lineto
0.08082 0.01085 lineto
0.09157 0.01075 lineto
0.10232 0.01063 lineto
0.11306 0.01048 lineto
0.12381 0.01029 lineto
0.13456 0.01007 lineto
0.14531 0.00979 lineto
0.15606 0.00946 lineto
0.1668 0.00905 lineto
0.17755 0.00855 lineto
0.1883 0.00794 lineto
0.19905 0.00718 lineto
0.22055 0.00506 lineto
0.23129 0.00358 lineto
0.23667 0.0027 lineto
0.24204 0.00171 lineto
0.24742 0.00059 lineto
0.24876 0.00029 lineto
0.24943 0.00013 lineto
0.2501 2e-05 lineto
Mistroke
0.25145 0.00035 lineto
0.25279 0.00068 lineto
0.26354 0.00377 lineto
0.27429 0.00783 lineto
0.28504 0.01324 lineto
0.29578 0.02062 lineto
0.30116 0.02533 lineto
0.30653 0.03093 lineto
0.31191 0.03767 lineto
0.31728 0.04583 lineto
0.32265 0.05584 lineto
0.32803 0.06827 lineto
0.3334 0.08391 lineto
0.33878 0.10388 lineto
0.34415 0.12982 lineto
0.34952 0.16395 lineto
0.3549 0.20923 lineto
0.36027 0.26848 lineto
0.36565 0.34111 lineto
0.36833 0.37938 lineto
0.37102 0.41516 lineto
0.37371 0.4446 lineto
0.37505 0.45585 lineto
0.37572 0.46047 lineto
0.3764 0.4644 lineto
0.37707 0.46763 lineto
0.37774 0.47015 lineto
0.37841 0.472 lineto
0.37908 0.47318 lineto
0.37975 0.47372 lineto
0.38043 0.47367 lineto
0.3811 0.47306 lineto
0.38177 0.47194 lineto
0.39252 0.42022 lineto
0.39789 0.3928 lineto
0.40327 0.37134 lineto
0.40595 0.36293 lineto
0.40864 0.35596 lineto
0.41133 0.35033 lineto
0.41401 0.34594 lineto
0.41536 0.34418 lineto
0.4167 0.3427 lineto
0.41804 0.34148 lineto
0.41939 0.34052 lineto
0.42006 0.34013 lineto
0.42073 0.33981 lineto
0.4214 0.33954 lineto
0.42208 0.33934 lineto
0.42275 0.33919 lineto
0.42342 0.3391 lineto
Mistroke
0.42409 0.33907 lineto
0.42476 0.3391 lineto
0.42543 0.33918 lineto
0.42611 0.33931 lineto
0.42678 0.33951 lineto
0.42745 0.33975 lineto
0.42879 0.3404 lineto
0.43014 0.34127 lineto
0.43282 0.34362 lineto
0.43551 0.34678 lineto
0.44088 0.35553 lineto
0.44626 0.36747 lineto
0.45701 0.40111 lineto
0.46776 0.4475 lineto
0.4785 0.50283 lineto
0.48388 0.53013 lineto
0.48656 0.54252 lineto
0.48925 0.55351 lineto
0.49194 0.56264 lineto
0.49328 0.56638 lineto
0.49463 0.56951 lineto
0.49597 0.57199 lineto
0.49664 0.57297 lineto
0.49731 0.57378 lineto
0.49798 0.57441 lineto
0.49866 0.57486 lineto
0.5 0.57523 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.01258 0.01113 lineto
-0.01091 0.01113 lineto
-0.00924 0.01113 lineto
-0.00757 0.01114 lineto
-0.0059 0.01114 lineto
-0.00423 0.01114 lineto
-0.0034 0.01114 lineto
-0.00256 0.01114 lineto
-0.00173 0.01114 lineto
-0.00089 0.01114 lineto
-6e-05 0.01114 lineto
0.00078 0.01114 lineto
0.00161 0.01114 lineto
0.00244 0.01114 lineto
0.00328 0.01114 lineto
0.00411 0.01114 lineto
0.00578 0.01114 lineto
0.00745 0.01114 lineto
0.01079 0.01113 lineto
0.01413 0.01113 lineto
0.01747 0.01113 lineto
0.02414 0.01112 lineto
0.03082 0.0111 lineto
0.03749 0.01108 lineto
0.05085 0.01103 lineto
0.0642 0.01097 lineto
0.07755 0.01088 lineto
0.0909 0.01076 lineto
0.10426 0.0106 lineto
0.11761 0.0104 lineto
0.13096 0.01015 lineto
0.14431 0.00982 lineto
0.15767 0.0094 lineto
0.17102 0.00887 lineto
0.18437 0.00818 lineto
0.19772 0.00728 lineto
0.21108 0.00611 lineto
0.22443 0.00456 lineto
0.23778 0.00251 lineto
0.24446 0.00122 lineto
0.24613 0.00087 lineto
0.24779 0.00051 lineto
0.24863 0.00032 lineto
0.24946 0.00013 lineto
0.2503 7e-05 lineto
0.25113 0.00027 lineto
0.2528 0.00068 lineto
0.25447 0.00111 lineto
0.25781 0.00202 lineto
Mistroke
0.26449 0.00409 lineto
0.27116 0.00653 lineto
0.27784 0.00944 lineto
0.28451 0.01294 lineto
0.29119 0.01718 lineto
0.29787 0.02235 lineto
0.30454 0.02874 lineto
0.31122 0.03673 lineto
0.31789 0.04687 lineto
0.32457 0.05996 lineto
0.33125 0.07718 lineto
0.33792 0.10036 lineto
0.3446 0.13232 lineto
0.35128 0.17733 lineto
0.35795 0.24107 lineto
0.36463 0.32663 lineto
0.36797 0.3742 lineto
0.3713 0.41863 lineto
0.37297 0.4374 lineto
0.37464 0.4527 lineto
0.37548 0.45886 lineto
0.37631 0.46395 lineto
0.37715 0.46796 lineto
0.37798 0.4709 lineto
0.37882 0.47278 lineto
0.37965 0.47368 lineto
0.38048 0.47364 lineto
0.38132 0.47275 lineto
0.38215 0.47109 lineto
0.38299 0.46877 lineto
0.38466 0.46247 lineto
0.39133 0.42685 lineto
0.39801 0.39227 lineto
0.40135 0.37828 lineto
0.40469 0.36671 lineto
0.40802 0.35744 lineto
0.41136 0.35027 lineto
0.41303 0.34741 lineto
0.4147 0.34501 lineto
0.41637 0.34304 lineto
0.41804 0.34148 lineto
0.41971 0.34033 lineto
0.42054 0.33989 lineto
0.42138 0.33955 lineto
0.42221 0.3393 lineto
0.42304 0.33914 lineto
0.42388 0.33907 lineto
0.42471 0.33909 lineto
0.42555 0.3392 lineto
0.42638 0.33939 lineto
Mistroke
0.42722 0.33966 lineto
0.42805 0.34002 lineto
0.42972 0.34098 lineto
0.43139 0.34226 lineto
0.43473 0.34578 lineto
0.43807 0.35054 lineto
0.44474 0.36378 lineto
0.45142 0.38199 lineto
0.46477 0.43344 lineto
0.47812 0.50084 lineto
0.4848 0.53452 lineto
0.48814 0.54915 lineto
0.49148 0.56122 lineto
0.49314 0.56603 lineto
0.49481 0.5699 lineto
0.49565 0.57146 lineto
0.49648 0.57275 lineto
0.49732 0.57378 lineto
0.49815 0.57454 lineto
0.49899 0.57502 lineto
0.49982 0.57522 lineto
0.50066 0.57514 lineto
0.50149 0.57478 lineto
0.50232 0.57414 lineto
0.50316 0.57323 lineto
0.50399 0.57204 lineto
0.50483 0.5706 lineto
0.51818 0.51996 lineto
0.53153 0.45097 lineto
0.53821 0.42027 lineto
0.54489 0.39424 lineto
0.55156 0.37324 lineto
0.5549 0.36462 lineto
0.55824 0.35726 lineto
0.56158 0.35113 lineto
0.56491 0.34623 lineto
0.56825 0.34258 lineto
0.56992 0.34123 lineto
0.57076 0.34067 lineto
0.57159 0.3402 lineto
0.57242 0.3398 lineto
0.57326 0.33949 lineto
0.57409 0.33927 lineto
0.57493 0.33913 lineto
0.57576 0.33907 lineto
0.5766 0.3391 lineto
0.57743 0.33922 lineto
0.57827 0.33943 lineto
0.5791 0.33973 lineto
0.57994 0.34013 lineto
Mistroke
0.5816 0.3412 lineto
0.58327 0.34267 lineto
0.58494 0.34455 lineto
0.58828 0.34962 lineto
0.59162 0.35657 lineto
0.59496 0.36561 lineto
0.5983 0.37693 lineto
0.625 0.45547 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.01193 0.01113 lineto
-0.00993 0.01113 lineto
-0.00794 0.01114 lineto
-0.00594 0.01114 lineto
-0.00495 0.01114 lineto
-0.00395 0.01114 lineto
-0.00295 0.01114 lineto
-0.00195 0.01114 lineto
-0.00096 0.01114 lineto
4e-05 0.01114 lineto
0.00104 0.01114 lineto
0.00204 0.01114 lineto
0.00303 0.01114 lineto
0.00403 0.01114 lineto
0.00602 0.01114 lineto
0.00802 0.01114 lineto
0.01001 0.01113 lineto
0.01201 0.01113 lineto
0.016 0.01113 lineto
0.01999 0.01112 lineto
0.02398 0.01112 lineto
0.03195 0.0111 lineto
0.03993 0.01108 lineto
0.04791 0.01105 lineto
0.06387 0.01097 lineto
0.07982 0.01086 lineto
0.09578 0.0107 lineto
0.11174 0.0105 lineto
0.12769 0.01022 lineto
0.14365 0.00984 lineto
0.15961 0.00933 lineto
0.17556 0.00865 lineto
0.19152 0.00773 lineto
0.20748 0.00645 lineto
0.22343 0.00469 lineto
0.23141 0.00356 lineto
0.23939 0.00222 lineto
0.24338 0.00145 lineto
0.24537 0.00103 lineto
0.24737 0.0006 lineto
0.24837 0.00038 lineto
0.24936 0.00015 lineto
0.25036 9e-05 lineto
0.25136 0.00032 lineto
0.25235 0.00057 lineto
0.25335 0.00082 lineto
0.25535 0.00134 lineto
0.26332 0.0037 lineto
0.2713 0.00659 lineto
Mistroke
0.27928 0.01015 lineto
0.28726 0.01458 lineto
0.29524 0.02019 lineto
0.30322 0.02736 lineto
0.31119 0.0367 lineto
0.31917 0.04912 lineto
0.32715 0.06604 lineto
0.33114 0.07687 lineto
0.33513 0.08979 lineto
0.33912 0.10534 lineto
0.34311 0.12422 lineto
0.3471 0.14734 lineto
0.35109 0.17582 lineto
0.35906 0.25386 lineto
0.36704 0.36107 lineto
0.37103 0.41529 lineto
0.37303 0.43794 lineto
0.37402 0.44747 lineto
0.37502 0.45562 lineto
0.37602 0.46228 lineto
0.37702 0.4674 lineto
0.37801 0.47099 lineto
0.37901 0.47308 lineto
0.38001 0.47377 lineto
0.381 0.47318 lineto
0.382 0.47145 lineto
0.383 0.46873 lineto
0.39098 0.42886 lineto
0.39497 0.40708 lineto
0.39896 0.38805 lineto
0.40294 0.37245 lineto
0.40693 0.36023 lineto
0.40893 0.3553 lineto
0.41092 0.3511 lineto
0.41292 0.34759 lineto
0.41491 0.34473 lineto
0.41691 0.34249 lineto
0.4189 0.34084 lineto
0.4199 0.34022 lineto
0.4209 0.33974 lineto
0.42189 0.33939 lineto
0.42289 0.33917 lineto
0.42389 0.33907 lineto
0.42488 0.33911 lineto
0.42588 0.33926 lineto
0.42688 0.33954 lineto
0.42788 0.33994 lineto
0.42887 0.34045 lineto
0.43087 0.34183 lineto
0.43286 0.34366 lineto
Mistroke
0.43486 0.34594 lineto
0.43885 0.35183 lineto
0.44284 0.35949 lineto
0.44683 0.36892 lineto
0.4548 0.39315 lineto
0.46278 0.42455 lineto
0.47874 0.50406 lineto
0.48273 0.5245 lineto
0.48672 0.54319 lineto
0.49071 0.55871 lineto
0.4927 0.56483 lineto
0.4937 0.56741 lineto
0.49469 0.56965 lineto
0.49569 0.57153 lineto
0.49669 0.57303 lineto
0.49769 0.57415 lineto
0.49868 0.57488 lineto
0.49968 0.57521 lineto
0.50068 0.57514 lineto
0.50168 0.57466 lineto
0.50267 0.57379 lineto
0.50367 0.57253 lineto
0.50467 0.57089 lineto
0.50666 0.56652 lineto
0.50866 0.5608 lineto
0.51065 0.55387 lineto
0.52661 0.47596 lineto
0.53459 0.4364 lineto
0.54256 0.40272 lineto
0.55054 0.37611 lineto
0.55852 0.35669 lineto
0.56251 0.34963 lineto
0.5645 0.34676 lineto
0.5665 0.34434 lineto
0.56849 0.34236 lineto
0.56949 0.34154 lineto
0.57049 0.34084 lineto
0.57149 0.34025 lineto
0.57248 0.33978 lineto
0.57348 0.33943 lineto
0.57448 0.33919 lineto
0.57547 0.33908 lineto
0.57647 0.33909 lineto
0.57747 0.33923 lineto
0.57847 0.3395 lineto
0.57946 0.33989 lineto
0.58046 0.34043 lineto
0.58146 0.34109 lineto
0.58246 0.3419 lineto
0.58445 0.34395 lineto
Mistroke
0.58645 0.34661 lineto
0.59043 0.35388 lineto
0.59442 0.36402 lineto
0.59841 0.37737 lineto
0.60639 0.41425 lineto
0.61038 0.43657 lineto
0.61237 0.44771 lineto
0.61437 0.45802 lineto
0.61537 0.46257 lineto
0.61636 0.46656 lineto
0.61736 0.46981 lineto
0.61836 0.47219 lineto
0.61936 0.47353 lineto
0.62035 0.47367 lineto
0.62135 0.47249 lineto
0.62235 0.46987 lineto
0.6383 0.28662 lineto
0.64229 0.23833 lineto
0.64628 0.19816 lineto
0.65426 0.13893 lineto
0.65825 0.11737 lineto
0.66224 0.09971 lineto
0.67022 0.07297 lineto
0.6782 0.05412 lineto
0.68617 0.0404 lineto
0.69415 0.03016 lineto
0.70213 0.02235 lineto
0.71011 0.01629 lineto
0.71809 0.0115 lineto
0.72607 0.00768 lineto
0.73404 0.00459 lineto
0.75 0 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.0136 0.01113 lineto
-0.01128 0.01113 lineto
-0.00896 0.01113 lineto
-0.0078 0.01114 lineto
-0.00664 0.01114 lineto
-0.00548 0.01114 lineto
-0.00432 0.01114 lineto
-0.00315 0.01114 lineto
-0.00199 0.01114 lineto
-0.00083 0.01114 lineto
0.00033 0.01114 lineto
0.00149 0.01114 lineto
0.00265 0.01114 lineto
0.00381 0.01114 lineto
0.00497 0.01114 lineto
0.00729 0.01114 lineto
0.00961 0.01113 lineto
0.01193 0.01113 lineto
0.01657 0.01113 lineto
0.02121 0.01112 lineto
0.03049 0.0111 lineto
0.03977 0.01108 lineto
0.04905 0.01104 lineto
0.05833 0.011 lineto
0.06761 0.01095 lineto
0.07689 0.01088 lineto
0.08617 0.0108 lineto
0.09545 0.01071 lineto
0.11401 0.01046 lineto
0.13257 0.01011 lineto
0.15113 0.00962 lineto
0.16969 0.00893 lineto
0.17897 0.00848 lineto
0.18825 0.00794 lineto
0.19753 0.00729 lineto
0.20681 0.00652 lineto
0.21609 0.00558 lineto
0.22537 0.00444 lineto
0.23465 0.00304 lineto
0.23929 0.00223 lineto
0.24393 0.00133 lineto
0.24625 0.00084 lineto
0.24858 0.00033 lineto
0.24974 6e-05 lineto
0.2509 0.00021 lineto
0.25322 0.00079 lineto
0.2625 0.00344 lineto
0.27178 0.00678 lineto
0.28106 0.01105 lineto
Mistroke
0.29034 0.01659 lineto
0.29962 0.02389 lineto
0.3089 0.03374 lineto
0.31818 0.04736 lineto
0.32282 0.05618 lineto
0.32746 0.06681 lineto
0.3321 0.07976 lineto
0.33674 0.09571 lineto
0.34138 0.11558 lineto
0.34602 0.14062 lineto
0.35066 0.17248 lineto
0.3553 0.21314 lineto
0.36458 0.32595 lineto
0.36922 0.39163 lineto
0.37154 0.42146 lineto
0.3727 0.43454 lineto
0.37386 0.446 lineto
0.37502 0.45562 lineto
0.37618 0.46322 lineto
0.37734 0.46874 lineto
0.3785 0.47219 lineto
0.37966 0.47368 lineto
0.38082 0.47338 lineto
0.38198 0.47149 lineto
0.38314 0.46828 lineto
0.38546 0.45883 lineto
0.38778 0.44687 lineto
0.39242 0.42075 lineto
0.39706 0.39668 lineto
0.4017 0.37694 lineto
0.40634 0.36184 lineto
0.40866 0.35591 lineto
0.41098 0.35098 lineto
0.4133 0.34699 lineto
0.41562 0.34387 lineto
0.41678 0.34262 lineto
0.41794 0.34156 lineto
0.4191 0.3407 lineto
0.42026 0.34003 lineto
0.42142 0.33953 lineto
0.42258 0.33922 lineto
0.42374 0.33908 lineto
0.4249 0.33911 lineto
0.42606 0.3393 lineto
0.42722 0.33966 lineto
0.42838 0.34018 lineto
0.42954 0.34086 lineto
0.43186 0.34268 lineto
0.43418 0.34512 lineto
0.43882 0.35179 lineto
Mistroke
0.44346 0.36086 lineto
0.4481 0.37231 lineto
0.45738 0.40253 lineto
0.46666 0.44227 lineto
0.47594 0.48935 lineto
0.48058 0.51366 lineto
0.48522 0.53649 lineto
0.48986 0.55577 lineto
0.49218 0.56337 lineto
0.49334 0.56654 lineto
0.4945 0.56925 lineto
0.49566 0.57148 lineto
0.49682 0.57321 lineto
0.49798 0.57441 lineto
0.49915 0.57508 lineto
0.50031 0.57521 lineto
0.50147 0.5748 lineto
0.50263 0.57384 lineto
0.50379 0.57237 lineto
0.50611 0.56788 lineto
0.50843 0.56153 lineto
0.51307 0.54413 lineto
0.52235 0.49837 lineto
0.54091 0.40916 lineto
0.55019 0.37715 lineto
0.55483 0.3648 lineto
0.55947 0.35485 lineto
0.56179 0.35078 lineto
0.56411 0.3473 lineto
0.56643 0.34442 lineto
0.56875 0.34214 lineto
0.57107 0.34048 lineto
0.57223 0.33989 lineto
0.57339 0.33945 lineto
0.57455 0.33918 lineto
0.57571 0.33907 lineto
0.57687 0.33913 lineto
0.57803 0.33936 lineto
0.57919 0.33977 lineto
0.58035 0.34036 lineto
0.58151 0.34113 lineto
0.58267 0.34209 lineto
0.58499 0.34461 lineto
0.58731 0.34795 lineto
0.58963 0.35219 lineto
0.59195 0.35737 lineto
0.59659 0.37085 lineto
0.60123 0.38886 lineto
0.60587 0.41146 lineto
0.61051 0.4373 lineto
Mistroke
0.61283 0.45017 lineto
0.61515 0.46163 lineto
0.61631 0.46636 lineto
0.61747 0.47012 lineto
0.61863 0.47267 lineto
0.61979 0.47375 lineto
0.62095 0.47313 lineto
0.62211 0.47063 lineto
0.62327 0.4661 lineto
0.62443 0.45948 lineto
0.62675 0.44019 lineto
0.62907 0.41403 lineto
0.63371 0.3503 lineto
0.63835 0.28601 lineto
0.64299 0.23073 lineto
0.64763 0.18633 lineto
0.65227 0.15146 lineto
0.65691 0.12412 lineto
0.66155 0.10251 lineto
0.66619 0.08525 lineto
0.67083 0.07128 lineto
0.67547 0.05987 lineto
0.68011 0.05043 lineto
0.68939 0.03592 lineto
0.69867 0.02549 lineto
0.70795 0.01778 lineto
0.71723 0.01196 lineto
0.72651 0.00749 lineto
0.73579 0.00399 lineto
0.74043 0.00253 lineto
0.74507 0.00123 lineto
0.74739 0.00063 lineto
0.74855 0.00035 lineto
0.74972 7e-05 lineto
0.75204 0.00047 lineto
0.75436 0.00098 lineto
0.76364 0.00275 lineto
0.77292 0.0042 lineto
0.7822 0.00538 lineto
0.79148 0.00636 lineto
0.80076 0.00716 lineto
0.81932 0.00839 lineto
0.8286 0.00885 lineto
0.83788 0.00924 lineto
0.85644 0.00984 lineto
0.875 0.01027 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; endGroup; endGroup; endGroup; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.01327 0.01113 lineto
-0.01062 0.01113 lineto
-0.00798 0.01114 lineto
-0.00666 0.01114 lineto
-0.00533 0.01114 lineto
-0.00401 0.01114 lineto
-0.00269 0.01114 lineto
-0.00136 0.01114 lineto
-4e-05 0.01114 lineto
0.00128 0.01114 lineto
0.0026 0.01114 lineto
0.00393 0.01114 lineto
0.00525 0.01114 lineto
0.0079 0.01114 lineto
0.01054 0.01113 lineto
0.01319 0.01113 lineto
0.01583 0.01113 lineto
0.02112 0.01112 lineto
0.02641 0.01111 lineto
0.037 0.01108 lineto
0.04758 0.01105 lineto
0.05816 0.011 lineto
0.06874 0.01094 lineto
0.08991 0.01077 lineto
0.10049 0.01065 lineto
0.11107 0.01051 lineto
0.12166 0.01033 lineto
0.13224 0.01012 lineto
0.14282 0.00986 lineto
0.1534 0.00955 lineto
0.17457 0.0087 lineto
0.18515 0.00813 lineto
0.19573 0.00743 lineto
0.20632 0.00656 lineto
0.2169 0.00549 lineto
0.22748 0.00414 lineto
0.23806 0.00246 lineto
0.24335 0.00145 lineto
0.246 0.0009 lineto
0.24732 0.00061 lineto
0.24865 0.00031 lineto
0.24997 1e-05 lineto
0.25129 0.00031 lineto
0.25261 0.00064 lineto
0.25394 0.00097 lineto
0.25923 0.00243 lineto
0.26981 0.006 lineto
0.28039 0.01071 lineto
0.29098 0.01703 lineto
Mistroke
0.30156 0.02571 lineto
0.30685 0.0313 lineto
0.31214 0.03799 lineto
0.31743 0.04609 lineto
0.32272 0.05598 lineto
0.33331 0.08359 lineto
0.3386 0.10313 lineto
0.34389 0.12838 lineto
0.34918 0.16146 lineto
0.35447 0.20514 lineto
0.35976 0.26221 lineto
0.36505 0.33265 lineto
0.37034 0.40659 lineto
0.37299 0.43756 lineto
0.37431 0.44998 lineto
0.37564 0.45991 lineto
0.37696 0.46715 lineto
0.37828 0.47169 lineto
0.3796 0.47365 lineto
0.38093 0.47327 lineto
0.38225 0.47086 lineto
0.38357 0.46679 lineto
0.38489 0.46143 lineto
0.38622 0.45512 lineto
0.39151 0.42586 lineto
0.3968 0.39793 lineto
0.40209 0.3755 lineto
0.40474 0.36655 lineto
0.40738 0.35905 lineto
0.41003 0.35289 lineto
0.41267 0.34798 lineto
0.41532 0.34423 lineto
0.41797 0.34154 lineto
0.41929 0.34058 lineto
0.42061 0.33986 lineto
0.42193 0.33937 lineto
0.42326 0.33912 lineto
0.42458 0.33908 lineto
0.4259 0.33927 lineto
0.42722 0.33966 lineto
0.42855 0.34027 lineto
0.42987 0.34108 lineto
0.43119 0.34209 lineto
0.43384 0.34472 lineto
0.43648 0.34813 lineto
0.43913 0.35232 lineto
0.44442 0.36303 lineto
0.44971 0.37685 lineto
0.46029 0.41401 lineto
0.47088 0.46301 lineto
Mistroke
0.48146 0.51814 lineto
0.48675 0.54334 lineto
0.4894 0.55405 lineto
0.49204 0.56295 lineto
0.49337 0.56659 lineto
0.49469 0.56964 lineto
0.49601 0.57205 lineto
0.49733 0.5738 lineto
0.49866 0.57486 lineto
0.49998 0.57523 lineto
0.5013 0.57489 lineto
0.50262 0.57385 lineto
0.50395 0.57212 lineto
0.50527 0.56972 lineto
0.50792 0.56307 lineto
0.51056 0.55421 lineto
0.51321 0.54352 lineto
0.52379 0.49075 lineto
0.53437 0.4374 lineto
0.54495 0.39399 lineto
0.55025 0.37698 lineto
0.55554 0.36312 lineto
0.56083 0.35239 lineto
0.56347 0.34819 lineto
0.56612 0.34477 lineto
0.56877 0.34213 lineto
0.57009 0.34111 lineto
0.57141 0.34029 lineto
0.57273 0.33968 lineto
0.57406 0.33928 lineto
0.57538 0.33909 lineto
0.5767 0.33911 lineto
0.57802 0.33936 lineto
0.57935 0.33984 lineto
0.58067 0.34055 lineto
0.58199 0.34151 lineto
0.58332 0.34271 lineto
0.58464 0.34418 lineto
0.58728 0.34791 lineto
0.58993 0.3528 lineto
0.59258 0.35894 lineto
0.59787 0.37534 lineto
0.60316 0.39772 lineto
0.60845 0.42562 lineto
0.61374 0.45491 lineto
0.61506 0.46124 lineto
0.61639 0.46664 lineto
0.61771 0.47075 lineto
0.61903 0.47322 lineto
0.62035 0.47367 lineto
Mistroke
0.62168 0.47179 lineto
0.623 0.46734 lineto
0.62432 0.46018 lineto
0.62961 0.40713 lineto
0.63491 0.33324 lineto
0.6402 0.26272 lineto
0.64549 0.20553 lineto
0.65078 0.16176 lineto
0.65607 0.12861 lineto
0.66136 0.10331 lineto
0.66665 0.08373 lineto
0.67194 0.06834 lineto
0.67724 0.05607 lineto
0.68253 0.04616 lineto
0.68782 0.03805 lineto
0.69311 0.03135 lineto
0.70369 0.02105 lineto
0.71427 0.01365 lineto
0.72486 0.00821 lineto
0.73544 0.00411 lineto
0.74073 0.00245 lineto
0.74338 0.00169 lineto
0.74602 0.00098 lineto
0.74734 0.00065 lineto
0.74867 0.00032 lineto
0.74999 0 lineto
0.75131 0.0003 lineto
0.75264 0.0006 lineto
0.75396 0.00089 lineto
0.7566 0.00144 lineto
0.76719 0.00334 lineto
0.77777 0.00485 lineto
0.78835 0.00605 lineto
0.79893 0.00701 lineto
0.80952 0.00779 lineto
0.8201 0.00843 lineto
0.83068 0.00894 lineto
0.85185 0.00971 lineto
0.86243 0.01 lineto
0.87301 0.01023 lineto
0.88359 0.01042 lineto
0.89418 0.01058 lineto
0.91534 0.01082 lineto
0.92592 0.0109 lineto
0.93651 0.01097 lineto
0.94709 0.01103 lineto
0.95767 0.01107 lineto
0.96296 0.01108 lineto
0.96825 0.0111 lineto
0.97354 0.01111 lineto
Mistroke
0.97884 0.01112 lineto
0.98413 0.01113 lineto
0.98677 0.01113 lineto
0.98942 0.01113 lineto
0.99206 0.01114 lineto
0.99339 0.01114 lineto
0.99471 0.01114 lineto
0.99603 0.01114 lineto
0.99735 0.01114 lineto
1 0.01114 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = section; inactive; startGroup; Cclosed; ]
References
:[font = subsection; inactive; ]
Alan V. Oppenheim and Ronald W. Schafer.  Discrete-Time Signal Processing.  1989.  Chapters 4 & 5.
:[font = subsection; inactive; ]
T.W. Parks and C.S. Burrus. Digital Filter Design.
:[font = subsection; inactive; endGroup; ]
Churchill and Brown.  Complex Variables and Applications.
:[font = smalltext; inactive; ]
This work was supported in part by the Joint Services Electronics Program
contract #DAAL-03-90-C-0004.  
^*)